//
//  ViewController.m
//  E8sx
//
//  Created by Alejandro Reimondo on 21/7/16.
//  Copyright © 2016 Alejandro Reimondo. All rights reserved.
//

#import "ViewController.h"
#include <JavaScriptCore/JavaScriptCore.h>

void JSValuePrint(JSContextRef ctx, JSValueRef value, JSValueRef *exception)
{
    JSStringRef string = JSValueToStringCopy(ctx, value, exception);
    size_t length = JSStringGetLength(string);
    
    char *buffer = malloc(length+1);
    JSStringGetUTF8CString(string, buffer, length+1);
    JSStringRelease(string);
    
    puts(buffer);
    free(buffer);
}

int evalJSFile(JSGlobalContextRef ctx, NSString *aFileName, JSValueRef *returnValue)
{
    NSString *path = [NSString stringWithFormat:@"%@/Contents/Resources/%@"
                      ,[[NSBundle mainBundle] bundlePath]
                      ,aFileName];
    
    NSError*	error;
    id script = [NSString stringWithContentsOfFile:path encoding:NSUTF8StringEncoding error:&error];
    if (script == nil)
    {
        NSLog(@"File not found %@", path);
        return	0;
    }

    
    JSStringRef scriptJS	= JSStringCreateWithCFString((__bridge CFStringRef)script);
    JSStringRef scriptPath	= JSStringCreateWithUTF8CString([path UTF8String]);
    
    JSValueRef	exception = NULL;
    JSValueRef result = JSEvaluateScript(ctx, scriptJS, NULL, scriptPath, 1, &exception);
    if (returnValue)	*returnValue = result;
    JSStringRelease(scriptPath);
    JSStringRelease(scriptJS);
    if (exception)
    {
        JSValuePrint(ctx, exception, NULL);
        //NSLog(@"JSException - %@", exception);
        return	0;
    }
    JSGarbageCollect(ctx);
    return	1;
}

@implementation ViewController

- (void)loadAll {
    JSGlobalContextRef	ctx;
    ctx = JSGlobalContextCreate(NULL);
    evalJSFile(ctx, @"prologue.js", NULL);
    evalJSFile(ctx, @"default.snapshot.js", NULL);
    evalJSFile(ctx, @"default.app.js", NULL);
}

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    [self performSelector:@selector(loadAll) withObject:nil afterDelay:0.5];
}

- (void)setRepresentedObject:(id)representedObject {
    [super setRepresentedObject:representedObject];

    // Update the view, if already loaded.
}

@end
