/*
S8 - A modern Smalltalk environment running on the "invisible machine".

Copyright (C) 2016 Alejandro F. Reimondo <aleReimondo@smalltalking.net>

Parts of source code written for Jtalk (Sept 2011),
Copyright (C) 2011 by Nicolas Petton <petton.nicolas@gmail.com>
Copyright (C) 2011 Jtalk contributors
	David Graham <dgraham@iphouse.com>
	Goran Krampe <goran@krampe.se>
Also code and ideas from Clamato (http://clamato.net), written by Avi Byrant.
The PetitParser library, published by Lukas Renggli (http://lukas-renggli.ch) and released under the MIT license.
And people that contributed to Smalltalk on diverse media years(decades) before this license holders claimed ownership.

Permission is hereby granted, free of charge, to any person obtaining
 a copy of this software and associated documentation files (the "Software"),
 to deal in the Software without restriction, including without limitation
 the rights to use, copy, modify, merge, publish, distribute, sublicense,
 and/or sell copies of the Software, and to permit persons to whom the
 Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included
 in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
 TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
----------------------------------------------------------------------

The text you are reading here is the residue of something that has run before.
Keep the system running with responsibility. Smalltalk is not the words,
 nor any definition, nor it current contents...
Smalltalk include your feelings when you see it running.
Smalltalk is what happens when time flows and you "are" here.
Stop reading/writing code (thinking you are outside the system),
 change your world with resposibility, one object at a time, with your hands,
 during all your life, in family.
*/


var StObject = function StObject(){};
var StBehavior = function StBehavior(){};
var StClass = function StClass(){};
var StMetaclass = function StMetaclass(){ this.$meta = true; };
var StMethod = function StMethod(){};
var StUndefinedObject = function StUndefinedObject(){};
var nil = new StUndefinedObject();
nil.toString = function () { return 'nil'; }
nil.isNil_ = function (x) {
	switch(typeof x) {
		case "undefined":
			return true;
		case "string": case "boolean":
		case "number": case "function":
			return false;
	};
	if ((x===null) || (x === this)) return true;
	if (x===smalltalk) return false;
	if ((x.$klass) && ("function" === typeof x.isNil)) return x.isNil();
	return false;
}
var StSystemDictionary = function StSystemDictionary(){
	var st = this;
	st.$imageFileName = "s8.image.js";
	st.isNil = function(x) { return (x || nil) === nil; }
	st.useManager = false;

	st.klass = function(spec) { // Private
		var aClass;
		if(spec.meta) {
			aClass = new StMetaclass();
		} else {
			var metaSpec = {meta:true};
			metaSpec.className = spec.className + " class";
			if (!st.isNil(spec.superclass)) {
				metaSpec.superclass = spec.superclass.$klass;
			}
			var metaClass = st.klass(metaSpec);
			aClass = new metaClass.$fn();
		}
		st.setClass(aClass,spec);
		aClass.$fn.prototype.$klass = aClass;
		aClass.$fn.prototype.$methods = {};
		if (aClass.$className == "Metaclass") { st.bindRoots(aClass); }
		return aClass;
	}
	st.setProtoOf_to_ = function(jsObject, proto) {
		jsObject.__proto__ = proto;
	}
	st.bindRoots = function(metaclass){ // Private
		var objectClassPrototype = st.Object.$klass.$fn.prototype;
		st.setProtoOf_to_(objectClassPrototype,st.Class.$fn.prototype);
		st.setProtoOf_to_(st.Smalltalk.$klass.$fn.prototype,objectClassPrototype);
		st.setProtoOf_to_(st.Behavior.$klass.$fn.prototype,objectClassPrototype);
		st.Object.$klass.$superclass = st.Class;
		metaclass.$superclass = st.Behavior;
	}
	st.setVarNames = function(aClass, iVarNames, aValue) { // Private
		aClass.$iVarNames = iVarNames;
		var i=iVarNames.length;while(i--){
			aClass.$fn.prototype["@"+iVarNames[i]] = aValue;
		}
	}
	st.setClass = function(aClass, spec) { // Private
		aClass.$className = spec.className;
		if(!spec.meta) { aClass.$klass["@instanceClass"] = aClass; }
		aClass.$category = spec.category || "";
		aClass.$superclass = spec.superclass || nil;
		if(!st.isNil(aClass.$superclass)) {
			delete aClass.$superclass["@subclasses"];
			if(!st.isNil(aClass.$klass)) {
				if(!spec.meta) aClass.$klass.$superclass = aClass.$superclass.$klass;
				if(aClass.$klass.$superclass)
					delete aClass.$klass.$superclass["@subclasses"];
			}
		}
		aClass.$fn = st.fnInSpec(spec);
		st.setVarNames(aClass,spec.iVarNames||[],nil);
		return aClass;
	}
	st.fnInSpec = function(spec) { // Private
		if (spec.meta && (st.isNil(spec.superclass))) {
			spec.superclass = st.Class;
		}
		if (spec.fn) {
			if (!st.isNil(spec.superclass))
				st.setProtoOf_to_(spec.fn.prototype,spec.superclass.$fn.prototype);
			return spec.fn;
		}
		var $s8Constructor = function(){};
		if (!st.isNil(spec.superclass))
			$s8Constructor.prototype = new spec.superclass.$fn();
		return $s8Constructor;
	}
	st.classes = function() {
		var classes = [];
		for (var i in st){ if (st.hasOwnProperty(i) && (i != "$klass")) {
		    var cls = st[i]; if(!st.isNil(cls)){
			if(cls.$klass && cls.$className){ classes.push(cls); }
		    } }
		}
		return classes;
	}
	st.subclasses = function(aClass) {
		if(aClass.hasOwnProperty("@subclasses")) return aClass["@subclasses"];
		var result = [];
		var classes = st.classes();
		var i=classes.length;while(i--){
		    if(classes[i].$fn) {
			if(classes[i].$klass
				&& classes[i].$klass.$superclass === aClass)
				{ result.push(classes[i].$klass); }
			if(classes[i].$superclass === aClass)
				{ result.push(classes[i]); }
		    }
		}
		if(st.Class){ // Class linked to Object.$klass
			if(aClass === st.Class) { var k;
				for(var i in result) {
					if(result[i] === st.Object.$klass) { k = i; }
				}
				if(k) result.splice(k,1);
			}
		}
		aClass["@subclasses"] = result;
		return result;
	}
	st.allSubclassesDo = function(aClass,aBlock) {
		var subclasses = st.subclasses(aClass);
		var i=subclasses.length;while(i--){
			var cls = subclasses[i];
			aBlock(cls);
			st.allSubclassesDo(cls,aBlock);
		}
		return st;
	}
	st.mapClassName = function(className, category, fn, superclass) {
		var spec = {
			className: className, 
			category: category, 
			superclass: superclass,
			fn: fn };
		if (st[className]) return st.setClass(st[className],spec);
		st[className] = st.klass(spec);
		return st[className];
	}
	st.addClass = function(className, superclass, iVarNames, category) {
		st.debugAddClass(className, superclass, iVarNames, category);
		if(st[className]) {
			var aClass = st[className];
			var sameShape = (aClass.$superclass == superclass)
				&& (aClass.$iVarNames == iVarNames);
			if (sameShape && (aClass.$category == category) ) return aClass;
			st.aboutToChangeClass(aClass,superclass,iVarNames,category);
			if(aClass.$superclass) {
				delete aClass.$superclass["@subclasses"];
				var aMeta = aClass.$klass;
				if (aMeta && superclass) {
					delete  aMeta.$superclass["@subclasses"];
					aMeta.$superclass = superclass.$klass;
				}
			}
			aClass.$superclass = superclass;
			if(superclass && (superclass["@subclasses"])) {
				if(st.isNil(superclass["@subclasses"])) { superclass["@subclasses"] = []; }
				superclass["@subclasses"].push(aClass); 
			}
			st.setVarNames(aClass,iVarNames||[],nil);
			aClass.$category = category || aClass.$category;
			if (!sameShape) st.classShapeChanged(aClass);
		} else {
			st.aboutToCreateClass(className,superclass,iVarNames,category);
			st[className] = st.klass({
				className: className, 
				iVarNames: iVarNames,
				superclass: superclass
			});
			st[className].$category = category || "";
		}
		st.classChanged(st[className]);
		return st[className];
	}
	st.renameClass = function(aClass,aString) {
		delete st[aClass.$className];
		aClass.$className = aString;
		st[aString] = aClass;
		st.classChanged(aClass);
	}
	st.removeClass = function(aClass) {
		var deleted = "Deleted-";
		if(aClass.$superclass) { delete aClass.$superclass["@subclasses"]; }
		delete st[aClass.$className];
		aClass.$className = deleted + aClass.$className;
		aClass.$klass.$className = deleted + aClass.$klass.$className;
		st.classChanged(aClass);
	}
	st.metaVarNames = function(aMetaClass,iVarNames) {
		if (aMetaClass.$iVarNames == iVarNames) return false;
		st.setVarNames(aMetaClass,iVarNames||[],nil);
		st.classShapeChanged(aMetaClass);
		st.classChanged(aMetaClass);
		return true;
	}

	st.smDo = function(block) {
		if (!st.useManager) return nil;
		if (!st.SystemManager) return nil;
		if (!st.SystemManager.currentOrNil) return nil;
		var sm = st.SystemManager.currentOrNil();
		if (!st.isNil(sm)) return block(sm);
	}
	st.classChanged = function(aBehavior) {
		st.smDo(function(sm){sm.classChanged_(aBehavior)});
	}
	st.classShapeChanged = function(aBehavior) {
		st.smDo(function(sm){sm.classShapeChanged_(aBehavior)});
	}
	st.aboutToCreateClass = function(className,superclass,iVarNames,category) {
		st.smDo(function(sm){
			sm.aboutToCreateClass_superclass_iVarNames_category_(className,superclass,iVarNames,category)
		});
	}
	st.aboutToChangeClass = function(aClass,superclass,iVarNames,category) {
		st.smDo(function(sm){
			sm.aboutToChange_superclass_iVarNames_category_(aClass,superclass,iVarNames,category)
		});
	}
	st.methodBoundTo = function(method,klass) {
		st.smDo(function(sm){sm.methodBound_to_(method,klass)})
		return method;
	}
	st.aboutToBindTo = function(method,klass) {
		st.smDo(function(sm){sm.aboutToBind_to_(method,klass)})
		return method;
	}
	st.aboutToRemoveFrom = function(method,klass) {
		st.smDo(function(sm){sm.aboutToRemove_from_(method,klass)})
		return method;
	}
	st.methodRemovedFrom = function(method,klass) {
		st.smDo(function(sm){sm.methodRemoved_from_(method,klass)})
		return method;
	}
	st.objectNotFound = function(object,indexOrKey,collection) {
		st.smDo(function(sm){sm.object_at_notFoundIn_(object,indexOrKey,collection)})
		return collection;
	}
	st.whoImplements = function(klass,jsSelector) {
		var cls = klass;
		do {	if(cls.$fn.prototype.hasOwnProperty(jsSelector)) return cls;
			cls = cls.$superclass;
		} while (cls);
		return nil;
	}
	st.superImplementor = function(klass,jsSelector) {
		if (st.isNil(klass.$superclass)
			|| st.isNil(klass.$superclass.$fn))
			return klass.missingImplementorFor_(jsSelector);
		var cls = st.whoImplements(klass.$superclass,jsSelector);
		if (st.isNil(cls))
			return klass.$superclass.missingImplementorFor_(jsSelector);
		return cls.$fn.prototype[jsSelector];
	}
	st.addMethod = function(jsSelector, method, klass) {
		st.aboutToBindTo(method,klass);
		klass.$fn.prototype[jsSelector] = method.$fn;
		klass.$fn.prototype.$methods[method.$selector] = method;
		method["@classField"] = klass;
		return st.methodBoundTo(method,klass);
	}

	st.bind = function(klass,stSelector,jsSelector,jsFunction,category,stSource) {
		st.debugBind(klass,stSelector,jsSelector,jsFunction,category,stSource);
		var method = new StMethod();
		method.$selector = stSelector;
		method.$fn	 = jsFunction;
		method.$category = category;
		method.$source   = stSource;
		method.$generation = st.$state;
		if(!st.isNil(klass)) {
			if(st.isNil(jsSelector)) { jsSelector = stSelector.replace(/\:/g,"_"); }
			st.addMethod(jsSelector,method,klass);
		}
		return method;
	}

	st.removeMethod = function(aClass,aMethod) {
		st.aboutToRemoveFrom(aMethod,aClass);
		delete aClass.$fn.prototype[aMethod.$selector.asSelector()];
		delete aClass.$fn.prototype.$methods[aMethod.$selector]
		return st.methodRemovedFrom(aMethod,aClass);
	}

	st.newMethod = function(currentClass,selector,fn,source) {
		return st.bind(nil,selector,nil,fn,nil,source);
	}
	st.method = function(spec) { // OBSOLETE
		return st.bind(nil,spec.selector,nil,spec.fn,spec.category,spec.source);
	}

	st.readJSObject = function(js) {
		if(!js) return nil;
		var object = js;
		var readObject = (js.constructor === Object);
		var readArray = (js.constructor === Array);
		if(readObject) { object = st.Dictionary.$$new(); }
		for(var i in js) {
			if (!js.hasOwnProperty(i)) break;
			if(readObject) { object.at_put_(i, st.readJSObject(js[i])); } 
			if(readArray) { object[i] = st.readJSObject(js[i]); }
		}
		return object;
	}

	st.globalsDo = function(action) {
		for (key in st) {
			if (!st.hasOwnProperty(key)) break;
			var aValue = st[key];
			if((typeof(aValue) != "function")
			 && (aValue.isClass
			 && (!aValue.isClass()))) { action(key) } }
		return st;
	}

	st.launchImage = function(imageName) {
		st.useManager = true;
		if(!st.isNil(imageName)) {
			st.$imageFileName = imageName;
			load(imageName);
		}
		st.$state = "launching";
		if(st.launch && typeof st.launch == "function") { st.launch(); }
		st.$state = "running";
		return st;
	}

	st.is_kindOf_ = function(anObject,aClass) {
		if(st.isNil(anObject) || ("undefined" === typeof anObject.isKindOf_)) return false;
		return anObject.isKindOf_(aClass);
	}
	st.responds_to_ = function(anObject,aSelector) {
		if(st.isNil(anObject) || ("undefined" === typeof anObject.respondsTo_)) return false;
		return anObject.respondsTo_(aSelector);
	}

	st.debugBind = function(klass,stSelector,jsSelector,jsFunction,category,stSource) { return st; }
	st.debugAddClass = function(className, superclass, iVarNames, category) { return st; }

	st.initClass = function(aClass) { return "DEPRECATED"; }
	st.initWithSubclasses = function(aClass) { return aClass; }
	st.init = function(aClass) { return "DEPRECATED"; }
	st.initRoots = function(){ return "DEPRECATED"; }
};
var smalltalk = new StSystemDictionary();
smalltalk.toString = function() { return "smalltalk"; }
smalltalk.$state = "booting";
smalltalk.OverwriteMethods = smalltalk.OverwriteMethods || nil;
smalltalk.DumpOverwritenMethods = smalltalk.DumpOverwritenMethods || nil;
smalltalk.mapClassName('Object','Kernel',StObject);
smalltalk.mapClassName('Smalltalk','Kernel',StSystemDictionary,smalltalk.Object);
smalltalk.mapClassName('Behavior','Kernel',StBehavior,smalltalk.Object);
smalltalk.mapClassName('Class','Kernel',StClass,smalltalk.Behavior);
smalltalk.mapClassName('Metaclass','Kernel',StMetaclass,smalltalk.Behavior);
smalltalk.mapClassName('CompiledMethod','Kernel',StMethod,smalltalk.Object);
smalltalk.mapClassName('Number','Kernel',Number,smalltalk.Object);
smalltalk.mapClassName('BlockClosure','Kernel',Function,smalltalk.Object);
smalltalk.mapClassName('Boolean','Kernel',Boolean,smalltalk.Object);
smalltalk.mapClassName('DateTime','Kernel',Date,smalltalk.Object);
smalltalk.mapClassName('UndefinedObject','Kernel',StUndefinedObject,smalltalk.Object);
smalltalk.mapClassName('Collection','Kernel',undefined,smalltalk.Object);
smalltalk.mapClassName('SequenceableCollection','Kernel',undefined,smalltalk.Collection);
smalltalk.mapClassName('String','Kernel',String,smalltalk.SequenceableCollection);
smalltalk.mapClassName('Array','Kernel',Array,smalltalk.SequenceableCollection);
smalltalk.mapClassName('RegularExpression','Kernel',RegExp,smalltalk.Object);
smalltalk.$state = "initialize";
smalltalk.st = function (code) { return code.evaluate(); };
smalltalk.doIt = function (code) { return code.doIt() };
var fileIn = function (fileName) { return read(fileName).fileIn(); };
var fileInJS = function (fileName) { return eval(read(fileName)); };
var doit = function (what) { if (what) { return smalltalk.st(what); } else { return vse("workspace"); } };
var exportCategory = function (aString) { return smalltalk.Exporter.exportCategory_(aString); };
var saveImage = function () { return smalltalk.saveImage(); };
var saveImageAs = function (fileName) { return smalltalk.saveImageAs_(fileName); };
smalltalk.$imageFileName = smalltalk.$imageFileName  || "s8.image.js";
smalltalk.$state = "startup";if(StObject && !smalltalk.Object) smalltalk.mapClassName("Object","Kernel",StObject,undefined);
smalltalk.addClass("Object",undefined, [], 'Kernel');
if(StSystemDictionary && !smalltalk.Smalltalk) smalltalk.mapClassName("Smalltalk","Kernel",StSystemDictionary,smalltalk.Object);
smalltalk.addClass("Smalltalk",smalltalk.Object, [], 'Kernel');
if(StBehavior && !smalltalk.Behavior) smalltalk.mapClassName("Behavior","Kernel",StBehavior,smalltalk.Object);
smalltalk.addClass("Behavior",smalltalk.Object, [], 'Kernel');
if(StClass && !smalltalk.Class) smalltalk.mapClassName("Class","Kernel",StClass,smalltalk.Behavior);
smalltalk.addClass("Class",smalltalk.Behavior, [], 'Kernel');
if(StMetaclass && !smalltalk.Metaclass) smalltalk.mapClassName("Metaclass","Kernel",StMetaclass,smalltalk.Behavior);
smalltalk.addClass("Metaclass",smalltalk.Behavior, ['instanceClass'], 'Kernel');
if(StMethod && !smalltalk.CompiledMethod) smalltalk.mapClassName("CompiledMethod","Kernel",StMethod,smalltalk.Object);
smalltalk.addClass("CompiledMethod",smalltalk.Object, ['classField'], 'Kernel');
if(Number && !smalltalk.Number) smalltalk.mapClassName("Number","Kernel",Number,smalltalk.Object);
smalltalk.addClass("Number",smalltalk.Object, [], 'Kernel');
if(Function && !smalltalk.BlockClosure) smalltalk.mapClassName("BlockClosure","Kernel",Function,smalltalk.Object);
smalltalk.addClass("BlockClosure",smalltalk.Object, [], 'Kernel');
if(Boolean && !smalltalk.Boolean) smalltalk.mapClassName("Boolean","Kernel",Boolean,smalltalk.Object);
smalltalk.addClass("Boolean",smalltalk.Object, [], 'Kernel');
if(Date && !smalltalk.DateTime) smalltalk.mapClassName("DateTime","Kernel",Date,smalltalk.Object);
smalltalk.addClass("DateTime",smalltalk.Object, [], 'Kernel');
if(StUndefinedObject && !smalltalk.UndefinedObject) smalltalk.mapClassName("UndefinedObject","Kernel",StUndefinedObject,smalltalk.Object);
smalltalk.addClass("UndefinedObject",smalltalk.Object, [], 'Kernel');
smalltalk.addClass("Collection",smalltalk.Object, [], 'Kernel');
smalltalk.addClass("SequenceableCollection",smalltalk.Collection, [], 'Kernel');
if(String && !smalltalk.String) smalltalk.mapClassName("String","Kernel",String,smalltalk.SequenceableCollection);
smalltalk.addClass("String",smalltalk.SequenceableCollection, [], 'Kernel');
if(Array && !smalltalk.Array) smalltalk.mapClassName("Array","Kernel",Array,smalltalk.SequenceableCollection);
smalltalk.addClass("Array",smalltalk.SequenceableCollection, [], 'Kernel');
smalltalk.addClass("ArrayedContents",smalltalk.SequenceableCollection, ['contents'], 'Kernel');
smalltalk.addClass("ComposedAssociations",smalltalk.ArrayedContents, [], 'Kernel');
smalltalk.addClass("Set",smalltalk.Collection, ['contents'], 'Kernel');
smalltalk.addClass("HashedSet",smalltalk.Set, ['hash'], 'Kernel');
smalltalk.addClass("KeyedCollection",smalltalk.Collection, [], 'Kernel');
smalltalk.addClass("Dictionary",smalltalk.KeyedCollection, ['keys', 'values'], 'Kernel');
smalltalk.addClass("PoolDictionary",smalltalk.KeyedCollection, ['hash', 'size'], 'Kernel');
if(RegExp && !smalltalk.RegularExpression) smalltalk.mapClassName("RegularExpression","Kernel",RegExp,smalltalk.Object);
smalltalk.addClass("RegularExpression",smalltalk.Object, [], 'Kernel');
smalltalk.addClass("Exception",smalltalk.Object, ['messageText'], 'Kernel');
smalltalk.addClass("Error",smalltalk.Exception, [], 'Kernel');
smalltalk.addClass("MessageNotUnderstood",smalltalk.Error, ['message', 'receiver'], 'Kernel');
smalltalk.addClass("Association",smalltalk.Object, ['key', 'value'], 'Kernel');
smalltalk.addClass("ClassBuilder",smalltalk.Object, [], 'Kernel');
smalltalk.addClass("Stream",smalltalk.Object, ['collection', 'position', 'readLimit'], 'Kernel');
smalltalk.addClass("StringStream",smalltalk.Stream, [], 'Kernel');
smalltalk.addClass("Random",smalltalk.Object, [], 'Kernel');
smalltalk.addClass("Point",smalltalk.Object, ['x', 'y'], 'Kernel');
smalltalk.addClass("Rectangle",smalltalk.Object, ['leftTop', 'rightBottom'], 'Kernel');
smalltalk.addClass("EvaluableAction",smalltalk.Object, [], 'Kernel');
smalltalk.EvaluableAction.$comment=unescape("%0D%0A%09Action%20model%2C%20evaluable%20and%20composable%20actions%20are%20implemented%20to%20support%20evaluations.%0D%0A");
smalltalk.addClass("Message",smalltalk.EvaluableAction, ['selector', 'arguments', 'receiver'], 'Kernel');
smalltalk.addClass("LinkMessage",smalltalk.Message, ['resultAction'], 'Kernel');
smalltalk.LinkMessage.$comment=unescape("%0D%0A%09Implement%20evaluation%20cascading%20argument%20evaluations.");
smalltalk.addClass("ActionSequence",smalltalk.Object, ['contents'], 'Kernel');
smalltalk.addClass("EventManager",smalltalk.Object, ['handlers'], 'Kernel');
smalltalk.EventManager.$comment=unescape("%0D%0A%09Event%20system%2C%20properties%20and%20change/update/release%20mechanism.%0D%0A%09We%20hook%20%24properties%20and%20%24handlers%20internal%20properties%20to%20manage%20properties%20and%20events%20at%20Object%20level.%0D%0A%09EventManager%20instances%20implement%20events%20handler%20as%20pure%20instance%20variable.%0D%0A");
smalltalk.EventManager.$klass.$iVarNames = ['eventsTriggered'];
smalltalk.addClass("CompilerNodeVisitor",smalltalk.EventManager, [], 'Compiler');
smalltalk.addClass("Compiler",smalltalk.CompilerNodeVisitor, ['stream', 'startOffset', 'nestedBlocks', 'earlyReturn', 'currentClass', 'functionName', 'unknownVariables', 'tempVariables', 'transformers', 'optimizationMap'], 'Compiler');
smalltalk.addClass("SmalltalkParser",smalltalk.EventManager, [], 'Compiler-Parser');
smalltalk.addClass("MethodReferences",smalltalk.EventManager, ['rootClasses', 'results'], 'Tools-References');
smalltalk.addClass("SystemManager",smalltalk.EventManager, [], 'Snapshot');
smalltalk.SystemManager.$classVariableNames="Current";
smalltalk.addClass("CompilerNode",smalltalk.Object, ['nodes', 'start', 'end'], 'Compiler');
smalltalk.addClass("MethodNode",smalltalk.CompilerNode, ['selector', 'arguments', 'source'], 'Compiler');
smalltalk.addClass("SendNode",smalltalk.CompilerNode, ['selector', 'arguments', 'receiver'], 'Compiler');
smalltalk.addClass("CascadeNode",smalltalk.CompilerNode, ['receiver'], 'Compiler');
smalltalk.addClass("AssignmentNode",smalltalk.CompilerNode, ['left', 'right'], 'Compiler');
smalltalk.addClass("BlockNode",smalltalk.CompilerNode, ['parameters'], 'Compiler');
smalltalk.addClass("SequenceNode",smalltalk.CompilerNode, ['temps'], 'Compiler');
smalltalk.addClass("BlockSequenceNode",smalltalk.SequenceNode, [], 'Compiler');
smalltalk.addClass("ExtendedSequenceNode",smalltalk.SequenceNode, ['directive'], 'Compiler');
smalltalk.addClass("ReturnNode",smalltalk.CompilerNode, [], 'Compiler');
smalltalk.addClass("ValueNode",smalltalk.CompilerNode, ['value'], 'Compiler');
smalltalk.addClass("VariableNode",smalltalk.ValueNode, ['indices'], 'Compiler');
smalltalk.addClass("GlobalReferenceNode",smalltalk.VariableNode, [], 'Compiler');
smalltalk.addClass("NoReceiverNode",smalltalk.VariableNode, [], 'Compiler');
smalltalk.addClass("AlienNode",smalltalk.VariableNode, [], 'Compiler');
smalltalk.addClass("InlineNode",smalltalk.CompilerNode, ['source'], 'Compiler');
smalltalk.addClass("DirectiveNode",smalltalk.CompilerNode, [], 'Compiler');
smalltalk.addClass("JSDirectiveNode",smalltalk.DirectiveNode, ['code', 'protected'], 'Compiler');
smalltalk.addClass("PPFailure",smalltalk.Object, ['position', 'reason'], 'Compiler-Parser');
smalltalk.addClass("PPParser",smalltalk.Object, ['memo'], 'Compiler-Parser');
smalltalk.addClass("PPEOFParser",smalltalk.PPParser, [], 'Compiler-Parser');
smalltalk.addClass("PPAnyParser",smalltalk.PPParser, [], 'Compiler-Parser');
smalltalk.addClass("PPEpsilonParser",smalltalk.PPParser, [], 'Compiler-Parser');
smalltalk.addClass("PPStringParser",smalltalk.PPParser, ['string'], 'Compiler-Parser');
smalltalk.addClass("PPStStringParser",smalltalk.PPParser, [], 'Compiler-Parser');
smalltalk.addClass("PPCharacterParser",smalltalk.PPParser, ['regexp'], 'Compiler-Parser');
smalltalk.addClass("PPListParser",smalltalk.PPParser, ['parsers'], 'Compiler-Parser');
smalltalk.addClass("PPSequenceParser",smalltalk.PPListParser, [], 'Compiler-Parser');
smalltalk.addClass("PPChoiceParser",smalltalk.PPListParser, [], 'Compiler-Parser');
smalltalk.addClass("PPDelegateParser",smalltalk.PPParser, ['parser'], 'Compiler-Parser');
smalltalk.addClass("PPAndParser",smalltalk.PPDelegateParser, [], 'Compiler-Parser');
smalltalk.addClass("PPNotParser",smalltalk.PPAndParser, [], 'Compiler-Parser');
smalltalk.addClass("PPActionParser",smalltalk.PPDelegateParser, ['block'], 'Compiler-Parser');
smalltalk.addClass("PPFlattenParser",smalltalk.PPDelegateParser, [], 'Compiler-Parser');
smalltalk.addClass("PPSourceParser",smalltalk.PPDelegateParser, [], 'Compiler-Parser');
smalltalk.addClass("PPRepeatingParser",smalltalk.PPDelegateParser, ['min'], 'Compiler-Parser');
smalltalk.addClass("PPInlineParser",smalltalk.PPParser, ['terminator'], 'Compiler-Parser');
smalltalk.addClass("FileInReader",smalltalk.Object, [], 'Tools-FileIn');
smalltalk.FileInReader.$comment=unescape("%0D%0A%09Perform%20sequential%20reading%20from%20aStream%20in%20chunk%20format.%0D%0A%09Instances%20implement%20%23scanFrom%3A%20message%2C%20advancing%20aStream%20upto%20next%20reader%20instantiation%20chunk.");
smalltalk.addClass("ChunkReader",smalltalk.FileInReader, ['actionBlock', 'terminationBlock'], 'Tools-FileIn');
smalltalk.ChunkReader.$comment=unescape("%0D%0A%09Pluggable%20FileInReader.%0D%0A%09actionBlock%20is%20evaluated%20with%20input%20stream%20as%20argument.%0D%0A%09Read%20chunks%20until%20empty%20chunk%2C%20terminationBlock%20is%20nil%20or%20evaluates%20to%20true.");
smalltalk.addClass("ClassCategoryReader",smalltalk.FileInReader, ['class', 'category'], 'Tools-FileIn');
smalltalk.addClass("ClassCommentReader",smalltalk.FileInReader, ['class'], 'Tools-FileIn');
smalltalk.addClass("SkipFileInReader",smalltalk.FileInReader, ['limit'], 'Tools-FileIn');
smalltalk.addClass("AssociationsReader",smalltalk.FileInReader, [], 'Tools-FileIn');
smalltalk.addClass("PoolDictionaryReader",smalltalk.AssociationsReader, ['scope'], 'Tools-FileIn');
smalltalk.addClass("JSReader",smalltalk.AssociationsReader, ['object'], 'Tools-FileIn');
smalltalk.addClass("Exporter",smalltalk.Object, [], 'Tools-FileOut');
smalltalk.addClass("APIBuilder",smalltalk.Object, ['parents', 'token', 'bound'], 'Builders');
smalltalk.APIBuilder.$klass.$iVarNames = ['default'];
smalltalk.addClass("Snapshot",smalltalk.Object, [], 'Snapshot');
smalltalk.Snapshot.$comment=unescape("%0D%0A%09Dump%20a%20binary%20representation%20of%20this%20S8%20system%20onto%20an%20image%20%28String%29.%0D%0A%09The%20default%20implementation%20export%20full/runnable%20images%20containing%20boot%20sections.%0D%0A%09The%20subclasses%20can%20refine%20behavior%20to%20select/customize%20exports%20and%20format.%0D%0A%09@2011%20Alejandro%20Reimondo%20aleReimondo@smalltalking.net");
smalltalk.addClass("Transcript",smalltalk.Object, ['stream'], 'Transcript');
smalltalk.Transcript.$classVariableNames="Current";
smalltalk.addClass("NativeObject",smalltalk.Object, ['handle'], 'Natives');
smalltalk.NativeObject.$comment=unescape("%0D%0A%09Implementation%20of%20wrapper%20to%20native%20%28js%29%20objects.%0D%0A%09@2011%20Alejandro%20F.%20Reimondo%0D%0A%09aleReimondo@smalltalking.net%0D%0A");
smalltalk.addClass("JS",smalltalk.NativeObject, [], 'Natives');
smalltalk.JS.$comment=unescape("%0D%0A%09Implementation%20of%20reflection%20interface%20for%20%28js%29%20objects.%0D%0A%09@2011%20Alejandro%20F.%20Reimondo%0D%0A%09aleReimondo@smalltalking.net%0D%0A");
smalltalk.addClass("NativeLibraryObject",smalltalk.NativeObject, [], 'Natives');
smalltalk.NativeLibraryObject.$comment=unescape("%0D%0A%09Abstract%20wrapper%20to%20external%20Javascript%20library.%0D%0A%09@2012%20Alejandro%20Reimondo%20-%20aleReimondo@smalltalking.net%0D%0A");
smalltalk.NativeLibraryObject.$classVariableNames="BindingListeners";
smalltalk.addClass("CocoObject",smalltalk.NativeObject, [], 'coco8');
smalltalk.addClass("Coco8Implementation",smalltalk.CocoObject, [], 'coco8');
smalltalk.Coco8Implementation.$klass.$iVarNames = ['readOnly','installed'];
smalltalk.addClass("NSObject",smalltalk.Coco8Implementation, [], 'Foundation');
smalltalk.addClass("Coco8Closure",smalltalk.NSObject, ['block'], 'Foundation');
smalltalk.addClass("JSCocoaController",smalltalk.NSObject, [], 'JSCocoa');
smalltalk.JSCocoaController.$classVariableNames="Current";
smalltalk.addClass("S8BlockAdaptor",smalltalk.NSObject, [], 'JSCocoa');
smalltalk.addClass("NSBlock",smalltalk.NSObject, [], 'Foundation');
smalltalk.addClass("NSArray",smalltalk.NSObject, [], 'Foundation');
smalltalk.addClass("UIResponder",smalltalk.NSObject, [], 'UIKit');
smalltalk.addClass("UIView",smalltalk.UIResponder, [], 'UIKit');
smalltalk.addClass("UIWindow",smalltalk.UIView, [], 'UIKit');
smalltalk.addClass("UIViewController",smalltalk.UIResponder, [], 'UIKit');
smalltalk.addClass("UIScreen",smalltalk.NSObject, [], 'UIKit');
smalltalk.addClass("Mini8AppDelegate",smalltalk.NSObject, [], 'Mini8AppDelegate');
smalltalk.addClass("JSC",smalltalk.CocoObject, [], 'coco8');
smalltalk.addClass("JSCocoa",smalltalk.CocoObject, [], 'coco8');
smalltalk.JSCocoa.$klass.$iVarNames = ['current','encodings','decodings','outArgument2','cache'];
smalltalk.addClass("JSCocoaFFIArgument",smalltalk.CocoObject, [], 'coco8');
smalltalk.addClass("CGGeometryObject",smalltalk.NativeObject, [], 'CGGeometry');
smalltalk.addClass("CGRect",smalltalk.CGGeometryObject, [], 'CGGeometry');

smalltalk.bind(smalltalk.Object.$klass,"eventsTriggered",0
,function (){var self=this;return self.constructEventsTriggered();;return self;}
,"events",unescape("eventsTriggered%0D%0A%09%22%20Return%20all%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20constructEventsTriggered"));
smalltalk.bind(smalltalk.Object.$klass,"constructEventsTriggered",0
,function (){var self=this;return ["changed"];;return self;}
,"events",unescape("constructEventsTriggered%0D%0A%09%22%20Private%20-%20Return%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%0D%0A%09The%20default%20implementation%20return%20support%20for%20MVC%20change/update%20mechanism.%0D%0A%09This%20method%20can%20be%20refined%20by%20the%20subclasses%20to%20extend%20event%20support.%0D%0A%09%22%0D%0A%0D%0A%09%5E%23%28%20%23changed%20%29"));
smalltalk.bind(smalltalk.Object.$klass,"canTriggerEvent:",0
,function (anEvent){var self=this;return self.eventsTriggered().includes_(anEvent);;return self;}
,"events",unescape("canTriggerEvent%3A%20anEvent%0D%0A%09%22%20Return%20true%20if%20instances%20of%20the%20receiver%20can%20trigger%20anEvent.%22%0D%0A%0D%0A%09%5Eself%20eventsTriggered%20includes%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"print:",0
,function (aString){var self=this;print(aString);return self;}
,"printing",unescape("print%3A%20aString%0D%0A%09%22%20Output%20aString%20to%20output%20device.%20%22%0D%0A%0D%0A%09%23%20%23print%3A%20aString"));
smalltalk.bind(smalltalk.Object,"fileIn:",0
,function (fileName){var self=this;self.print_(unescape("//%20fileIn%28%22")._comma(fileName)._comma(unescape("%22%29%3B")));
return fileIn(fileName);;return self;}
,"fileIn",unescape("fileIn%3A%20fileName%0D%0A%09%22%20FileIn%20contents%20of%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09self%20print%3A%20%27//%20fileIn%28%22%27%2C%20fileName%2C%20%27%22%29%3B%27.%0D%0A%09%5E%23%20%23fileIn%3A%20fileName"));
smalltalk.bind(smalltalk.Object,"fileInJS:",0
,function (fileName){var self=this;self.print_(unescape("//%20fileInJS%28%22")._comma(fileName)._comma(unescape("%22%29%3B")));
return fileInJS(fileName);;return self;}
,"fileIn",unescape("fileInJS%3A%20fileName%0D%0A%09%22%20Load%20javascript%20code%20from%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09self%20print%3A%20%27//%20fileInJS%28%22%27%2C%20fileName%2C%20%27%22%29%3B%27.%0D%0A%09%5E%23%20%23fileInJS%3A%20fileName"));
smalltalk.bind(smalltalk.Object,"smalltalk",0
,function (){var self=this;return smalltalk;;return self;}
,"system",unescape("smalltalk%0D%0A%09%22%20Return%20the%20smalltalk%20system%20containing%20the%20receiver.%20%22%0D%0A%0D%0A%09%20%5E%23%7Bsmalltalk%7D"));
smalltalk.bind(smalltalk.Object,"halt",0
,function (){var self=this;debugger;return self;}
,"debug",unescape("halt%0D%0A%09%22%20Private%20-%20Halt%20execution%20entering%20debugger.%20%22%0D%0A%0D%0A%09%23%7Bdebugger%7D"));
smalltalk.bind(smalltalk.Object,"notImplementedYet",0
,function (){var self=this;self.error_("Not implemented. Yet".halt());return self;}
,"development",unescape("notImplementedYet%0D%0A%09%22%20Private%20-%20Halt%20execution%20and/or%20generate%20an%20error%20reporting%20implementation%20incomplete.%20%22%0D%0A%0D%0A%09self%20error%3A%20%27Not%20implemented.%20Yet%27%20halt"));
smalltalk.bind(smalltalk.Object,"accept:",0
,function (what){var self=this;self.print_(unescape("%5Bbug%5D%20")._comma(self.asString())._comma(" accept: ")._comma(what.asString()));
return self.error_(unescape("%23accept%3A%20out%20of%20control."));;return self;}
,"parserBug",unescape("accept%3A%20what%0D%0A%09%22%20Private%20-%20Report%20buggy%20send%20by%20compiler.%20%22%0D%0A%0D%0A%09self%20print%3A%20%27%5Bbug%5D%20%27%2Cself%20asString%2C%27%20accept%3A%20%27%2Cwhat%20asString.%0D%0A%09%5Eself%20error%3A%20%27%23accept%3A%20out%20of%20control.%27"));
smalltalk.bind(smalltalk.Object,"=","_eq"
,function (anObject){var self=this;  if (nil.isNil_(anObject)) return false;
    return (self === anObject);
;return self;}
,"comparing",unescape("%3D%20anObject%0D%0A%20%20%20%20%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%7B%27%20%20if%20%28nil.isNil_%28anObject%29%29%20return%20false%3B%0D%0A%20%20%20%20return%20%28self%20%3D%3D%3D%20anObject%29%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.Object,"~=","_no_eq"
,function (anObject){var self=this;return (self._eq(anObject) === false);;return self;}
,"comparing",unescape("%7E%3D%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%09%5E%28self%20%3D%20anObject%29%20%3D%3D%20false"));
smalltalk.bind(smalltalk.Object,"initialize",0
,function (){var self=this;return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%0D%0A%09The%20default%20implementation%20do%20nothing.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20support%20creation%20time%20initialization%20of%20collaborators.%0D%0A%09%22"));
smalltalk.bind(smalltalk.Object,"yourself",0
,function (){var self=this;return self;;return self;}
,"identity",unescape("yourself%0D%0A%09%22%20Return%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Object,"class","$$class"
,function (){var self=this;return ((function(){var $1$=self["$klass"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("class%0D%0A%09%22%20Return%20the%20class%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24klass%27"));
smalltalk.bind(smalltalk.Object,"size",0
,function (){var self=this;return (0);;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%0D%0A%09The%20default%20implementation%20return%20zero.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20support%20indexed%20access.%0D%0A%09%22%0D%0A%0D%0A%09%5E0"));
smalltalk.bind(smalltalk.Object,"copy",0
,function (){var self=this;return self.shallowCopy();;return self;}
,"copying",unescape("copy%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20shallowCopy"));
smalltalk.bind(smalltalk.Object,"shallowCopy",0
,function (){var self=this;var result=nil;result=self.$klass.basicNew();
self.$klass.allInstVarNamesDo_((function(instVarName){return (result[unescape("@")._comma(instVarName)]=(((function(){var $1$=self[unescape("@")._comma(instVarName)];if(nil.isNil_($1$))return nil;return $1$;})())));}));
return result;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20basicNew.%0D%0A%09self%20class%20allInstVarNamesDo%3A%20%5B%3AinstVarName%7C%0D%0A%09%09result%09basicAt%3A%20%24@%2CinstVarName%0D%0A%09%09%09put%3A%20%28self%20basicAt%3A%20%24@%2CinstVarName%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Object,"deepCopy",0
,function (){var self=this;var result=nil;result=self.$klass.basicNew();
self.$klass.allInstVarNamesDo_((function(instVarName){return (result[unescape("@")._comma(instVarName)]=(((function(){var $1$=self[unescape("@")._comma(instVarName)];if(nil.isNil_($1$))return nil;return $1$;})()).deepCopy()));}));
return result;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20basicNew.%0D%0A%09self%20class%20allInstVarNamesDo%3A%20%5B%3AinstVarName%7C%0D%0A%09%09result%09basicAt%3A%20%24@%2CinstVarName%0D%0A%09%09%09put%3A%20%28self%20basicAt%3A%20%24@%2CinstVarName%29%20deepCopy%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Object,"->","_minus_gt"
,function (anObject){var self=this;return smalltalk.Association.key_value_(self, anObject);;return self;}
,"converting",unescape("-%3E%20anObject%0D%0A%09%22%20Return%20an%20association%20of%20the%20receiver%20to%20anObject.%20%22%0D%0A%0D%0A%09%5EAssociation%20key%3A%20self%20value%3A%20anObject"));
smalltalk.bind(smalltalk.Object,"asString",0
,function (){var self=this;return self.printString();;return self;}
,"converting",unescape("asString%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20String.%20%22%0D%0A%0D%0A%09%5Eself%20printString"));
smalltalk.bind(smalltalk.Object,"toString",0
,function (){var self=this;return unescape("%7Bst%3Aa")._comma(self.$klass.name())._comma(unescape("%7D"));;return self;}
,"converting",unescape("toString%0D%0A%09%22%20Convert%20the%20receiver%20to%20a%20String.%20%22%0D%0A%0D%0A%09%5E%27%7Bst%3Aa%27%2Cself%20class%20name%2C%24%7D"));
smalltalk.bind(smalltalk.Object,"asJavascript",0
,function (){var self=this;return self.asString();;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%0D%0A%09The%20default%20implementation%20return%20the%20receiver%20as%20a%20String.%0D%0A%09This%20method%20must%20be%20refined%20by%20subclasses%20implementing%20literal%20representation%20in%20javascript.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20asString"));
smalltalk.bind(smalltalk.Object,"asJSON",0
,function (){var self=this;var json=nil;json=smalltalk.Smalltalk.jsObjectAt_("JSON");
return json.stringify(self.asJSONObject());;return self;}
,"converting",unescape("asJSON%0D%0A%09%22%20JSON%20-%20Return%20the%20JSON%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20json%20%7C%0D%0A%09json%20%3A%3D%20Smalltalk%20jsObjectAt%3A%20%23JSON.%0D%0A%09%5Ejson%20%23stringify%3A%20self%20asJSONObject"));
smalltalk.bind(smalltalk.Object,"escapedCode",0
,function (){var self=this;return self.asJavascript();;return self;}
,"converting",unescape("escapedCode%0D%0A%09%22%20Return%20the%20code%20to%20reproduce%20receiver%20from%20%28javascript%29%20code.%20%22%0D%0A%0D%0A%09%5Eself%20asJavascript"));
smalltalk.bind(smalltalk.Object,"perform:",0
,function (aSymbol){var self=this;return self.perform_withArguments_(aSymbol, []);;return self;}
,"perform",unescape("perform%3A%20aSymbol%0D%0A%09%22%20Return%20the%20result%20of%20sending%20message%20aSymbol%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20perform%3A%20aSymbol%20withArguments%3A%20%23%28%29"));
smalltalk.bind(smalltalk.Object,"perform:with:",0
,function (aSymbol,argument){var self=this;return self.basicPerform_withArguments_(aSymbol.asSelector(), smalltalk.Array.with_(argument));;return self;}
,"perform",unescape("perform%3A%20aSymbol%20with%3A%20argument%0D%0A%09%22%20Return%20the%20result%20of%20sending%20message%20aSymbol%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicPerform%3A%20aSymbol%20asSelector%20withArguments%3A%20%28Array%20with%3A%20argument%29"));
smalltalk.bind(smalltalk.Object,"perform:withArguments:",0
,function (aSymbol,aCollection){var self=this;((aCollection.isArray()).mustBeBoolean()==true ? nil : (function(){return self.error_(unescape("//%20Invalid%20arguments%20in%20%23perform%3AwithArguments%3A%20%28%23")._comma(aSymbol)._comma(unescape("%29%20%28must%20be%20anArray%29.")));})());
return self.basicPerform_withArguments_(aSymbol.asSelector(), aCollection);;return self;}
,"perform",unescape("perform%3A%20aSymbol%20withArguments%3A%20aCollection%0D%0A%09%22%20Return%20the%20result%20of%20sending%20message%20aSymbol%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09aCollection%20isArray%20ifFalse%3A%20%5B%20self%20error%3A%20%27//%20Invalid%20arguments%20in%20%23perform%3AwithArguments%3A%20%28%23%27%2CaSymbol%2C%27%29%20%28must%20be%20anArray%29.%27%20%5D.%0D%0A%09%5Eself%20basicPerform%3A%20aSymbol%20asSelector%20withArguments%3A%20aCollection"));
smalltalk.bind(smalltalk.Object,"basicAt:",0
,function (aString){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=self[aString];
(((nil.isNil_(result))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("basicAt%3A%20aString%0D%0A%09%22%20Return%20the%20property%20of%20the%20receiver%20known%20as%20aString%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%5BaString%5D.%0D%0A%09result%20isNil%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Object,"basicAt:ifAbsent:",0
,function (aString,aBlock){var self=this;return (function(){var $1$ = self[aString];if (typeof ($1$) == "undefined") return (function(){return aBlock.value();})(); return $1$;})();;return self;}
,"accessing",unescape("basicAt%3A%20aString%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20property%20of%20the%20receiver%20known%20as%20aString%20%28or%20the%20result%20of%20evaluating%20aBlock%29.%20%22%0D%0A%0D%0A%09%5Eself%5BaString%5D%20ifUndefined%3A%20%5B%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.Object,"basicAt:ifAbsentPut:",0
,function (aString,aBlock){var self=this;return ((function(){var $1$=self[aString];if(nil.isNil_($1$))return ((function(){return (self[aString]=(aBlock.value()));}).value());return $1$;})());;return self;}
,"accessing",unescape("basicAt%3A%20aString%20ifAbsentPut%3A%20aBlock%0D%0A%09%22%20Return%20the%20property%20of%20the%20receiver%20known%20as%20aString%20%28or%20set%20it%20with%20the%20result%20of%20evaluating%20aBlock%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20aString%20ifAbsent%3A%20%5B%20self%20basicAt%3A%20aString%20put%3A%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.Object,"instVarAt:",0
,function (instVarName){var $s8Ret$={name:"stReturn"};try{var self=this;((instVarName.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.instVarAt_(self.$klass.allInstVarNames().at_(instVarName));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return ((function(){var $1$=self[unescape("@")._comma(instVarName)];if(nil.isNil_($1$))return nil;return $1$;})());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("instVarAt%3A%20instVarName%0D%0A%09%22%20Return%20the%20internal%20collaborator%20of%20the%20receiver%20known%20as%20instVarName.%20%22%0D%0A%0D%0A%09instVarName%20isNumber%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20instVarAt%3A%20%28self%20class%20allInstVarNames%20at%3A%20instVarName%29%0D%0A%09%5D.%0D%0A%09%5Eself%20basicAt%3A%20%27@%27%2C%20instVarName"));
smalltalk.bind(smalltalk.Object,"instVarAt:put:",0
,function (instVarName,anObject){var $s8Ret$={name:"stReturn"};try{var self=this;((instVarName.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.instVarAt_put_(self.$klass.allInstVarNames().at_(instVarName), anObject);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return (self[unescape("@")._comma(instVarName)]=(anObject));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("instVarAt%3A%20instVarName%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20internal%20collaborator%20of%20the%20receiver%20known%20as%20instVarName%20to%20anObject.%20%22%0D%0A%0D%0A%09instVarName%20isNumber%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20instVarAt%3A%20%28self%20class%20allInstVarNames%20at%3A%20instVarName%29%20put%3A%20anObject%0D%0A%09%5D.%0D%0A%09%5Eself%20basicAt%3A%20%27@%27%2C%20instVarName%20put%3A%20anObject"));
smalltalk.bind(smalltalk.Object,"basicAt:put:",0
,function (aString,anObject){var self=this;return self[aString]=anObject;;return self;}
,"accessing",unescape("basicAt%3A%20aString%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20property%20of%20the%20receiver%20known%20as%20aString.%20%22%0D%0A%0D%0A%09%5Eself%5BaString%5D%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.Object,"error:",0
,function (aString){var self=this;return smalltalk.Error.signal_(aString);;return self;}
,"error",unescape("error%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20managing%20error%28aString%29%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EError%20signal%3A%20aString"));
smalltalk.bind(smalltalk.Object,"subclassResponsibility",0
,function (){var self=this;return self.subclassResponsibility_(nil);;return self;}
,"error",unescape("subclassResponsibility%0D%0A%09%22%20Private%20-%20The%20concrete%20implementation%20on%20the%20receiver%20is%20not%20complete.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20nil"));
smalltalk.bind(smalltalk.Object,"implementedBySubclass",0
,function (){var self=this;return self.subclassResponsibility();;return self;}
,"error",unescape("implementedBySubclass%0D%0A%09%22%20Private%20-%20The%20concrete%20implementation%20on%20the%20receiver%20is%20not%20complete.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility"));
smalltalk.bind(smalltalk.Object,"shouldNotImplement",0
,function (){var self=this;return self.shouldNotImplement_(nil);;return self;}
,"error",unescape("shouldNotImplement%0D%0A%09%22%20The%20receiver%20received%20a%20message%20that%20is%20not%20expected.%20%22%0D%0A%0D%0A%09%5Eself%20shouldNotImplement%3A%20nil"));
smalltalk.bind(smalltalk.Object,"invalidMessage",0
,function (){var self=this;return self.invalidMessage_(nil);;return self;}
,"error",unescape("invalidMessage%0D%0A%09%22%20The%20receiver%20received%20a%20message%20that%20is%20invalid%20%28not%20expected%20for%20this%20object%29.%20%22%0D%0A%0D%0A%09%5Eself%20invalidMessage%3A%20nil"));
smalltalk.bind(smalltalk.Object,"subclassResponsibility:",0
,function (aSelector){var self=this;debugger;
return self.error_("Implementation of"._comma((((nil.isNil_(aSelector))).mustBeBoolean()==true ? (function(){return " ";})() : (function(){return unescape("%20%23")._comma(aSelector);})()))._comma(unescape("%20is%20a%20responsibility%20of%20the%20subclass%28"))._comma(self.$klass.name())._comma(unescape("%29.")));;return self;}
,"error",unescape("subclassResponsibility%3A%20aSelector%0D%0A%09%22%20Private%20-%20The%20concrete%20implementation%20on%20the%20receiver%20is%20not%20complete.%20%22%0D%0A%0D%0A%23%7Bdebugger%7D.%0D%0A%09%5Eself%20error%3A%0D%0A%09%09%20%27Implementation%20of%27%0D%0A%09%09%2C%28aSelector%20isNil%20ifTrue%3A%20%5B%27%20%27%5D%20ifFalse%3A%20%5B%27%20%23%27%2CaSelector%5D%29%0D%0A%09%09%2C%27%20is%20a%20responsibility%20of%20the%20subclass%28%27%2Cself%20class%20name%2C%27%29.%27"));
smalltalk.bind(smalltalk.Object,"implementedBySubclass:",0
,function (aSelector){var self=this;return self.subclassResponsibility_(aSelector);;return self;}
,"error",unescape("implementedBySubclass%3A%20aSelector%0D%0A%09%22%20Private%20-%20The%20concrete%20implementation%20on%20the%20receiver%20is%20not%20complete.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20aSelector"));
smalltalk.bind(smalltalk.Object,"shouldNotImplement:",0
,function (aSelector){var self=this;return self.error_("Message"._comma((((nil.isNil_(aSelector))).mustBeBoolean()==true ? (function(){return " ";})() : (function(){return unescape("%20%23")._comma(aSelector);})()))._comma(" should not be implemented for instances of ")._comma(self.$klass.name()));;return self;}
,"error",unescape("shouldNotImplement%3A%20aSelector%0D%0A%09%22%20The%20receiver%20received%20a%20message%20that%20is%20not%20expected.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%0D%0A%09%09%20%27Message%27%0D%0A%09%09%2C%28aSelector%20isNil%20ifTrue%3A%20%5B%27%20%27%5D%20ifFalse%3A%20%5B%27%20%23%27%2CaSelector%5D%29%0D%0A%09%09%2C%27%20should%20not%20be%20implemented%20for%20instances%20of%20%27%2C%20self%20class%20name"));
smalltalk.bind(smalltalk.Object,"invalidMessage:",0
,function (aSelector){var self=this;return self.error_("Message"._comma((((nil.isNil_(aSelector))).mustBeBoolean()==true ? (function(){return " ";})() : (function(){return unescape("%20%23")._comma(aSelector);})()))._comma(" should not be sent to instances of ")._comma(self.$klass.name()));;return self;}
,"error",unescape("invalidMessage%3A%20aSelector%0D%0A%09%22%20The%20receiver%20received%20a%20message%20that%20is%20invalid%20%28not%20expected%20for%20this%20object%29.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%0D%0A%09%09%20%27Message%27%0D%0A%09%09%2C%28aSelector%20isNil%20ifTrue%3A%20%5B%27%20%27%5D%20ifFalse%3A%20%5B%27%20%23%27%2CaSelector%5D%29%0D%0A%09%09%2C%27%20should%20not%20be%20sent%20to%20instances%20of%20%27%2C%20self%20class%20name"));
smalltalk.bind(smalltalk.Object,"smalltalkErrorOf:",0
,function (aNativeException){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;((self.isObject_(aNativeException)).mustBeBoolean()==true ? (function(){((smalltalk.is_kindOf_(aNativeException,(smalltalk.Exception))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aNativeException;})();throw($s8Ret$)})();})() : nil);return (function(){$s8Ret$.result=(function(){return smalltalk.Error.$$new().messageText_(aNativeException);})();throw($s8Ret$)})();})() : nil);
result=((function(){var $1$=aNativeException["smalltalkError"];if(nil.isNil_($1$))return nil;return $1$;})());
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return (function($rec){$rec.messageText_((aNativeException.description || aNativeException.message));$rec.nativeException_(aNativeException);return $rec.yourself();})(smalltalk.Error.$$new());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("smalltalkErrorOf%3A%20aNativeException%0D%0A%09%22%20Private%2C%20Internal%20-%20Return%20anException%20associated%20with%20a%20native%28javascript%29%20exception.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09%28self%20isObject%3A%20aNativeException%29%20ifTrue%3A%20%5B%0D%0A%09%09%28aNativeException%20isKindOf%3A%20Exception%29%20ifTrue%3A%20%5B%20%5EaNativeException%20%5D.%0D%0A%09%09%5EError%20new%20messageText%3A%20aNativeException%0D%0A%09%5D.%0D%0A%09result%20%3A%3D%20aNativeException%20basicAt%3A%20%23smalltalkError.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%5EError%20new%0D%0A%09%09messageText%3A%20aNativeException%23description%20%7C%7C%20aNativeException%23message%3B%0D%0A%09%09nativeException%3A%20aNativeException%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Object,"printString",0
,function (){var self=this;return "a "._comma(self.$klass.name());;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20a%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27a%20%27%2C%20self%20class%20name"));
smalltalk.bind(smalltalk.Object,"isKindOf:",0
,function (aClass){var self=this;return self.$klass.inheritsFrom_(aClass);;return self;}
,"testing",unescape("isKindOf%3A%20aClass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20kind%20of%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20class%20inheritsFrom%3A%20aClass"));
smalltalk.bind(smalltalk.Object,"isMemberOf:",0
,function (aClass){var self=this;return (self.$klass === aClass);;return self;}
,"testing",unescape("isMemberOf%3A%20aClass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20member%20of%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20class%20%3D%3D%20aClass"));
smalltalk.bind(smalltalk.Object,"ifNil:",0
,function (aBlock){var self=this;return self;;return self;}
,"testing",unescape("ifNil%3A%20aBlock%0D%0A%09%22%20Return%20the%20receiver%20if%20it%20is%20not%20nil%2C%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20it%20is%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Object,"ifNil:ifNotNil:",0
,function (aBlock,anotherBlock){var self=this;return anotherBlock.value();;return self;}
,"testing",unescape("ifNil%3A%20aBlock%20ifNotNil%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20nil%20or%20the%20result%20of%20evaluating%20anotherBlock%20%28if%20not%20nil%29.%20%22%0D%0A%0D%0A%09%5EanotherBlock%20value"));
smalltalk.bind(smalltalk.Object,"ifNotNil:",0
,function (aBlock){var self=this;return aBlock.value();;return self;}
,"testing",unescape("ifNotNil%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20not%20nil%2C%20or%20nil%20if%20it%20is%20nil.%20%22%0D%0A%0D%0A%09%5EaBlock%20value"));
smalltalk.bind(smalltalk.Object,"ifNotNil:ifNil:",0
,function (aBlock,anotherBlock){var self=this;return aBlock.value();;return self;}
,"testing",unescape("ifNotNil%3A%20aBlock%20ifNil%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20not%20nil%2C%20or%20the%20result%20of%20evaluating%20anotherBlock%20if%20it%20is%20nil.%20%22%0D%0A%0D%0A%09%5EaBlock%20value"));
smalltalk.bind(smalltalk.Object,"isNil",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isNil%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20nil.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"notNil",0
,function (){var self=this;return (nil.isNil_(self)).not();;return self;}
,"testing",unescape("notNil%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20nil.%20%22%0D%0A%0D%0A%09%5Eself%20isNil%20not"));
smalltalk.bind(smalltalk.Object,"isClass",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isClass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20Class.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isMetaclass",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isMetaclass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20metaclass.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isNumber",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20Number.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isString",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20String.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isArray",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isArray%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20an%20Array.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isObject:",0
,function (anObject){var self=this;	return ((anObject) && anObject.$klass) ? true:false; ;return self;}
,"testing",unescape("isObject%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20a%20smalltalk%20object.%0D%0A%09Return%20false%20if%20the%20object%20is%20foreign%20%28e.g.%20javascript%29%20object.%0D%0A%09%22%0D%0A%0D%0A%7B%27%09return%20%28%28anObject%29%20%26%26%20anObject.%24klass%29%20%3F%20true%3Afalse%3B%20%27%7D"));
smalltalk.bind(smalltalk.Object,"typeOf:",0
,function (jsObject){var self=this;	return typeof jsObject; ;return self;}
,"utilities",unescape("typeOf%3A%20jsObject%0D%0A%09%22%20Return%20the%20type%20of%20%28javascript%29Object.%20%22%0D%0A%0D%0A%7B%27%09return%20typeof%20jsObject%3B%20%27%7D"));
smalltalk.bind(smalltalk.Object,"methodFor:",0
,function (aSymbol){var self=this;return self.$klass._gt_gt_gt(aSymbol);;return self;}
,"messages",unescape("methodFor%3A%20aSymbol%20%0D%0A%09%22%20Return%20the%20method%20implementing%20aSymbol%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20class%20%3E%3E%3E%20aSymbol"));
smalltalk.bind(smalltalk.Object,"respondsTo:",0
,function (aSymbol){var self=this;return (nil.isNil_(self.methodFor_(aSymbol))===false);;return self;}
,"messages",unescape("respondsTo%3A%20aSymbol%20%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20respond%20to%20message%20aSymbol.%20%22%0D%0A%0D%0A%09%5E%28self%20methodFor%3A%20aSymbol%29%20notNil"));
smalltalk.bind(smalltalk.Object,"basicPerform:withArguments:",0
,function (aSymbol,aCollection){var self=this;return self[aSymbol].apply(self, aCollection);;return self;}
,"messages",unescape("basicPerform%3A%20aSymbol%20withArguments%3A%20aCollection%0D%0A%09%22%20Private%20-%20Basic%20implementation%20of%20%23perform...%20%22%0D%0A%0D%0A%09%5Eself%5BaSymbol%5D%20%23apply%3A%20self%20withArguments%3A%20aCollection"));
smalltalk.bind(smalltalk.Object,"basicDelete:",0
,function (aString){var self=this;	delete self[aString];return self;}
,"accessing",unescape("basicDelete%3A%20aString%0D%0A%09%22%20Private%20-%20Basic%20implementation%20of%20deletion%20of%20property%20aString%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09delete%20self%5BaString%5D%27%7D"));
smalltalk.bind(smalltalk.Object,"doesNotUnderstand:",0
,function (aMessage){var self=this;return (function($rec){$rec.receiver_(self);$rec.message_(aMessage);return $rec.signal();})(smalltalk.MessageNotUnderstood.$$new());;return self;}
,"error",unescape("doesNotUnderstand%3A%20aMessage%0D%0A%09%22%20Private%20-%20Basic%20implementation%20of%20a%20message%20sent%20and%20not%20understood%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EMessageNotUnderstood%20new%0D%0A%09%09receiver%3A%20self%3B%0D%0A%09%09message%3A%20aMessage%3B%0D%0A%09%09signal"));
smalltalk.bind(smalltalk.Object,"json",0
,function (){var self=this;return self.asJSONObject();;return self;}
,"converting",unescape("json%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20hash%20object.%20%22%0D%0A%0D%0A%09%5Eself%20asJSONObject"));
smalltalk.bind(smalltalk.Object,"asJson:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(anObject))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil.json();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return ((self.isObject_(anObject)).mustBeBoolean()==true ? (function(){return anObject.json();})() : (function(){return anObject;})());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asJson%3A%20anObject%0D%0A%09%22%20Return%20anObject%20as%20a%20hash%20object.%20%22%0D%0A%0D%0A%09anObject%20isNil%20ifTrue%3A%20%5B%20%5Enil%20json%20%5D.%0D%0A%09%5E%28self%20isObject%3A%20anObject%29%0D%0A%09%09ifTrue%3A%20%5B%20anObject%20json%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20anObject%20%5D"));
smalltalk.bind(smalltalk.Object,"asJSONObject",0
,function (){var self=this;var result=nil;result={};
self.jsonFieldsDo_ignoring_((function(field,value){return (((nil.isNil_(value)===false).or_((function(){return self.jsonExportNil();}))).mustBeBoolean()==true ? (function(){return (result[field]=(self.asJson_(value)));})() : nil);}), self.jsonHiddenNames());
return result;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20%7B%27%7B%7D%27%7D.%0D%0A%09self%09jsonFieldsDo%3A%20%5B%3Afield%20%3Avalue%7C%0D%0A%09%09%28value%20notNil%20or%3A%20%5B%20self%20jsonExportNil%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09result%20basicAt%3A%20field%20put%3A%20%28self%20asJson%3A%20value%29%0D%0A%09%09%5D.%0D%0A%09%5D%09ignoring%3A%20self%20jsonHiddenNames.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Object,"jsonHiddenNames",0
,function (){var self=this;return [];;return self;}
,"converting",unescape("jsonHiddenNames%0D%0A%09%22%20Private%20-%20Return%20the%20names%20of%20the%20fields%20to%20skip%20when%20mapping%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.Object,"jsonFieldsDo:ignoring:",0
,function (aBlock,ignored){var self=this;return self.$klass.allInstVarNamesDo_((function(each){return (((nil.isNil_(ignored)===false).and_((function(){return ignored.includes_(each);}))).mustBeBoolean()==true ? nil : (function(){return aBlock.value_value_(each, self.instVarAt_(each));})());}));;return self;}
,"converting",unescape("jsonFieldsDo%3A%20aBlock%20ignoring%3A%20ignored%0D%0A%09%22%20Private%20-%20Evaluates%20a%28TwoArguments%29Block%20with%20the%20fields%20to%20map%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself%20class%20allInstVarNamesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09%28ignored%20notNil%20and%3A%20%5B%20ignored%20includes%3A%20each%20%5D%29%20ifFalse%3A%20%5B%0D%0A%09%09%09aBlock%20value%3A%20each%20value%3A%20%28self%20instVarAt%3A%20each%29%0D%0A%09%09%5D.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Object,"jsonExportNil",0
,function (){var self=this;return false;;return self;}
,"converting",unescape("jsonExportNil%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20export%20nil%20values.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"mustBeBoolean",0
,function (){var self=this;return self.error_("Must be boolean.");;return self;}
,"testing",unescape("mustBeBoolean%0D%0A%09%22%20Signal%20an%20error%20if%20the%20receiver%20is%20not%20a%20Boolean.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Must%20be%20boolean.%27"));
smalltalk.bind(smalltalk.Object,"mustBeNumber",0
,function (){var self=this;return self.error_("Must be a Number.");;return self;}
,"testing",unescape("mustBeNumber%0D%0A%09%22%20Signal%20an%20error%20if%20the%20receiver%20is%20not%20a%20Number.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Must%20be%20a%20Number.%27"));
smalltalk.bind(smalltalk.Object,"isBoolean",0
,function (){var self=this;return false;;return self;}
,"query",unescape("isBoolean%0D%0A%09%22%20Returns%20true%20if%20the%20receiver%20is%20a%20boolean.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"asLiteral",0
,function (){var self=this;return self.printString();;return self;}
,"converting",unescape("asLiteral%0D%0A%09%22%20Return%20the%20receiver%20in%20literal%20notation.%20%22%0D%0A%0D%0A%09%5Eself%20printString"));
smalltalk.bind(smalltalk.Object,"-->","_minus_minus_gt"
,function (anObject){var self=this;return smalltalk.Association.key_value_(self.asArrayOfSubstringsSeparatedBy_("."), anObject);;return self;}
,"converting",unescape("--%3E%20anObject%0D%0A%09%22%20Return%20a%20far-association%20of%20the%20receiver%20to%20anObject.%20%22%0D%0A%0D%0A%09%5EAssociation%20key%3A%20%28self%20asArrayOfSubstringsSeparatedBy%3A%20%24.%29%20value%3A%20anObject"));
smalltalk.bind(smalltalk.Object,"isCharacter",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isCharacter%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20character.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isAssociation",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isAssociation%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20anAssociation.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isDictionary",0
,function (){var self=this;return false;;return self;}
,"query",unescape("isDictionary%0D%0A%09%22%20Returns%20true%20if%20the%20receiver%20is%20a%20dictionary.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isRectangle",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isRectangle%0D%0A%09%22%20Return%20true%20if%20receiver%20is%20a%20Rectangle.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"isMessage",0
,function (){var self=this;return false;;return self;}
,"query",unescape("isMessage%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20message.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"argumentCount",0
,function (){var self=this;return (0);;return self;}
,"evaluating",unescape("argumentCount%0D%0A%09%22%20Return%20the%20number%20of%20arguments%20required%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E0"));
smalltalk.bind(smalltalk.Object,"numberOfArguments",0
,function (){var self=this;return self.argumentCount();;return self;}
,"evaluating",unescape("numberOfArguments%0D%0A%09%22%20Return%20the%20number%20of%20arguments%20required%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20argumentCount"));
smalltalk.bind(smalltalk.Object,"evaluate",0
,function (){var self=this;return self;;return self;}
,"evaluating",unescape("evaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Object,"evaluateDeferred",0
,function (){var self=this;(function(){return self.evaluate();}).valueDeferred();return self;}
,"evaluating",unescape("evaluateDeferred%0D%0A%09%22%20Evaluating%20the%20receiver%20deferred%20in%20time.%0D%0A%09Return%20the%20receiver.%20%22%0D%0A%0D%0A%09%5B%20self%20evaluate%20%5D%20valueDeferred."));
smalltalk.bind(smalltalk.Object,"evaluateWithArguments:",0
,function (anArray){var self=this;return self;;return self;}
,"evaluating",unescape("evaluateWithArguments%3A%20anArray%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Object,"evaluateWith:",0
,function (anObject){var self=this;return self.evaluateWithArguments_(smalltalk.Array.with_(anObject));;return self;}
,"evaluating",unescape("evaluateWith%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20evaluateWithArguments%3A%20%28Array%20with%3A%20anObject%29"));
smalltalk.bind(smalltalk.Object,"logEvaluate:",0
,function (source){var self=this;var result=nil;result=self.evaluate();
smalltalk.SystemManager.log_(source);
return result;;return self;}
,"evaluating",unescape("logEvaluate%3A%20source%0D%0A%09%22%20Return%20the%20result%20of%20valuating%20the%20receiver.%0D%0A%09Log%20the%20source%20expression%20as%20reference%20of%20evaluation.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20evaluate.%0D%0A%09SystemManager%20log%3A%20source.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Object,"asActionSequence",0
,function (){var self=this;return smalltalk.ActionSequence.with_(self);;return self;}
,"converting",unescape("asActionSequence%0D%0A%09%22%20Return%20an%20action%20sequence%20containing%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EActionSequence%20with%3A%20self"));
smalltalk.bind(smalltalk.Object,"eventTable",0
,function (){var self=this;return ((function(){var $1$=self[unescape("@handlers")];if(nil.isNil_($1$))return ((function(){return self.eventTableCreate();}).value());return $1$;})());;return self;}
,"events",unescape("eventTable%0D%0A%09%22%20Private%20-%20Returns%20the%20mapping%20event%20names%20to%20actions%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27@handlers%27%20ifAbsent%3A%20%5B%20self%20eventTableCreate%20%5D"));
smalltalk.bind(smalltalk.Object,"eventTableForEdit",0
,function (){var self=this;return ((function(){var $1$=self[unescape("@handlers")];if(nil.isNil_($1$))return ((function(){return (self[unescape("@handlers")]=(self.eventTableCreate()));}).value());return $1$;})());;return self;}
,"events",unescape("eventTableForEdit%0D%0A%09%22%20Private%20-%20Returns%20the%20mapping%20event%20names%20to%20actions%20of%20the%20receiver.%0D%0A%09Set%20the%20internal%20map%20if%20not%20present.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27@handlers%27%20ifAbsent%3A%20%5B%0D%0A%09%09self%20basicAt%3A%20%27@handlers%27%20put%3A%20self%20eventTableCreate%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Object,"releaseEventTable",0
,function (){var self=this;self.basicDelete_(unescape("@handlers"));return self;}
,"events",unescape("releaseEventTable%0D%0A%09%22%20Private%20-%20Release%20the%20event%20table.%20%22%0D%0A%0D%0A%09self%20basicDelete%3A%20%27@handlers%27"));
smalltalk.bind(smalltalk.Object,"release",0
,function (){var self=this;self.releaseEventTable();return self;}
,"release",unescape("release%0D%0A%09%22%20Release%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20releaseEventTable%20"));
smalltalk.bind(smalltalk.Object,"eventTableCreate",0
,function (){var self=this;return smalltalk.PoolDictionary.$$new();;return self;}
,"events",unescape("eventTableCreate%0D%0A%09%22%20Private%20-%20Returns%20a%20new%20mapping%20for%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPoolDictionary%20new"));
smalltalk.bind(smalltalk.Object,"canTriggerEvent:",0
,function (anEvent){var self=this;return self.$klass.canTriggerEvent_(anEvent);;return self;}
,"events",unescape("canTriggerEvent%3A%20anEvent%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20can%20trigger%20anEvent.%22%0D%0A%0D%0A%09%5Eself%20class%20canTriggerEvent%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"invalidEvent:",0
,function (anEvent){var self=this;return self;;return self;}
,"events",unescape("invalidEvent%3A%20anEvent%0D%0A%09%22%20Private%20-%20Notify%20the%20situation%20where%20an%20unknown%20event%20is%20registered.%0D%0A%09Default%20implementation%20ignore%20error%20during%20unknown%20event%20registration.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%0D%0A%22DEBUG-%09%5Eself%20print%3A%20self%20class%20name%2C%27%20invalidEvent%3A%20%23%27%2CanEvent%20asString.%20%22"));
smalltalk.bind(smalltalk.Object,"when:evaluate:",0
,function (anEvent,anAction){var $s8Ret$={name:"stReturn"};try{var self=this;var actions=nil;((self.canTriggerEvent_(anEvent)).mustBeBoolean()==true ? nil : (function(){return self.invalidEvent_(anEvent);})());
actions=self.actionListForEvent_(anEvent);
((actions.includes_(anAction)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
self.setActionList_forEvent_(actions.copyWith_(anAction), anEvent);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("when%3A%20anEvent%20evaluate%3A%20anAction%0D%0A%09%22%20Register%20anAction%20to%20the%20be%20evaluated%20when%20the%20receiver%20triggers%20the%20event.%20%22%0D%0A%0D%0A%09%7C%20actions%20%7C%0D%0A%09%28self%20canTriggerEvent%3A%20anEvent%29%20ifFalse%3A%20%5B%20self%20invalidEvent%3A%20anEvent%20%5D.%0D%0A%09actions%20%3A%3D%20self%20actionListForEvent%3A%20anEvent.%0D%0A%09%28actions%20includes%3A%20anAction%29%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09self%0D%0A%09%09setActionList%3A%20%28actions%20copyWith%3A%20anAction%29%0D%0A%09%09forEvent%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"actionListForEvent:",0
,function (anEvent){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=self.eventTable().at_ifAbsent_(anEvent, (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.ActionSequence.$$new();})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return result.asActionSequence();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("actionListForEvent%3A%20anEvent%0D%0A%09%22%20Private%20-%20Return%20a%20collection%20of%20actions%20to%20evaluate%20when%20the%20event%20is%20triggered.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20eventTable%20at%3A%20anEvent%20ifAbsent%3A%20%5B%20%5EActionSequence%20new%20%5D.%0D%0A%09%5Eresult%20asActionSequence"));
smalltalk.bind(smalltalk.Object,"setActionList:forEvent:",0
,function (actionSequence,anEvent){var $s8Ret$={name:"stReturn"};try{var self=this;var action=nil;action=actionSequence.asActionSequence().reduced();
(((nil.isNil_(action))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.removeActionsForEvent_(anEvent);})();throw($s8Ret$)})();})() : nil);
self.eventTableForEdit().at_put_(anEvent, action);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("setActionList%3A%20actionSequence%20forEvent%3A%20anEvent%0D%0A%09%22%20Private%20-%20Set%20the%20list%20of%20actions%20to%20evaluate%20when%20the%20event%20is%20triggered%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20action%20%7C%0D%0A%09action%20%3A%3D%20actionSequence%20asActionSequence%20reduced.%0D%0A%09action%20isNil%20ifTrue%3A%20%5B%20%5Eself%20removeActionsForEvent%3A%20anEvent%20%5D.%0D%0A%09self%20eventTableForEdit%20at%3A%20anEvent%20put%3A%20action."));
smalltalk.bind(smalltalk.Object,"removeActionsSatisfying:forEvent:",0
,function (aBlock,anEvent){var self=this;self.setActionList_forEvent_(self.actionListForEvent_(anEvent).asArray().reject_(aBlock), anEvent);return self;}
,"events",unescape("removeActionsSatisfying%3A%20aBlock%20forEvent%3A%20anEvent%0D%0A%09%22%20Private%20-%20Remove%20all%20actions%20for%20the%20event%20that%20evaluates%20aBlock%20to%20true.%22%0D%0A%0D%0A%09self%0D%0A%09%09setActionList%3A%20%28%28self%20actionListForEvent%3A%20anEvent%29%20asArray%20reject%3A%20aBlock%29%0D%0A%09%09forEvent%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"removeActionsWithReceiver:forEvent:",0
,function (anObject,anEvent){var self=this;self.removeActionsSatisfying_forEvent_((function(each){return smalltalk.responds_to_(each,("receiver")).and_((function(){return (each.receiver() === anObject);}));}), anEvent);return self;}
,"events",unescape("removeActionsWithReceiver%3A%20anObject%20forEvent%3A%20anEvent%0D%0A%09%22%20Remove%20all%20actions%20for%20the%20event%20in%20the%20receiver%27s%20event%20table%20which%20have%20anObject%20as%20receiver.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09removeActionsSatisfying%3A%20%5B%3Aeach%7C%20%28each%20respondsTo%3A%20%23receiver%29%20and%3A%20%5B%20each%20receiver%20%3D%3D%20anObject%20%5D%20%5D%0D%0A%09%09forEvent%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"removeAction:forEvent:",0
,function (anAction,anEvent){var self=this;self.removeActionsSatisfying_forEvent_((function(each){return each._eq(anAction);}), anEvent);return self;}
,"events",unescape("removeAction%3A%20anAction%20forEvent%3A%20anEvent%0D%0A%09%22%20Remove%20anAction%20for%20the%20event%20in%20the%20receiver%27s%20event%20table%20which%20have%20anObject%20as%20receiver.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09removeActionsSatisfying%3A%20%5B%3Aeach%7C%20each%20%3D%20anAction%20%5D%0D%0A%09%09forEvent%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"when:do:",0
,function (anEvent,aBlock){var self=this;self.when_evaluate_(anEvent, aBlock);return self;}
,"events",unescape("when%3A%20anEvent%20do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20when%20the%20receiver%20triggers%20the%20event.%20%22%0D%0A%0D%0A%09self%20when%3A%20anEvent%20evaluate%3A%20aBlock"));
smalltalk.bind(smalltalk.Object,"when:send:to:withArguments:",0
,function (anEvent,selector,anObject,array){var self=this;self.when_evaluate_(anEvent, smalltalk.LinkMessage.receiver_selector_arguments_(anObject, selector, array));return self;}
,"events",unescape("when%3A%20anEvent%20send%3A%20selector%20to%3A%20anObject%20withArguments%3A%20array%0D%0A%09%22%20Send%20the%20message%20when%20the%20receiver%20triggers%20the%20event.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09when%3A%20anEvent%0D%0A%09%09evaluate%3A%20%28LinkMessage%0D%0A%09%09%09receiver%3A%20anObject%0D%0A%09%09%09selector%3A%20selector%0D%0A%09%09%09arguments%3A%20array%29"));
smalltalk.bind(smalltalk.Object,"when:send:to:",0
,function (anEvent,selector,anObject){var self=this;self.when_evaluate_(anEvent, smalltalk.Message.receiver_selector_arguments_(anObject, selector, smalltalk.Array.new_(selector.argumentCount())));return self;}
,"events",unescape("when%3A%20anEvent%20send%3A%20selector%20to%3A%20anObject%0D%0A%09%22%20Send%20the%20message%20when%20the%20receiver%20triggers%20the%20event.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09when%3A%20anEvent%0D%0A%09%09evaluate%3A%20%28Message%0D%0A%09%09%09receiver%3A%20anObject%0D%0A%09%09%09selector%3A%20selector%0D%0A%09%09%09arguments%3A%20%28Array%20new%3A%20selector%20argumentCount%29%29"));
smalltalk.bind(smalltalk.Object,"triggerEvent:ifNotHandled:",0
,function (anEvent,aBlock){var self=this;return self.eventTable().at_ifAbsent_(anEvent, (function(){return aBlock;})).evaluate();;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%20ifNotHandled%3A%20aBlock%0D%0A%09%22%20Trigger%20the%20event.%0D%0A%09If%20the%20event%20is%20not%20handled%2C%20return%20the%20value%20of%20evaluating%20aBlock%2C%0D%0A%20%20%20%20%20%20%20%20or%20the%20value%20returned%20by%20the%20most%20recently%20defined%20event%20handler.%0D%0A%09%22%0D%0A%0D%0A%09%5E%28self%20eventTable%20at%3A%20anEvent%20ifAbsent%3A%20%5B%20aBlock%20%5D%29%20evaluate"));
smalltalk.bind(smalltalk.Object,"actionForEvent:",0
,function (anEvent){var self=this;return self.eventTable().at_ifAbsent_(anEvent, (function(){return nil;}));;return self;}
,"events",unescape("actionForEvent%3A%20anEvent%0D%0A%09%22%20Return%20the%20action%20to%20evaluate%20when%20the%20event%20is%20triggered%20by%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20eventTable%20at%3A%20anEvent%20ifAbsent%3A%20%5B%20nil%20%5D"));
smalltalk.bind(smalltalk.Object,"triggerEvent:",0
,function (anEvent){var self=this;return self.actionForEvent_(anEvent).evaluate();;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%0D%0A%09%22%20Return%20the%20result%20of%20triggering%20the%20event.%20%22%0D%0A%0D%0A%09%5E%28self%20actionForEvent%3A%20anEvent%29%20evaluate"));
smalltalk.bind(smalltalk.Object,"triggerEvent:withArguments:",0
,function (anEvent,array){var self=this;return self.actionForEvent_(anEvent).evaluateWithArguments_(array);;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%20withArguments%3A%20array%0D%0A%09%22%20Return%20the%20result%20of%20triggering%20the%20event.%20%22%0D%0A%0D%0A%09%5E%28self%20actionForEvent%3A%20anEvent%29%20evaluateWithArguments%3A%20array"));
smalltalk.bind(smalltalk.Object,"triggerEvent:with:",0
,function (anEvent,anObject){var self=this;return self.triggerEvent_withArguments_(anEvent, smalltalk.Array.with_(anObject));;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%20with%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20triggering%20the%20event.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20anEvent%20withArguments%3A%20%28Array%20with%3A%20anObject%29"));
smalltalk.bind(smalltalk.Object,"triggerEvent:with:with:",0
,function (anEvent,anObject,anotherObject){var self=this;return self.triggerEvent_withArguments_(anEvent, smalltalk.Array.with_with_(anObject, anotherObject));;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%20with%3A%20anObject%20with%3A%20anotherObject%0D%0A%09%22%20Return%20the%20result%20of%20triggering%20the%20event.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20anEvent%20withArguments%3A%20%28Array%20with%3A%20anObject%20with%3A%20anotherObject%29"));
smalltalk.bind(smalltalk.Object,"triggerEvent:withArguments:ifNotHandled:",0
,function (anEvent,array,aBlock){var self=this;return self.eventTable().at_ifAbsent_(anEvent, (function(){return aBlock;})).evaluateWithArguments_(array);;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%20withArguments%3A%20array%20ifNotHandled%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20triggering%20the%20eventwith%20the%20arguments.%0D%0A%09If%20the%20event%20is%20not%20handled%2C%20return%20the%20value%20of%20evaluating%20aBlock%2C%0D%0A%09or%20the%20value%20returned%20by%20the%20most%20recently%20defined%20event%20handler%20action.%0D%0A%09%22%0D%0A%0D%0A%09%5E%28self%20eventTable%20at%3A%20anEvent%20ifAbsent%3A%20%5B%20aBlock%20%5D%29%20evaluateWithArguments%3A%20array"));
smalltalk.bind(smalltalk.Object,"triggerEvent:with:ifNotHandled:",0
,function (anEvent,anObject,aBlock){var self=this;return self.triggerEvent_withArguments_ifNotHandled_(anEvent, smalltalk.Array.with_(anObject), aBlock);;return self;}
,"events",unescape("triggerEvent%3A%20anEvent%20with%3A%20anObject%20ifNotHandled%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20triggering%20the%20eventwith.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20anEvent%20withArguments%3A%20%28Array%20with%3A%20anObject%29%20ifNotHandled%3A%20aBlock"));
smalltalk.bind(smalltalk.Object,"hasActionForEvent:",0
,function (anEvent){var self=this;return self.eventTable().includesKey_(anEvent);;return self;}
,"events",unescape("hasActionForEvent%3A%20anEvent%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20has%20an%20action%20registered%20for%20the%20event.%20%22%0D%0A%0D%0A%09%5Eself%20eventTable%20includesKey%3A%20anEvent"));
smalltalk.bind(smalltalk.Object,"eventsHandled",0
,function (){var self=this;return self.eventTable().keys();;return self;}
,"events",unescape("eventsHandled%0D%0A%09%22%20Return%20the%20events%20for%20which%20there%20are%20actions%20registered%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20eventTable%20keys"));
smalltalk.bind(smalltalk.Object,"removeAllActionsWithReceiver:",0
,function (anObject){var self=this;self.eventTable().keys().do_((function(each){return self.removeActionsWithReceiver_forEvent_(anObject, each);}));return self;}
,"events",unescape("removeAllActionsWithReceiver%3A%20anObject%0D%0A%09%22%20Remove%20all%20actions%20for%20all%20events%20in%20the%20receiver%27s%20event%20table%20with%20anObject%20as%20receiver.%20%22%0D%0A%0D%0A%09self%20eventTable%20keys%20do%3A%20%5B%3Aeach%7Cself%20removeActionsWithReceiver%3A%20anObject%20forEvent%3A%20each%20%5D"));
smalltalk.bind(smalltalk.Object,"removeActionsForEvent:",0
,function (anEvent){var $s8Ret$={name:"stReturn"};try{var self=this;var actions=nil;actions=self.eventTable();
actions.removeKey_ifAbsent_(anEvent, (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();}));
((actions.isEmpty()).mustBeBoolean()==true ? (function(){return self.releaseEventTable();})() : nil);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("removeActionsForEvent%3A%20anEvent%0D%0A%09%22%20Remove%20all%20actions%20for%20the%20event.%20%22%0D%0A%0D%0A%09%7C%20actions%20%7C%0D%0A%09actions%20%3A%3D%20self%20eventTable.%0D%0A%09actions%20removeKey%3A%20anEvent%20ifAbsent%3A%20%5B%20%5Eself%20%5D.%0D%0A%09actions%20isEmpty%20ifTrue%3A%20%5B%20self%20releaseEventTable%20%5D."));
smalltalk.bind(smalltalk.Object,"addDependent:",0
,function (anObject){var self=this;self.when_send_to_("changed", "update", anObject);return self;}
,"changes",unescape("addDependent%3A%20anObject%0D%0A%09%22%20Make%20anObject%20dependent%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20when%3A%20%23changed%20send%3A%20%23update%20to%3A%20anObject"));
smalltalk.bind(smalltalk.Object,"changed",0
,function (){var self=this;self.triggerEvent_("changed");return self;}
,"changes",unescape("changed%0D%0A%09%22%20Update%20the%20dependents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23changed"));
smalltalk.bind(smalltalk.Object,"updateEvent:selector:arguments:",0
,function (anEvent,selector,array){var $s8Ret$={name:"stReturn"};try{var self=this;var action=nil;action=self.eventTable().at_ifAbsent_(anEvent, (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();}));
action.asActionSequence().evaluateWithSelector_withArguments_(selector, array);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"changes",unescape("updateEvent%3A%20anEvent%20selector%3A%20selector%20arguments%3A%20array%0D%0A%09%22%20Private%20-%20Trigger%20the%20event%20with%20the%20message%20selector%20and%20the%20arguments.%20%22%0D%0A%0D%0A%09%7C%20action%20%7C%0D%0A%09action%20%3A%3D%20self%20eventTable%20at%3A%20anEvent%20ifAbsent%3A%20%5B%20%5Enil%20%5D.%0D%0A%09action%20asActionSequence%0D%0A%20%20%20%20%20%20%20%20%20%20%20%20evaluateWithSelector%3A%20selector%0D%0A%20%20%20%20%20%20%20%20%20%20%20%20withArguments%3A%20array"));
smalltalk.bind(smalltalk.Object,"changed:",0
,function (aspect){var self=this;self.updateEvent_selector_arguments_("changed", "update:", smalltalk.Array.with_(aspect));return self;}
,"changes",unescape("changed%3A%20aspect%0D%0A%09%22%20Update%20the%20dependents%20on%20aspect%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20updateEvent%3A%20%23changed%20selector%3A%20%23update%3A%20arguments%3A%20%28Array%20with%3A%20aspect%29"));
smalltalk.bind(smalltalk.Object,"changed:with:",0
,function (aspect,anObject){var self=this;self.updateEvent_selector_arguments_("changed", "update:with:", smalltalk.Array.with_with_(aspect, anObject));return self;}
,"changes",unescape("changed%3A%20aspect%20with%3A%20anObject%0D%0A%09%22%20Update%20the%20dependents%20on%20aspect%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20updateEvent%3A%20%23changed%20selector%3A%20%23update%3Awith%3A%20arguments%3A%20%28Array%20with%3A%20aspect%20with%3A%20anObject%29"));
smalltalk.bind(smalltalk.Object,"changed:with:with:",0
,function (aspect,anObject,anotherObject){var self=this;self.updateEvent_selector_arguments_("changed", "update:with:with:", smalltalk.Array.with_with_with_(aspect, anObject, anotherObject));return self;}
,"changes",unescape("changed%3A%20aspect%20with%3A%20anObject%20with%3A%20anotherObject%0D%0A%09%22%20Update%20the%20dependents%20on%20aspect%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20updateEvent%3A%20%23changed%20selector%3A%20%23update%3Awith%3Awith%3A%20arguments%3A%20%28Array%20with%3A%20aspect%20with%3A%20anObject%20with%3A%20anotherObject%29"));
smalltalk.bind(smalltalk.Object,"dependents",0
,function (){var self=this;return self.actionListForEvent_("changed").collect_((function(each){return each.receiver();}));;return self;}
,"changes",unescape("dependents%0D%0A%09%22%20Return%20the%20dependents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28self%20actionListForEvent%3A%20%23changed%29%20collect%3A%20%5B%3Aeach%20%7C%20each%20receiver%20%5D"));
smalltalk.bind(smalltalk.Object,"update:with:",0
,function (anObject,anotherObject){var self=this;return self;}
,"changes",unescape("update%3A%20anObject%20with%3A%20anotherObject%0D%0A%09%22%20Update%20the%20receiver.%0D%0A%09Default%20implementation%20do%20nothing.%0D%0A%09This%20method%20must%20be%20refined%20by%20subclasses%20to%20support%20change/update%20protocoll.%0D%0A%09%22"));
smalltalk.bind(smalltalk.Object,"update:",0
,function (anObject){var self=this;return self;}
,"changes",unescape("update%3A%20anObject%0D%0A%09%22%20Update%20the%20receiver.%0D%0A%09Default%20implementation%20do%20nothing.%0D%0A%09This%20method%20must%20be%20refined%20by%20subclasses%20to%20support%20change/update%20protocoll.%0D%0A%09%22"));
smalltalk.bind(smalltalk.Object,"printingWith:do:",0
,function (printBlock,aBlock){var self=this;var backup=nil;var result=nil;backup=print;
(function(){printBlock.installAs_("print");return result=aBlock.value();}).ensure_((function(){return backup.installAs_("print");}));
return result;;return self;}
,"printing",unescape("printingWith%3A%20printBlock%20do%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%2C%20redirecting%20output%20to%20printBlock.%20%22%0D%0A%0D%0A%09%7C%20backup%20result%20%7C%0D%0A%09backup%20%3A%3D%20%23%7Bprint%7D.%0D%0A%09%5B%09printBlock%20installAs%3A%20%23print.%0D%0A%09%09result%20%3A%3D%20aBlock%20value.%0D%0A%09%5D%20ensure%3A%20%5B%20backup%20installAs%3A%20%23print%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Object,"isParseFailure",0
,function (){var self=this;return false;;return self;}
,"Compiler-testing",unescape("isParseFailure%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20parsing%20failure.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Object,"asParser",0
,function (){var self=this;return self.subclassResponsibility_("asParser");;return self;}
,"Compiler-converting",unescape("asParser%0D%0A%09%22%20Return%20a%20parser%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23asParser"));
smalltalk.bind(smalltalk.Object,"ifUndefined:",0
,function (aBlock){var self=this;return self;;return self;}
,"Compiler-inlines",unescape("ifUndefined%3A%20aBlock%0D%0A%09%22%20Return%20the%20receiver%20or%20the%20result%20of%20evaluating%20aBlock%20if%20it%20is%20undefined.%0D%0A%09Notes%3A%09-this%20message%20is%20inlined%20by%20compiler%20%28it%20is%20not%20sent%29%0D%0A%09%09-aBlock%20is%20evaluated%20ONLY%20in%20case%20of%20undefined.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Object,"basicValueOrNil",0
,function (){var self=this;return self;;return self;}
,"Compiler-inlines",unescape("basicValueOrNil%0D%0A%09%22%20Return%20the%20receiver%20or%20nil.%0D%0A%09Notes%3A%09-this%20message%20is%20inlined%20by%20compiler%20%28it%20is%20not%20sent%29%0D%0A%09%09-null%20and%20undefined%20returns%20nil.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Object,"scanFrom:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var chunk=nil;chunk=aStream.nextChunk();
((chunk.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return chunk.evaluateIn_(self);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Tools-fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20FileIn%20-%20Return%20the%20result%20of%20evaluating%20the%20next%20chunk%20of%20data%20from%20aStream.%0D%0A%09The%20method%20can%20be%20refined%20by%20chunk%20readers%20to%20support%20custom%20fileIn%20features.%0D%0A%09Must%20return%20the%20next%20reader%20to%20use%20for%20reading%20remaining%20contents%20from%20aStream.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20chunk%20%7C%0D%0A%09chunk%20%3A%3D%20aStream%20nextChunk.%0D%0A%09chunk%20isEmpty%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5Echunk%20evaluateIn%3A%20self"));
smalltalk.bind(smalltalk.Object,"javascriptCodeFollows",0
,function (){var self=this;return smalltalk.ChunkReader.javascript();;return self;}
,"Tools-fileIn",unescape("javascriptCodeFollows%0D%0A%09%22%20FileIn%20-%20FileIn%20javascript%20code%20on%20current%20stream.%0D%0A%09Consume%20stream%20contents%20upto%20end%20of%20stream%20evaluating%20the%20contents%20as%20javascript%20code.%0D%0A%09%22%0D%0A%0D%0A%09%5EChunkReader%20javascript"));
smalltalk.bind(smalltalk.Object,"cancelFileIn",0
,function (){var self=this;return self.ignoreFileInUpTo_(nil);;return self;}
,"Tools-fileIn",unescape("cancelFileIn%0D%0A%09%22%20FileIn%20-%20Cancel%20fileIn%20on%20current%20stream.%20%22%0D%0A%0D%0A%09%5Eself%20ignoreFileInUpTo%3A%20nil"));
smalltalk.bind(smalltalk.Object,"ignoreFileInUpTo:",0
,function (aToken){var self=this;return smalltalk.SkipFileInReader.upTo_(aToken);;return self;}
,"Tools-fileIn",unescape("ignoreFileInUpTo%3A%20aToken%0D%0A%09%22%20FileIn%20-%20Ignore%20fileIn%20on%20current%20stream%20upto%20token.%20%22%0D%0A%0D%0A%09%5ESkipFileInReader%20upTo%3A%20aToken"));
smalltalk.bind(smalltalk.Object,"==","_eq_eq"
,function (anObject){var self=this;return (self === anObject);;return self;}
,"Tools-comparing",unescape("%3D%3D%20anObject%0D%0A%09%5Eself%20%3D%3D%3D%20anObject"));
smalltalk.bind(smalltalk.Object,"~~","_no_no"
,function (anObject){var self=this;return ((self === anObject) === false);;return self;}
,"Tools-comparing",unescape("%7E%7E%20anObject%0D%0A%09%5E%28self%20%3D%3D%20anObject%29%20%3D%3D%20false"));
smalltalk.bind(smalltalk.Object,"isFile:olderThan:",0
,function (fileName,referenceFileName){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(((function(){var $1$=smalltalk.Smalltalk.global()["isFileOlderThan"];if(nil.isNil_($1$))return nil;return $1$;})())))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return isFileOlderThan(fileName, referenceFileName);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-emmiting",unescape("isFile%3A%20fileName%20olderThan%3A%20referenceFileName%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20file%20at%20pathName%20is%20older%20than%20file%20at%20referenceFileName.%20%22%0D%0A%0D%0A%09%28Smalltalk%20global%20basicAt%3A%20%23isFileOlderThan%29%20isNil%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5E%23%20%23isFileOlderThan%3A%20fileName%20with%3A%20referenceFileName"));
smalltalk.bind(smalltalk.Object,"emmit:startingWith:",0
,function (fileName,initial){var $s8Ret$={name:"stReturn"};try{var self=this;var output=nil;var cr=nil;var jsFileName=nil;jsFileName=fileName._comma(".js");
((self.isFile_olderThan_(fileName, jsFileName)).mustBeBoolean()==true ? (function(){self.fileInJS_(jsFileName);return (function(){$s8Ret$.result=(function(){return fileContents(jsFileName);})();throw($s8Ret$)})();})() : nil);
output=initial;
cr=unescape("%0D%0A");
self.print_(unescape("//%20emmit%28%22")._comma(fileName)._comma(unescape("%22%29")));
(function(){self.printingWith_do_((function(what){return output=(((nil.isNil_(output))).mustBeBoolean()==true ? (function(){return what;})() : (function(){return output._comma(cr)._comma(what);})());}), (function(){return self.fileIn_(fileName);}));return output.outputToFile_(jsFileName);}).on_do_(smalltalk.Error, (function(ex){output.asString()._comma(cr)._comma(ex.toString()).outputToFile_(fileName._comma(".error.txt"));self.print_(ex.toString());return (function(){$s8Ret$.result=(function(){return ex.toString();})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return output;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-emmiting",unescape("emmit%3A%20fileName%20startingWith%3A%20initial%0D%0A%09%22%20FileIn%20the%20contents%20of%20file%20at%20fileName%20redirecting%20output%28emmited%20code%29%20to%20a%20.js%20file.%20%22%0D%0A%0D%0A%09%7C%20output%20cr%20jsFileName%20%7C%0D%0A%09jsFileName%20%3A%3D%20fileName%2C%27.js%27.%0D%0A%09%28self%20isFile%3A%20fileName%20olderThan%3A%20jsFileName%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20fileInJS%3A%20jsFileName.%0D%0A%09%09%5E%23%20%23fileContents%3A%20jsFileName%0D%0A%09%5D.%0D%0A%09output%20%3A%3D%20initial.%20cr%20%3A%3D%20%27%0D%0A%27.%09self%20print%3A%20%27//%20emmit%28%22%27%2CfileName%2C%27%22%29%27.%0D%0A%5B%09self%09printingWith%3A%20%5B%3Awhat%7C%0D%0A%09%09%09output%20%3A%3D%20output%20isNil%20ifTrue%3A%20%5Bwhat%5D%0D%0A%09%09%09%09ifFalse%3A%20%5B%20output%20%2Ccr%20%2Cwhat%20%5D%0D%0A%09%09%5D%20do%3A%20%5B%20self%20fileIn%3A%20fileName%20%5D.%0D%0A%09output%20outputToFile%3A%20jsFileName.%0D%0A%5D%09on%3A%20Error%20do%3A%20%5B%3Aex%7C%0D%0A%09%28output%20asString%20%2Ccr%20%2Cex%20toString%29%0D%0A%09%09outputToFile%3A%20fileName%2C%27.error.txt%27.%0D%0A%09self%20print%3A%20ex%20toString.%0D%0A%09%5Eex%20toString%0D%0A%5D.%09%5Eoutput"));
smalltalk.bind(smalltalk.Object,"emmit:",0
,function (fileName){var $s8Ret$={name:"stReturn"};try{var self=this;((fileName.isString()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return fileName.asArray().emmit();})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return self.emmit_startingWith_(fileName, nil);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-emmiting",unescape("emmit%3A%20fileName%0D%0A%09%22%20FileIn%20the%20contents%20of%20file%20at%20fileName%20redirecting%20output%28emmited%20code%29%20to%20a%20.js%20file.%20%22%0D%0A%0D%0A%09fileName%20isString%20ifFalse%3A%20%5B%20%5EfileName%20asArray%20emmit%20%5D.%0D%0A%09%5Eself%20emmit%3A%20fileName%20startingWith%3A%20nil"));
smalltalk.bind(smalltalk.Object,"asJS",0
,function (){var self=this;return smalltalk.JS._at(self);;return self;}
,"converting",unescape("asJS%0D%0A%09%22%20Convert%20the%20receiver%20to%20JS%20instance%20%28for%20reflection%29.%20%22%0D%0A%0D%0A%09%5EJS%20@%20self"));
smalltalk.bind(smalltalk.Object,"handleOf:",0
,function (jsObject){var self=this;return (((nil.isNil_(jsObject)===false)).mustBeBoolean()==true ? (function(){return ((self.isObject_(jsObject).and_((function(){return (nil.isNil_(jsObject.handle)===false);}))).mustBeBoolean()==true ? (function(){return jsObject.handle();})() : (function(){return jsObject;})());})() : (function(){return undefined;})());;return self;}
,"Natives-converting",unescape("handleOf%3A%20jsObject%0D%0A%09%22%20Private%20-%20Return%20the%20handle%20of%20jsObject%20%28or%20the%20jsObject%29.%20%22%0D%0A%0D%0A%09%5EjsObject%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%28%28self%20isObject%3A%20jsObject%29%0D%0A%09%09and%3A%20%5B%20jsObject%5B%23handle%5D%20notNil%20%5D%29%0D%0A%09%09ifTrue%3A%20%5B%20jsObject%20handle%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20jsObject%20%5D%0D%0A%09%5D%20ifFalse%3A%20%5B%20%23%7Bundefined%7D%20%5D"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"current",0
,function (){var self=this;return smalltalk;;return self;}
,"accessing",unescape("current%0D%0A%09%22%20Return%20the%20current%20smalltalk%20system%20instance.%20%22%0D%0A%0D%0A%09%5E%23%7Bsmalltalk%7D"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"at:ifAbsent:",0
,function (aGlobalName,aBlock){var self=this;return ((function(){var $1$=self.current()[aGlobalName];if(nil.isNil_($1$))return (aBlock.value());return $1$;})());;return self;}
,"accessing",unescape("at%3A%20aGlobalName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20global%20known%20as%20aGlobalName%20in%20the%20receiver%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20current%20basicAt%3A%20aGlobalName%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"includesKey:",0
,function (aGlobalName){var $s8Ret$={name:"stReturn"};try{var self=this;self.at_ifAbsent_(aGlobalName, (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("includesKey%3A%20aGlobalName%0D%0A%09%22%20Return%20true%20if%20the%20global%20aGlobalName%20is%20defined%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20at%3A%20aGlobalName%20ifAbsent%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"at:",0
,function (aGlobalName){var self=this;return ((function(){var $1$=self.current()[aGlobalName];if(nil.isNil_($1$))return ((function(){return nil;}).value());return $1$;})());;return self;}
,"accessing",unescape("at%3A%20aGlobalName%0D%0A%09%22%20Return%20the%20global%20known%20as%20aGlobalName%20in%20the%20receiver%20or%20nil.%20%22%0D%0A%0D%0A%09%5Eself%20current%20basicAt%3A%20aGlobalName%20ifAbsent%3A%20%5B%20nil%20%5D"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"at:put:",0
,function (aGlobalName,anObject){var self=this;return (self.current()[aGlobalName]=(anObject));;return self;}
,"accessing",unescape("at%3A%20aGlobalName%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20global%20known%20as%20aGlobalName%20in%20the%20receiver%20top%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20current%20basicAt%3A%20aGlobalName%20put%3A%20anObject"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"at:ifAbsentPut:",0
,function (aGlobalName,aBlock){var self=this;return self.at_ifAbsent_(aGlobalName, (function(){return self.at_put_(aGlobalName, aBlock.value());}));;return self;}
,"accessing",unescape("at%3A%20aGlobalName%20ifAbsentPut%3A%20aBlock%0D%0A%09%22%20Return%20the%20global%20known%20as%20aGlobalName%20in%20the%20receiver%20or%20the%20result%20of%20evaluating%20aBlock.%0D%0A%09Set%20the%20global%20to%20return%20value%20if%20was%20absent.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20at%3A%20aGlobalName%20ifAbsent%3A%20%5B%0D%0A%09%09self%20at%3A%20aGlobalName%20put%3A%20aBlock%20value%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"removeKey:ifAbsent:",0
,function (aKey,aBlock){var self=this;return self.current().removeKey_ifAbsent_(aKey, aBlock);;return self;}
,"removing",unescape("removeKey%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%20%22%0D%0A%0D%0A%09%5Eself%20current%20removeKey%3A%20aKey%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"@","_at"
,function (aGlobalName){var $s8Ret$={name:"stReturn"};try{var self=this;var binding=nil;binding=self.at_ifAbsent_(aGlobalName, (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Array.$$new();})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return smalltalk.Array.with_(binding);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("@%20aGlobalName%0D%0A%09%22%20Return%20a%20collection%20with%20the%20objects%20bound%20to%20aGlobalName%20%28or%20an%20empty%20collection%20if%20global%20is%20not%20defined%29.%0D%0A%09It%20is%20used%20in%20expressions%20like%3A%0D%0A%09%09Smalltalk%20@%20%23MyGlobal%20do%3A%20%5B%3Aglobal%7C%20...%20%5D%0D%0A%09%22%0D%0A%0D%0A%09%7C%20binding%20%7C%0D%0A%09binding%20%3A%3D%20self%20at%3A%20aGlobalName%20ifAbsent%3A%20%5B%20%5EArray%20new%20%5D.%0D%0A%09%5EArray%20with%3A%20binding"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"definePool:with:",0
,function (poolName,tuples){var self=this;return self.current().definePool_with_(poolName, tuples);;return self;}
,"accessing",unescape("definePool%3A%20poolName%20with%3A%20tuples%0D%0A%09%22%20Define%20the%20pool%20dictionary%20from%20tuples%20specification.%20%22%0D%0A%0D%0A%09%5Eself%20current%20definePool%3A%20poolName%20with%3A%20tuples"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"poolDictionary:ifAbsent:",0
,function (aPoolName,aBlock){var self=this;return self.current().poolDictionary_ifAbsent_(aPoolName, aBlock);;return self;}
,"accessing",unescape("poolDictionary%3A%20aPoolName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20pool%20dictionary%20named%20aPoolName%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20current%20poolDictionary%3A%20aPoolName%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"objectAt:ifAbsent:",0
,function (aName,aBlock){var self=this;return self.current().objectAt_ifAbsent_(aName, aBlock);;return self;}
,"accessing",unescape("objectAt%3A%20aName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20%28global%20scoped%29%20smalltalk%20object%20at%20aName%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20undefined%20or%20not%20an%20Object%20instance%29.%20%22%0D%0A%0D%0A%09%5Eself%20current%20objectAt%3A%20aName%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"jsObjectAt:ifAbsent:",0
,function (aName,aBlock){var self=this;return self.current().jsObjectAt_ifAbsent_(aName, aBlock);;return self;}
,"accessing",unescape("jsObjectAt%3A%20aName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20%28global%20scoped%29%20javascript%20object%20at%20aName%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20undefined%29.%20%22%0D%0A%0D%0A%09%5Eself%20current%20jsObjectAt%3A%20aName%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"jsObjectAt:",0
,function (aName){var self=this;return self.jsObjectAt_ifAbsent_(aName, (function(){return self.error_("Undefined "._comma(aName));}));;return self;}
,"accessing",unescape("jsObjectAt%3A%20aName%0D%0A%09%22%20Return%20the%20%28global%20scoped%29%20javascript%20object%20at%20aName.%20%22%0D%0A%0D%0A%09%5Eself%20jsObjectAt%3A%20aName%20ifAbsent%3A%20%5B%20self%20error%3A%20%27Undefined%20%27%2CaName%20%5D"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"global",0
,function (){var self=this;return (function(){return this;}).call(null);;return self;}
,"accessing",unescape("global%0D%0A%09%22%20Return%20the%20global%20%28javascript%29%20object.%20%22%0D%0A%0D%0A%09%5E%5B%23%7Bthis%7D%5D%20%23call%3A%20%23%7Bnull%7D"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"classes",0
,function (){var self=this;return self.current().classes();;return self;}
,"accessing",unescape("classes%0D%0A%09%22%20Return%20the%20classes%20defined%20in%20current%20instance.%20%22%0D%0A%0D%0A%09%5Eself%20current%20classes"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"rootClasses",0
,function (){var self=this;return self.current().rootClasses();;return self;}
,"accessing",unescape("rootClasses%0D%0A%09%22%20Return%20the%20collection%20of%20topLevel%20classes%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20current%20rootClasses"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"implementorsOf:",0
,function (aSymbol){var self=this;return self.current().implementorsOf_(aSymbol);;return self;}
,"tools",unescape("implementorsOf%3A%20aSymbol%0D%0A%09%22%20Return%20a%20collection%20of%20methods%20implementing%20aSymbol.%20%22%0D%0A%0D%0A%09%5Eself%20current%20implementorsOf%3A%20aSymbol"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"gc",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;self.jsObjectAt_ifAbsent_("gc", (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})).value();
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"tools",unescape("gc%0D%0A%09%22%20Collect%20garbage.%20%22%0D%0A%0D%0A%09%28self%20jsObjectAt%3A%20%23gc%20ifAbsent%3A%20%5B%20%5Efalse%20%5D%29%20value.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"bindingsFor:",0
,function (aScope){var self=this;return smalltalk.PoolDictionaryReader.$$new().scope_(aScope);;return self;}
,unescape("Tools-pool%20variables"),unescape("bindingsFor%3A%20aScope%0D%0A%09%22%20FileIn%20-%20Return%20a%20reader%20to%20fileIn%20bindings%20in%20a%20%28global%29%20scope.%0D%0A%09aScope%20can%20be%20a%20string%20or%20a%20dictionary.%0D%0A%09In%20case%20of%20aScope%20been%20a%20String%2C%20it%20will%20be%20considered%20a%20PoolDictionaryName%0D%0A%09See%20PoolDictionaryReader%3E%3E%23scanFrom%3A%0D%0A%09%22%0D%0A%0D%0A%09%5EPoolDictionaryReader%20new%20scope%3A%20aScope"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"sendersOf:",0
,function (selector){var self=this;return self.current().sendersOf_(selector);;return self;}
,"Tools-query",unescape("sendersOf%3A%20selector%0D%0A%09%22%20Return%20the%20senders%20of%20message%20selector.%20%22%0D%0A%0D%0A%09%5Eself%20current%20sendersOf%3A%20selector"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"saveImageAs:",0
,function (fileName){var self=this;self.current().saveImageAs_(fileName);return self;}
,"Snapshot-snapshot",unescape("saveImageAs%3A%20fileName%0D%0A%09%22%20Dump%20the%20image%20contents%20onto%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09self%20current%20saveImageAs%3A%20fileName"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"saveImage",0
,function (){var self=this;self.current().saveImage();return self;}
,"Snapshot-snapshot",unescape("saveImage%0D%0A%09%22%20Dump%20the%20image%20contents%20onto%20image%20file.%20%22%0D%0A%0D%0A%09self%20current%20saveImage"));
smalltalk.bind(smalltalk.Smalltalk.$klass,"exit",0
,function (){var self=this;self.current().exit();return self;}
,"Snapshot-exiting",unescape("exit%0D%0A%09%22%20Exit%20to%20OS%20system.%20%22%0D%0A%0D%0A%09%0D%0A%09self%20current%20exit"));
smalltalk.bind(smalltalk.Smalltalk,"globalAt:",0
,function (aKey){var self=this;return ((function(){var $1$=self[aKey];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("globalAt%3A%20aKey%0D%0A%09%22%20Return%20the%20global%20at%20aKey%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20aKey"));
smalltalk.bind(smalltalk.Smalltalk,"globalAt:ifAbsent:",0
,function (aKey,aBlock){var self=this;return ((function(){var $1$=self[aKey];if(nil.isNil_($1$))return (aBlock.value());return $1$;})());;return self;}
,"accessing",unescape("globalAt%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20global%20at%20aKey%20%28or%20the%20result%20of%20evaluating%20aBlock%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20aKey%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk,"rootClasses",0
,function (){var self=this;return self.classes().select_((function(each){return (nil.isNil_(each.superclass()));}));;return self;}
,"accessing",unescape("rootClasses%0D%0A%09%22%20Return%20the%20collection%20of%20topLevel%20classes%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20classes%20select%3A%20%5B%3Aeach%7C%20each%20superclass%20isNil%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"implementorsOf:",0
,function (aSymbol){var self=this;return self.rootClasses().inject_into_([], (function(total,each){return total._comma(each.implementorsOf_(aSymbol));}));;return self;}
,"testing",unescape("implementorsOf%3A%20aSymbol%0D%0A%09%22%20Return%20a%20collection%20of%20methods%20implementing%20aSymbol.%20%22%0D%0A%0D%0A%09%5Eself%20rootClasses%20inject%3A%20%23%28%29%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09total%20%2C%28each%20implementorsOf%3A%20aSymbol%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Smalltalk,"objectAt:ifAbsent:",0
,function (aName,aBlock){var self=this;var result=nil;result=self.jsObjectAt_ifAbsent_(aName, aBlock);
return (((nil.isNil_(result.yourself)===false)).mustBeBoolean()==true ? (function(){return result;})() : nil);;return self;}
,"accessing",unescape("objectAt%3A%20aName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20%28global%20scoped%29%20smalltalk%20object%20at%20aName%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20undefined%20or%20not%20an%20Object%20instance%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20jsObjectAt%3A%20aName%20ifAbsent%3A%20aBlock.%0D%0A%09%5Eresult%23yourself%20notNil%20ifTrue%3A%20%5B%20result%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"jsObjectAt:ifAbsent:",0
,function (aName,aBlock){var self=this;return ((function(){var $1$=smalltalk.Smalltalk.global()[aName];if(nil.isNil_($1$))return (aBlock.value());return $1$;})());;return self;}
,"accessing",unescape("jsObjectAt%3A%20aName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20%28global%20scoped%29%20javascript%20object%20at%20aName%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20undefined%29.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20global%20basicAt%3A%20aName%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk,"jsObjectAt:",0
,function (aName){var self=this;return self.jsObjectAt_ifAbsent_(aName, (function(){return self.error_("Undefined "._comma(aName));}));;return self;}
,"accessing",unescape("jsObjectAt%3A%20aName%0D%0A%09%22%20Return%20the%20%28global%20scoped%29%20javascript%20object%20at%20aName.%20%22%0D%0A%0D%0A%09%5Eself%20jsObjectAt%3A%20aName%20ifAbsent%3A%20%5B%20self%20error%3A%20%27Undefined%20%27%2CaName%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"removeKey:ifAbsent:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;((function(){var $1$=self[aKey];if(nil.isNil_($1$))return ((function(){return (function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();}).value());return $1$;})());
self.basicDelete_(aKey);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"removing",unescape("removeKey%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20aKey%20ifAbsent%3A%20%5B%20%5EaBlock%20value%20%5D.%0D%0A%09self%20basicDelete%3A%20aKey"));
smalltalk.bind(smalltalk.Smalltalk,"definePool:",0
,function (poolName){var self=this;return self.definePool_with_(poolName, smalltalk.Array.$$new());;return self;}
,"accessing",unescape("definePool%3A%20poolName%0D%0A%09%22%20Define%20the%20pool%20dictionary%20%28if%20it%20is%20not%20defined%20yet%29.%20%22%0D%0A%0D%0A%09%5Eself%20definePool%3A%20poolName%20with%3A%20Array%20new"));
smalltalk.bind(smalltalk.Smalltalk,"poolDictionary:ifAbsent:",0
,function (aPoolName,aBlock){var self=this;return ((function(){var $1$=self[aPoolName];if(nil.isNil_($1$))return ((function(){return aBlock.value();}).value());return $1$;})());;return self;}
,"accessing",unescape("poolDictionary%3A%20aPoolName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20pool%20dictionary%20named%20aPoolName%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20aPoolName%20ifAbsent%3A%20%5B%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"poolDictionary:",0
,function (aPoolName){var self=this;return self.poolDictionary_ifAbsent_(aPoolName, (function(){return self.definePool_(aPoolName);}));;return self;}
,"accessing",unescape("poolDictionary%3A%20aPoolName%0D%0A%09%22%20Return%20the%20pool%20dictionary%20named%20aPoolName.%20%22%0D%0A%0D%0A%09%5Eself%20poolDictionary%3A%20aPoolName%20ifAbsent%3A%20%5B%0D%0A%09%09%22self%20error%3A%20%27Missing%20Pool%20dictionary%3A%20%27%2CaPoolName.%20%22%0D%0A%09%09self%20definePool%3A%20aPoolName%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Smalltalk,"printDefinePool:with:",0
,function (poolName,tuples){var self=this;self.print_(unescape("smalltalk.definePool_with_%28%22")._comma(poolName)._comma(unescape("%22%2C%5B")));
tuples.do_((function(tuple){return ((tuple.isArray()).mustBeBoolean()==true ? (function(){return self.print_(unescape("%09%5B")._comma(tuple.first().printString())._comma(unescape("%2C"))._comma(tuple.last().asJavascript())._comma(unescape("%5D%2C")));})() : (function(){return self.print_(unescape("%09")._comma(tuple.asJavascript())._comma(unescape("%2C")));})());}));
self.print_(unescape("%09%5D%29%3B"));return self;}
,"compiling",unescape("printDefinePool%3A%20poolName%20with%3A%20tuples%0D%0A%09%22%20DEBUG%20-%20Dump%20definition%20of%20the%20pool%20dictionary.%20%22%0D%0A%0D%0A%09self%20print%3A%20%27smalltalk.definePool_with_%28%22%27%2CpoolName%2C%27%22%2C%5B%27.%0D%0A%09tuples%20do%3A%20%5B%3Atuple%7C%0D%0A%09%09tuple%20isArray%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20print%3A%20%27%09%5B%27%2Ctuple%20first%20printString%2C%27%2C%27%2Ctuple%20last%20asJavascript%2C%27%5D%2C%27%0D%0A%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09self%20print%3A%20%27%09%27%2Ctuple%20asJavascript%20%2C%27%2C%27%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09self%20print%3A%20%27%09%5D%29%3B%27."));
smalltalk.bind(smalltalk.Smalltalk,"definePool:with:",0
,function (poolName,tuples){var self=this;var dictionary=nil;var offset=nil;dictionary=((function(){var $1$=self[poolName];if(nil.isNil_($1$))return ((function(){return (self[poolName]=(smalltalk.PoolDictionary.$$new()));}).value());return $1$;})());
offset=(0);
tuples.do_((function(each){return ((each.isArray()).mustBeBoolean()==true ? (function(){dictionary.at_put_(each.first(), each.last());return ((each.last().isNumber()).mustBeBoolean()==true ? (function(){return offset=each.last()._plus((1));})() : nil);})() : (function(){return ((each.isNumber()).mustBeBoolean()==true ? (function(){return offset=each;})() : (function(){dictionary.at_put_(each, offset);return offset=offset._plus((1));})());})());}));
return dictionary;;return self;}
,"compiling",unescape("definePool%3A%20poolName%20with%3A%20tuples%0D%0A%09%22%20Define%20the%20pool%20dictionary.%20%22%0D%0A%0D%0A%09%7C%20dictionary%20offset%20%7C%0D%0A%09dictionary%20%3A%3D%20self%20basicAt%3A%20poolName%20ifAbsent%3A%20%5B%0D%0A%09%09self%20basicAt%3A%20poolName%20put%3A%20PoolDictionary%20new%0D%0A%09%5D.%0D%0A%09offset%20%3A%3D%200.%0D%0A%09tuples%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20isArray%20ifTrue%3A%20%5B%0D%0A%09%09%09dictionary%20at%3A%20each%20first%20put%3A%20each%20last.%0D%0A%09%09%09each%20last%20isNumber%20ifTrue%3A%20%5B%20offset%20%3A%3D%20each%20last%20+%201%20%5D.%0D%0A%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09each%20isNumber%20ifTrue%3A%20%5B%20offset%20%3A%3D%20each%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%0D%0A%09%09%09%09dictionary%20at%3A%20each%20put%3A%20offset.%0D%0A%09%09%09%09offset%20%3A%3D%20offset%20+%201.%0D%0A%09%09%09%5D%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Edictionary"));
smalltalk.bind(smalltalk.Smalltalk,"state",0
,function (){var self=this;return ((function(){var $1$=self["$state"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("state%0D%0A%09%22%20Return%20the%20state%20of%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24state%27"));
smalltalk.bind(smalltalk.Smalltalk,"state:",0
,function (aState){var self=this;(self["$state"]=(aState));return self;}
,"accessing",unescape("state%3A%20aState%0D%0A%09%22%20Set%20the%20state%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24state%27%20put%3A%20aState"));
smalltalk.bind(smalltalk.Smalltalk,"withState:do:",0
,function (aState,aBlock){var self=this;var old=nil;old=self.state();
return (function(){self.state_(aState);return aBlock.value();}).ensure_((function(){return self.state_(old);}));;return self;}
,"accessing",unescape("withState%3A%20aState%20do%3A%20aBlock%0D%0A%09%22%20Set%20the%20state%20of%20the%20receiver%20to%20aState%20during%20execution%20of%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20old%20%7C%0D%0A%09old%20%3A%3D%20self%20state.%0D%0A%09%5E%5B%09self%20state%3A%20aState.%0D%0A%09%09aBlock%20value%0D%0A%09%5D%20ensure%3A%20%5B%0D%0A%09%09self%20state%3A%20old%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Smalltalk,"eval:",0
,function (jsExpression){var self=this;return eval(jsExpression);;return self;}
,"javascript",unescape("eval%3A%20jsExpression%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20a%20javascript%20expression%20in%20global%20context.%20%22%0D%0A%0D%0A%09%5E%23%20%23eval%3A%20jsExpression"));
smalltalk.bind(smalltalk.Smalltalk,"eval:as:",0
,function (jsExpression,aState){var self=this;return self.withState_do_(aState, (function(){return self.eval_(jsExpression);}));;return self;}
,"javascript",unescape("eval%3A%20jsExpression%20as%3A%20aState%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20a%20javascript%20expression%20in%20global%20context.%0D%0A%09The%20state%20of%20the%20system%20change%20to%20state%20while%20evaluating%20the%20expression.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20withState%3A%20aState%20do%3A%20%5B%20self%20eval%3A%20jsExpression%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"removeSources",0
,function (){var self=this;self.classes().do_((function(each){return each.removeSources();}));return self;}
,"tools",unescape("removeSources%0D%0A%09%22%20Remove%20all%20development%20sources%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20classes%20do%3A%20%5B%3Aeach%20%7C%20each%20removeSources%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"readJSON:",0
,function (anObject){var self=this;return self.readJSObject(anObject);;return self;}
,"json",unescape("readJSON%3A%20anObject%0D%0A%09%22%20Return%20an%20object%20read%20from%20JSON%20map%20object%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20%23readJSObject%3A%20anObject"));
smalltalk.bind(smalltalk.Smalltalk,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Smalltalk,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Smalltalk,"compilerSupport",0
,function (){var self=this;return smalltalk.Compiler;;return self;}
,"Compiler-accessing",unescape("compilerSupport%0D%0A%09%22%20Return%20the%20compiler%20support%20for%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ECompiler"));
smalltalk.bind(smalltalk.Smalltalk,"recompileAll",0
,function (){var self=this;self.classes().do_((function(each){return each.recompile();}));return self;}
,"Compiler-compiling",unescape("recompileAll%0D%0A%09%22%20Recompile%20all%20classes%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20classes%20do%3A%20%5B%3Aeach%20%7C%20each%20recompile%20%5D"));
smalltalk.bind(smalltalk.Smalltalk,"fileInCode:",0
,function (code){var self=this;return code.stream().fileIn();;return self;}
,"Tools-fileIn",unescape("fileInCode%3A%20code%0D%0A%09%22%20FileIn%20the%20code%20into%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ecode%20stream%20fileIn"));
smalltalk.bind(smalltalk.Smalltalk,"sendersOf:",0
,function (selector){var self=this;return smalltalk.MethodReferences.$$new().sendersOf_(selector);;return self;}
,"Tools-query",unescape("sendersOf%3A%20selector%0D%0A%09%22%20Return%20the%20senders%20of%20message%20selector.%20%22%0D%0A%0D%0A%09%5EMethodReferences%20new%20sendersOf%3A%20selector"));
smalltalk.bind(smalltalk.Smalltalk,"exit",0
,function (){var self=this;self.classes().do_((function(each){return each.aboutToExit_(self);}));
quit();return self;}
,"Snapshot-exiting",unescape("exit%0D%0A%09%22%20Exit%20to%20OS%20system.%20%22%0D%0A%0D%0A%09self%20classes%20do%3A%20%5B%3Aeach%7C%20each%20aboutToExit%3A%20self%20%5D.%0D%0A%09%23%20quit"));
smalltalk.bind(smalltalk.Smalltalk,"product",0
,function (){var self=this;return "S8";;return self;}
,"Snapshot-accessing",unescape("product%0D%0A%09%22%20Private%20-%20Return%20the%20name%20of%20the%20system.%20%22%0D%0A%0D%0A%09%5E%23S8"));
smalltalk.bind(smalltalk.Smalltalk,"description",0
,function (){var self=this;return unescape("A%20modern%20Smalltalk%20environment%20running%20on%20the%20%22invisible%20machine%22.");;return self;}
,"Snapshot-accessing",unescape("description%0D%0A%09%22%20Private%20-%20Return%20the%20description%20of%20the%20system.%20%22%0D%0A%0D%0A%09%5E%27A%20modern%20Smalltalk%20environment%20running%20on%20the%20%22invisible%20machine%22.%27"));
smalltalk.bind(smalltalk.Smalltalk,"licenseComment",0
,function (){var self=this;return unescape("%0D%0AThe%20text%20you%20are%20reading%20here%20is%20the%20residue%20of%20something%20that%20has%20run%20before.%0D%0AKeep%20the%20system%20running%20with%20responsibility.%20Smalltalk%20is%20not%20the%20words%2C%0D%0A%20nor%20any%20definition%2C%20nor%20it%20current%20contents...%0D%0ASmalltalk%20include%20your%20feelings%20when%20you%20see%20it%20running.%0D%0ASmalltalk%20is%20what%20happens%20when%20time%20flows%20and%20you%20%22are%22%20here.%0D%0AStop%20reading/writing%20code%20%28thinking%20you%20are%20outside%20the%20system%29%2C%0D%0A%20change%20your%20world%20with%20resposibility%2C%20one%20object%20at%20a%20time%2C%20with%20your%20hands%2C%0D%0A%20during%20all%20your%20life%2C%20in%20family.");;return self;}
,"Snapshot-license",unescape("licenseComment%0D%0A%09%22%20Private%20-%20Comment%20note%20about%20license%20of%20this%20product.%20%22%0D%0A%0D%0A%09%5E%27%0D%0AThe%20text%20you%20are%20reading%20here%20is%20the%20residue%20of%20something%20that%20has%20run%20before.%0D%0AKeep%20the%20system%20running%20with%20responsibility.%20Smalltalk%20is%20not%20the%20words%2C%0D%0A%20nor%20any%20definition%2C%20nor%20it%20current%20contents...%0D%0ASmalltalk%20include%20your%20feelings%20when%20you%20see%20it%20running.%0D%0ASmalltalk%20is%20what%20happens%20when%20time%20flows%20and%20you%20%22are%22%20here.%0D%0AStop%20reading/writing%20code%20%28thinking%20you%20are%20outside%20the%20system%29%2C%0D%0A%20change%20your%20world%20with%20resposibility%2C%20one%20object%20at%20a%20time%2C%20with%20your%20hands%2C%0D%0A%20during%20all%20your%20life%2C%20in%20family.%27"));
smalltalk.bind(smalltalk.Smalltalk,"licenseTerms",0
,function (){var self=this;return self.product()._comma(unescape("%20-%20"))._comma(self.description())._comma(unescape("%0D%0A"))._comma(self.licenseMoreHolders())._comma(unescape("%0D%0A"))._comma(self.licenseHolders())._comma(unescape("%0D%0APermission%20is%20hereby%20granted%2C%20free%20of%20charge%2C%20to%20any%20person%20obtaining%0D%0A%20a%20copy%20of%20this%20software%20and%20associated%20documentation%20files%20%28the%20%22Software%22%29%2C%0D%0A%20to%20deal%20in%20the%20Software%20without%20restriction%2C%20including%20without%20limitation%0D%0A%20the%20rights%20to%20use%2C%20copy%2C%20modify%2C%20merge%2C%20publish%2C%20distribute%2C%20sublicense%2C%0D%0A%20and/or%20sell%20copies%20of%20the%20Software%2C%20and%20to%20permit%20persons%20to%20whom%20the%0D%0A%20Software%20is%20furnished%20to%20do%20so%2C%20subject%20to%20the%20following%20conditions%3A%0D%0A%0D%0AThe%20above%20copyright%20notice%20and%20this%20permission%20notice%20shall%20be%20included%0D%0A%20in%20all%20copies%20or%20substantial%20portions%20of%20the%20Software.%0D%0A%0D%0ATHE%20SOFTWARE%20IS%20PROVIDED%20%22AS%20IS%22%2C%20WITHOUT%20WARRANTY%20OF%20ANY%20KIND%2C%0D%0A%20EXPRESS%20OR%20IMPLIED%2C%20INCLUDING%20BUT%20NOT%20LIMITED%20TO%20THE%20WARRANTIES%0D%0A%20OF%20MERCHANTABILITY%2C%20FITNESS%20FOR%20A%20PARTICULAR%20PURPOSE%20AND%20NONINFRINGEMENT.%0D%0A%20IN%20NO%20EVENT%20SHALL%20THE%20AUTHORS%20OR%20COPYRIGHT%20HOLDERS%20BE%20LIABLE%20FOR%20ANY%0D%0A%20CLAIM%2C%20DAMAGES%20OR%20OTHER%20LIABILITY%2C%20WHETHER%20IN%20AN%20ACTION%20OF%20CONTRACT%2C%0D%0A%20TORT%20OR%20OTHERWISE%2C%20ARISING%20FROM%2C%20OUT%20OF%20OR%20IN%20CONNECTION%20WITH%20THE%20SOFTWARE%0D%0A%20OR%20THE%20USE%20OR%20OTHER%20DEALINGS%20IN%20THE%20SOFTWARE.%0D%0A----------------------------------------------------------------------%0D%0A"))._comma(self.licenseComment());;return self;}
,"Snapshot-license",unescape("licenseTerms%0D%0A%09%22%20Private%20-%20Return%20the%20license%20terms%20to%20use%20this%20system.%20%22%0D%0A%0D%0A%09%5Eself%20product%2C%27%20-%20%27%2Cself%20description%20%2C%27%0D%0A%27%2Cself%20licenseMoreHolders%09%2C%27%0D%0A%27%2Cself%20licenseHolders%09%09%2C%27%0D%0APermission%20is%20hereby%20granted%2C%20free%20of%20charge%2C%20to%20any%20person%20obtaining%0D%0A%20a%20copy%20of%20this%20software%20and%20associated%20documentation%20files%20%28the%20%22Software%22%29%2C%0D%0A%20to%20deal%20in%20the%20Software%20without%20restriction%2C%20including%20without%20limitation%0D%0A%20the%20rights%20to%20use%2C%20copy%2C%20modify%2C%20merge%2C%20publish%2C%20distribute%2C%20sublicense%2C%0D%0A%20and/or%20sell%20copies%20of%20the%20Software%2C%20and%20to%20permit%20persons%20to%20whom%20the%0D%0A%20Software%20is%20furnished%20to%20do%20so%2C%20subject%20to%20the%20following%20conditions%3A%0D%0A%0D%0AThe%20above%20copyright%20notice%20and%20this%20permission%20notice%20shall%20be%20included%0D%0A%20in%20all%20copies%20or%20substantial%20portions%20of%20the%20Software.%0D%0A%0D%0ATHE%20SOFTWARE%20IS%20PROVIDED%20%22AS%20IS%22%2C%20WITHOUT%20WARRANTY%20OF%20ANY%20KIND%2C%0D%0A%20EXPRESS%20OR%20IMPLIED%2C%20INCLUDING%20BUT%20NOT%20LIMITED%20TO%20THE%20WARRANTIES%0D%0A%20OF%20MERCHANTABILITY%2C%20FITNESS%20FOR%20A%20PARTICULAR%20PURPOSE%20AND%20NONINFRINGEMENT.%0D%0A%20IN%20NO%20EVENT%20SHALL%20THE%20AUTHORS%20OR%20COPYRIGHT%20HOLDERS%20BE%20LIABLE%20FOR%20ANY%0D%0A%20CLAIM%2C%20DAMAGES%20OR%20OTHER%20LIABILITY%2C%20WHETHER%20IN%20AN%20ACTION%20OF%20CONTRACT%2C%0D%0A%20TORT%20OR%20OTHERWISE%2C%20ARISING%20FROM%2C%20OUT%20OF%20OR%20IN%20CONNECTION%20WITH%20THE%20SOFTWARE%0D%0A%20OR%20THE%20USE%20OR%20OTHER%20DEALINGS%20IN%20THE%20SOFTWARE.%0D%0A----------------------------------------------------------------------%0D%0A%27%2Cself%20licenseComment"));
smalltalk.bind(smalltalk.Smalltalk,"licenseYear",0
,function (){var self=this;return smalltalk.DateTime.today().year();;return self;}
,"Snapshot-license",unescape("licenseYear%0D%0A%09%22%20Private%20-%20Return%20the%20license%20information.%20%22%0D%0A%0D%0A%09%5EDateTime%20today%20year"));
smalltalk.bind(smalltalk.Smalltalk,"licenseMoreHolders",0
,function (){var self=this;return "";;return self;}
,"Snapshot-license",unescape("licenseMoreHolders%0D%0A%09%22%20Private%20-%20Return%20additional%20license%20holders%20information.%20%22%0D%0A%0D%0A%09%5E%27%27"));
smalltalk.bind(smalltalk.Smalltalk,"licenseHolders",0
,function (){var self=this;return unescape("Copyright%20%28C%29%20")._comma(self.licenseYear().asString())._comma(" ")._comma(unescape("Alejandro%20F.%20Reimondo%20%3CaleReimondo@smalltalking.net%3E%0D%0A%0D%0AParts%20of%20source%20code%20written%20for%20Jtalk%20%28Sept%202011%29%2C%0D%0ACopyright%20%28C%29%202011%20by%20Nicolas%20Petton%20%3Cpetton.nicolas@gmail.com%3E%0D%0ACopyright%20%28C%29%202011%20Jtalk%20contributors%0D%0A%09David%20Graham%20%3Cdgraham@iphouse.com%3E%0D%0A%09Goran%20Krampe%20%3Cgoran@krampe.se%3E%0D%0AAlso%20code%20and%20ideas%20from%20Clamato%20%28http%3A//clamato.net%29%2C%20written%20by%20Avi%20Byrant.%0D%0AThe%20PetitParser%20library%2C%20published%20by%20Lukas%20Renggli%20%28http%3A//lukas-renggli.ch%29%20and%20released%20under%20the%20MIT%20license.%0D%0AAnd%20people%20that%20contributed%20to%20Smalltalk%20on%20diverse%20media%20years%28decades%29%20before%20this%20license%20holders%20claimed%20ownership.%0D%0A"));;return self;}
,"Snapshot-license",unescape("licenseHolders%0D%0A%09%22%20Private%20-%20Return%20the%20license%20holders%20information.%20%22%0D%0A%0D%0A%09%5E%27Copyright%20%28C%29%20%27%0D%0A%09%09%2Cself%20licenseYear%20asString%20%2C%27%20%27%0D%0A%09%09%2C%27Alejandro%20F.%20Reimondo%20%3CaleReimondo@smalltalking.net%3E%0D%0A%0D%0AParts%20of%20source%20code%20written%20for%20Jtalk%20%28Sept%202011%29%2C%0D%0ACopyright%20%28C%29%202011%20by%20Nicolas%20Petton%20%3Cpetton.nicolas@gmail.com%3E%0D%0ACopyright%20%28C%29%202011%20Jtalk%20contributors%0D%0A%09David%20Graham%20%3Cdgraham@iphouse.com%3E%0D%0A%09Goran%20Krampe%20%3Cgoran@krampe.se%3E%0D%0AAlso%20code%20and%20ideas%20from%20Clamato%20%28http%3A//clamato.net%29%2C%20written%20by%20Avi%20Byrant.%0D%0AThe%20PetitParser%20library%2C%20published%20by%20Lukas%20Renggli%20%28http%3A//lukas-renggli.ch%29%20and%20released%20under%20the%20MIT%20license.%0D%0AAnd%20people%20that%20contributed%20to%20Smalltalk%20on%20diverse%20media%20years%28decades%29%20before%20this%20license%20holders%20claimed%20ownership.%0D%0A%27"));
smalltalk.bind(smalltalk.Smalltalk,"globalsDo:",0
,function (aBlock){var self=this;return self.globalsDo(aBlock);;return self;}
,"Snapshot-evaluating",unescape("globalsDo%3A%20aBlock%0D%0A%09%22%20Private%20-%20Evaluates%20aBlock%20for%20each%20globals%20defined%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23globalsDo%3A%20aBlock"));
smalltalk.bind(smalltalk.Smalltalk,"globalsDo:separatedBy:",0
,function (aBlock,anotherBlock){var self=this;var first=nil;first=true;
return self.globalsDo((function(each){((first).mustBeBoolean()==true ? (function(){return first=false;})() : (function(){return anotherBlock.value();})());return aBlock.value_(each);}));;return self;}
,"Snapshot-evaluating",unescape("globalsDo%3A%20aBlock%20separatedBy%3A%20anotherBlock%0D%0A%09%22%20Private%20-%20Evaluates%20aBlock%20for%20each%20globals%20defined%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20first%20%7C%20first%20%3A%3D%20true.%0D%0A%09%5Eself%20%23globalsDo%3A%20%5B%3Aeach%7C%0D%0A%09%20%20%20%20first%0D%0A%09%09ifTrue%3A%20%5B%20first%20%3A%3D%20false%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20anotherBlock%20value%20%5D.%0D%0A%09%20%20%20%20aBlock%20value%3A%20each%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Smalltalk,"saveImageOn:",0
,function (stream){var self=this;var exporter=nil;var allClasses=nil;(function($rec){$rec.nextPutAll_(unescape("/*"));$rec.cr();$rec.nextPutAll_(self.licenseTerms());$rec.cr();$rec.nextPutAll_(unescape("*/"));$rec.cr();return $rec.cr();})(stream);
allClasses=self.classes().select_((function(each){return (nil.isNil_(each.superclass()));})).inject_into_(smalltalk.Array.$$new(), (function(total,each){return total._comma(each.withAllSubclasses());})).collect_((function(each){return each.aboutToSaveImage_on_(self, stream);})).select_((function(each){return (nil.isNil_(each)===false);}));
exporter=smalltalk.Exporter.$$new();
(function($rec){$rec.cr();$rec.nextPutAll_(unescape("//%20Smalltalk%20Classes."));return $rec.cr();})(stream);
exporter.exportClasses_on_(allClasses, stream);
(function($rec){$rec.cr();return $rec.nextPutAll_(unescape("//%20Smalltalk%20Globals%20set-up."));})(stream);
self.globalsDo_((function(key){return (function($rec){$rec.cr();return $rec.nextPutAll_("smalltalk."._comma(key)._comma(unescape("%3D"))._comma(exporter.exportObject_(((function(){var $1$=self[key];if(nil.isNil_($1$))return nil;return $1$;})())))._comma(unescape("%3B")));})(stream);}));
allClasses.do_((function(each){return each.imageSaved_on_(self, stream);}));return self;}
,"Snapshot-writing",unescape("saveImageOn%3A%20stream%0D%0A%09%22%20Dump%20the%20receiver%27s%20contents%20onto%20stream.%20%22%0D%0A%0D%0A%09%7C%20exporter%20allClasses%20%7C%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20%27/*%27%3Bcr%3B%0D%0A%09%09nextPutAll%3A%20self%20licenseTerms%3Bcr%3B%0D%0A%09%09nextPutAll%3A%20%27*/%27%3Bcr%3B%0D%0A%09%09cr.%0D%0A%09allClasses%20%3A%3D%20%28%28%28self%20classes%0D%0A%09%09select%3A%20%5B%3Aeach%7C%20each%20superclass%20isNil%20%5D%29%0D%0A%09%09inject%3A%20Array%20new%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2C%20each%20withAllSubclasses%20%5D%29%0D%0A%09%09collect%3A%20%5B%3Aeach%7C%20each%20aboutToSaveImage%3A%20self%20on%3A%20stream%20%5D%29%0D%0A%09%09select%3A%20%5B%3Aeach%7C%20each%20notNil%20%5D.%0D%0A%09exporter%20%3A%3D%20Exporter%20new.%0D%0A%22%09stream%20nextPutAll%3A%20%27//%20Smalltalk%20Globals%20%28pre%29definition.%27%3B%20cr.%0D%0A%09self%0D%0A%09%09globalsDo%3A%20%5B%3Akey%7C%20stream%20nextPutAll%3A%20%27smalltalk.%27%2Ckey%20%5D%0D%0A%09%09separatedBy%3A%20%5B%20stream%20nextPutAll%3A%20%27%20%2C%20%27%20%5D.%0D%0A%09stream%20nextPutAll%3A%20%27%3Dnil%3B%27%3B%20cr.%0D%0A%22%09stream%20cr%3B%20nextPutAll%3A%20%27//%20Smalltalk%20Classes.%27%3B%20cr.%0D%0A%09exporter%20exportClasses%3A%20allClasses%20on%3A%20stream.%0D%0A%09stream%20cr%3B%20nextPutAll%3A%20%27//%20Smalltalk%20Globals%20set-up.%27.%0D%0A%09self%20globalsDo%3A%20%5B%3Akey%7C%0D%0A%09%09stream%20cr%3B%20nextPutAll%3A%20%27smalltalk.%27%2Ckey%2C%27%3D%27%0D%0A%09%09%09%2C%28exporter%20exportObject%3A%20%28self%20basicAt%3A%20key%29%29%0D%0A%09%09%09%2C%27%3B%27%0D%0A%09%5D.%0D%0A%09allClasses%20do%3A%20%5B%3Aeach%7C%20each%20imageSaved%3A%20self%20on%3A%20stream%20%5D."));
smalltalk.bind(smalltalk.Smalltalk,"imageContents",0
,function (){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.saveImageOn_(stream);
return stream.contents();;return self;}
,"Snapshot-contents",unescape("imageContents%0D%0A%09%22%20Return%20a%20dump%20of%20the%20system%20contents.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20saveImageOn%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Smalltalk,"snapshot",0
,function (){var self=this;return smalltalk.Snapshot.contents();;return self;}
,"Snapshot-contents",unescape("snapshot%0D%0A%09%22%20Return%20a%20system%20snapshot.%20%22%0D%0A%0D%0A%09%5ESnapshot%20contents"));
smalltalk.bind(smalltalk.Smalltalk,"imageFileName",0
,function (){var self=this;return ((function(){var $1$=self["$imageFileName"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"Snapshot-fileName",unescape("imageFileName%0D%0A%09%22%20Return%20the%20image%20file%20name.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24imageFileName%27"));
smalltalk.bind(smalltalk.Smalltalk,"imageFileName:",0
,function (fileName){var self=this;return (self["$imageFileName"]=(fileName));;return self;}
,"Snapshot-fileName",unescape("imageFileName%3A%20fileName%0D%0A%09%22%20Set%20the%20image%20file%20name.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24imageFileName%27%20put%3A%20fileName"));
smalltalk.bind(smalltalk.Smalltalk,"saveImage",0
,function (){var self=this;self.saveImageAs_(self.imageFileName());return self;}
,"Snapshot-save",unescape("saveImage%0D%0A%09%22%20Dump%20the%20image%20contents%20onto%20default%20image%20file.%20%22%0D%0A%0D%0A%09self%20saveImageAs%3A%20self%20imageFileName"));
smalltalk.bind(smalltalk.Smalltalk,"saveImageAs:",0
,function (fileName){var self=this;self.imageContents().outputToFile_(fileName);
self.imageFileName_(fileName);return self;}
,"Snapshot-save",unescape("saveImageAs%3A%20fileName%0D%0A%09%22%20Dump%20the%20image%20contents%20onto%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09self%20imageContents%20outputToFile%3A%20fileName.%0D%0A%09self%20imageFileName%3A%20fileName."));
smalltalk.bind(smalltalk.Smalltalk,"launch",0
,function (){var self=this;self.classes().do_((function(each){return each.launch();}));
return smalltalk.Smalltalk.at_ifAbsent_("LaunchExpression", (function(){return nil;})).evaluate();;return self;}
,"Snapshot-startup",unescape("launch%0D%0A%09%22%20The%20system%20has%20been%20launched%20and%20start%20execution.%0D%0A%09The%20default%20action%20is%20to%20propagate%20%23launch%20to%20current%20classes%20and%20evaluate%20%23LaunchExpression.%0D%0A%09%22%0D%0A%0D%0A%09self%20classes%20do%3A%20%5B%3Aeach%7C%20each%20launch%20%5D.%0D%0A%09%5E%28Smalltalk%20at%3A%20%23LaunchExpression%20ifAbsent%3A%20%5B%5D%29%20evaluate"));
smalltalk.bind(smalltalk.Behavior,"new","$$new"
,function (){var self=this;return self.basicNew().initialize();;return self;}
,"instantiation",unescape("new%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20initialize"));
smalltalk.bind(smalltalk.Behavior,"new:",0
,function (size){var self=this;return self.basicNew_(size);;return self;}
,"instantiation",unescape("new%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%3A%20size"));
smalltalk.bind(smalltalk.Behavior,"basicNew:",0
,function (size){var self=this;return self.invalidMessage_("basicNew:");;return self;}
,"instantiation",unescape("basicNew%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%09%5Eself%20invalidMessage%3A%20%23basicNew%3A"));
smalltalk.bind(smalltalk.Behavior,"basicNew",0
,function (){var self=this;	return new self.$fn();return self;}
,"instantiation",unescape("basicNew%0D%0A%09%22%20Return%20a%20new%20%28non-initialized%29%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20new%20self.%24fn%28%29%27%7D"));
smalltalk.bind(smalltalk.Behavior,"name",0
,function (){var self=this;return ((function(){var $1$=self["$className"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("name%0D%0A%09%22%20Return%20the%20name%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24className%27"));
smalltalk.bind(smalltalk.Behavior,"superclass",0
,function (){var self=this;return ((function(){var $1$=self["$superclass"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("superclass%0D%0A%09%22%20Return%20the%20superclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24superclass%27"));
smalltalk.bind(smalltalk.Behavior,"subclasses",0
,function (){var self=this;return self.smalltalk().subclasses(self);;return self;}
,"accessing",unescape("subclasses%0D%0A%09%22%20Return%20the%20subclasses%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20%23subclasses%3A%20self"));
smalltalk.bind(smalltalk.Behavior,"allSubclasses",0
,function (){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.allSubclassesDo_((function(each){return result.add_(each);}));
return result;;return self;}
,"testing",unescape("allSubclasses%0D%0A%09%22%20Return%20all%20the%20subclasses%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20allSubclassesDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"allSubclassesDo:",0
,function (aBlock){var self=this;self.smalltalk().allSubclassesDo(self, aBlock);return self;}
,"testing",unescape("allSubclassesDo%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20with%20all%20the%20subclasses%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20smalltalk%20%23allSubclassesDo%3A%20self%20value%3A%20aBlock"));
smalltalk.bind(smalltalk.Behavior,"withAllSubclassesDo:",0
,function (aBlock){var self=this;aBlock.value_(self);
self.allSubclassesDo_(aBlock);return self;}
,"testing",unescape("withAllSubclassesDo%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20with%20the%20receiver%20and%20all%20the%20subclasses.%20%22%0D%0A%0D%0A%09aBlock%20value%3A%20self.%0D%0A%09self%20allSubclassesDo%3A%20aBlock"));
smalltalk.bind(smalltalk.Behavior,"withAllSubclasses",0
,function (){var self=this;var result=nil;result=smalltalk.Array.with_(self);
self.allSubclassesDo_((function(each){return result.add_(each);}));
return result;;return self;}
,"accessing",unescape("withAllSubclasses%0D%0A%09%22%20Return%20a%20collection%20with%20the%20receiver%20and%20all%20subclasses.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20with%3A%20self.%0D%0A%09self%20allSubclassesDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"allSuperclassesDo:",0
,function (aBlock){var self=this;var current=nil;current=self.superclass();
(function(){while((function(){return (nil.isNil_(current)===false);})()){(function(){aBlock.value_(current);return current=current.superclass();})()};return nil})();return self;}
,"accessing",unescape("allSuperclassesDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20superclasses%20of%20the%20receiver.%0D%0A%09The%20superclasses%20are%20walked%20in%20inverse%20hierarchical%20order%2C%20i.e%20class%20Object%20is%20last.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20current%20%7C%0D%0A%09current%20%3A%3D%20self%20superclass.%0D%0A%09%5B%20current%20notNil%20%5D%20whileTrue%3A%20%5B%0D%0A%09%20%20%20%20%20%20%20%20aBlock%20value%3A%20current.%0D%0A%09%09current%20%3A%3D%20current%20superclass.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"withAllSuperclassesDo:",0
,function (aBlock){var self=this;aBlock.value_(self);
return self.allSuperclassesDo_(aBlock);;return self;}
,"accessing",unescape("withAllSuperclassesDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20receiver%20and%20it%27s%20superclasses.%0D%0A%09The%20superclasses%20are%20walked%20in%20inverse%20hierarchical%20order%2C%20i.e%20class%20Object%20is%20last.%0D%0A%09%22%0D%0A%0D%0A%09aBlock%20value%3A%20self.%0D%0A%09%5Eself%20allSuperclassesDo%3A%20aBlock"));
smalltalk.bind(smalltalk.Behavior,"withAllSuperclasses",0
,function (){var self=this;return smalltalk.Array.with_(self)._comma(self.allSuperclasses());;return self;}
,"accessing",unescape("withAllSuperclasses%0D%0A%09%22%20Return%20a%20collection%20with%20the%20receiver%20and%20all%20superclasses.%20%22%0D%0A%0D%0A%09%5E%28Array%20with%3A%20self%29%20%2C%20self%20allSuperclasses"));
smalltalk.bind(smalltalk.Behavior,"allSuperclasses",0
,function (){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.allSuperclassesDo_((function(each){return result.add_(each);}));
return result;;return self;}
,"accessing",unescape("allSuperclasses%0D%0A%09%22%20Return%20a%20collection%20of%20all%20the%20superclasses%20of%20the%20receiver.%0D%0A%09The%20superclasses%20are%20in%20inverse%20hierarchical%20order%2C%20i.e%20class%20Object%20is%20last.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20allSuperclassesDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"inheritsFrom:",0
,function (aClass){var $s8Ret$={name:"stReturn"};try{var self=this;(((self === aClass)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
self.allSuperclassesDo_((function(each){return (((aClass === each)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("inheritsFrom%3A%20aClass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20inherits%20from%20aClass.%20%22%0D%0A%0D%0A%09self%20%3D%3D%20aClass%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09self%20allSuperclassesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09aClass%20%3D%3D%20each%20ifTrue%3A%20%5B%20%5Etrue%20%5D%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Behavior,"prototype",0
,function (){var self=this;return ((function(){var $1$=self.$fn["prototype"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("prototype%0D%0A%09%22%20Return%20the%20prototype%20of%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%5B%27%24fn%27%5D%20basicAt%3A%20%23prototype"));
smalltalk.bind(smalltalk.Behavior,"constructorName",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;var fn=nil;fn=self.$fn;
result=((function(){var $1$=fn["name"];if(nil.isNil_($1$))return nil;return $1$;})());
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){((result.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);((result._eq("$s8Constructor")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
result=fn.toString().upTo_(unescape("%28")).asArrayOfSubstrings();
((result.size()._eq((2))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return result.last();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("constructorName%0D%0A%09%22%20Return%20the%20name%20of%20the%20constructor%20of%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20result%20fn%20%7C%0D%0A%09fn%20%3A%3D%20self%5B%27%24fn%27%5D.%0D%0A%09result%20%3A%3D%20fn%20basicAt%3A%20%23name.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09result%20isEmpty%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%09result%20%3D%20%27%24s8Constructor%27%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%09%5Eresult%0D%0A%09%5D.%0D%0A%09result%20%3A%3D%20%28fn%20toString%20upTo%3A%20%24%28%29%20asArrayOfSubstrings.%0D%0A%09result%20size%20%3D%202%20ifFalse%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5Eresult%20last"));
smalltalk.bind(smalltalk.Behavior,"methodsDo:",0
,function (aBlock){var self=this;	var methods = self.$fn.prototype.$methods;
	for(var i in methods) {
		if (!methods.hasOwnProperty(i)) break;
		aBlock(methods[i]);
	}; ;return self;}
,"accessing",unescape("methodsDo%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20for%20all%20the%20methods%20defined%20by%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09var%20methods%20%3D%20self.%24fn.prototype.%24methods%3B%0D%0A%09for%28var%20i%20in%20methods%29%20%7B%0D%0A%09%09if%20%28%21methods.hasOwnProperty%28i%29%29%20break%3B%0D%0A%09%09aBlock%28methods%5Bi%5D%29%3B%0D%0A%09%7D%3B%20%27%7D"));
smalltalk.bind(smalltalk.Behavior,"selectorsDo:",0
,function (aBlock){var self=this;	var methods = self.$fn.prototype.$methods;
	for(var i in methods) {
		if (!methods.hasOwnProperty(i)) break;
		aBlock(methods[i].$selector);
	}; ;return self;}
,"accessing",unescape("selectorsDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20all%20the%20selectors%20implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09var%20methods%20%3D%20self.%24fn.prototype.%24methods%3B%0D%0A%09for%28var%20i%20in%20methods%29%20%7B%0D%0A%09%09if%20%28%21methods.hasOwnProperty%28i%29%29%20break%3B%0D%0A%09%09aBlock%28methods%5Bi%5D.%24selector%29%3B%0D%0A%09%7D%3B%20%27%7D"));
smalltalk.bind(smalltalk.Behavior,"methodDictionary",0
,function (){var self=this;var result=nil;result=smalltalk.PoolDictionary.$$new();
self.methodsDo_((function(each){return result.at_put_(each.selector(), each);}));
return result;;return self;}
,"accessing",unescape("methodDictionary%0D%0A%09%22%20Return%20a%20dictionary%20with%20the%20methods%20implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20PoolDictionary%20new.%0D%0A%09self%20methodsDo%3A%20%5B%3Aeach%7C%20result%20at%3A%20each%20selector%20put%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"selectors",0
,function (){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.selectorsDo_((function(each){return result.add_(each);}));
return result;;return self;}
,"accessing",unescape("selectors%0D%0A%09%22%20Return%20the%20selectors%20implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20selectorsDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"implements:",0
,function (aSymbol){var self=this;	return (aSymbol in self.$fn.prototype.$methods); ;return self;}
,"testing",unescape("implements%3A%20aSymbol%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20implements%20message%20aSymbol.%20%22%0D%0A%0D%0A%7B%27%09return%20%28aSymbol%20in%20self.%24fn.prototype.%24methods%29%3B%20%27%7D"));
smalltalk.bind(smalltalk.Behavior,"compiledMethodAt:",0
,function (aSymbol){var self=this;	return self.$fn.prototype.$methods[aSymbol] || nil; ;return self;}
,"accessing",unescape("compiledMethodAt%3A%20aSymbol%0D%0A%09%22%20Return%20the%20compiled%20method%20at%20aSymbol%20implemented%20by%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%7B%27%09return%20self.%24fn.prototype.%24methods%5BaSymbol%5D%20%7C%7C%20nil%3B%20%27%7D"));
smalltalk.bind(smalltalk.Behavior,">>","_gt_gt"
,function (aSymbol){var self=this;return self.compiledMethodAt_(aSymbol);;return self;}
,"accessing",unescape("%3E%3E%20aSymbol%0D%0A%09%22%20Return%20the%20method%20at%20aSymbol%20%28or%20nil%20if%20not%20implemented%20by%20the%20receiver%29.%20%22%0D%0A%0D%0A%09%5Eself%20compiledMethodAt%3A%20aSymbol"));
smalltalk.bind(smalltalk.Behavior,">>>","_gt_gt_gt"
,function (aSymbol){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=self.compiledMethodAt_(aSymbol);
(((nil.isNil_(result)).and_((function(){return (nil.isNil_(self.superclass())===false);}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.superclass()._gt_gt_gt(aSymbol);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("%3E%3E%3E%20aSymbol%0D%0A%09%22%20Return%20the%20method%20at%20aSymbol%20searching%20up%20in%20receiver%27s%20hierarchy%20%28or%20nil%20if%20not%20implemented%20by%20the%20receiver%20nor%20its%20superclasses%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20compiledMethodAt%3A%20aSymbol.%0D%0A%09%28result%20isNil%20and%3A%20%5Bself%20superclass%20notNil%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20superclass%20%3E%3E%3E%20aSymbol%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"instVarNames",0
,function (){var self=this;return ((function(){var $1$=self["$iVarNames"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("instVarNames%0D%0A%09%22%20Return%20the%20instance%20variable%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24iVarNames%27"));
smalltalk.bind(smalltalk.Behavior,"allInstVarNames",0
,function (){var self=this;var result=nil;result=self.instVarNames();
self.allSuperclassesDo_((function(each){return result=each.instVarNames()._comma(result);}));
return result;;return self;}
,"accessing",unescape("allInstVarNames%0D%0A%09%22%20Return%20all%20of%20the%20instance%20variable%20names%20defined%20in%20the%20receiver%20and%20its%20superclasses.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20instVarNames.%0D%0A%09self%20allSuperclassesDo%3A%20%5B%20%3Aeach%20%7C%20result%20%3A%3D%20each%20instVarNames%20%2C%20result%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"instanceVariableNames",0
,function (){var self=this;return ((function(){var $1$=self["$iVarNames"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("instanceVariableNames%0D%0A%09%22%20Return%20the%20instance%20variable%20names%20defined%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24iVarNames%27"));
smalltalk.bind(smalltalk.Behavior,"propertyNames",0
,function (){var self=this;return ((function(){var $1$=self["$propertyNames"];if(nil.isNil_($1$))return ((function(){return smalltalk.Array.$$new();}).value());return $1$;})());;return self;}
,"accessing",unescape("propertyNames%0D%0A%09%22%20Return%20the%20property%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24propertyNames%27%20ifAbsent%3A%20%5B%20Array%20new%20%5D"));
smalltalk.bind(smalltalk.Behavior,"propertyNames:",0
,function (anArray){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(anArray))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.basicDelete_("$propertyNames");})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return (self["$propertyNames"]=(anArray));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("propertyNames%3A%20anArray%0D%0A%09%22%20Set%20the%20property%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09anArray%20isNil%20ifTrue%3A%20%5B%20%5Eself%20basicDelete%3A%20%27%24propertyNames%27%20%5D.%0D%0A%09%5Eself%20basicAt%3A%20%27%24propertyNames%27%20put%3A%20anArray"));
smalltalk.bind(smalltalk.Behavior,"allPropertyNamesDo:",0
,function (aBlock){var self=this;self.propertyNames().do_(aBlock);
self.allSuperclassesDo_((function(each){return each.propertyNames().do_(aBlock);}));return self;}
,"accessing",unescape("allPropertyNamesDo%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20for%20the%20property%20names%20defined%20in%20the%20receiver%20and%20its%20superclasses.%20%22%0D%0A%0D%0A%09self%20propertyNames%20do%3A%20aBlock.%0D%0A%09self%20allSuperclassesDo%3A%20%5B%20%3Aeach%20%7C%20each%20propertyNames%20do%3A%20aBlock%20%5D."));
smalltalk.bind(smalltalk.Behavior,"allInstVarNamesDo:",0
,function (aBlock){var self=this;self.instVarNames().do_(aBlock);
self.allSuperclassesDo_((function(each){return each.instVarNames().do_(aBlock);}));return self;}
,"accessing",unescape("allInstVarNamesDo%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20for%20the%20instance%20variable%20names%20defined%20in%20the%20receiver%20and%20its%20superclasses.%20%22%0D%0A%0D%0A%09self%20instVarNames%20do%3A%20aBlock.%0D%0A%09self%20allSuperclassesDo%3A%20%5B%20%3Aeach%20%7C%20each%20instVarNames%20do%3A%20aBlock%20%5D."));
smalltalk.bind(smalltalk.Behavior,"comment",0
,function (){var self=this;return ((function(){var $1$=self.instanceClass()["$comment"];if(nil.isNil_($1$))return ((function(){return "";}).value());return $1$;})());;return self;}
,"accessing",unescape("comment%0D%0A%09%22%20Return%20the%20comment%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20basicAt%3A%20%27%24comment%27%20ifAbsent%3A%20%5B%20%27%27%20%5D"));
smalltalk.bind(smalltalk.Behavior,"comment:",0
,function (aString){var self=this;(self.instanceClass()["$comment"]=(aString));return self;}
,"accessing",unescape("comment%3A%20aString%0D%0A%09%22%20Set%20the%20comment%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20instanceClass%20basicAt%3A%20%27%24comment%27%20put%3A%20aString"));
smalltalk.bind(smalltalk.Behavior,"removeSources",0
,function (){var self=this;self.instanceClass().removeSources();return self;}
,"tools",unescape("removeSources%0D%0A%09%22%20Remove%20all%20development%20sources%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20instanceClass%20removeSources"));
smalltalk.bind(smalltalk.Behavior,"poolDictionaryNames",0
,function (){var self=this;return self.instanceClass().poolDictionaryNames();;return self;}
,"accessing",unescape("poolDictionaryNames%0D%0A%09%22%20Return%20the%20shared%20pool%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20poolDictionaryNames"));
smalltalk.bind(smalltalk.Behavior,"sharedPoolsAndNamesDo:",0
,function (aBlock){var self=this;var pool=nil;self.instanceClass().withAllSuperclassesDo_((function(each){return each.poolDictionaryNames().do_((function(aName){pool=smalltalk.Smalltalk.poolDictionary_ifAbsent_(aName, (function(){return nil;}));return (((nil.isNil_(pool)===false)).mustBeBoolean()==true ? (function(){return aBlock.value_value_(aName, pool);})() : nil);}));}));return self;}
,"accessing",unescape("sharedPoolsAndNamesDo%3A%20aBlock%0D%0A%09%22%20Execute%20aBlock%20for%20the%20pool%20dictionaries%20known%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20pool%20%7C%0D%0A%09self%20instanceClass%20withAllSuperclassesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20poolDictionaryNames%20do%3A%20%5B%3AaName%7C%0D%0A%09%09%09pool%20%3A%3D%20Smalltalk%20poolDictionary%3A%20aName%20ifAbsent%3A%20%5B%20nil%20%5D.%0D%0A%09%09%09pool%20notNil%20ifTrue%3A%20%5B%20aBlock%20value%3A%20aName%20value%3A%20pool%20%5D%0D%0A%09%09%5D.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"sharedPoolsDo:",0
,function (aBlock){var self=this;self.sharedPoolsAndNamesDo_((function(aName,aPool){return aBlock.value_(aPool);}));return self;}
,"accessing",unescape("sharedPoolsDo%3A%20aBlock%0D%0A%09%22%20Execute%20aBlock%20for%20the%20pool%20dictionaries%20known%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20sharedPoolsAndNamesDo%3A%20%5B%3AaName%20%3AaPool%7C%20aBlock%20value%3A%20aPool%20%5D"));
smalltalk.bind(smalltalk.Behavior,"classVariablesDo:",0
,function (aBlock){var self=this;var bindings=nil;return self.instanceClass().withAllSuperclassesDo_((function(each){bindings=each.classVariables();return (((nil.isNil_(bindings)===false)).mustBeBoolean()==true ? (function(){return bindings.associationsDo_((function(assoc){return aBlock.value_(assoc);}));})() : nil);}));;return self;}
,"accessing",unescape("classVariablesDo%3A%20aBlock%0D%0A%09%22%20Execute%20aBlock%20for%20the%20classVariables%20bindings%20known%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20bindings%20%7C%0D%0A%09%5Eself%20instanceClass%20withAllSuperclassesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09bindings%20%3A%3D%20each%20classVariables.%0D%0A%09%09bindings%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09bindings%20associationsDo%3A%20%5B%3Aassoc%7C%20aBlock%20value%3A%20assoc%20%5D%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"classVariableNamesDo:",0
,function (aBlock){var self=this;var bindings=nil;return self.instanceClass().withAllSuperclassesDo_((function(each){bindings=each.classVariables();return (((nil.isNil_(bindings)===false)).mustBeBoolean()==true ? (function(){return bindings.keysDo_((function(aName){return aBlock.value_(aName);}));})() : nil);}));;return self;}
,"accessing",unescape("classVariableNamesDo%3A%20aBlock%0D%0A%09%22%20Execute%20aBlock%20for%20the%20classVariable%20names%20known%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20bindings%20%7C%0D%0A%09%5Eself%20instanceClass%20withAllSuperclassesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09bindings%20%3A%3D%20each%20classVariables.%0D%0A%09%09bindings%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09bindings%20keysDo%3A%20%5B%3AaName%7C%20aBlock%20value%3A%20aName%20%5D%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"classVariableAt:put:",0
,function (aName,anObject){var self=this;return self.instanceClass().classVariables().at_put_(aName, anObject);;return self;}
,"accessing",unescape("classVariableAt%3A%20aName%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20classVariable%20of%20the%20receiver%20to%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20classVariables%20at%3A%20aName%20put%3A%20anObject"));
smalltalk.bind(smalltalk.Behavior,"classVariableAt:ifAbsent:",0
,function (aName,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var bindings=nil;self.instanceClass().withAllSuperclassesDo_((function(each){bindings=each.classVariables();return (((nil.isNil_(bindings)===false)).mustBeBoolean()==true ? (function(){return ((bindings.includesKey_(aName)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return bindings.at_(aName);})();throw($s8Ret$)})();})() : nil);})() : nil);}));
(function(){$s8Ret$.result=(function(){return aBlock.evaluate();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("classVariableAt%3A%20aName%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20of%20classVariable%20named%20aName.%20%22%0D%0A%0D%0A%09%7C%20bindings%20%7C%0D%0A%09self%20instanceClass%20withAllSuperclassesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09bindings%20%3A%3D%20each%20classVariables.%0D%0A%09%09bindings%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09%28bindings%20includesKey%3A%20aName%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%5Ebindings%20at%3A%20aName%0D%0A%09%09%09%5D%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5EaBlock%20evaluate"));
smalltalk.bind(smalltalk.Behavior,"classVariableAt:",0
,function (aName){var self=this;return self.classVariableAt_ifAbsent_(aName, (function(){return self.error_("Undefined class variable "._comma(aName)._comma(" in ")._comma(self.name()));}));;return self;}
,"accessing",unescape("classVariableAt%3A%20aName%0D%0A%09%22%20Return%20the%20value%20of%20classVariable%20named%20aName%20or%20generates%20an%20error.%20%22%0D%0A%0D%0A%09%5Eself%20classVariableAt%3A%20aName%20ifAbsent%3A%20%5B%0D%0A%09%09self%20error%3A%20%27Undefined%20class%20variable%20%27%2CaName%20%2C%27%20in%20%27%20%2Cself%20name%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"pool:variableAt:put:",0
,function (poolName,aName,anObject){var $s8Ret$={name:"stReturn"};try{var self=this;var pool=nil;pool=smalltalk.Smalltalk.poolDictionary_ifAbsent_(poolName, (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Undefined pool variable "._comma(poolName)._comma(" in ")._comma(self.name()));})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return pool.at_put_(aName, anObject);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("pool%3A%20poolName%20variableAt%3A%20aName%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20pool%20Variable%20of%20the%20receiver%20to%20anObject.%20%22%0D%0A%0D%0A%09%7C%20pool%20%7C%0D%0A%09pool%20%3A%3D%20Smalltalk%0D%0A%09%09poolDictionary%3A%20poolName%0D%0A%09%09ifAbsent%3A%20%5B%20%5Eself%20error%3A%20%27Undefined%20pool%20variable%20%27%2CpoolName%20%2C%27%20in%20%27%20%2Cself%20name%20%5D.%0D%0A%09%5Epool%20at%3A%20aName%20put%3A%20anObject"));
smalltalk.bind(smalltalk.Behavior,"loadRequirementsInto:",0
,function (aCollection){var self=this;return self;;return self;}
,"loading",unescape("loadRequirementsInto%3A%20aCollection%0D%0A%09%22%20Add%20the%20requirements%20to%20load%20the%20receiver%20from%20sources%20to%20aCollection.%0D%0A%09Default%20action%20do%20nothing%2C%20this%20method%20can%20be%20refined%20by%20the%20subclasses.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Behavior,"removeSelectors:",0
,function (aCollection){var self=this;aCollection.do_((function(each){return self.removeSelector_(each);}));return self;}
,"methods",unescape("removeSelectors%3A%20aCollection%0D%0A%09%22%20Remove%20the%20methods%20for%20messages%20in%20aCollection%2C%20implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09aCollection%20do%3A%20%5B%3Aeach%7C%20self%20removeSelector%3A%20each%20%5D"));
smalltalk.bind(smalltalk.Behavior,"removeCompiledMethod:",0
,function (aMethod){var self=this;self.smalltalk().removeMethod(self, aMethod);return self;}
,"private",unescape("removeCompiledMethod%3A%20aMethod%0D%0A%09%22%20Remove%20aMethod%20from%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20smalltalk%20%23removeMethod%3A%20self%20method%3A%20aMethod"));
smalltalk.bind(smalltalk.Behavior,"missingImplementorFor:",0
,function (jsSelector){var self=this;return self.error_("Missing implementor for "._comma(jsSelector.asStSelector().asLiteral())._comma(" in ")._comma(self.name()));;return self;}
,"private",unescape("missingImplementorFor%3A%20jsSelector%0D%0A%09%22%20Private%20-%20Handle%20the%20situation%20where%20there%20is%20no%20implementor%20for%20jsSelector.%0D%0A%09This%20can%20happen%20when%20there%20is%20no%20implementation%20for%20jsSelector%20and%20the%20message%0D%0A%09%20has%20been%20dispatched%20through%20a%20superSend.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Missing%20implementor%20for%20%27%0D%0A%09%09%2C%20jsSelector%20asStSelector%20asLiteral%0D%0A%09%09%2C%27%20in%20%27%2Cself%20name"));
smalltalk.bind(smalltalk.Behavior,"removeSelector:",0
,function (aSelector){var self=this;var method=nil;method=self.compiledMethodAt_(aSelector);
(((nil.isNil_(method)===false)).mustBeBoolean()==true ? (function(){return self.removeCompiledMethod_(method);})() : nil);return self;}
,"methods",unescape("removeSelector%3A%20aSelector%0D%0A%09%22%20Remove%20the%20method%20for%20message%20aSelector%20implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20method%20%7C%0D%0A%09method%20%3A%3D%20self%20compiledMethodAt%3A%20aSelector.%0D%0A%09method%20notNil%20ifTrue%3A%20%5B%20self%20removeCompiledMethod%3A%20method%20%5D."));
smalltalk.bind(smalltalk.Behavior,"removeFromSystem",0
,function (){var self=this;self.instanceClass().removeFromSystem();return self;}
,"remove",unescape("removeFromSystem%0D%0A%09%22%20Remove%20the%20receiver%20from%20system.%20%22%0D%0A%0D%0A%09self%20instanceClass%20removeFromSystem"));
smalltalk.bind(smalltalk.Behavior,"implementorsOf:",0
,function (aSymbol){var self=this;var result=nil;var method=nil;result=smalltalk.Array.$$new();
self.withAllSubclassesDo_((function(each){method=each._gt_gt(aSymbol);(((nil.isNil_(method)===false)).mustBeBoolean()==true ? (function(){return result.add_(method);})() : nil);method=each.$klass._gt_gt(aSymbol);return (((nil.isNil_(method)===false)).mustBeBoolean()==true ? (function(){return result.add_(method);})() : nil);}));
return result;;return self;}
,"testing",unescape("implementorsOf%3A%20aSymbol%0D%0A%09%22%20Return%20a%20collection%20of%20methods%20of%20the%20receiver%20and%20its%20subclasses%20that%20implement%20aSymbol.%20%22%0D%0A%0D%0A%09%7C%20result%20method%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20withAllSubclassesDo%3A%20%5B%3Aeach%20%7C%0D%0A%09%09method%20%3A%3D%20each%20%3E%3E%20aSymbol.%0D%0A%09%09method%20notNil%20ifTrue%3A%20%5B%20result%20add%3A%20method%20%5D.%0D%0A%09%09method%20%3A%3D%20each%20class%20%3E%3E%20aSymbol.%0D%0A%09%09method%20notNil%20ifTrue%3A%20%5B%20result%20add%3A%20method%20%5D.%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Behavior,"asJSONObject",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Behavior,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Behavior,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Behavior,"toString",0
,function (){var self=this;return unescape("%7Bst%3A")._comma(self.name())._comma(unescape("%7D"));;return self;}
,"converting",unescape("toString%0D%0A%09%22%20Convert%20the%20receiver%20to%20a%20String.%20%22%0D%0A%0D%0A%09%5E%27%7Bst%3A%27%2Cself%20name%2C%24%7D"));
smalltalk.bind(smalltalk.Behavior,"basicAddCompiledMethod:",0
,function (aMethod){var self=this;smalltalk.APIBuilder.register_(aMethod);
smalltalk.addMethod(aMethod.selector().asSelector(), aMethod, self);return self;}
,"Builders-private",unescape("basicAddCompiledMethod%3A%20aMethod%0D%0A%09%22%20Private%20-%20Effectivelly%20add%20aMethod%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09APIBuilder%20register%3A%20aMethod.%0D%0A%09%23%7Bsmalltalk%7D%20%23addMethod%3A%20aMethod%20selector%20asSelector%20method%3A%20aMethod%20to%3A%20self"));
smalltalk.bind(smalltalk.Behavior,"addCompiledMethod:",0
,function (aMethod){var $s8Ret$={name:"stReturn"};try{var self=this;var isDoIt=nil;isDoIt=aMethod.selector()._eq(smalltalk.String.doItSelector());
(((nil.isNil_(smalltalk.OverwriteMethods)===false).and_((function(){return smalltalk.OverwriteMethods;}))).mustBeBoolean()==true ? nil : (function(){return ((self.implements_(aMethod.selector())).mustBeBoolean()==true ? (function(){return ((isDoIt).mustBeBoolean()==true ? nil : (function(){(((nil.isNil_(smalltalk.DumpOverwritenMethods)===false).and_((function(){return smalltalk.DumpOverwritenMethods.and_((function(){return (nil.isNil_(smalltalk.Exporter)===false);}));}))).mustBeBoolean()==true ? (function(){self.print_(unescape("//%3F%20")._comma(self.name())._comma(unescape("%3E%3E%23"))._comma(aMethod.selector()));return self.print_(smalltalk.Exporter.$$new().export_method_(self, aMethod));})() : (function(){return self.print_(unescape("//-Overwrite%20Conflict-%20")._comma(self.name())._comma(unescape("%3E%3E%23"))._comma(aMethod.selector()));})());return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})());})() : nil);})());
(((nil.isNil_(smalltalk.Exporter)===false).and_((function(){return isDoIt.not();}))).mustBeBoolean()==true ? (function(){return self.print_(smalltalk.Exporter.$$new().export_method_(self, aMethod));})() : nil);
(function(){$s8Ret$.result=(function(){return self.basicAddCompiledMethod_(aMethod);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"methods",unescape("addCompiledMethod%3A%20aMethod%0D%0A%09%22%20Add%20the%20compiled%20method%2C%20if%20appropiate%2C%20and%20register%20the%20method%20in%20recent%20methods.%20%22%0D%0A%0D%0A%09%7C%20isDoIt%20%7C%0D%0A%09isDoIt%20%3A%3D%20aMethod%20selector%20%3D%20String%20doItSelector.%0D%0A%09%28OverwriteMethods%20notNil%20and%3A%20%5B%09OverwriteMethods%20%5D%29%20ifFalse%3A%20%5B%0D%0A%09%09%28self%20implements%3A%20aMethod%20selector%29%20ifTrue%3A%20%5B%0D%0A%09%09%09isDoIt%20ifFalse%3A%20%5B%0D%0A%09%09%09%09%28DumpOverwritenMethods%20notNil%0D%0A%09%09%09%09and%3A%20%5B%20DumpOverwritenMethods%0D%0A%09%09%09%09and%3A%20%5B%20Exporter%20notNil%20%5D%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%09self%20print%3A%20%27//%3F%20%27%2Cself%20name%2C%27%3E%3E%23%27%2CaMethod%20selector.%0D%0A%09%09%09%09%09self%20print%3A%20%28Exporter%20new%20export%3A%20self%20method%3A%20aMethod%29.%0D%0A%09%09%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09%09%09self%20print%3A%20%27//-Overwrite%20Conflict-%20%27%2Cself%20name%2C%27%3E%3E%23%27%2CaMethod%20selector.%0D%0A%09%09%09%09%5D.%0D%0A%09%09%09%09%5Eself%0D%0A%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%28Exporter%20notNil%20and%3A%20%5B%20isDoIt%20not%20%5D%29%20ifTrue%3A%20%5B%0D%0A%22%20DEBUG%20-%09self%20print%3A%20%27//%20%27%2Cself%20name%2C%27%3E%3E%23%27%2CaMethod%20selector.%22%0D%0A%09%09self%20print%3A%20%28Exporter%20new%20export%3A%20self%20method%3A%20aMethod%29.%0D%0A%09%5D.%0D%0A%09%5Eself%20basicAddCompiledMethod%3A%20aMethod"));
smalltalk.bind(smalltalk.Behavior,"codeFor:accessing:",0
,function (aCompiler,aNode){var $s8Ret$={name:"stReturn"};try{var self=this;var aName=nil;aName=aNode.value();
self.allInstVarNamesDo_((function(each){return ((aName._eq(each)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aCompiler.codeToAccessInstanceVariable_(aName);})();throw($s8Ret$)})();})() : nil);}));
self.allPropertyNamesDo_((function(each){return ((aName._eq(each)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aCompiler.codeToAccessProperty_(aName);})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Compiler-generation",unescape("codeFor%3A%20aCompiler%20accessing%3A%20aNode%0D%0A%09%22%20Return%20the%20code%20to%20access%20variable%20in%20aNode%20%28aVariableNode%29.%0D%0A%09Return%20nil%20if%20the%20code%20to%20access%20variable%20can%uFFFDt%20be%20generated.%0D%0A%09The%20default%20implementation%20return%20code%20to%20access%20instance%20variables.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20aName%20%7C%0D%0A%09aName%20%3A%3D%20aNode%20value.%0D%0A%09self%20allInstVarNamesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09aName%20%3D%20each%20ifTrue%3A%20%5B%0D%0A%09%09%09%5EaCompiler%20codeToAccessInstanceVariable%3A%20aName%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09self%20allPropertyNamesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09aName%20%3D%20each%20ifTrue%3A%20%5B%0D%0A%09%09%09%5EaCompiler%20codeToAccessProperty%3A%20aName%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Enil"));
smalltalk.bind(smalltalk.Behavior,"compiler",0
,function (){var self=this;return self.smalltalk().compilerSupport().for_(self);;return self;}
,"Compiler-compiling",unescape("compiler%0D%0A%09%22%20Return%20a%20compiler%20for%20receiver%27s%20source%20code.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20compilerSupport%20for%3A%20self"));
smalltalk.bind(smalltalk.Behavior,"recompile",0
,function (){var self=this;return self.compiler().recompile_(self);;return self;}
,"Compiler-compiling",unescape("recompile%0D%0A%09%22%20Recompile%20all%20the%20methods%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20compiler%20recompile%3A%20self"));
smalltalk.bind(smalltalk.Behavior,"recompileAll",0
,function (){var self=this;return self.instanceClass().withAllSubclasses().do_((function(each){return each.recompile();}));;return self;}
,"Compiler-compiling",unescape("recompileAll%0D%0A%09%22%20Recompile%20all%20the%20methods%20of%20the%20receiver%20and%20its%20subclasses.%09%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20withAllSubclasses%20do%3A%20%5B%3Aeach%7C%20each%20recompile%20%5D"));
smalltalk.bind(smalltalk.Behavior,"recompile:",0
,function (what){var $s8Ret$={name:"stReturn"};try{var self=this;((what.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.recompile_(smalltalk.Array.with_(what));})();throw($s8Ret$)})();})() : nil);
what.do_((function(selector){return self._gt_gt(selector).recompile();}));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Compiler-compiling",unescape("recompile%3A%20what%0D%0A%09%22%20Recompile%20the%20method%28s%29%20at%20selector%28s%29%20of%20the%20receiver.%09%22%0D%0A%0D%0A%09what%20isString%20ifTrue%3A%20%5B%20%5Eself%20recompile%3A%20%28Array%20with%3A%20what%29%20%5D.%0D%0A%09what%20do%3A%20%5B%3Aselector%7C%20%28self%20%3E%3E%20selector%29%20recompile%20%5D"));
smalltalk.bind(smalltalk.Behavior,"methodsFor:",0
,function (aString){var self=this;return smalltalk.ClassCategoryReader.$$new().class_category_(self, aString);;return self;}
,"Tools-fileIn",unescape("methodsFor%3A%20aString%0D%0A%09%22%20FileIn%20-%20Return%20a%20chunk%20reader%20to%20fileIn%20methods%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EClassCategoryReader%20new%20class%3A%20self%20category%3A%20aString"));
smalltalk.bind(smalltalk.Behavior,"methods",0
,function (){var self=this;return self.methodsFor_("unclassified");;return self;}
,"Tools-fileIn",unescape("methods%0D%0A%09%22%20FileIn%20-%20Return%20a%20chunk%20reader%20to%20fileIn%20methods%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20methodsFor%3A%20%23unclassified%20"));
smalltalk.bind(smalltalk.Behavior,"commentStamp",0
,function (){var self=this;return smalltalk.ClassCommentReader.$$new().class_(self);;return self;}
,"Tools-fileIn",unescape("commentStamp%0D%0A%09%22%20Return%20a%20comment%20reader%20for%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EClassCommentReader%20new%20class%3A%20self"));
smalltalk.bind(smalltalk.Behavior,"fileOut",0
,function (){var self=this;return smalltalk.Exporter.fileOut_(self.instanceClass());;return self;}
,"Tools-fileOut",unescape("fileOut%0D%0A%09%22%20Return%20fileOut%20definition%20and%20code%20of%20a%20class.%20%22%0D%0A%0D%0A%09%5EExporter%20fileOut%3A%20self%20instanceClass"));
smalltalk.bind(smalltalk.Behavior,"export","$$export"
,function (){var self=this;return smalltalk.Exporter.export_(self.instanceClass());;return self;}
,"Tools-export",unescape("export%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20definition%20and%20source%20code%20of%20a%20class.%20%22%0D%0A%0D%0A%09%5EExporter%20export%3A%20self%20instanceClass"));
smalltalk.bind(smalltalk.Behavior,"references",0
,function (){var self=this;var result=nil;result=smalltalk.PoolDictionary.$$new();
self.methodsDo_((function(mth){var refs=nil;refs=mth.references();return refs.keys().do_((function(key){return result.at_ifAbsentPut_(key, (function(){return smalltalk.Set.$$new();})).addAll_(refs.at_(key));}));}));
return result.collect_((function(each){return each.asArray();}));;return self;}
,"Tools-references",unescape("references%0D%0A%09%22%20Return%20all%20the%20references%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20PoolDictionary%20new.%0D%0A%09self%20methodsDo%3A%20%5B%3Amth%7C%20%7C%20refs%20%7C%0D%0A%09%09refs%20%3A%3D%20mth%20references.%0D%0A%09%09refs%20keys%20do%3A%20%5B%3Akey%7C%0D%0A%09%09%09%28result%20at%3A%20key%20ifAbsentPut%3A%20%5BSet%20new%5D%29%0D%0A%09%09%09%09addAll%3A%20%28refs%20at%3A%20key%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eresult%20collect%3A%20%5B%3Aeach%7C%20each%20asArray%20%5D"));
smalltalk.bind(smalltalk.Behavior,"implement:comment:as:category:",0
,function (messageHeader,aComment,sourceCode,aCategory){var self=this;var code=nil;code=unescape("%21%20")._comma(self.name())._comma((((nil.isNil_(aCategory))).mustBeBoolean()==true ? (function(){return " methods";})() : (function(){return " methodsFor: "._comma(aCategory.asLiteral());})()))._comma(unescape("%20%21%0D%0A"))._comma(messageHeader)._comma((((nil.isNil_(aComment))).mustBeBoolean()==true ? (function(){return "";})() : (function(){return unescape("%0D%0A%09%22%20")._comma(aComment)._comma(unescape("%20%22"));})()))._comma(unescape("%0D%0A%0D%0A%09"))._comma(sourceCode)._comma(unescape("%21%20%21%0D%0A%0D%0A"));
return (function($rec){$rec.fileIn();return $rec.yourself();})(code);;return self;}
,"Builders-implementing",unescape("implement%3A%20messageHeader%0D%0A%09comment%3A%20aComment%0D%0A%09as%3A%20sourceCode%0D%0A%09category%3A%20aCategory%0D%0A%09%22%20Private%20-%20Implement%20a%20method%20in%20the%20receiver.%0D%0A%09Note%3A%20sourceCode%20must%20be%20the%20source%20code%20in%20chunk%20format.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20code%20%7C%0D%0A%09code%20%3A%3D%20%27%21%20%27%2Cself%20name%2C%0D%0A%09%09%28aCategory%20isNil%0D%0A%09%09%09ifTrue%3A%20%5B%20%27%20methods%27%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20%27%20methodsFor%3A%20%27%2C%20aCategory%20asLiteral%20%5D%29%0D%0A%2C%27%20%21%0D%0A%27%2CmessageHeader%2C%20%28aComment%20isNil%20ifTrue%3A%20%5B%20%27%27%20%5D%20ifFalse%3A%20%5B%27%0D%0A%09%22%20%27%2C%20aComment%2C%20%27%20%22%27%5D%29%2C%27%0D%0A%0D%0A%09%27%2CsourceCode%20%2C%27%21%20%21%0D%0A%0D%0A%27.%09%5Ecode%20fileIn%3B%20yourself"));
smalltalk.bind(smalltalk.Behavior,"implement:comment:as:",0
,function (messageHeader,aComment,sourceCode){var self=this;return self.implement_comment_as_category_(messageHeader, aComment, sourceCode, nil);;return self;}
,"Builders-implementing",unescape("implement%3A%20messageHeader%20comment%3A%20aComment%20as%3A%20sourceCode%0D%0A%09%22%20Private%20-%20Implement%20a%20method%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09implement%3A%20messageHeader%0D%0A%09%09comment%3A%20aComment%0D%0A%09%09as%3A%20sourceCode%0D%0A%09%09category%3A%20nil"));
smalltalk.bind(smalltalk.Behavior,"implement:as:",0
,function (messageHeader,sourceCode){var self=this;return self.implement_comment_as_category_(messageHeader, nil, sourceCode, nil);;return self;}
,"Builders-implementing",unescape("implement%3A%20messageHeader%20as%3A%20sourceCode%0D%0A%09%22%20Private%20-%20Implement%20a%20method%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09implement%3A%20messageHeader%0D%0A%09%09comment%3A%20nil%0D%0A%09%09as%3A%20sourceCode%0D%0A%09%09category%3A%20nil"));
smalltalk.bind(smalltalk.Behavior,"implement:as:category:",0
,function (messageHeader,sourceCode,aCategory){var self=this;return self.implement_comment_as_category_(messageHeader, nil, sourceCode, aCategory);;return self;}
,"Builders-implementing",unescape("implement%3A%20messageHeader%20as%3A%20sourceCode%20category%3A%20aCategory%0D%0A%09%22%20Private%20-%20Implement%20a%20method%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09implement%3A%20messageHeader%0D%0A%09%09comment%3A%20nil%0D%0A%09%09as%3A%20sourceCode%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.Behavior,"class:implement:comment:as:category:",0
,function (aClass,message,aComment,sourceCode,aCategory){var $s8Ret$={name:"stReturn"};try{var self=this;((aClass.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.class_implement_comment_as_category_(aClass.evaluateIn_(nil), message, aComment, sourceCode, aCategory);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return aClass.implement_comment_as_category_(message, aComment, sourceCode, aCategory);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-implementing",unescape("class%3A%20aClass%20implement%3A%20message%0D%0A%09comment%3A%20aComment%20as%3A%20sourceCode%0D%0A%09category%3A%20aCategory%0D%0A%09%22%20Private%20-%20Implement%20a%20method%20in%20aClass.%20%22%0D%0A%0D%0A%09aClass%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%0D%0A%09%09%09class%3A%20%28aClass%20evaluateIn%3A%20nil%29%0D%0A%09%09%09implement%3A%20message%0D%0A%09%09%09comment%3A%20aComment%0D%0A%09%09%09as%3A%20sourceCode%0D%0A%09%09%09category%3A%20aCategory%0D%0A%09%5D.%0D%0A%09%5EaClass%0D%0A%09%09implement%3A%20message%0D%0A%09%09comment%3A%20aComment%0D%0A%09%09as%3A%20sourceCode%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.Behavior,"build:doing:",0
,function (token,aBlock){var self=this;return smalltalk.APIBuilder.build_doing_(token, aBlock);;return self;}
,"Builders-private",unescape("build%3A%20token%20doing%3A%20aBlock%0D%0A%09%22%20Process%20a%20%28build...%3A%20spec%29%20definition%20marking%20methods%20generated%20while%20evaluating%20aBlock.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5EAPIBuilder%20build%3A%20token%20doing%3A%20aBlock"));
smalltalk.bind(smalltalk.Behavior,"buildAPI:",0
,function (specs){var self=this;specs.do_((function(spec){return ((spec.isString()).mustBeBoolean()==true ? (function(){spec.evaluateIn();return self;})() : (function(){return self.perform_withArguments_(spec.first(), spec.copyFrom_to_((2), spec.size()));})());}));return self;}
,"Builders-obsolete",unescape("buildAPI%3A%20specs%0D%0A%09%22%20Generate%20code%20to%20implement%20API%20protocoll%20defined%20by%20specs.%0D%0A%09WARNING%3A%20OBSOLETE%20-%20this%20builder%20generate%20changes%20that%20will%20not%20be%20filedOut%20to%20builder%20code.%0D%0A%09specs%20must%20be%20an%20array%20of%20%3A%0D%0A%09%09-%20string%20%3A%20it%20will%20be%20considered%20as%20an%20evaluable%20expression%20to%20be%20executed%20in%20the%20context%20of%20the%20receiver.%0D%0A%09%09-%20anArray%20%3A%20of%20%23%28%20selector%20arg1%20arg2%20arg3%20arg4...%20%29%20to%20be%20performed%20for%20code%20generation/setup%20of%20the%20receiver%0D%0A%09%09%09where%20selector%20is%20frequently%20a%20build...%3A%20selector.%0D%0A%09%22%0D%0A%0D%0A%09specs%20do%3A%20%5B%3Aspec%7C%0D%0A%09%09spec%20isString%0D%0A%09%09ifTrue%3A%20%5B%20spec%20evaluateIn.%20self%20%5D%0D%0A%09%09ifFalse%3A%20%5B%0D%0A%09%09%09self%09perform%3A%20spec%20first%0D%0A%09%09%09%09withArguments%3A%20%28spec%20copyFrom%3A%202%20to%3A%20spec%20size%29%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"stMessageHeader:",0
,function (msgHeader){var self=this;return msgHeader;;return self;}
,"Builders-private",unescape("stMessageHeader%3A%20msgHeader%0D%0A%09%22%20Private%20-%20Return%20a%20message%20header%20string%20with%20nice%20smalltalk%20looking.%0D%0A%09Default%20implementation%20leave%20the%20message%20header%20as%20is.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20transform%20message%20pattern%20for%20better%20code%20generation.%0D%0A%09%22%0D%0A%0D%0A%09%5EmsgHeader"));
smalltalk.bind(smalltalk.Behavior,"buildAccessor:",0
,function (accessor){var $s8Ret$={name:"stReturn"};try{var self=this;((accessor.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildGetter_(accessor)._comma(self.buildSetter_(accessor));})();throw($s8Ret$)})();})() : nil);
((accessor.size()._gt((1)).and_((function(){return accessor.second()._eq("initialize");}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildGetter_initialize_(accessor.first(), accessor.last())._comma(self.buildSetter_(accessor.first()));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("Accessor"._minus_gt(accessor), (function(){return accessor.inject_into_(" ", (function(total,tuple){return total._comma(self.implement_comment_as_category_(tuple.first(), tuple.at_((2)), tuple.at_((3)), "accessing"));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-api",unescape("buildAccessor%3A%20accessor%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20access%20native%20property.%20%22%0D%0A%0D%0A%09accessor%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5E%28self%20buildGetter%3A%20accessor%29%0D%0A%09%09%2C%28self%20buildSetter%3A%20accessor%29%0D%0A%09%5D.%0D%0A%09%28accessor%20size%20%3E%201%20and%3A%20%5B%20accessor%20second%20%3D%20%23initialize%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5E%28self%20buildGetter%3A%20accessor%20first%20initialize%3A%20accessor%20last%29%0D%0A%09%09%2C%28self%20buildSetter%3A%20accessor%20first%29%0D%0A%09%5D.%0D%0A%0D%0A%09%5Eself%20build%3A%20%23Accessor%20-%3E%20accessor%20doing%3A%20%5B%0D%0A%09%09accessor%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Atuple%7C%0D%0A%09%09%09total%20%2C%20%28self%0D%0A%09%09%09%09implement%3A%20tuple%20first%20comment%3A%20%28tuple%20at%3A%202%29%0D%0A%09%09%09%09as%3A%20%28tuple%20at%3A%203%29%20category%3A%20%23accessing%29%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildGetterCode:",0
,function (aSelector){var self=this;return unescape("%5E")._comma(aSelector);;return self;}
,"Builders-private",unescape("buildGetterCode%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20source%20code%20to%20get%20aSelector.%20%22%0D%0A%0D%0A%09%5E%27%5E%27%20%2CaSelector"));
smalltalk.bind(smalltalk.Behavior,"buildGetter:",0
,function (aSelector){var self=this;return self.build_doing_("Getter"._minus_gt(aSelector), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), self.buildGetterCode_(aSelector), "accessing");}));;return self;}
,"Builders-api",unescape("buildGetter%3A%20aSelector%0D%0A%09%22%20Build%20method%20to%20get%20instance%20aSelector.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23Getter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%28self%20buildGetterCode%3A%20aSelector%29%20category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildInitialize:with:",0
,function (aSelector,initializer){var self=this;return self.implement_comment_as_category_("initialize"._comma(aSelector.asSmalltalkName_(true)), unescape("Private%20-%20Initialize%20the%20")._comma(aSelector)._comma(" of the receiver."), initializer, "initialize");;return self;}
,"Builders-private",unescape("buildInitialize%3A%20aSelector%20with%3A%20initializer%0D%0A%09%22%20Private%20-%20Build%20method%20to%20initialize%20instance%20variable%20aSelector.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09implement%3A%20%23initialize%20%2C%28aSelector%20asSmalltalkName%3A%20true%29%0D%0A%09%09comment%3A%20%27Private%20-%20Initialize%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09as%3A%20initializer%0D%0A%09%09category%3A%20%23initialize"));
smalltalk.bind(smalltalk.Behavior,"buildGetter:initialize:",0
,function (aSelector,initializer){var self=this;var code=nil;code=((initializer._eq("initialize")).mustBeBoolean()==true ? (function(){return unescape("%5Eself%20implementedBySubclass%3A%20%23initialize");})() : (function(){return ((initializer.notEmpty()).mustBeBoolean()==true ? (function(){return ((initializer.first()._eq(".")).mustBeBoolean()==true ? (function(){return initializer.copyFrom_to_((2), initializer.size());})() : (function(){return aSelector._comma(unescape("%20%3A%3D%20"))._comma(((initializer.first().isUppercase().and_((function(){return initializer.asArrayOfSubstrings().size()._eq((1));}))).mustBeBoolean()==true ? (function(){return initializer._comma(" new");})() : (function(){return initializer;})()));})());})() : nil);})());
return (((nil.isNil_(code)===false)).mustBeBoolean()==true ? (function(){return self.buildInitialize_with_(aSelector, code);})() : (function(){return "";})())._comma(self.implement_comment_as_category_(self.stMessageHeader_(aSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), aSelector._comma(unescape("%20isNil%20ifTrue%3A%20%5B%20self%20"))._comma("initialize")._comma(aSelector.asSmalltalkName_(true))._comma(unescape("%20%5D.%0D%0A%09%5E"))._comma(aSelector), "accessing"));;return self;}
,"Builders-private",unescape("buildGetter%3A%20aSelector%20initialize%3A%20initializer%0D%0A%09%22%20Private%20-%20Build%20method%20to%20get%20instance%20aSelector%20w/deferred%20initialization%20mode.%0D%0A%09Note%3A%20%23initializer%20can%20be%3A%0D%0A%09%09%23initialize%20to%20generate%20default/deferred%20implementation.%0D%0A%09%09empty%20string%20to%20do%20NOT%20generate%20%23initialize...%20method.%0D%0A%09%09smalltalk%20code%20starting%20with%20%24.%20to%20use%20that%20code%20as%20method%20implementation.%0D%0A%09%09smalltalk%20expression%20for%20asignment%20%28to%20be%20used%20as%20assignment%20to%20instance%29.%0D%0A%09%09GlobalName%20if%20code%20do%20not%20have%20blanks%20and%20start%20with%20uppercase%2C%20it%20will%20be%20used%20as%20class%20to%20instantiate%20during%20initialization.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20code%20%7C%0D%0A%09code%20%3A%3D%20initializer%20%3D%20%23initialize%0D%0A%09%20%20ifTrue%3A%20%5B%20%27%5Eself%20implementedBySubclass%3A%20%23initialize%27%20%5D%20ifFalse%3A%20%5B%0D%0A%09%09initializer%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09%09initializer%20first%20%3D%20%24.%0D%0A%09%09%09ifTrue%3A%20%5B%20initializer%20copyFrom%3A%202%20to%3A%20initializer%20size%20%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09%09aSelector%20%2C%27%20%3A%3D%20%27%20%2C%28%0D%0A%09%09%09%09%09%28initializer%20first%20isUppercase%20and%3A%20%5B%20initializer%20asArrayOfSubstrings%20size%20%3D%201%20%5D%29%0D%0A%09%09%09%09%09ifTrue%3A%20%5B%20initializer%20%2C%27%20new%27%20%5D%0D%0A%09%09%09%09%09ifFalse%3A%20%5B%20initializer%20%5D%29%0D%0A%09%09%09%5D%0D%0A%09%09%5D%0D%0A%09%20%20%5D.%0D%0A%09%5E%28code%20notNil%20ifTrue%3A%20%5B%20self%20buildInitialize%3A%20aSelector%20with%3A%20code%20%5D%20ifFalse%3A%20%5B%20%27%27%20%5D%29%0D%0A%09%2C%28self%0D%0A%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%0D%0A%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09as%3A%20aSelector%2C%27%20isNil%20ifTrue%3A%20%5B%20self%20%27%20%2C%20%23initialize%20%2C%28aSelector%20asSmalltalkName%3A%20true%29%20%2C%27%20%5D.%0D%0A%09%5E%27%20%2CaSelector%20category%3A%20%23accessing%29"));
smalltalk.bind(smalltalk.Behavior,"buildSetterCode:",0
,function (aSelector){var self=this;return aSelector._comma(unescape("%20%3A%3D%20anObject"));;return self;}
,"Builders-private",unescape("buildSetterCode%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20source%20code%20to%20set%20aSelector.%20%22%0D%0A%0D%0A%09%5EaSelector%20%2C%27%20%3A%3D%20anObject%27"));
smalltalk.bind(smalltalk.Behavior,"buildSetter:",0
,function (aSelector){var self=this;return self.build_doing_("Setter"._minus_gt(aSelector), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector)._comma(": anObject"), "Set the "._comma(aSelector)._comma(" of the receiver."), self.buildSetterCode_(aSelector), "accessing");}));;return self;}
,"Builders-api",unescape("buildSetter%3A%20aSelector%0D%0A%09%22%20Build%20method%20to%20set%20instance%20aSelector.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23Setter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%20%2C%27%3A%20anObject%27%0D%0A%09%09%09comment%3A%20%27Set%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%28self%20buildSetterCode%3A%20aSelector%29%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildGetters:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildGetters_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("Getters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildGetter_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-api",unescape("buildGetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20get%20instances.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildGetters%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23Getters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildGetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildSetters:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildSetters_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("Setters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildSetter_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-api",unescape("buildSetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20set%20instances.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildSetters%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23Setters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildSetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildAccessors:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildAccessors_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("Accessors"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildAccessor_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Builders-api",unescape("buildAccessors%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20access%20instances.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildAccessors%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23Accessors%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildAccessor%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildAccessors",0
,function (){var self=this;return self.build_doing_("Accessors"._minus_gt([]), (function(){return self.buildAccessors_(self.instanceVariableNames());}));;return self;}
,"Builders-api",unescape("buildAccessors%0D%0A%09%22%20Private%20-%20Build%20methods%20to%20access%20all%20instance%20variables.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23Accessors%20-%3E%20%23%28%29%20doing%3A%20%5B%0D%0A%09%09self%20buildAccessors%3A%20self%20instanceVariableNames%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Behavior,"buildPool:with:",0
,function (poolName,spec){var self=this;return self.build_doing_("Pool"._minus_gt(spec), (function(){return (function($rec){$rec.definePool_with_(poolName, spec);$rec.printDefinePool_with_(poolName, spec);return $rec.yourself();})(smalltalk.Smalltalk.current());}));;return self;}
,"Builders-api",unescape("buildPool%3A%20poolName%20with%3A%20spec%0D%0A%09%22%20Private%20-%20Build%20a%20PoolDictionary%20with%20spec%20%28and%20log%20definition%20in%20log%20stream%29.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23Pool%20-%3E%20spec%20doing%3A%20%5B%0D%0A%09%09Smalltalk%20current%0D%0A%09%09%09definePool%3A%20poolName%20with%3A%20spec%3B%0D%0A%09%09%09printDefinePool%3A%20poolName%20with%3A%20spec%3B%0D%0A%09%09%09yourself%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Class.$klass,"categories",0
,function (){var self=this;return smalltalk.Smalltalk.classes().collect_((function(each){return each.category();})).asSet();;return self;}
,"export",unescape("categories%0D%0A%09%22%20Return%20a%20collection%20with%20all%20defined%20categories.%20%22%0D%0A%0D%0A%09%5E%28Smalltalk%20classes%20collect%3A%20%5B%3Aeach%20%7C%20each%20category%20%5D%29%20asSet"));
smalltalk.bind(smalltalk.Class.$klass,"uncategorized",0
,function (){var self=this;return smalltalk.Smalltalk.classes().select_((function(each){return each.category()._eq("unclassified");}));;return self;}
,"export",unescape("uncategorized%0D%0A%09%22%20Return%20a%20collection%20with%20classes%20without%20category.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20classes%20select%3A%20%5B%3Aeach%20%7C%20each%20category%20%3D%20%23unclassified%20%5D"));
smalltalk.bind(smalltalk.Class,"category",0
,function (){var self=this;return ((function(){var $1$=self["$category"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("category%0D%0A%09%22%20Return%20the%20category%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24category%27"));
smalltalk.bind(smalltalk.Class,"category:",0
,function (aString){var self=this;(self["$category"]=(aString));return self;}
,"accessing",unescape("category%3A%20aString%0D%0A%09%22%20Set%20the%20category%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24category%27%20put%3A%20aString"));
smalltalk.bind(smalltalk.Class,"classVariables",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var names=nil;names=((function(){var $1$=self["$classVariableNames"];if(nil.isNil_($1$))return ((function(){return nil;}).value());return $1$;})());
(((nil.isNil_(names))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return ((function(){var $1$=self["$classVariables"];if(nil.isNil_($1$))return nil;return $1$;})());})();throw($s8Ret$)})();})() : nil);
self.basicDelete_("$classVariableNames");
self.classVariableNames_(names);
(function(){$s8Ret$.result=(function(){return ((function(){var $1$=self["$classVariables"];if(nil.isNil_($1$))return nil;return $1$;})());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("classVariables%0D%0A%09%22%20Return%20the%20class%20variables%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20names%20%7C%0D%0A%09names%20%3A%3D%20self%20basicAt%3A%20%27%24classVariableNames%27%20ifAbsent%3A%20%5B%5D.%0D%0A%09names%20isNil%20ifTrue%3A%20%5B%20%5Eself%20basicAt%3A%20%27%24classVariables%27%20%5D.%0D%0A%09self%20basicDelete%3A%20%27%24classVariableNames%27.%0D%0A%09self%20classVariableNames%3A%20names.%0D%0A%09%5Eself%20basicAt%3A%20%27%24classVariables%27"));
smalltalk.bind(smalltalk.Class,"classVariables:",0
,function (aDictionary){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(aDictionary)).or_((function(){return aDictionary.isEmpty();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.basicDelete_("$classVariables");})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return (self["$classVariables"]=(aDictionary));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("classVariables%3A%20aDictionary%0D%0A%09%22%20Set%20the%20class%20variables%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%28aDictionary%20isNil%20or%3A%20%5B%20aDictionary%20isEmpty%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20basicDelete%3A%20%27%24classVariables%27%0D%0A%09%5D.%0D%0A%09%5Eself%20basicAt%3A%20%27%24classVariables%27%20put%3A%20aDictionary"));
smalltalk.bind(smalltalk.Class,"poolDictionaries",0
,function (){var self=this;return ((function(){var $1$=self["$poolDictionaries"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("poolDictionaries%0D%0A%09%22%20Return%20the%20poolDictionaries%20of%20the%20receiver%20%28anArray%20or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24poolDictionaries%27"));
smalltalk.bind(smalltalk.Class,"poolDictionaries:",0
,function (anArray){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(anArray)===false).and_((function(){return anArray.isEmpty();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.poolDictionaries_(nil);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return (self["$poolDictionaries"]=(anArray));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("poolDictionaries%3A%20anArray%0D%0A%09%22%20Set%20the%20poolDictionaries%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%28anArray%20notNil%20and%3A%20%5B%20anArray%20isEmpty%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20poolDictionaries%3A%20nil%0D%0A%09%5D.%0D%0A%09%5Eself%20basicAt%3A%20%27%24poolDictionaries%27%20put%3A%20anArray"));
smalltalk.bind(smalltalk.Class,"classVariableNames",0
,function (){var self=this;return (((nil.isNil_(self.classVariables()))).mustBeBoolean()==true ? (function(){return smalltalk.Array.$$new();})() : (function(){return self.classVariables().keys();})());;return self;}
,"accessing",unescape("classVariableNames%0D%0A%09%22%20Return%20the%20class%20variable%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20classVariables%20isNil%0D%0A%09%09ifTrue%3A%20%5B%20Array%20new%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20classVariables%20keys%20%5D"));
smalltalk.bind(smalltalk.Class,"classVariablesString",0
,function (){var self=this;return self.classVariableNames().inject_into_("", (function(total,each){return total._comma(each)._comma(" ");})).trimBlanks();;return self;}
,"accessing",unescape("classVariablesString%0D%0A%09%22%20Return%20the%20class%20variable%20names%20of%20the%20receiver%20as%20aString.%20%22%0D%0A%0D%0A%09%5E%28self%20classVariableNames%20inject%3A%20%27%27%0D%0A%09%09into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2C%20each%20%2C%20%27%20%27%20%5D%0D%0A%09%09%29%20trimBlanks"));
smalltalk.bind(smalltalk.Class,"poolDictionaryNames",0
,function (){var self=this;return (((nil.isNil_(self.poolDictionaries()))).mustBeBoolean()==true ? (function(){return smalltalk.Array.$$new();})() : (function(){return self.poolDictionaries();})());;return self;}
,"accessing",unescape("poolDictionaryNames%0D%0A%09%22%20Return%20the%20pool%20dictionary%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20poolDictionaries%20isNil%0D%0A%09%09ifTrue%3A%20%5B%20Array%20new%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20poolDictionaries%20%5D"));
smalltalk.bind(smalltalk.Class,"poolDictionariesString",0
,function (){var self=this;return self.poolDictionaryNames().inject_into_("", (function(total,each){return total._comma(each)._comma(" ");})).trimBlanks();;return self;}
,"accessing",unescape("poolDictionariesString%0D%0A%09%22%20Return%20the%20poolDictionary%20names%20of%20the%20receiver%20as%20aString.%20%22%0D%0A%0D%0A%09%5E%28self%20poolDictionaryNames%20inject%3A%20%27%27%0D%0A%09%09into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2C%20each%20%2C%20%27%20%27%20%5D%0D%0A%09%09%29%20trimBlanks"));
smalltalk.bind(smalltalk.Class,"classVariableNames:",0
,function (classVarNames){var $s8Ret$={name:"stReturn"};try{var self=this;var names=nil;var dictionary=nil;var old=nil;(((nil.isNil_(classVarNames))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.classVariables_(nil);})();throw($s8Ret$)})();})() : nil);
names=((classVarNames.isString()).mustBeBoolean()==true ? (function(){return classVarNames.asArrayOfSubstrings();})() : (function(){return classVarNames;})());
dictionary=smalltalk.PoolDictionary.$$new();
old=self.classVariables();
(((nil.isNil_(old))).mustBeBoolean()==true ? (function(){return old=dictionary;})() : nil);
names.do_((function(each){return dictionary.at_put_(each, old.at_ifAbsent_(each, (function(){return nil;})));}));
self.classVariables_(dictionary);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("classVariableNames%3A%20classVarNames%0D%0A%09%22%20Set%20the%20variable%20names%20defined%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20names%20dictionary%20old%20%7C%0D%0A%09classVarNames%20isNil%20ifTrue%3A%20%5B%20%5Eself%20classVariables%3A%20nil%20%5D.%0D%0A%09names%20%3A%3D%20classVarNames%20isString%0D%0A%09%09ifTrue%3A%20%5B%20classVarNames%20asArrayOfSubstrings%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20classVarNames%20%5D.%0D%0A%09dictionary%20%3A%3D%20PoolDictionary%20new.%0D%0A%09old%20%3A%3D%20self%20classVariables.%20old%20isNil%20ifTrue%3A%20%5B%20old%20%3A%3D%20dictionary%20%5D.%0D%0A%09names%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09dictionary%20at%3A%20each%20put%3A%20%28old%20at%3A%20each%20ifAbsent%3A%20%5B%20nil%20%5D%29%0D%0A%09%5D.%0D%0A%09self%20classVariables%3A%20dictionary."));
smalltalk.bind(smalltalk.Class,"poolDictionaryNames:",0
,function (poolVarNames){var self=this;self.poolDictionaries_(((poolVarNames.isString()).mustBeBoolean()==true ? (function(){return poolVarNames.asArrayOfSubstrings();})() : (function(){return poolVarNames;})()));return self;}
,"accessing",unescape("poolDictionaryNames%3A%20poolVarNames%0D%0A%09%22%20Set%20the%20pool%20dictionary%20names%20known%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20poolDictionaries%3A%20%28poolVarNames%20isString%0D%0A%09%09ifTrue%3A%20%5B%20poolVarNames%20asArrayOfSubstrings%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20poolVarNames%20%5D%29."));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:",0
,function (aString,aString2){var self=this;return self.subclass_instanceVariableNames_classVariableNames_(aString, aString2, "");;return self;}
,"instantiation",unescape("subclass%3A%20aString%20instanceVariableNames%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"subclass:category:",0
,function (aString,aCategory){var self=this;return self.subclass_instanceVariableNames_category_(aString, "", aCategory);;return self;}
,"instantiation",unescape("subclass%3A%20aString%20category%3A%20aCategory%0D%0A%09%22%20Create%20a%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:category:",0
,function (aString,aString2,aString3){var self=this;return smalltalk.ClassBuilder.$$new().superclass_subclass_instanceVariableNames_category_(self, aString, aString2, aString3);;return self;}
,"instantiation",unescape("subclass%3A%20aString%20instanceVariableNames%3A%20aString2%20category%3A%20aString3%0D%0A%09%22%20Create%20a%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EClassBuilder%20new%0D%0A%09%09superclass%3A%20self%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09category%3A%20aString3"));
smalltalk.bind(smalltalk.Class,"isClass",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isClass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20Class.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Class,"printString",0
,function (){var self=this;return self.name();;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20a%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20name"));
smalltalk.bind(smalltalk.Class,"instanceClass",0
,function (){var self=this;return self;;return self;}
,"accessing",unescape("instanceClass%0D%0A%09%22%20Return%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Class,"rename:",0
,function (aString){var self=this;self.smalltalk().renameClass(self, aString);return self;}
,"renaming",unescape("rename%3A%20aString%0D%0A%09%22%20Rename%20the%20receiver%20to%20aString.%20%22%0D%0A%0D%0A%09self%20smalltalk%20%23renameClass%3A%20self%20to%3A%20aString"));
smalltalk.bind(smalltalk.Class,"removeFromSystem",0
,function (){var self=this;self.subclasses().do_((function(each){return each.removeFromSystem();}));
self.smalltalk().removeClass(self);return self;}
,"remove",unescape("removeFromSystem%0D%0A%09%22%20Remove%20the%20receiver%20from%20system.%20%22%0D%0A%0D%0A%09self%20subclasses%20do%3A%20%5B%3Aeach%7C%20each%20removeFromSystem%20%5D.%0D%0A%09self%20smalltalk%20%23removeClass%3A%20self"));
smalltalk.bind(smalltalk.Class,"removeSources",0
,function (){var self=this;self.$klass.methodsDo_((function(each){return each.removeSources();}));
self.methodsDo_((function(each){return each.removeSources();}));
(function($rec){$rec.comment_("");return $rec.category_("s8");})(self);return self;}
,"tools",unescape("removeSources%0D%0A%09%22%20Remove%20all%20development%20sources%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20class%20methodsDo%3A%20%5B%3Aeach%20%7C%20each%20removeSources%20%5D.%0D%0A%09self%20methodsDo%3A%20%5B%3Aeach%20%7C%20each%20removeSources%20%5D.%0D%0A%09self%20comment%3A%20%27%27%3B%20category%3A%20%23s8"));
smalltalk.bind(smalltalk.Class,"variableByteSubclass:classVariableNames:poolDictionaries:",0
,function (aString,classVarNames,poolVarNames){var self=this;self.print_(unescape("//%20WARNING%3A%20")._comma(aString)._comma(" defined as variableByteSubclass:..."));
return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, "", classVarNames, poolVarNames);;return self;}
,"instantiation",unescape("variableByteSubclass%3A%20aString%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20print%3A%20%27//%20WARNING%3A%20%27%2CaString%2C%27%20defined%20as%20variableByteSubclass%3A...%27.%0D%0A%09%5Eself%20%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20poolVarNames"));
smalltalk.bind(smalltalk.Class,"variableSubclass:instanceVariableNames:classVariableNames:poolDictionaries:",0
,function (aString,aString2,classVarNames,poolVarNames){var self=this;self.print_(unescape("//%20WARNING%3A%20")._comma(aString)._comma(" defined as variableSubclass:..."));
return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, aString2, classVarNames, poolVarNames);;return self;}
,"instantiation",unescape("variableSubclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20print%3A%20%27//%20WARNING%3A%20%27%2CaString%2C%27%20defined%20as%20variableSubclass%3A...%27.%0D%0A%09%5Eself%20%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20poolVarNames"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:classVariableNames:poolDictionaries:category:",0
,function (aString,aString2,classVarNames,poolVarNames,aCategory){var self=this;(((nil.isNil_(self.smalltalk().globalAt_(aString))===false)).mustBeBoolean()==true ? (function(){return self.print_(unescape("//%20WARNING%3A%20class%20REdefinition%20for%20")._comma(aString));})() : nil);
return smalltalk.ClassBuilder.$$new().superclass_subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(self, aString, aString2, classVarNames, poolVarNames, aCategory);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09category%3A%20aCategory%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%28self%20smalltalk%20globalAt%3A%20aString%29%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09self%20print%3A%20%27//%20WARNING%3A%20class%20REdefinition%20for%20%27%2CaString.%0D%0A%09%09%22%5Eself%20smalltalk%20globalAt%3A%20aString%22%0D%0A%09%5D.%0D%0A%0D%0A%09%22self%20print%3A%20%27//%20Creating%20%27%2CaString.%22%0D%0A%09%5EClassBuilder%20new%0D%0A%09%09superclass%3A%20self%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20poolVarNames%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:classVariableNames:category:",0
,function (aString,aString2,classVarNames,aCategory){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(aString, aString2, classVarNames, "", aCategory);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09category%3A%20aCategory%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20%27%27%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:classVariableNames:poolDictionaries:",0
,function (aString,aString2,classVarNames,poolVarNames){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(aString, aString2, classVarNames, poolVarNames, nil);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20poolVarNames%0D%0A%09%09category%3A%20nil"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:poolDictionaries:category:",0
,function (aString,aString2,poolVarNames,aCategory){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(aString, aString2, "", poolVarNames, aCategory);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09category%3A%20aCategory%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20%27%27%0D%0A%09%09poolDictionaries%3A%20poolVarNames%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.Class,"variableByteSubclass:classVariableNames:",0
,function (aString,classVarNames){var self=this;return self.variableByteSubclass_classVariableNames_poolDictionaries_(aString, classVarNames, "");;return self;}
,"instantiation",unescape("variableByteSubclass%3A%20aString%20classVariableNames%3A%20classVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09variableByteSubclass%3A%20aString%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"variableByteSubclass:poolDictionaries:",0
,function (aString,aString2){var self=this;return self.variableByteSubclass_classVariableNames_poolDictionaries_(aString, "", aString2);;return self;}
,"instantiation",unescape("variableByteSubclass%3A%20aString%20poolDictionaries%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09variableByteSubclass%3A%20aString%0D%0A%09%09classVariableNames%3A%20%27%27%0D%0A%09%09poolDictionaries%3A%20aString2"));
smalltalk.bind(smalltalk.Class,"variableByteSubclass:",0
,function (aString){var self=this;return self.variableByteSubclass_classVariableNames_(aString, "");;return self;}
,"instantiation",unescape("variableByteSubclass%3A%20aString%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09variableByteSubclass%3A%20aString%0D%0A%09%09classVariableNames%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"variableSubclass:instanceVariableNames:classVariableNames:",0
,function (aString,aString2,classVarNames){var self=this;return self.variableSubclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, aString2, classVarNames, "");;return self;}
,"instantiation",unescape("variableSubclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%0D%0A%09%09variableSubclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"variableSubclass:instanceVariableNames:",0
,function (aString,aString2){var self=this;return self.variableSubclass_instanceVariableNames_classVariableNames_(aString, aString2, "");;return self;}
,"instantiation",unescape("variableSubclass%3A%20aString%20instanceVariableNames%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%0D%0A%09%09variableSubclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"variableSubclass:classVariableNames:",0
,function (aString,aString2){var self=this;return self.variableSubclass_instanceVariableNames_classVariableNames_(aString, "", aString2);;return self;}
,"instantiation",unescape("variableSubclass%3A%20aString%20classVariableNames%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%0D%0A%09%09variableSubclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09classVariableNames%3A%20aString2"));
smalltalk.bind(smalltalk.Class,"variableSubclass:poolDictionaries:",0
,function (aString,aString2){var self=this;return self.variableSubclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, "", "", aString2);;return self;}
,"instantiation",unescape("variableSubclass%3A%20aString%20poolDictionaries%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%0D%0A%09%09variableSubclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09classVariableNames%3A%20%27%27%0D%0A%09%09poolDictionaries%3A%20aString2"));
smalltalk.bind(smalltalk.Class,"variableSubclass:",0
,function (aString){var self=this;return self.variableSubclass_instanceVariableNames_(aString, "");;return self;}
,"instantiation",unescape("variableSubclass%3A%20aString%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%0D%0A%09%09variableSubclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:classVariableNames:",0
,function (aString,aString2,classVarNames){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, aString2, classVarNames, "");;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"subclass:instanceVariableNames:poolDictionaries:",0
,function (aString,aString2,aString3){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, aString2, "", aString3);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09poolDictionaries%3A%20aString3%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20%27%27%0D%0A%09%09poolDictionaries%3A%20aString3"));
smalltalk.bind(smalltalk.Class,"subclass:classVariableNames:",0
,function (aString,aString2){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, "", aString2, "");;return self;}
,"instantiation",unescape("subclass%3A%20aString%20classVariableNames%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09classVariableNames%3A%20aString2%0D%0A%09%09poolDictionaries%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"subclass:poolDictionaries:",0
,function (aString,aString2){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_(aString, "", "", aString2);;return self;}
,"instantiation",unescape("subclass%3A%20aString%20poolDictionaries%3A%20aString2%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09classVariableNames%3A%20%27%27%0D%0A%09%09poolDictionaries%3A%20aString2"));
smalltalk.bind(smalltalk.Class,"subclass:",0
,function (aString){var self=this;return self.subclass_instanceVariableNames_(aString, "");;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27"));
smalltalk.bind(smalltalk.Class,"hackDNU",0
,function (){var self=this;var all=nil;all=smalltalk.HashedSet.$$new();
smalltalk.Smalltalk.rootClasses().do_((function(root){return root.allSubclasses().do_((function(each){return (function($rec){$rec.addAll_(each.selectors());return $rec.addAll_(each.$klass.selectors());})(all);}));}));
smalltalk.Smalltalk.rootClasses().do_((function(root){return root.selectors().do_((function(each){return all.remove_ifAbsent_(each, (function(){return nil;}));}));}));
["handleOrNil", "start:end:"].do_((function(each){return all.remove_ifAbsent_(each, (function(){return nil;}));}));
all.do_((function(selector){var mth=nil;mth=smalltalk.CompiledMethod.$$new();(function($rec){$rec.selector_(selector);$rec.classField_(self);$rec.category_("hackDNU");return $rec.source_(selector._comma(unescape("%28dnu%29")));})(mth);mth.fn_(function(){
			this.print_("//DNU "+selector);
			this.doesNotUnderstand_(smalltalk.Message.receiver_selector_arguments_(this,selector,[].slice.call(arguments)))});
		;return self.basicAddCompiledMethod_(mth);}));return self;}
,"Tools-hacking",unescape("hackDNU%0D%0A%09%22%20Catch%20DNU%20condition%20in%20the%20receiver%20and%20its%20subclasses.%0D%0A%09Note%3A%20hack%20will%20persist%20until%20%23unhackDNU%20is%20sent%20to%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20all%20%7C%0D%0A%09all%20%3A%3D%20HashedSet%20new.%0D%0A%09Smalltalk%20rootClasses%20do%3A%20%5B%3Aroot%7C%0D%0A%09%09root%20allSubclasses%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%09all%20addAll%3A%20each%20selectors%3B%20addAll%3A%20each%20class%20selectors%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09Smalltalk%20rootClasses%20do%3A%20%5B%3Aroot%7C%20root%20selectors%20do%3A%20%5B%3Aeach%7C%20all%20remove%3A%20each%20ifAbsent%3A%20%5B%5D%5D%20%5D.%0D%0A%09%23%28%20%23handleOrNil%20%23start%3Aend%3A%20%29%20do%3A%20%5B%3Aeach%7C%20all%20remove%3A%20each%20ifAbsent%3A%20%5B%5D%5D.%0D%0A%09all%20do%3A%20%5B%3Aselector%7C%20%7C%20mth%20%7C%0D%0A%09%09mth%20%3A%3D%20CompiledMethod%20new.%0D%0A%09%09mth%20selector%3A%20selector%3B%20classField%3A%20self%3B%20category%3A%20%23hackDNU%3B%20source%3A%20selector%2C%27%28dnu%29%27.%0D%0A%09%09%7B%27mth.fn_%28function%28%29%7B%0D%0A%09%09%09this.print_%28%22//DNU%20%22+selector%29%3B%0D%0A%09%09%09this.doesNotUnderstand_%28smalltalk.Message.receiver_selector_arguments_%28this%2Cselector%2C%5B%5D.slice.call%28arguments%29%29%29%7D%29%3B%0D%0A%09%09%27%7D.%0D%0A%09%09self%20basicAddCompiledMethod%3A%20mth.%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Class,"unhackDNU",0
,function (){var self=this;self.removeSelectors_(self.selectors().select_((function(each){return smalltalk.Object._gt_gt(each).category()._eq("hackDNU");})));return self;}
,"Tools-hacking",unescape("unhackDNU%0D%0A%09%22%20Remove%20Catch%20DNU%20hacking%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20removeSelectors%3A%20%28self%20selectors%0D%0A%09%09select%3A%20%5B%3Aeach%7C%20%28Object%20%3E%3E%20each%29%20category%20%3D%20%23hackDNU%20%5D%29"));
smalltalk.bind(smalltalk.Class,"hackDNUWhile:",0
,function (aBlock){var self=this;var result=nil;(function(){self.hackDNU();return result=aBlock.evaluate();}).ensure_((function(){return self.unhackDNU();}));
return result;;return self;}
,"Tools-hacking",unescape("hackDNUWhile%3A%20aBlock%0D%0A%09%22%20Catch%20DNU%20hacking%20on%20the%20receiver%20while%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09%5B%09self%20hackDNU.%0D%0A%09%09result%20%3A%3D%20aBlock%20evaluate%0D%0A%09%5D%20ensure%3A%20%5B%20self%20unhackDNU%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Class,"launch",0
,function (){var self=this;return self;}
,"Snapshot-startup",unescape("launch%0D%0A%09%22%20Private%20-%20The%20system%20has%20been%20launched%20and%20start%20execution.%0D%0A%09The%20default%20action%20is%20to%20do%20nothing.%0D%0A%09Subclasses%20can%20refine%20this%20method%20to%20execute%20actions%20on%20startup.%0D%0A%09%22"));
smalltalk.bind(smalltalk.Class,"aboutToSaveImage:on:",0
,function (snapshot,stream){var self=this;return self;;return self;}
,"Snapshot-snapshot",unescape("aboutToSaveImage%3A%20snapshot%20on%3A%20stream%0D%0A%09%22%20Private%20-%20A%20system%20snapshot%20will%20be%20taken%2C%20the%20receiver%20can%20prepare%20the%20contents%20to%20be%20stored%20on%20snapshot.%0D%0A%09Must%20return%20the%20receiver%20or%20a%20replacement%20to%20act%20as%20the%20receiver%20when%20persisting%20data.%0D%0A%09The%20default%20action%20return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Class,"imageSaved:on:",0
,function (snapshot,stream){var self=this;return self;}
,"Snapshot-snapshot",unescape("imageSaved%3A%20snapshot%20on%3A%20stream%0D%0A%09%22%20Private%20-%20A%20system%20snapshot%20has%20been%20taken%2C%20the%20receiver%20can%20emmit%20code%20to%20restore%20state.%0D%0A%09The%20default%20action%20do%20nothing.%0D%0A%09This%20method%20can%20be%20refined%20by%20the%20subclasses.%0D%0A%09%22"));
smalltalk.bind(smalltalk.Class,"aboutToExit:",0
,function (aSystemDictionary){var self=this;return self;}
,"Snapshot-snapshot",unescape("aboutToExit%3A%20aSystemDictionary%0D%0A%09%22%20Private%20-%20A%20system%20will%20exit%2C%20and%20the%20receiver%20can%20act%20executing%20actions%20just%20before%20exiting.%0D%0A%09The%20default%20action%20do%20nothing.%0D%0A%09This%20method%20can%20be%20refined%20by%20the%20subclasses.%0D%0A%09%22"));
smalltalk.bind(smalltalk.Metaclass,"instanceClass",0
,function (){var self=this;return self['@instanceClass'];;return self;}
,"accessing",unescape("instanceClass%0D%0A%09%22%20Return%20the%20instance%20class%20of%20receiver.%20%22%0D%0A%0D%0A%09%5EinstanceClass"));
smalltalk.bind(smalltalk.Metaclass,"instanceVariableNames:",0
,function (aCollection){var self=this;smalltalk.ClassBuilder.$$new().class_instanceVariableNames_(self, aCollection);return self;}
,"accessing",unescape("instanceVariableNames%3A%20aCollection%0D%0A%09%22%20Set%20the%20instance%20variable%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09ClassBuilder%20new%0D%0A%09%09class%3A%20self%0D%0A%09%09instanceVariableNames%3A%20aCollection"));
smalltalk.bind(smalltalk.Metaclass,"isMetaclass",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isMetaclass%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20metaclass.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Metaclass,"printString",0
,function (){var self=this;return self.instanceClass().name()._comma(" class");;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20a%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20name%2C%20%27%20class%27"));
smalltalk.bind(smalltalk.Metaclass,"poolDictionaries",0
,function (){var self=this;return self.instanceClass().poolDictionaries();;return self;}
,"accessing",unescape("poolDictionaries%0D%0A%09%22%20Return%20the%20poolDictionaries%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20poolDictionaries"));
smalltalk.bind(smalltalk.Metaclass,"classVariables",0
,function (){var self=this;return self.instanceClass().classVariables();;return self;}
,"accessing",unescape("classVariables%0D%0A%09%22%20Return%20the%20class%20variables%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20instanceClass%20classVariables"));
smalltalk.bind(smalltalk.CompiledMethod,"source",0
,function (){var self=this;return ((function(){var $1$=self["$source"];if(nil.isNil_($1$))return ((function(){return "";}).value());return $1$;})());;return self;}
,"accessing",unescape("source%0D%0A%09%22%20Return%20the%20source%20code%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24source%27%20ifAbsent%3A%20%5B%27%27%5D"));
smalltalk.bind(smalltalk.CompiledMethod,"source:",0
,function (aString){var self=this;(self["$source"]=(aString));return self;}
,"accessing",unescape("source%3A%20aString%0D%0A%09%22%20Set%20the%20source%20code%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24source%27%20put%3A%20aString"));
smalltalk.bind(smalltalk.CompiledMethod,"category",0
,function (){var self=this;return ((function(){var $1$=self["$category"];if(nil.isNil_($1$))return ((function(){return "";}).value());return $1$;})());;return self;}
,"accessing",unescape("category%0D%0A%09%22%20Return%20the%20category%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24category%27%20ifAbsent%3A%20%5B%27%27%5D"));
smalltalk.bind(smalltalk.CompiledMethod,"category:",0
,function (aString){var self=this;(self["$category"]=(aString));return self;}
,"accessing",unescape("category%3A%20aString%0D%0A%09%22%20Set%20the%20category%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24category%27%20put%3A%20aString"));
smalltalk.bind(smalltalk.CompiledMethod,"selector",0
,function (){var self=this;return ((function(){var $1$=self["$selector"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("selector%0D%0A%09%22%20Return%20the%20selector%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24selector%27"));
smalltalk.bind(smalltalk.CompiledMethod,"selector:",0
,function (aString){var self=this;(self["$selector"]=(aString));return self;}
,"accessing",unescape("selector%3A%20aString%0D%0A%09%22%20Set%20the%20selector%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24selector%27%20put%3A%20aString"));
smalltalk.bind(smalltalk.CompiledMethod,"fn",0
,function (){var self=this;return ((function(){var $1$=self["$fn"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("fn%0D%0A%09%22%20Return%20the%20function%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24fn%27"));
smalltalk.bind(smalltalk.CompiledMethod,"fn:",0
,function (aBlock){var self=this;(self["$fn"]=(aBlock));return self;}
,"accessing",unescape("fn%3A%20aBlock%0D%0A%09%22%20Set%20the%20function%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24fn%27%20put%3A%20aBlock"));
smalltalk.bind(smalltalk.CompiledMethod,"classField",0
,function (){var self=this;return self['@classField'];;return self;}
,"accessing",unescape("classField%0D%0A%09%22%20Return%20the%20implementor%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EclassField"));
smalltalk.bind(smalltalk.CompiledMethod,"classField:",0
,function (aClass){var self=this;self['@classField']=aClass;return self;}
,"accessing",unescape("classField%3A%20aClass%0D%0A%09%22%20Set%20the%20implementor%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09classField%20%3A%3D%20aClass"));
smalltalk.bind(smalltalk.CompiledMethod,"generation",0
,function (){var self=this;return ((function(){var $1$=self["$generation"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("generation%0D%0A%09%22%20Returns%20the%20generation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24generation%27"));
smalltalk.bind(smalltalk.CompiledMethod,"comment",0
,function (){var self=this;return (function($rec){$rec.upTo_(unescape("%22"));return $rec.upTo_(unescape("%22"));})(self.source().stream()).trimBlanks();;return self;}
,"accessing",unescape("comment%0D%0A%09%22%20Return%20the%20comment%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28self%20source%20stream%20upTo%3A%20%24%22%3B%20upTo%3A%20%24%22%29%20trimBlanks"));
smalltalk.bind(smalltalk.CompiledMethod,"toString",0
,function (){var self=this;return (((nil.isNil_(self['@classField']))).mustBeBoolean()==true ? (function(){return self['@classField'].toString();})() : (function(){return self['@classField'].name();})())._comma(unescape("%3E%3E%23"))._comma(self.selector().toString());;return self;}
,"printing",unescape("toString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28classField%20isNil%0D%0A%09%09ifTrue%3A%20%5BclassField%20toString%5D%0D%0A%09%09ifFalse%3A%20%5BclassField%20name%5D%29%0D%0A%09%09%2C%27%3E%3E%23%27%20%2Cself%20selector%20toString"));
smalltalk.bind(smalltalk.CompiledMethod,"printString",0
,function (){var self=this;return self.toString();;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20toString"));
smalltalk.bind(smalltalk.CompiledMethod,"asJSONObject",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.CompiledMethod,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.CompiledMethod,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.CompiledMethod,"removeSources",0
,function (){var self=this;(function($rec){$rec.source_("");$rec.category_("");return $rec.builder_(nil);})(self);return self;}
,"bilders-tools",unescape("removeSources%0D%0A%09%22%20Remove%20all%20development%20sources%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20source%3A%20%27%27%3B%20category%3A%20%27%27%3B%20builder%3A%20nil"));
smalltalk.bind(smalltalk.CompiledMethod,"recompile",0
,function (){var self=this;self.classField().compiler().compile_forClass_category_(self.source(), self.classField(), self.category());return self;}
,"Compiler-compiling",unescape("recompile%0D%0A%09%22%20Recompile%20the%20source%20of%20the%20receiver%20and%20install%20the%20new%20compiled%20method.%20%22%0D%0A%0D%0A%09self%20classField%20compiler%0D%0A%09%09compile%3A%20self%20source%0D%0A%09%09forClass%3A%20self%20classField%0D%0A%09%09category%3A%20self%20category"));
smalltalk.bind(smalltalk.CompiledMethod,"messages",0
,function (){var self=this;return smalltalk.MethodReferences.$$new().messagesOf_(self);;return self;}
,"Tools-accessing",unescape("messages%0D%0A%09%22%20Return%20all%20the%20messages%20that%20can%20be%20sent%20during%20execution%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EMethodReferences%20new%20messagesOf%3A%20self"));
smalltalk.bind(smalltalk.CompiledMethod,"globalReferences",0
,function (){var self=this;return smalltalk.MethodReferences.$$new().globalReferencesOf_(self);;return self;}
,"Tools-accessing",unescape("globalReferences%0D%0A%09%22%20Return%20all%20the%20global%20references%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EMethodReferences%20new%20globalReferencesOf%3A%20self"));
smalltalk.bind(smalltalk.CompiledMethod,"references",0
,function (){var self=this;return (function($rec){$rec.at_put_("messages", self.messages());$rec.at_put_("globalReferences", self.globalReferences());return $rec.yourself();})(smalltalk.PoolDictionary.$$new());;return self;}
,"Tools-accessing",unescape("references%0D%0A%09%22%20Return%20all%20the%20references%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPoolDictionary%20new%0D%0A%09%09at%3A%20%23messages%20put%3A%20self%20messages%3B%0D%0A%09%09at%3A%20%23globalReferences%20put%3A%20self%20globalReferences%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.CompiledMethod,"builder:",0
,function (cookie){var self=this;(self["$builder"]=(cookie));return self;}
,"Builders-accessing",unescape("builder%3A%20cookie%0D%0A%09%22%20Private%20-%20Set%20the%20builder%20cookie%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24builder%27%20put%3A%20cookie"));
smalltalk.bind(smalltalk.CompiledMethod,"builder",0
,function (){var self=this;return ((function(){var $1$=self["$builder"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"Builders-accessing",unescape("builder%0D%0A%09%22%20Private%20-%20Return%20the%20builder%20cookie%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24builder%27"));
smalltalk.bind(smalltalk.Number.$klass,"pi",0
,function (){var self=this;return ((function(){var $1$=Math["PI"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"instantiation",unescape("pi%0D%0A%09%22%20Return%20the%20singular%20value%20PI.%20%22%0D%0A%0D%0A%09%5E%23%7BMath%7D%20basicAt%3A%20%23PI"));
smalltalk.bind(smalltalk.Number.$klass,"readFrom:radix:",0
,function (aStream,radix){var $s8Ret$={name:"stReturn"};try{var self=this;var value=nil;var $$char=nil;value=(0);
(function(){while((function(){$$char=aStream.peek();return (nil.isNil_($$char)===false).and_((function(){return $$char.isDigit().or_((function(){return $$char.isUpperCase();}));}));})()){(function(){((radix._lt($$char.digitValue())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return value;})();throw($s8Ret$)})();})() : nil);value=value._star(radix)._plus($$char.digitValue());return aStream.next();})()};return nil})();
(function(){$s8Ret$.result=(function(){return value;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("readFrom%3A%20aStream%20radix%3A%20radix%0D%0A%09%22%20Private%20-%20Read%20an%20integer%20from%20%3CaStream%3E%20and%20return%20it.%20%22%0D%0A%0D%0A%09%7C%20value%20char%20%7C%0D%0A%09value%20%3A%3D%200.%0D%0A%09%5B%09char%20%3A%3D%20aStream%20peek.%0D%0A%09%09char%20notNil%20and%3A%20%5B%20char%20isDigit%20or%3A%20%5B%20char%20isUpperCase%20%5D%20%5D%0D%0A%09%5D%20whileTrue%3A%20%5B%0D%0A%09%09radix%20%3C%20%20char%20digitValue%20ifTrue%3A%20%5B%20%5Evalue%20%5D.%0D%0A%09%09value%20%3A%3D%20value%20*%20radix%20+%20char%20digitValue.%0D%0A%09%09aStream%20next%0D%0A%09%5D.%0D%0A%09%5Evalue"));
smalltalk.bind(smalltalk.Number.$klass,"readFrom:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var value=nil;var $$char=nil;value=(0);
(function(){while((function(){$$char=aStream.peek();return (nil.isNil_($$char)===false).and_((function(){return $$char.isDigit();}));})()){(function(){value=value._star((10))._plus($$char.digitValue());return aStream.next();})()};return nil})();
((($$char === "r")).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return value;})();throw($s8Ret$)})();})());
aStream.next();
(function(){$s8Ret$.result=(function(){return self.readFrom_radix_(aStream, value);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("readFrom%3A%20aStream%0D%0A%09%22%20Private%20-%20Read%20an%20integer%20from%20%3CaStream%3E%20and%20return%20it.%20%22%0D%0A%0D%0A%09%7C%20value%20char%20%7C%0D%0A%09value%20%3A%3D%200.%0D%0A%09%5B%09char%20%3A%3D%20aStream%20peek.%0D%0A%09%09char%20notNil%20and%3A%20%5B%20char%20isDigit%20%5D%0D%0A%09%5D%20whileTrue%3A%20%5B%0D%0A%09%09value%20%3A%3D%20value%20*%2010%20+%20char%20digitValue.%0D%0A%09%09aStream%20next%0D%0A%09%5D.%0D%0A%09char%20%3D%3D%20%22%24r%22%27r%27%20ifFalse%3A%20%5B%20%5Evalue%20%5D.%0D%0A%09aStream%20next.%20%22skip%20the%20r%22%0D%0A%09%5Eself%20readFrom%3A%20aStream%20radix%3A%20value"));
smalltalk.bind(smalltalk.Number,"=","_eq"
,function (anObject){var self=this;  if (nil.isNil_(anObject)) return false;
    if (!(anObject.isNumber)) return false;
    if (!(anObject.isNumber())) return false;
    if (self == anObject) return true;
    return ((0+self-anObject) == 0);
;return self;}
,"comparing",unescape("%3D%20anObject%0D%0A%20%20%20%20%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%7B%27%20%20if%20%28nil.isNil_%28anObject%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28%21%28anObject.isNumber%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28%21%28anObject.isNumber%28%29%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28self%20%3D%3D%20anObject%29%20return%20true%3B%0D%0A%20%20%20%20return%20%28%280+self-anObject%29%20%3D%3D%200%29%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.Number,"mustBeNumber",0
,function (){var self=this;return self;}
,"testing",unescape("mustBeNumber%0D%0A%09%22%20Signal%20an%20error%20if%20the%20receiver%20is%20not%20a%20Number.%0D%0A%09WARNING%3A%20this%20check%20impose%20a%20severe%20loss%20of%20perfomance%20%28five%20times%20slower%29.%0D%0A%09If%20you%20are%20sure%20the%20operation/compare%20arguments%20are%20ok%20%28a%20number%29%2C%0D%0A%09%20comment%20the%20implementation%20of%20this%20method%20making%20the%20code%20empty.%0D%0A%09%22%0D%0A%0D%0A%09%22%28%23%20%23isNaN%3A%20self%29%20ifTrue%3A%20%5B%20super%20mustBeNumber%20%5D%22"));
smalltalk.bind(smalltalk.Number,">","_gt"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self > aNumber; ;return self;}
,"comparing",unescape("%3E%20aNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20greater%20to%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20%3E%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"<","_lt"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self < aNumber; ;return self;}
,"comparing",unescape("%3C%20aNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20smaller%20to%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20%3C%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,">=","_gt_eq"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self >= aNumber; ;return self;}
,"comparing",unescape("%3E%3D%20aNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20greater%20or%20equal%20to%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20%3E%3D%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"<=","_lt_eq"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self <= aNumber; ;return self;}
,"comparing",unescape("%3C%3D%20aNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20smaller%20or%20equal%20to%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20%3C%3D%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"+","_plus"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self + aNumber; ;return self;}
,"arithmetic",unescape("+%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20+%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"-","_minus"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self - aNumber; ;return self;}
,"arithmetic",unescape("-%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20-%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"*","_star"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self * aNumber; ;return self;}
,"arithmetic",unescape("*%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20*%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"/","_slash"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self / aNumber; ;return self;}
,"arithmetic",unescape("/%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20/%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"divideByZero",0
,function (){var self=this;return self.error_("Divide by Zero");;return self;}
,"signaling",unescape("divideByZero%0D%0A%09%22%20Signal%20divide%20by%20cero%20attempt.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Divide%20by%20Zero%27"));
smalltalk.bind(smalltalk.Number,unescape("%5C%5C"),"_bk_bk"
,function (aNumber){var self=this;aNumber.mustBeNumber();
((aNumber._eq((0))).mustBeBoolean()==true ? (function(){return self.divideByZero();})() : nil);
return self._minus(self._slash_slash(aNumber)._star(aNumber));;return self;}
,"arithmetic",unescape("%5C%5C%5C%5C%20aNumber%0D%0A%09%22%20Return%20the%20reminder%20of%20dividing%20the%20receiver%20by%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%09aNumber%20%3D%200%20ifTrue%3A%20%5B%20self%20divideByZero%20%5D.%0D%0A%09%5Eself%20-%20%28self%20//%20aNumber%20*%20aNumber%29"));
smalltalk.bind(smalltalk.Number,"//","_slash_slash"
,function (aNumber){var self=this;aNumber.mustBeNumber();
((aNumber._eq((0))).mustBeBoolean()==true ? (function(){return self.divideByZero();})() : nil);
return self._slash(aNumber).truncated();;return self;}
,"arithmetic",unescape("//%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%09aNumber%20%3D%200%20ifTrue%3A%20%5B%20self%20divideByZero%20%5D.%0D%0A%09%5E%28self%20/%20aNumber%29%20truncated"));
smalltalk.bind(smalltalk.Number,"sin",0
,function (){var self=this;return Math.sin(self);;return self;}
,"arithmetic",unescape("sin%0D%0A%09%5E%23%7BMath%7D%20%23sin%3A%20self"));
smalltalk.bind(smalltalk.Number,"cos",0
,function (){var self=this;return Math.cos(self);;return self;}
,"arithmetic",unescape("cos%0D%0A%09%5E%23%7BMath%7D%20%23cos%3A%20self"));
smalltalk.bind(smalltalk.Number,"tan",0
,function (){var self=this;return Math.tan(self);;return self;}
,"arithmetic",unescape("tan%0D%0A%09%5E%23%7BMath%7D%20%23tan%3A%20self"));
smalltalk.bind(smalltalk.Number,"atan2:",0
,function (aNumber){var self=this;aNumber.mustBeNumber();
return Math.atan2(self, aNumber);;return self;}
,"arithmetic",unescape("atan2%3A%20aNumber%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%09%5E%23%7BMath%7D%20%23atan2%3A%20self%20with%3A%20aNumber"));
smalltalk.bind(smalltalk.Number,"arcTan",0
,function (){var self=this;return Math.atan(self);;return self;}
,"arithmetic",unescape("arcTan%0D%0A%09%5E%23%7BMath%7D%20%23atan%3A%20self"));
smalltalk.bind(smalltalk.Number,"arcSin",0
,function (){var self=this;return Math.asin(self);;return self;}
,"arithmetic",unescape("arcSin%0D%0A%09%5E%23%7BMath%7D%20%23asin%3A%20self"));
smalltalk.bind(smalltalk.Number,"arcCos",0
,function (){var self=this;return Math.acos(self);;return self;}
,"arithmetic",unescape("arcCos%0D%0A%09%5E%23%7BMath%7D%20%23acos%3A%20self"));
smalltalk.bind(smalltalk.Number,"negated",0
,function (){var self=this;return (-1)._star(self);;return self;}
,"arithmetic",unescape("negated%0D%0A%09%5E-1%20*%20self%20"));
smalltalk.bind(smalltalk.Number,"squared",0
,function (){var self=this;return self._star(self);;return self;}
,"arithmetic",unescape("squared%0D%0A%09%5Eself%20*%20self%20"));
smalltalk.bind(smalltalk.Number,"sqrt",0
,function (){var self=this;return Math.sqrt(self);;return self;}
,"arithmetic",unescape("sqrt%0D%0A%09%5E%23%7BMath%7D%20%23sqrt%3A%20self"));
smalltalk.bind(smalltalk.Number,"<<","_lt_lt"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self << aNumber; ;return self;}
,"arithmetic",unescape("%3C%3C%20aNumber%0D%0A%09%22%20Return%20the%20receiver%20shifted%20aNumber%20of%20bits%20to%20the%20left.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20%3C%3C%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,">>","_gt_gt"
,function (aNumber){var self=this;aNumber.mustBeNumber();
	return self >> aNumber; ;return self;}
,"arithmetic",unescape("%3E%3E%20aNumber%0D%0A%09%22%20Return%20the%20receiver%20shifted%20aNumber%20of%20bits%20to%20the%20right.%20%22%0D%0A%0D%0A%09aNumber%20mustBeNumber.%0D%0A%7B%27%09return%20self%20%3E%3E%20aNumber%3B%20%27%7D"));
smalltalk.bind(smalltalk.Number,"bitShift:",0
,function (anInteger){var $s8Ret$={name:"stReturn"};try{var self=this;((anInteger._lt((0))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self._gt_gt(anInteger.negated());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self._lt_lt(anInteger);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("bitShift%3A%20anInteger%0D%0A%09%22%20Return%20the%20receiver%20shifted%20left%20anInteger%20number%20of%20bits%20if%20anInteger%20is%20positive%2C%20or%20shifted%20right%20for%20anInteger%20negated%20number%20of%20bits%20if%20anInteger%20is%20negative.%22%0D%0A%0D%0A%09anInteger%20%3C%200%20ifTrue%3A%20%5B%20%5Eself%20%3E%3E%20anInteger%20negated%20%5D.%0D%0A%09%5Eself%20%3C%3C%20anInteger"));
smalltalk.bind(smalltalk.Number,"max:",0
,function (aNumber){var self=this;return Math.max(self, aNumber);;return self;}
,"arithmetic",unescape("max%3A%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09%5E%23%7BMath%7D%20%23max%3A%20self%20with%3A%20aNumber"));
smalltalk.bind(smalltalk.Number,"min:",0
,function (aNumber){var self=this;return Math.min(self, aNumber);;return self;}
,"arithmetic",unescape("min%3A%20aNumber%0D%0A%09%22%20Return%20the%20result%20of%20operation%20on%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09%5E%23%7BMath%7D%20%23min%3A%20self%20with%3A%20aNumber"));
smalltalk.bind(smalltalk.Number,"asNumber",0
,function (){var self=this;return self._plus((0));;return self;}
,"converting",unescape("asNumber%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20Number.%20%22%0D%0A%0D%0A%09%5Eself%20+%200"));
smalltalk.bind(smalltalk.Number,"abs",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self._lt((0))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.negated();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("abs%0D%0A%09%22%20Return%20the%20absolute%20value%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%3C%200%20ifTrue%3A%20%5B%20%5Eself%20negated%20%5D.%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Number,"rounded",0
,function (){var self=this;return Math.round(self);;return self;}
,"converting",unescape("rounded%0D%0A%09%22%20Return%20the%20receiver%20rounded.%20%22%0D%0A%0D%0A%09%5E%23%7BMath%7D%20%23round%3A%20self"));
smalltalk.bind(smalltalk.Number,"truncated",0
,function (){var self=this;return Math.floor(self);;return self;}
,"converting",unescape("truncated%0D%0A%09%22%20Return%20the%20receiver%20truncated.%20%22%0D%0A%0D%0A%09%5E%23%7BMath%7D%20%23floor%3A%20self"));
smalltalk.bind(smalltalk.Number,"asCharacter",0
,function (){var self=this;return smalltalk.String.fromCharCode_(self);;return self;}
,"converting",unescape("asCharacter%0D%0A%09%22%20Return%20the%20character%20with%20the%20receiver%27s%20code.%20%22%0D%0A%0D%0A%09%5EString%20fromCharCode%3A%20self"));
smalltalk.bind(smalltalk.Number,"to:",0
,function (aNumber){var $s8Ret$={name:"stReturn"};try{var self=this;var array=nil;var first=nil;var last=nil;var count=nil;first=self.truncated();
last=aNumber.truncated()._plus((1));
count=(1);
((first._lt_eq(last)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Wrong interval");})();throw($s8Ret$)})();})());
array=smalltalk.Array.$$new();
(function(){for(var $1$=last._minus(first);$1$>0;$1$--){(function(){array.at_put_(count, first);count=count._plus((1));return first=first._plus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return array;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("to%3A%20aNumber%0D%0A%09%22%20Return%20a%20collection%20of%20numbers%20from%20the%20receiver%20to%20aNumber.%20%22%0D%0A%0D%0A%09%7C%20array%20first%20last%20count%20%7C%0D%0A%09first%20%3A%3D%20self%20truncated.%0D%0A%09last%20%3A%3D%20aNumber%20truncated%20+%201.%0D%0A%09count%20%3A%3D%201.%0D%0A%09first%20%3C%3D%20last%20ifFalse%3A%20%5B%20%5Eself%20error%3A%20%27Wrong%20interval%27%20%5D.%0D%0A%09array%20%3A%3D%20Array%20new.%0D%0A%09last%20-%20first%20timesRepeat%3A%20%5B%0D%0A%09%09array%20at%3A%20count%20put%3A%20first.%0D%0A%09%09count%20%3A%3D%20count%20+%201.%0D%0A%09%09first%20%3A%3D%20first%20+%201%0D%0A%09%5D.%0D%0A%09%5Earray"));
smalltalk.bind(smalltalk.Number,"timesRepeat:",0
,function (aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var count=nil;((aBlock.argumentCount()._eq((1))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (1).to_do_(self, aBlock);})();throw($s8Ret$)})();})() : nil);
count=(1);
(function(){while(!(function(){return count._gt(self);})()){(function(){aBlock.value();return count=count._plus((1));})()};return nil})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"enumerating",unescape("timesRepeat%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20a%20number%20of%20times%20given%20by%20the%20receiver.%0D%0A%09Return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20count%20%7C%0D%0A%09aBlock%20argumentCount%20%3D%201%20ifTrue%3A%20%5B%0D%0A%09%09%5E1%20to%3A%20self%20do%3A%20aBlock%0D%0A%09%5D.%0D%0A%09count%20%3A%3D%201.%0D%0A%09%5B%20count%20%3E%20self%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09aBlock%20value.%0D%0A%09%09count%20%3A%3D%20count%20+%201%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Number,"to:do:",0
,function (aNumber,aBlock){var self=this;	for(var i=self;i<=aNumber;i++){aBlock(i);} ;return self;}
,"iterating",unescape("to%3A%20aNumber%20do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20from%20the%20receiver%20to%20aNumber.%0D%0A%09Return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3Dself%3Bi%3C%3DaNumber%3Bi++%29%7BaBlock%28i%29%3B%7D%20%27%7D"));
smalltalk.bind(smalltalk.Number,"to:by:do:",0
,function (aNumber,increment,aBlock){var self=this;	if(increment>0) {
		for(var i=self;i<=aNumber;i=i+increment){aBlock(i);}
	} else{
		for(var i=self;aNumber<=i;i=i+increment){aBlock(i);}
	}	;return self;}
,"iterating",unescape("to%3A%20aNumber%20by%3A%20increment%20do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20the%20numbers%20between%20the%20receiver%20and%20aNumber%20where%20each%20number%20is%20the%20previous%20number%20plus%20increment.%0D%0A%09Return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%7B%27%09if%28increment%3E0%29%20%7B%0D%0A%09%09for%28var%20i%3Dself%3Bi%3C%3DaNumber%3Bi%3Di+increment%29%7BaBlock%28i%29%3B%7D%0D%0A%09%7D%20else%7B%0D%0A%09%09for%28var%20i%3Dself%3BaNumber%3C%3Di%3Bi%3Di+increment%29%7BaBlock%28i%29%3B%7D%0D%0A%09%7D%09%27%7D"));
smalltalk.bind(smalltalk.Number,"asString",0
,function (){var self=this;return self.printString();;return self;}
,"converting",unescape("asString%0D%0A%09%22%20Return%20the%20text%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20printString"));
smalltalk.bind(smalltalk.Number,"asJavascript",0
,function (){var self=this;return unescape("%28")._comma(self.printString())._comma(unescape("%29"));;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27%28%27%2C%20self%20printString%2C%20%27%29%27"));
smalltalk.bind(smalltalk.Number,"printString",0
,function (){var self=this;return String(self);;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%20%23String%3A%20self"));
smalltalk.bind(smalltalk.Number,"isNumber",0
,function (){var self=this;return isNaN(self).not();;return self;}
,"testing",unescape("isNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20number.%20%22%0D%0A%0D%0A%09%5E%28%23%20%23isNaN%3A%20self%29%20not"));
smalltalk.bind(smalltalk.Number,"atRandom",0
,function (){var self=this;return smalltalk.Random.$$new().next()._star(self).truncated()._plus((1));;return self;}
,"converting",unescape("atRandom%0D%0A%09%22%20Return%20a%20random%20integer%20in%20the%20interval%20from%201%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28Random%20new%20next%20*%20self%29%20truncated%20+%201"));
smalltalk.bind(smalltalk.Number,"@","_at"
,function (aNumber){var self=this;return smalltalk.Point.x_y_(self, (((nil.isNil_(aNumber))).mustBeBoolean()==true ? (function(){return (0);})() : (function(){return aNumber;})()));;return self;}
,"converting",unescape("@%20aNumber%0D%0A%09%22%20Return%20a%20Point%20with%20coordinates%20given%20by%20the%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09%5EPoint%20x%3A%20self%20y%3A%20%28aNumber%20isNil%20ifTrue%3A%20%5B0%5D%20ifFalse%3A%20%5BaNumber%5D%29"));
smalltalk.bind(smalltalk.Number,"asPoint",0
,function (){var self=this;return smalltalk.Point.x_y_(self, self);;return self;}
,"converting",unescape("asPoint%0D%0A%09%22%20Return%20a%20Point%20with%20both%20coordinates%20given%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPoint%20x%3A%20self%20y%3A%20self"));
smalltalk.bind(smalltalk.Number,"asJSONObject",0
,function (){var self=this;return self._plus((0));;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself%20+%200%0D%0A%22Note%3A%09we%20need%20to%20normalize%20result%20to%20do%20not%20destroy%20typeof%20checkings%0D%0A%09Do%20NOT%20modify%20this%20method%20if%20you%20do%20not%20know%20what%20you%20are%20doing.%0D%0A%09If%20you%20remove%20the%20+%200%20computation%2C%20the%20returned%20object%20will%20return%20%27object%27%20and%20not%20%27number%27%20as%20result%20of%20typeof%20operation.%0D%0A%22"));
smalltalk.bind(smalltalk.Number,"between:and:",0
,function (min,max){var self=this;return min._lt_eq(self).and_((function(){return self._lt_eq(max);}));;return self;}
,"testing",unescape("between%3A%20min%20and%3A%20max%0D%0A%09%22%20Answer%20true%20if%20the%20receiver%20is%20greater%20than%20or%20equal%20to%20min%20and%20less%20than%20or%20equal%20to%20max%2C%20else%20answer%20false.%20%22%0D%0A%0D%0A%09%5Emin%20%3C%3D%20self%20and%3A%20%5B%20self%20%3C%3D%20max%20%5D"));
smalltalk.bind(smalltalk.Number,"even",0
,function (){var self=this;return self._bk_bk((2))._eq((0));;return self;}
,"testing",unescape("even%0D%0A%09%22%20Answer%20true%20if%20the%20receiver%20is%20an%20even%20number.%20%22%0D%0A%0D%0A%09%5Eself%20%5C%5C%202%20%3D%200"));
smalltalk.bind(smalltalk.Number,"odd",0
,function (){var self=this;return self._bk_bk((2))._eq((1));;return self;}
,"testing",unescape("odd%0D%0A%09%22%20Answer%20true%20if%20the%20receiver%20is%20an%20odd%20number.%20%22%0D%0A%0D%0A%09%5Eself%20%5C%5C%202%20%3D%201"));
smalltalk.bind(smalltalk.Number,"clearInterval",0
,function (){var self=this;clearInterval(Number(self));return self;}
,"intervals",unescape("clearInterval%0D%0A%0D%0A%09%23%20%23clearInterval%3A%20%28%23%20%23Number%3A%20self%29"));
smalltalk.bind(smalltalk.Number,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Number,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Number,"yourself",0
,function (){var self=this;return self._plus((0));;return self;}
,"identity",unescape("yourself%20%0D%0A%09%22%20Return%20the%20receiver.%0D%0A%09Note%3A%20do%20NOT%20modify/remove%20this%20method%20if%20you%20dont%20know%20what%20you%20are%20doing.%0D%0A%09Test%20the%20following%20expression%20after%20changing%20this%20code%3A%0D%0A%09%09123%20yourself%20%3D%3D%20123%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20+%200"));
smalltalk.bind(smalltalk.BlockClosure.$klass,"hasDeferredSupport",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(function(){return (nil.isNil_(setTimeout)===false);}).on_do_(smalltalk.Error, (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return (nil.isNil_(setTimeout)===false);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"deferredEvaluation",unescape("hasDeferredSupport%0D%0A%09%22%20Return%20true%20if%20the%20platform%20can%20defer%20instance%20evaluation.%20%22%0D%0A%0D%0A%09%5B%20%23%7BsetTimeout%7D%20notNil%20%5D%20on%3A%20Error%20do%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5E%23%7BsetTimeout%7D%20notNil"));
smalltalk.bind(smalltalk.BlockClosure,"compiledSource",0
,function (){var self=this;return self.toString();;return self;}
,"accessing",unescape("compiledSource%0D%0A%09%22%20Return%20the%20source%20code%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20toString"));
smalltalk.bind(smalltalk.BlockClosure,"whileTrue:",0
,function (aBlock){var self=this;	while(self()) {aBlock()}; ;return self;}
,"iterating",unescape("whileTrue%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20while%20the%20result%20of%20evaluating%20the%20receiver%20is%20true.%20%22%0D%0A%0D%0A%7B%27%09while%28self%28%29%29%20%7BaBlock%28%29%7D%3B%20%27%7D"));
smalltalk.bind(smalltalk.BlockClosure,"whileFalse:",0
,function (aBlock){var self=this;	while(!self()) {aBlock()}; ;return self;}
,"iterating",unescape("whileFalse%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20while%20the%20result%20of%20evaluating%20the%20receiver%20is%20false.%20%22%0D%0A%0D%0A%7B%27%09while%28%21self%28%29%29%20%7BaBlock%28%29%7D%3B%20%27%7D"));
smalltalk.bind(smalltalk.BlockClosure,"value",0
,function (){var self=this;return self();;return self;}
,"evaluating",unescape("value%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%20%23self"));
smalltalk.bind(smalltalk.BlockClosure,"value:",0
,function (anObject){var self=this;return self(anObject);;return self;}
,"evaluating",unescape("value%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%5E%23%20%23self%3A%20anObject"));
smalltalk.bind(smalltalk.BlockClosure,"value:value:",0
,function (firstArgument,secondArgument){var self=this;return self(firstArgument, secondArgument);;return self;}
,"evaluating",unescape("value%3A%20firstArgument%20value%3A%20secondArgument%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20arguments.%20%22%0D%0A%0D%0A%09%5E%23%20%23self%3A%20firstArgument%20value%3A%20secondArgument"));
smalltalk.bind(smalltalk.BlockClosure,"value:value:value:",0
,function (firstArgument,secondArgument,thirdArgument){var self=this;return self(firstArgument, secondArgument, thirdArgument);;return self;}
,"evaluating",unescape("value%3A%20firstArgument%20value%3A%20secondArgument%20value%3A%20thirdArgument%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20arguments.%20%22%0D%0A%0D%0A%09%5E%23%20%23self%3A%20firstArgument%20value%3A%20secondArgument%20value%3A%20thirdArgument"));
smalltalk.bind(smalltalk.BlockClosure,"valueWithPossibleArguments:",0
,function (aCollection){var self=this;((aCollection.isArray()).mustBeBoolean()==true ? nil : (function(){return self.error_(unescape("//%20Invalid%20arguments%20in%20%23valueWithPossibleArguments%3A%20%28must%20be%20anArray%29.%20receiver%3D")._comma(self.toString()));})());
return self.apply(null, aCollection);;return self;}
,"evaluating",unescape("valueWithPossibleArguments%3A%20aCollection%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20potential%20arguments.%20%22%0D%0A%0D%0A%09aCollection%20isArray%20ifFalse%3A%20%5B%0D%0A%09%09self%20error%3A%20%27//%20Invalid%20arguments%20in%20%23valueWithPossibleArguments%3A%20%28must%20be%20anArray%29.%20receiver%3D%27%2Cself%20toString%0D%0A%09%5D.%0D%0A%09%5Eself%20%23apply%3A%20%23%7Bnull%7D%20arguments%3A%20aCollection"));
smalltalk.bind(smalltalk.BlockClosure,"on:do:",0
,function (anExceptionType,aBlock){var self=this;return self.try_catch_(self, (function(error){return ((smalltalk.is_kindOf_(error,(anExceptionType))).mustBeBoolean()==true ? (function(){return aBlock.value_(error);})() : (function(){return error.signal();})());}));;return self;}
,"error",unescape("on%3A%20anExceptionType%20do%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20catching%20exceptions.%20%22%0D%0A%0D%0A%09%5Eself%20try%3A%20self%20catch%3A%20%5B%3Aerror%20%7C%0D%0A%09%09%28error%20isKindOf%3A%20anExceptionType%29%0D%0A%09%09ifTrue%3A%20%5B%20aBlock%20value%3A%20error%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20error%20signal%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.BlockClosure,"try:catch:",0
,function (aBlock,anotherBlock){var self=this;	var result;
	try{ result = aBlock() } catch(e) {
		result = anotherBlock( self.smalltalkErrorOf_(e) )
	};
	return result;;return self;}
,"private",unescape("try%3A%20aBlock%20catch%3A%20anotherBlock%0D%0A%09%22%20Private%20-%20Try%20to%20evaluate%20aBlock%20catching%20exceptions%20with%20catchBlock.%20%22%0D%0A%0D%0A%7B%27%09var%20result%3B%0D%0A%09try%7B%20result%20%3D%20aBlock%28%29%20%7D%20catch%28e%29%20%7B%0D%0A%09%09result%20%3D%20anotherBlock%28%20self.smalltalkErrorOf_%28e%29%20%29%0D%0A%09%7D%3B%0D%0A%09return%20result%3B%27%7D"));
smalltalk.bind(smalltalk.BlockClosure,"valueDeferred:",0
,function (milliseconds){var self=this;self.valueWithTimeout_(milliseconds);return self;}
,"evaluating",unescape("valueDeferred%3A%20milliseconds%0D%0A%09%22%20Evaluate%20the%20receiver%20deferred%20in%20time.%0D%0A%09Return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09self%20valueWithTimeout%3A%20milliseconds"));
smalltalk.bind(smalltalk.BlockClosure,"valueDeferred",0
,function (){var self=this;self.valueDeferred_((0));return self;}
,"evaluating",unescape("valueDeferred%0D%0A%09%22%20Evaluate%20the%20receiver%20deferred%20in%20time.%0D%0A%09Return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09self%20valueDeferred%3A%200"));
smalltalk.bind(smalltalk.BlockClosure,"valueWithTimeout:",0
,function (aNumber){var $s8Ret$={name:"stReturn"};try{var self=this;((smalltalk.Coco8Closure.isInstalled()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Coco8Closure.value_after_(self, aNumber);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return setTimeout(self, aNumber);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"NSObject-timeout",unescape("valueWithTimeout%3A%20aNumber%0D%0A%09%22%20Evaluate%20the%20receiver%20with%20time%20out.%20%22%0D%0A%0D%0A%09Coco8Closure%20isInstalled%20ifTrue%3A%20%5B%0D%0A%09%09%5ECoco8Closure%20value%3A%20self%20after%3A%20aNumber%0D%0A%09%5D.%0D%0A%09%22if%20coco8%20is%20not%20running%2C%20we%20will%20try%20with%20default%20impl.%22%0D%0A%09%5E%23%20%23setTimeout%3A%20self%20with%3A%20aNumber"));
smalltalk.bind(smalltalk.BlockClosure,"valueWithInterval:",0
,function (aNumber){var self=this;return setInterval(self, aNumber);;return self;}
,"timeout",unescape("valueWithInterval%3A%20aNumber%0D%0A%09%22%20Evaluate%20the%20receiver%20with%20interval.%20%22%0D%0A%0D%0A%09%5E%23%20%23setInterval%3A%20self%20with%3A%20aNumber"));
smalltalk.bind(smalltalk.BlockClosure,"ensure:",0
,function (aBlock){var self=this;	try{return self();} finally {aBlock();}	;return self;}
,"error",unescape("ensure%3A%20aBlock%0D%0A%09%22%20Returns%20the%20result%20of%20evaluating%20the%20receiver.%0D%0A%09Execute%20aBlock%20after%20the%20receiver%20is%20executed.%0D%0A%09%22%0D%0A%0D%0A%7B%27%09try%7Breturn%20self%28%29%3B%7D%20finally%20%7BaBlock%28%29%3B%7D%09%27%7D"));
smalltalk.bind(smalltalk.BlockClosure,"argumentCount",0
,function (){var self=this;return self.length;;return self;}
,"evaluating",unescape("argumentCount%0D%0A%09%22%20Return%20the%20number%20of%20arguments%20defined%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%23length"));
smalltalk.bind(smalltalk.BlockClosure,"installAs:",0
,function (functionName){var self=this;return (smalltalk.Smalltalk.global()[functionName]=(self));;return self;}
,"installing",unescape("installAs%3A%20functionName%0D%0A%09%22%20Install%20the%20receiver%20as%20a%20function%20in%20global%20scope.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20global%20basicAt%3A%20functionName%20put%3A%20self"));
smalltalk.bind(smalltalk.BlockClosure,"asJSONObject",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.BlockClosure,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.BlockClosure,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.BlockClosure,"ms",0
,function (){var self=this;return smalltalk.DateTime.millisecondsToRun_(self);;return self;}
,"timming",unescape("ms%0D%0A%09%22%20Return%20the%20milliseconds%20taken%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EDateTime%20millisecondsToRun%3A%20self"));
smalltalk.bind(smalltalk.BlockClosure,"evaluateFor:",0
,function (anObject){var self=this;return self(anObject);;return self;}
,"evaluating",unescape("evaluateFor%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%5E%23%20%23self%3A%20anObject"));
smalltalk.bind(smalltalk.BlockClosure,"evaluate",0
,function (){var self=this;return self();;return self;}
,"evaluating",unescape("evaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%20self"));
smalltalk.bind(smalltalk.BlockClosure,"evaluateWithArguments:",0
,function (anArray){var self=this;return self.valueWithPossibleArguments_(anArray);;return self;}
,"evaluating",unescape("evaluateWithArguments%3A%20anArray%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20valueWithPossibleArguments%3A%20anArray"));
smalltalk.bind(smalltalk.BlockClosure,"valueWithArguments:",0
,function (anArray){var self=this;return self.valueWithPossibleArguments_(anArray);;return self;}
,"evaluating",unescape("valueWithArguments%3A%20anArray%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20arguments.%20%22%0D%0A%0D%0A%09%5Eself%20valueWithPossibleArguments%3A%20anArray"));
smalltalk.bind(smalltalk.BlockClosure,"valueWithDNU",0
,function (){var self=this;return smalltalk.Object.hackDNUWhile_(self);;return self;}
,"Tools-hacking",unescape("valueWithDNU%0D%0A%09%22%20Catch%20DNU%20hacking%20while%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EObject%20hackDNUWhile%3A%20self"));
smalltalk.bind(smalltalk.BlockClosure,"valueOnMainThreadWithArguments:",0
,function (args){var $s8Ret$={name:"stReturn"};try{var self=this;((smalltalk.Coco8Closure.isInstalled()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Coco8Closure.value_withArguments_(self, args);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.valueWithArguments_(args);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"NSObject-timeout",unescape("valueOnMainThreadWithArguments%3A%20args%0D%0A%09%22%20Evaluate%20the%20receiver%20in%20the%20main%20thread.%20%22%0D%0A%0D%0A%09Coco8Closure%20isInstalled%20ifTrue%3A%20%5B%0D%0A%09%09%5ECoco8Closure%20value%3A%20self%20withArguments%3A%20args%0D%0A%09%5D.%0D%0A%09%22if%20coco8%20is%20not%20running%2C%20we%20simulate%20the%20evaluation.%22%0D%0A%09%5Eself%20valueWithArguments%3A%20args"));
smalltalk.bind(smalltalk.BlockClosure,"valueOnMainThread",0
,function (){var self=this;return self.valueOnMainThreadWithArguments_([]);;return self;}
,"NSObject-timeout",unescape("valueOnMainThread%0D%0A%09%22%20Evaluate%20the%20receiver%20in%20the%20main%20thread.%20%22%0D%0A%0D%0A%09%5Eself%20valueOnMainThreadWithArguments%3A%20%23%28%29"));
smalltalk.bind(smalltalk.Boolean.$klass,"@","_at"
,function (aBOOL){var self=this;
	if (aBOOL === true) return true;
	if (aBOOL === 1) return true;
	if ((1 & aBOOL) + 0 == 1) return true;
;
return false;;return self;}
,"Natives-converting",unescape("@%20aBOOL%0D%0A%09%22%20Return%20aBOOL%20as%20a%20Boolean%20instance.%20%22%0D%0A%7B%27%0D%0A%09if%20%28aBOOL%20%3D%3D%3D%20true%29%20return%20true%3B%0D%0A%09if%20%28aBOOL%20%3D%3D%3D%201%29%20return%20true%3B%0D%0A%09if%20%28%281%20%26%20aBOOL%29%20+%200%20%3D%3D%201%29%20return%20true%3B%0D%0A%27%7D.%09%5Efalse"));
smalltalk.bind(smalltalk.Boolean,"mustBeBoolean",0
,function (){var self=this;return self;;return self;}
,"testing",unescape("mustBeBoolean%0D%0A%09%22%20Signal%20an%20error%20if%20the%20receiver%20is%20not%20a%20Boolean.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Boolean,"=","_eq"
,function (anObject){var self=this;  if (nil.isNil_(anObject)) return false;
    if (!(self.$klass === anObject.$klass)) return false;
    return (self.valueOf() == anObject.valueOf());
;return self;}
,"comparing",unescape("%3D%20anObject%0D%0A%20%20%20%20%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%7B%27%20%20if%20%28nil.isNil_%28anObject%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28%21%28self.%24klass%20%3D%3D%3D%20anObject.%24klass%29%29%20return%20false%3B%0D%0A%20%20%20%20return%20%28self.valueOf%28%29%20%3D%3D%20anObject.valueOf%28%29%29%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.Boolean,"ifTrue:",0
,function (aBlock){var self=this;return ((self).mustBeBoolean()==true ? (function(){return aBlock.value();})() : (function(){return nil;})());;return self;}
,"control",unescape("ifTrue%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20true%2C%20else%20return%20nil.%20%22%0D%0A%0D%0A%09%5Eself%20ifTrue%3A%20%5B%20aBlock%20value%20%5D%20ifFalse%3A%20%5B%5D"));
smalltalk.bind(smalltalk.Boolean,"ifFalse:",0
,function (aBlock){var self=this;return ((self).mustBeBoolean()==true ? (function(){return nil;})() : (function(){return aBlock.value();})());;return self;}
,"control",unescape("ifFalse%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20false%2C%20else%20return%20nil.%20%22%0D%0A%0D%0A%09%5Eself%20ifTrue%3A%20%5B%5D%20ifFalse%3A%20%5B%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.Boolean,"ifFalse:ifTrue:",0
,function (aBlock,anotherBlock){var self=this;return self.ifTrue_ifFalse_(anotherBlock, (function(){return aBlock.value();}));;return self;}
,"control",unescape("ifFalse%3A%20aBlock%20ifTrue%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20false%2C%20else%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%09%5Eself%20ifTrue%3A%20anotherBlock%20ifFalse%3A%20%5B%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.Boolean,"ifTrue:ifFalse:",0
,function (aBlock,anotherBlock){var self=this;	if(self == true) { return aBlock.value(); } else { return anotherBlock.value(); }; ;return self;}
,"control",unescape("ifTrue%3A%20aBlock%20ifFalse%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20the%20receiver%20is%20true%2C%20else%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%7B%27%09if%28self%20%3D%3D%20true%29%20%7B%20return%20aBlock.value%28%29%3B%20%7D%20else%20%7B%20return%20anotherBlock.value%28%29%3B%20%7D%3B%20%27%7D"));
smalltalk.bind(smalltalk.Boolean,"and:",0
,function (aBlock){var self=this;return ((self).mustBeBoolean()==true ? (function(){return aBlock.value();})() : (function(){return false;})());;return self;}
,"control",unescape("and%3A%20aBlock%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20true%20and%20the%20result%20of%20evaluating%20aBlock%20is%20also%20true.%20%22%0D%0A%0D%0A%09%5Eself%20ifTrue%3A%20%5B%20aBlock%20value%20%5D%20ifFalse%3A%20%5Bfalse%5D"));
smalltalk.bind(smalltalk.Boolean,"or:",0
,function (aBlock){var self=this;return ((self).mustBeBoolean()==true ? (function(){return true;})() : (function(){return aBlock.value();})());;return self;}
,"control",unescape("or%3A%20aBlock%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20true%20or%20the%20result%20of%20evaluating%20aBlock%20is%20true.%20%22%0D%0A%0D%0A%09%5Eself%20ifTrue%3A%20%5Btrue%5D%20ifFalse%3A%20%5B%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.Boolean,"not",0
,function (){var self=this;return  self == false ;;return self;}
,"control",unescape("not%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20false.%20%22%0D%0A%0D%0A%09%5E%7B%27%20self%20%3D%3D%20false%20%27%7D"));
smalltalk.bind(smalltalk.Boolean,"printString",0
,function (){var self=this;return self.toString();;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20a%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23toString"));
smalltalk.bind(smalltalk.Boolean,"asJSONObject",0
,function (){var self=this;return self.and_((function(){return true;}));;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself%20and%3A%20%5B%20true%20%5D"));
smalltalk.bind(smalltalk.Boolean,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Boolean,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Boolean,"isBoolean",0
,function (){var self=this;return true;;return self;}
,"query",unescape("isBoolean%0D%0A%09%22%20Returns%20true%20if%20the%20receiver%20is%20a%20boolean.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Boolean,"yourself",0
,function (){var self=this;return self.and_((function(){return true;}));;return self;}
,"identity",unescape("yourself%0D%0A%09%22%20Return%20the%20receiver.%0D%0A%09Note%3A%20do%20NOT%20modify/remove%20this%20method%20if%20you%20dont%20know%20what%20you%20are%20doing.%0D%0A%09Test%20the%20following%20expression%20after%20changing%20this%20code%3A%0D%0A%09%09true%20yourself%20%3D%3D%20true%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20and%3A%20%5B%20true%20%5D"));
smalltalk.bind(smalltalk.DateTime.$klass,"new:",0
,function (anObject){var self=this;	return new Date(anObject); ;return self;}
,"instantiation",unescape("new%3A%20anObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20new%20Date%28anObject%29%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime.$klass,"fromString:",0
,function (aString){var self=this;return self.new_(aString);;return self;}
,"instantiation",unescape("fromString%3A%20aString%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%0D%0A%09DateTime%20fromString%3A%20%271962/12/15%2001%3A40%3A00%27%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20new%3A%20aString"));
smalltalk.bind(smalltalk.DateTime.$klass,"fromSeconds:",0
,function (aNumber){var self=this;return self.fromMilliseconds_(aNumber._star((1000)));;return self;}
,"instantiation",unescape("fromSeconds%3A%20aNumber%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20fromMilliseconds%3A%20aNumber%20*%201000"));
smalltalk.bind(smalltalk.DateTime.$klass,"fromMilliseconds:",0
,function (aNumber){var self=this;return self.new_(aNumber);;return self;}
,"instantiation",unescape("fromMilliseconds%3A%20aNumber%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime.$klass,"today",0
,function (){var self=this;return self.$$new();;return self;}
,"instantiation",unescape("today%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new"));
smalltalk.bind(smalltalk.DateTime.$klass,"now",0
,function (){var self=this;return self.today();;return self;}
,"instantiation",unescape("now%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20today"));
smalltalk.bind(smalltalk.DateTime.$klass,"millisecondsToRun:",0
,function (aBlock){var self=this;var start=nil;start=smalltalk.DateTime.now();
aBlock.value();
return smalltalk.DateTime.now()._minus(start);;return self;}
,"instantiation",unescape("millisecondsToRun%3A%20aBlock%0D%0A%09%22%20Return%20the%20time%20elapsed%20during%20evaluation%20of%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20start%20%7C%0D%0A%09start%20%3A%3D%20DateTime%20now.%0D%0A%09aBlock%20value.%0D%0A%09%5EDateTime%20now%20-%20start"));
smalltalk.bind(smalltalk.DateTime,"year",0
,function (){var self=this;return self.getFullYear();;return self;}
,"accessing",unescape("year%0D%0A%09%22%20Return%20the%20year%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getFullYear"));
smalltalk.bind(smalltalk.DateTime,"month",0
,function (){var self=this;return self.getMonth()._plus((1));;return self;}
,"accessing",unescape("month%0D%0A%09%22%20Return%20the%20month%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getMonth%20+%201"));
smalltalk.bind(smalltalk.DateTime,"month:",0
,function (aNumber){var self=this;self.setMonth(aNumber._minus((1)));return self;}
,"accessing",unescape("month%3A%20aNumber%0D%0A%09%22%20Set%20the%20month%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setMonth%3A%20aNumber%20-%201"));
smalltalk.bind(smalltalk.DateTime,"day",0
,function (){var self=this;return self.dayOfWeek();;return self;}
,"accessing",unescape("day%0D%0A%09%22%20Return%20the%20day%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20dayOfWeek"));
smalltalk.bind(smalltalk.DateTime,"dayOfWeek",0
,function (){var self=this;return self.getDay()._plus((1));;return self;}
,"accessing",unescape("dayOfWeek%0D%0A%09%22%20Return%20the%20day%20of%20week%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getDay%20+%201"));
smalltalk.bind(smalltalk.DateTime,"dayOfWeek:",0
,function (aNumber){var self=this;self.setDay(aNumber._minus((1)));return self;}
,"accessing",unescape("dayOfWeek%3A%20aNumber%0D%0A%09%22%20Set%20the%20day%20of%20week%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setDay%3A%20aNumber%20-%201"));
smalltalk.bind(smalltalk.DateTime,"day:",0
,function (aNumber){var self=this;self.day_(aNumber);return self;}
,"accessing",unescape("day%3A%20aNumber%0D%0A%09%22%20Set%20the%20day%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20day%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"year:",0
,function (aNumber){var self=this;self.setFullYear(aNumber);return self;}
,"accessing",unescape("year%3A%20aNumber%0D%0A%09%22%20Set%20the%20year%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setFullYear%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"dayOfMonth",0
,function (){var self=this;return self.getDate();;return self;}
,"accessing",unescape("dayOfMonth%0D%0A%09%22%20Return%20the%20day%20of%20month%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getDate"));
smalltalk.bind(smalltalk.DateTime,"dayOfMonth:",0
,function (aNumber){var self=this;self.setDate(aNumber);return self;}
,"accessing",unescape("dayOfMonth%3A%20aNumber%0D%0A%09%22%20Set%20the%20day%20of%20month%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setDate%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"asString",0
,function (){var self=this;return self.toString();;return self;}
,"converting",unescape("asString%0D%0A%09%22%20Return%20the%20text%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23toString"));
smalltalk.bind(smalltalk.DateTime,"printString",0
,function (){var self=this;return self.asString();;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20asString"));
smalltalk.bind(smalltalk.DateTime,"asMilliseconds",0
,function (){var self=this;return self.time();;return self;}
,"converting",unescape("asMilliseconds%0D%0A%09%22%20Return%20the%20receiver%20as%20milliseconds.%20%22%0D%0A%0D%0A%09%5Eself%20time"));
smalltalk.bind(smalltalk.DateTime,"time",0
,function (){var self=this;return self.getTime();;return self;}
,"accessing",unescape("time%0D%0A%09%22%20Return%20the%20time%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getTime"));
smalltalk.bind(smalltalk.DateTime,"time:",0
,function (aNumber){var self=this;self.setTime(aNumber);return self;}
,"accessing",unescape("time%3A%20aNumber%0D%0A%09%22%20Set%20the%20time%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setTime%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"asDateString",0
,function (){var self=this;return self.toDateString();;return self;}
,"converting",unescape("asDateString%0D%0A%09%22%20Return%20the%20date%20string%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23toDateString"));
smalltalk.bind(smalltalk.DateTime,"asTimeString",0
,function (){var self=this;return self.toTimeString();;return self;}
,"converting",unescape("asTimeString%0D%0A%09%22%20Return%20the%20time%20string%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23toTimeString"));
smalltalk.bind(smalltalk.DateTime,"asLocaleString",0
,function (){var self=this;return self.toLocaleString();;return self;}
,"converting",unescape("asLocaleString%0D%0A%09%22%20Return%20the%20locale%20string%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23toLocaleString"));
smalltalk.bind(smalltalk.DateTime,"asNumber",0
,function (){var self=this;return self.asMilliseconds();;return self;}
,"converting",unescape("asNumber%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20Number.%20%22%0D%0A%0D%0A%09%5Eself%20asMilliseconds"));
smalltalk.bind(smalltalk.DateTime,"hours:",0
,function (aNumber){var self=this;return self.setHours(aNumber);;return self;}
,"accessing",unescape("hours%3A%20aNumber%0D%0A%09%22%20Set%20the%20hours%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23setHours%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"minutes:",0
,function (aNumber){var self=this;self.setMinutes(aNumber);return self;}
,"accessing",unescape("minutes%3A%20aNumber%0D%0A%09%22%20Set%20the%20minutes%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setMinutes%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"seconds:",0
,function (aNumber){var self=this;self.setSeconds(aNumber);return self;}
,"accessing",unescape("seconds%3A%20aNumber%0D%0A%09%22%20Set%20the%20seconds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setSeconds%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"milliseconds:",0
,function (aNumber){var self=this;self.setMilliseconds(aNumber);return self;}
,"accessing",unescape("milliseconds%3A%20aNumber%0D%0A%09%22%20Set%20the%20milliseconds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23setMilliseconds%3A%20aNumber"));
smalltalk.bind(smalltalk.DateTime,"hours",0
,function (){var self=this;return self.getHours();;return self;}
,"accessing",unescape("hours%0D%0A%09%22%20Return%20the%20hours%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getHours"));
smalltalk.bind(smalltalk.DateTime,"minutes",0
,function (){var self=this;return self.getMinutes();;return self;}
,"accessing",unescape("minutes%0D%0A%09%22%20Return%20the%20minutes%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20getMinutes"));
smalltalk.bind(smalltalk.DateTime,"seconds",0
,function (){var self=this;return self.getSeconds();;return self;}
,"accessing",unescape("seconds%0D%0A%09%22%20Return%20the%20seconds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getSeconds"));
smalltalk.bind(smalltalk.DateTime,"milliseconds",0
,function (){var self=this;return self.getMilliseconds();;return self;}
,"accessing",unescape("milliseconds%0D%0A%09%22%20Return%20the%20milliseconds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23getMilliseconds"));
smalltalk.bind(smalltalk.DateTime,"<","_lt"
,function (aDateTime){var self=this;	return self < aDateTime; ;return self;}
,"comparing",unescape("%3C%20aDateTime%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20previous%20to%20aDateTime.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20%3C%20aDateTime%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime,">","_gt"
,function (aDateTime){var self=this;	return self > aDateTime; ;return self;}
,"comparing",unescape("%3E%20aDateTime%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20later%20than%20aDateTime.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20%3E%20aDateTime%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime,"<=","_lt_eq"
,function (aDateTime){var self=this;	return self <= aDateTime; ;return self;}
,"comparing",unescape("%3C%3D%20aDateTime%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20previous%20or%20equal%20to%20aDateTime.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20%3C%3D%20aDateTime%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime,">=","_gt_eq"
,function (aDateTime){var self=this;	return self >= aDateTime; ;return self;}
,"comparing",unescape("%3E%3D%20aDateTime%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20later%20or%20equal%20to%20aDateTime.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20%3E%3D%20aDateTime%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime,"-","_minus"
,function (aDateTime){var self=this;	return self - aDateTime; ;return self;}
,"arithmetic",unescape("-%20aDateTime%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20receiver%20and%20aDateTime.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20-%20aDateTime%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime,"+","_plus"
,function (aDateTime){var self=this;	return self + aDateTime; ;return self;}
,"arithmetic",unescape("+%20aDateTime%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20receiver%20and%20aDateTime.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20+%20aDateTime%3B%20%27%7D"));
smalltalk.bind(smalltalk.DateTime,"isValid",0
,function (){var self=this;return isFinite(self);;return self;}
,"testing",unescape("isValid%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20valid%20instance.%20%22%0D%0A%0D%0A%09%5E%23%20%23isFinite%3A%20self"));
smalltalk.bind(smalltalk.DateTime,"asJSONObject",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.UndefinedObject.$klass,"new","$$new"
,function (){var self=this;return self.error_(unescape("UndefinedObject%20can%27t%20be%20instantiated."));;return self;}
,"instantiation",unescape("new%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27UndefinedObject%20can%27%27t%20be%20instantiated.%27"));
smalltalk.bind(smalltalk.UndefinedObject,"ifNil:",0
,function (aBlock){var self=this;return aBlock.value();;return self;}
,"testing",unescape("ifNil%3A%20aBlock%0D%0A%09%22%20Return%20the%20receiver%20if%20it%20is%20not%20nil%2C%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20it%20is%20nil%29.%20%22%0D%0A%0D%0A%09%5EaBlock%20value"));
smalltalk.bind(smalltalk.UndefinedObject,"ifNotNil:",0
,function (aBlock){var self=this;return self;;return self;}
,"testing",unescape("ifNotNil%3A%20aBlock%0D%0A%09%22%20Return%20the%20receiver%20if%20it%20is%20nil%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.UndefinedObject,"ifNil:ifNotNil:",0
,function (aBlock,anotherBlock){var self=this;return aBlock.value();;return self;}
,"testing",unescape("ifNil%3A%20aBlock%20ifNotNil%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20receiver%20if%20it%20is%20nil%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5EaBlock%20value"));
smalltalk.bind(smalltalk.UndefinedObject,"ifNotNil:ifNil:",0
,function (aBlock,anotherBlock){var self=this;return anotherBlock.value();;return self;}
,"testing",unescape("ifNotNil%3A%20aBlock%20ifNil%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20anotherBlock%20if%20teh%20receiver%20is%20nil%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5EanotherBlock%20value"));
smalltalk.bind(smalltalk.UndefinedObject,"isNil",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isNil%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20nil.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.UndefinedObject,"notNil",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("notNil%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20nil.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.UndefinedObject,"printString",0
,function (){var self=this;return "nil";;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20the%20text%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23nil"));
smalltalk.bind(smalltalk.UndefinedObject,"subclass:instanceVariableNames:",0
,function (aString,anotherString){var self=this;return self.subclass_instanceVariableNames_category_(aString, anotherString, nil);;return self;}
,"instantiation",unescape("subclass%3A%20aString%20instanceVariableNames%3A%20anotherString%0D%0A%09%22%20Create%20a%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20anotherString%0D%0A%09%09category%3A%20nil"));
smalltalk.bind(smalltalk.UndefinedObject,"subclass:instanceVariableNames:category:",0
,function (aString,aString2,aString3){var self=this;return smalltalk.ClassBuilder.$$new().superclass_subclass_instanceVariableNames_category_(self, aString, aString2, aString3);;return self;}
,"instantiation",unescape("subclass%3A%20aString%20instanceVariableNames%3A%20aString2%20category%3A%20aString3%0D%0A%09%22%20Create%20a%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EClassBuilder%20new%0D%0A%09%09superclass%3A%20self%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09category%3A%20aString3"));
smalltalk.bind(smalltalk.UndefinedObject,"asJSONObject",0
,function (){var self=this;return null;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5E%23%7Bnull%7D"));
smalltalk.bind(smalltalk.UndefinedObject,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.UndefinedObject,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.UndefinedObject,"value",0
,function (){var self=this;return self;}
,"evaluating",unescape("value%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22"));
smalltalk.bind(smalltalk.UndefinedObject,"@","_at"
,function (aNumber){var self=this;return smalltalk.Point.x_y_((0), aNumber);;return self;}
,"converting",unescape("@%20aNumber%0D%0A%09%22%20Return%20a%20Point%20with%20coordinates%20given%20by%20the%20receiver%20and%20aNumber.%20%22%0D%0A%0D%0A%09%5EPoint%20x%3A%200%20y%3A%20aNumber"));
smalltalk.bind(smalltalk.UndefinedObject,"=","_eq"
,function (anObject){var self=this;return (nil.isNil_(anObject));;return self;}
,"comparing",unescape("%3D%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%09%5EanObject%20isNil"));
smalltalk.bind(smalltalk.UndefinedObject,"~=","_no_eq"
,function (anObject){var self=this;return (nil.isNil_(anObject)===false);;return self;}
,"comparing",unescape("%7E%3D%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%09%5EanObject%20notNil"));
smalltalk.bind(smalltalk.UndefinedObject,"category:",0
,function (ignored){var self=this;return self;}
,"instantiation",unescape("category%3A%20ignored%0D%0A%09%22%20BUG%20-%20throw%20an%20error%20in%20ClassBuilder.%20%22%20"));
smalltalk.bind(smalltalk.UndefinedObject,"subclass:instanceVariableNames:classVariableNames:poolDictionaries:category:",0
,function (aString,aString2,classVarNames,poolVarNames,aCategory){var self=this;(((nil.isNil_(self.smalltalk().globalAt_(aString))===false)).mustBeBoolean()==true ? (function(){return self.print_(unescape("//%20WARNING%3A%20class%20REdefinition%20for%20")._comma(aString));})() : nil);
return smalltalk.ClassBuilder.$$new().superclass_subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(self, aString, aString2, classVarNames, poolVarNames, aCategory);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09category%3A%20aCategory%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%28self%20smalltalk%20globalAt%3A%20aString%29%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09self%20print%3A%20%27//%20WARNING%3A%20class%20REdefinition%20for%20%27%2CaString.%0D%0A%09%09%22%5Eself%20smalltalk%20globalAt%3A%20aString%22%0D%0A%09%5D.%0D%0A%0D%0A%09%22self%20print%3A%20%27//%20Creating%20ROOT%20class%20%27%2CaString.%22%0D%0A%09%5EClassBuilder%20new%0D%0A%09%09superclass%3A%20self%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20poolVarNames%0D%0A%09%09category%3A%20aCategory"));
smalltalk.bind(smalltalk.UndefinedObject,"subclass:instanceVariableNames:classVariableNames:poolDictionaries:",0
,function (aString,aString2,classVarNames,poolVarNames){var self=this;return self.subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(aString, aString2, classVarNames, poolVarNames, nil);;return self;}
,"instantiation",unescape("subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09%22%20Create%20a%20new%20subclass%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20classVarNames%0D%0A%09%09poolDictionaries%3A%20poolVarNames%0D%0A%09%09category%3A%20nil"));
smalltalk.bind(smalltalk.UndefinedObject,"compiler",0
,function (){var self=this;return self.smalltalk().compilerSupport().for_(nil);;return self;}
,"Tools-printing",unescape("compiler%0D%0A%09%22%20Return%20the%20compiler%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20compilerSupport%20for%3A%20nil"));
smalltalk.bind(smalltalk.UndefinedObject,"==","_eq_eq"
,function (anObject){var self=this;return (nil.isNil_(anObject));;return self;}
,"Tools-comparing",unescape("%3D%3D%20anObject%0D%0A%09%5EanObject%20isNil"));
smalltalk.bind(smalltalk.UndefinedObject,"~~","_no_no"
,function (anObject){var self=this;return (nil.isNil_(anObject)===false);;return self;}
,"Tools-comparing",unescape("%7E%7E%20anObject%0D%0A%09%5EanObject%20notNil"));
smalltalk.bind(smalltalk.UndefinedObject,"handle",0
,function (){var self=this;return self.asJSONObject();;return self;}
,"Natives-converting",unescape("handle%0D%0A%09%22%20Return%20the%20handle%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20asJSONObject"));
smalltalk.bind(smalltalk.UndefinedObject,"s8DoIt",0
,function (){var self=this;return (function(){return smalltalk.Snapshot.outputToFile_(smalltalk.Smalltalk.current().imageFileName());}).value();;return self;}
,"",unescape("s8DoIt%20%5E%5B%20Snapshot%20outputToFile%3A%20Smalltalk%20current%20imageFileName%20%5D%20value"));
smalltalk.bind(smalltalk.Collection.$klass,"streamClass",0
,function (){var self=this;return smalltalk.Stream;;return self;}
,"accessing",unescape("streamClass%0D%0A%09%22%20Private%20-%20Return%20the%20support%20for%20streamming%20on%20the%20receiver%27s%20instances.%20%22%0D%0A%0D%0A%09%5EStream"));
smalltalk.bind(smalltalk.Collection.$klass,"with:",0
,function (anObject){var self=this;return (function($rec){$rec.add_(anObject);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("with%3A%20anObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09add%3A%20anObject%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection.$klass,"with:with:",0
,function (anObject,anotherObject){var self=this;return (function($rec){$rec.add_(anObject);$rec.add_(anotherObject);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("with%3A%20anObject%20with%3A%20anotherObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09add%3A%20anObject%3B%0D%0A%09%09add%3A%20anotherObject%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection.$klass,"with:with:with:",0
,function (firstObject,secondObject,thirdObject){var self=this;return (function($rec){$rec.add_(firstObject);$rec.add_(secondObject);$rec.add_(thirdObject);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("with%3A%20firstObject%20with%3A%20secondObject%20with%3A%20thirdObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09add%3A%20firstObject%3B%0D%0A%09%09add%3A%20secondObject%3B%0D%0A%09%09add%3A%20thirdObject%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection.$klass,"with:with:with:with:",0
,function (firstObject,secondObject,thirdObject,fourthObject){var self=this;return (function($rec){$rec.add_(firstObject);$rec.add_(secondObject);$rec.add_(thirdObject);$rec.add_(fourthObject);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("with%3A%20firstObject%20with%3A%20secondObject%20with%3A%20thirdObject%20with%3A%20fourthObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09add%3A%20firstObject%3B%0D%0A%09%09add%3A%20secondObject%3B%0D%0A%09%09add%3A%20thirdObject%3B%0D%0A%09%09add%3A%20fourthObject%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection.$klass,"withAll:",0
,function (aCollection){var self=this;return (function($rec){$rec.addAll_(aCollection);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("withAll%3A%20aCollection%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09addAll%3A%20aCollection%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection.$klass,"basicNew:",0
,function (size){var self=this;return self.subclassResponsibility_("basicNew:");;return self;}
,"instantiation",unescape("basicNew%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23basicNew%3A"));
smalltalk.bind(smalltalk.Collection,"size",0
,function (){var self=this;return self.subclassResponsibility_("size");;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23size"));
smalltalk.bind(smalltalk.Collection,"readStream",0
,function (){var self=this;return self.stream();;return self;}
,"accessing",unescape("readStream%0D%0A%09%22%20Return%20a%20read%20stream%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20stream"));
smalltalk.bind(smalltalk.Collection,"writeStream",0
,function (){var self=this;return self.stream();;return self;}
,"accessing",unescape("writeStream%0D%0A%09%22%20Return%20a%20write%20stream%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20stream"));
smalltalk.bind(smalltalk.Collection,"stream",0
,function (){var self=this;return self.streamClass().on_(self);;return self;}
,"accessing",unescape("stream%0D%0A%09%22%20Return%20a%20stream%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20streamClass%20on%3A%20self"));
smalltalk.bind(smalltalk.Collection,"streamClass",0
,function (){var self=this;return self.$klass.streamClass();;return self;}
,"accessing",unescape("streamClass%0D%0A%09%22%20Private%20-%20Return%20the%20support%20for%20streamming%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20streamClass"));
smalltalk.bind(smalltalk.Collection,"errorNotFound",0
,function (){var self=this;return self.objectNotFound();;return self;}
,"error",unescape("errorNotFound%0D%0A%09%22%20DEPRECATED%20-%20Generates%20an%20error.%0D%0A%09An%20object%20was%20not%20found%20in%20the%20receiver%27s%20contents.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20objectNotFound"));
smalltalk.bind(smalltalk.Collection,"objectNotFound",0
,function (){var self=this;self.smalltalk().objectNotFound(nil, nil, self);
return self.error_("Object is not in the collection");;return self;}
,"error",unescape("objectNotFound%0D%0A%09%22%20Private%20-%20Generates%20an%20error.%0D%0A%09An%20object%20was%20not%20found%20in%20the%20receiver%27s%20contents.%0D%0A%09%22%0D%0A%0D%0A%09self%20smalltalk%20%23objectNotFound%3A%20nil%20at%3A%20nil%20in%3A%20self.%0D%0A%09%5Eself%20error%3A%20%27Object%20is%20not%20in%20the%20collection%27"));
smalltalk.bind(smalltalk.Collection,"objectNotFound:",0
,function (anObject){var self=this;self.smalltalk().objectNotFound(anObject, nil, self);
return self.error_("Object not found: "._comma(anObject.toString()));;return self;}
,"error",unescape("objectNotFound%3A%20anObject%0D%0A%09%22%20Private%20-%20Generates%20an%20error.%0D%0A%09anObject%20was%20not%20found%20in%20the%20receiver%27s%20contents.%0D%0A%09%22%0D%0A%0D%0A%09self%20smalltalk%20%23objectNotFound%3A%20anObject%20at%3A%20nil%20in%3A%20self.%0D%0A%09%5Eself%20error%3A%20%27Object%20not%20found%3A%20%27%2CanObject%20toString"));
smalltalk.bind(smalltalk.Collection,"objectNotFoundAt:",0
,function (indexOrKey){var self=this;self.smalltalk().objectNotFound(nil, indexOrKey, self);
return self.error_("Object not found at "._comma(indexOrKey.toString()));;return self;}
,"error",unescape("objectNotFoundAt%3A%20indexOrKey%0D%0A%09%22%20Private%20-%20Generates%20an%20error.%0D%0A%09The%20object%20at%20key/index%20was%20not%20found%20in%20the%20receiver%27s%20contents.%0D%0A%09%22%0D%0A%0D%0A%09self%20smalltalk%20%23objectNotFound%3A%20nil%20at%3A%20indexOrKey%20in%3A%20self.%0D%0A%09%5Eself%20error%3A%20%27Object%20not%20found%20at%20%27%2CindexOrKey%20toString"));
smalltalk.bind(smalltalk.Collection,"add:",0
,function (anObject){var self=this;return self.subclassResponsibility_("add:");;return self;}
,"adding",unescape("add%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23add%3A"));
smalltalk.bind(smalltalk.Collection,"addAll:",0
,function (aCollection){var self=this;aCollection.do_((function(each){return self.add_(each);}));
return aCollection;;return self;}
,"adding",unescape("addAll%3A%20aCollection%0D%0A%09%22%20Add%20objects%20in%20aCollection%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09aCollection%20do%3A%20%5B%3Aeach%20%7C%20self%20add%3A%20each%20%5D.%0D%0A%09%5EaCollection"));
smalltalk.bind(smalltalk.Collection,",","_comma"
,function (aCollection){var self=this;return (function($rec){$rec.addAll_(aCollection);return $rec.yourself();})(self.copy());;return self;}
,"copying",unescape("%2C%20aCollection%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20all%20contents%20of%20aCollection.%20%22%0D%0A%0D%0A%09%5Eself%20copy%0D%0A%09%09addAll%3A%20aCollection%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection,"copyWith:",0
,function (anObject){var self=this;return (function($rec){$rec.add_(anObject);return $rec.yourself();})(self.copy());;return self;}
,"copying",unescape("copyWith%3A%20anObject%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20copy%20add%3A%20anObject%3B%20yourself"));
smalltalk.bind(smalltalk.Collection,"copyWithAll:",0
,function (aCollection){var self=this;return (function($rec){$rec.addAll_(aCollection);return $rec.yourself();})(self.copy());;return self;}
,"copying",unescape("copyWithAll%3A%20aCollection%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20all%20contents%20of%20aCollection.%20%22%0D%0A%0D%0A%09%5Eself%20copy%0D%0A%09%09addAll%3A%20aCollection%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Collection,"asArray",0
,function (){var self=this;var result=nil;var index=nil;result=smalltalk.Array.$$new();
index=(0);
self.do_((function(each){index=index._plus((1));return result.at_put_(index, each);}));
return result;;return self;}
,"converting",unescape("asArray%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20index%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09index%20%3A%3D%200.%0D%0A%09self%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%20%20%20%20index%20%3A%3D%20index%20+%201.%0D%0A%09%20%20%20%20result%20at%3A%20index%20put%3A%20each%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Collection,"do:",0
,function (aBlock){var self=this;return self.subclassResponsibility_("do:");;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23do%3A"));
smalltalk.bind(smalltalk.Collection,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;return self.subclassResponsibility_("detect:ifNone:");;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20that%20return%20true%20when%20evaluated%20with%20aBlock%20or%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23detect%3AifNone%3A"));
smalltalk.bind(smalltalk.Collection,"reverseDo:",0
,function (aBlock){var self=this;return self.subclassResponsibility_("reverseDo:");;return self;}
,"enumerating",unescape("reverseDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order%20of%20iteration.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23reverseDo%3A"));
smalltalk.bind(smalltalk.Collection,"collect:",0
,function (aBlock){var self=this;var result=nil;result=self.$klass.$$new();
self.do_((function(each){return result.add_(aBlock.value_(each));}));
return result;;return self;}
,"enumerating",unescape("collect%3A%20aBlock%0D%0A%09%22%20Return%20a%20collection%20with%20the%20result%20of%20evaluating%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09self%20do%3A%20%5B%3Aeach%20%7C%20result%20add%3A%20%28aBlock%20value%3A%20each%29%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Collection,"select:",0
,function (aBlock){var self=this;var stream=nil;stream=self.$klass.$$new().writeStream();
self.do_((function(each){return ((aBlock.value_(each)).mustBeBoolean()==true ? (function(){return stream.nextPut_(each);})() : nil);}));
return stream.contents();;return self;}
,"enumerating",unescape("select%3A%20aBlock%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20wich%20evaluates%20aBlock%20to%20true.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20self%20class%20new%20writeStream.%0D%0A%09self%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%20%20%20%20%28aBlock%20value%3A%20each%29%20ifTrue%3A%20%5B%20stream%20nextPut%3A%20each%20%5D%0D%0A%09%5D.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Collection,"detect:",0
,function (aBlock){var self=this;return self.detect_ifNone_(aBlock, (function(){return self.objectNotFound();}));;return self;}
,"enumerating",unescape("detect%3A%20aBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20that%20return%20true%20when%20evaluated%20with%20aBlock.%0D%0A%09Generates%20an%20error%20if%20there%20is%20no%20object%20that%20evaluates%20aBlock%20to%20true.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20detect%3A%20aBlock%20ifNone%3A%20%5B%20self%20objectNotFound%20%5D"));
smalltalk.bind(smalltalk.Collection,"do:separatedBy:",0
,function (aBlock,anotherBlock){var self=this;var first=nil;first=true;
self.do_((function(each){((first).mustBeBoolean()==true ? (function(){return first=false;})() : (function(){return anotherBlock.value();})());return aBlock.value_(each);}));return self;}
,"enumerating",unescape("do%3A%20aBlock%20separatedBy%3A%20anotherBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20contents%20of%20the%20receiver%20evaluating%20anotherBlock%20inbetween%20aBlock%20evaluations.%20%22%0D%0A%0D%0A%09%7C%20first%20%7C%0D%0A%09first%20%3A%3D%20true.%0D%0A%09self%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%20%20%20%20first%0D%0A%09%09ifTrue%3A%20%5B%20first%20%3A%3D%20false%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20anotherBlock%20value%20%5D.%0D%0A%09%20%20%20%20aBlock%20value%3A%20each%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Collection,"inject:into:",0
,function (anObject,aBlock){var self=this;var result=nil;result=anObject;
self.do_((function(each){return result=aBlock.value_value_(result, each);}));
return result;;return self;}
,"enumerating",unescape("inject%3A%20anObject%20into%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20result%20of%20previous%20evaluation%20and%20contents%20of%20the%20receiver.%0D%0A%09On%20first%20evaluation%20anObject%20is%20used%20as%20first%20argument%20to%20evaluate%20aBlock.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20anObject.%0D%0A%09self%20do%3A%20%5B%3Aeach%20%7C%20result%20%3A%3D%20aBlock%20value%3A%20result%20value%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Collection,"reject:",0
,function (aBlock){var self=this;return self.select_((function(each){return aBlock.value_(each)._eq(false);}));;return self;}
,"enumerating",unescape("reject%3A%20aBlock%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20wich%20evaluates%20aBlock%20to%20false.%20%22%0D%0A%0D%0A%09%5Eself%20select%3A%20%5B%3Aeach%20%7C%20%28aBlock%20value%3A%20each%29%20%3D%20false%5D"));
smalltalk.bind(smalltalk.Collection,"select:thenCollect:",0
,function (selectBlock,collectBlock){var self=this;return self.select_(selectBlock).collect_(collectBlock);;return self;}
,"enumerating",unescape("select%3A%20selectBlock%20thenCollect%3A%20collectBlock%0D%0A%09%22%20Return%20a%20new%20collection%20with%20the%20result%20of%20evaluating%20collectBlock%20on%20the%20contents%20of%20the%20receiver%20wich%20evaluates%20selectBlock%20to%20true.%20%22%0D%0A%0D%0A%09%5E%28self%20select%3A%20selectBlock%29%20collect%3A%20collectBlock"));
smalltalk.bind(smalltalk.Collection,"collect:thenSelect:",0
,function (collectBlock,selectBlock){var self=this;return self.collect_(collectBlock).select_(selectBlock);;return self;}
,"enumerating",unescape("collect%3A%20collectBlock%20thenSelect%3A%20selectBlock%0D%0A%09%22%20Return%20a%20new%20collection%20with%20the%20result%20of%20evaluating%20collectBlock%20on%20the%20contents%20of%20the%20receiver%20wich%20evaluates%20selectBlock%20to%20true.%20%22%0D%0A%0D%0A%09%5E%28self%20collect%3A%20collectBlock%29%20select%3A%20selectBlock"));
smalltalk.bind(smalltalk.Collection,"reversed",0
,function (){var self=this;return self.subclassResponsibility_("reversed");;return self;}
,"copying",unescape("reversed%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23reversed"));
smalltalk.bind(smalltalk.Collection,"includes:",0
,function (anObject){var self=this;return self.subclassResponsibility_("includes:");;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23includes%3A"));
smalltalk.bind(smalltalk.Collection,"notEmpty",0
,function (){var self=this;return self.isEmpty().not();;return self;}
,"testing",unescape("notEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20empty.%20%22%0D%0A%0D%0A%09%5Eself%20isEmpty%20not"));
smalltalk.bind(smalltalk.Collection,"isEmpty",0
,function (){var self=this;return (self.size() === (0));;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Eself%20size%20%3D%3D%200"));
smalltalk.bind(smalltalk.Collection,"remove:",0
,function (anObject){var self=this;return self.remove_ifAbsent_(anObject, (function(){return self.objectNotFound_(anObject);}));;return self;}
,"removing",unescape("remove%3A%20anObject%0D%0A%09%22%20Remove%20anObject%20from%20receiver%2C%20return%20the%20removed%20object.%20%22%0D%0A%0D%0A%09%5Eself%20remove%3A%20anObject%20ifAbsent%3A%20%5B%20self%20objectNotFound%3A%20anObject%20%5D"));
smalltalk.bind(smalltalk.Collection,"remove:ifAbsent:",0
,function (anObject,aBlock){var self=this;return self.subclassResponsibility_("remove:ifAbsent:");;return self;}
,"removing",unescape("remove%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20anObject%20from%20receiver.%0D%0A%09Return%20the%20removed%20object%20or%20the%20result%20of%20evaluating%20aBlock%20%28if%20the%20object%20is%20not%20found%29.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23remove%3AifAbsent%3A"));
smalltalk.bind(smalltalk.Collection,"removeAll:",0
,function (aCollection){var self=this;aCollection.do_((function(each){return self.remove_(each);}));
return aCollection;;return self;}
,"removing",unescape("removeAll%3A%20aCollection%0D%0A%09%22%20Remove%20aCollection%20from%20receiver.%20%22%0D%0A%0D%0A%09aCollection%20do%3A%20%5B%3Aeach%7C%20self%20remove%3A%20each%20%5D.%0D%0A%09%5EaCollection"));
smalltalk.bind(smalltalk.Collection,"removeAll",0
,function (){var self=this;self.removeAll_(self.shallowCopy());return self;}
,"removing",unescape("removeAll%0D%0A%09%22%20Remove%20all%20elements%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20removeAll%3A%20self%20shallowCopy"));
smalltalk.bind(smalltalk.Collection,"occurrencesOf:",0
,function (anObject){var self=this;return self.inject_into_((0), (function(total,each){return ((each._eq(anObject)).mustBeBoolean()==true ? (function(){return total._plus((1));})() : (function(){return total;})());}));;return self;}
,"counting",unescape("occurrencesOf%3A%20anObject%0D%0A%09%22%20Return%20the%20occurrences%20of%20anObject%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20inject%3A%200%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09each%20%3D%20anObject%20ifTrue%3A%20%5B%20total%20+%201%20%5D%20ifFalse%3A%20%5Btotal%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Collection,"shallowCopy",0
,function (){var self=this;return self.collect_((function(each){return each;}));;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20collect%3A%20%5B%3Aeach%7C%20each%20%5D"));
smalltalk.bind(smalltalk.Collection,"deepCopy",0
,function (){var self=this;return self.collect_((function(each){return each.deepCopy();}));;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20collect%3A%20%5B%3Aeach%7C%20each%20deepCopy%20%5D"));
smalltalk.bind(smalltalk.Collection,"asSet",0
,function (){var self=this;return smalltalk.Set.withAll_(self);;return self;}
,"converting",unescape("asSet%0D%0A%09%22%20Return%20the%20receiver%20contents%20in%20a%20Set.%20%22%0D%0A%0D%0A%09%5ESet%20withAll%3A%20self"));
smalltalk.bind(smalltalk.Collection,"asParser",0
,function (){var self=this;return smalltalk.PPChoiceParser.withAll_(self.asArray());;return self;}
,"Compiler-converting",unescape("asParser%0D%0A%09%22%20Return%20a%20parser%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPChoiceParser%20withAll%3A%20self%20asArray"));
smalltalk.bind(smalltalk.Collection,"fileOut",0
,function (){var self=this;var cr=nil;cr=unescape("%0D%0A");
return self.inject_into_("", (function(total,each){return total._comma(cr)._comma(each.fileOut());}));;return self;}
,"Tools-fileOut",unescape("fileOut%0D%0A%09%22%20Return%20fileOut%20definition%20and%20code%20of%20classes%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20cr%20%7C%0D%0A%09cr%20%3A%3D%20%27%0D%0A%27.%09%5Eself%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2Ccr%2C%20each%20fileOut%20%5D"));
smalltalk.bind(smalltalk.Collection,"export","$$export"
,function (){var self=this;var cr=nil;cr=unescape("%0D%0A");
return self.inject_into_("", (function(total,each){return total._comma(cr)._comma(each.$$export());}));;return self;}
,"Tools-export",unescape("export%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20definition%20and%20source%20code%20of%20classes%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20cr%20%7C%0D%0A%09cr%20%3A%3D%20%27%0D%0A%27.%09%5Eself%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2Ccr%2C%20each%20export%20%5D"));
smalltalk.bind(smalltalk.Collection,"emmit",0
,function (){var self=this;return self.inject_into_("", (function(total,each){return total._comma(self.emmit_(each));}));;return self;}
,"Builders-emmiting",unescape("emmit%0D%0A%09%22%20Emmit%28fileIn%20%26%20save%20generated%20code%20of%29%20the%20fileNames%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2C%28self%20emmit%3A%20each%29%20%5D"));
smalltalk.bind(smalltalk.Collection,"emmitSt",0
,function (){var self=this;return self.collect_((function(module){return module._comma(".st");})).emmit();;return self;}
,"Builders-emmiting",unescape("emmitSt%0D%0A%09%22%20Emmit%20the%20code%20of%20modules%20%28.st%20files%29%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28self%20collect%3A%20%5B%3Amodule%7C%20module%20%2C%27.st%27%20%5D%29%20emmit"));
smalltalk.bind(smalltalk.Collection,"handles",0
,function (){var self=this;return self.asArray().handles();;return self;}
,"Natives-converting",unescape("handles%0D%0A%09%22%20Return%20an%20array%20with%20the%20handles%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20asArray%20handles"));
smalltalk.bind(smalltalk.SequenceableCollection,"at:",0
,function (anIndex){var self=this;return self.at_ifAbsent_(anIndex, (function(){return self.objectNotFoundAt_(anIndex);}));;return self;}
,"accessing",unescape("at%3A%20anIndex%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20at%20anIndex%20position.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%20anIndex%20ifAbsent%3A%20%5B%20self%20objectNotFoundAt%3A%20anIndex%20%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"at:ifAbsent:",0
,function (anIndex,aBlock){var self=this;return self.subclassResponsibility_("at:ifAbsent:");;return self;}
,"accessing",unescape("at%3A%20anIndex%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20at%20anIndex%20position%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23at%3AifAbsent%3A"));
smalltalk.bind(smalltalk.SequenceableCollection,"at:put:",0
,function (anIndex,anObject){var self=this;return self.subclassResponsibility_("at:put:");;return self;}
,"accessing",unescape("at%3A%20anIndex%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20object%20in%20the%20receiver%20at%20anIndex%20position.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23at%3Aput%3A"));
smalltalk.bind(smalltalk.SequenceableCollection,"copyFrom:to:",0
,function (anIndex,anotherIndex){var self=this;return self.subclassResponsibility_("copyFrom:to:");;return self;}
,"copying",unescape("copyFrom%3A%20anIndex%20to%3A%20anotherIndex%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23copyFrom%3Ato%3A"));
smalltalk.bind(smalltalk.SequenceableCollection,"indexOf:",0
,function (anObject){var self=this;return self.indexOf_ifAbsent_(anObject, (function(){return (0);}));;return self;}
,"testing",unescape("indexOf%3A%20anObject%0D%0A%09%22%20Return%20the%20position%20of%20anObject%20in%20the%20receiver%2C%20or%200.%20%22%0D%0A%0D%0A%09%5Eself%20indexOf%3A%20anObject%20ifAbsent%3A%20%5B%200%20%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"indexOf:ifAbsent:",0
,function (anObject,aBlock){var self=this;	for(var i=0;i<self.length;i++){ if (self[i]._eq(anObject)) { return i + 1; } }
	return aBlock(); ;return self;}
,"testing",unescape("indexOf%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20position%20of%20anObject%20in%20the%20receiver%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7B%20if%20%28self%5Bi%5D._eq%28anObject%29%29%20%7B%20return%20i%20+%201%3B%20%7D%20%7D%0D%0A%09return%20aBlock%28%29%3B%20%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"do:",0
,function (aBlock){var self=this;	for(var i=0;i<self.length;i++){aBlock(self[i]);} ;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7BaBlock%28self%5Bi%5D%29%3B%7D%20%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;	for(var i = 0; i < self.length; i++) if(aBlock(self[i])) return self[i];
	return anotherBlock();
;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20that%20return%20true%20when%20evaluated%20with%20aBlock%20or%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%20%3D%200%3B%20i%20%3C%20self.length%3B%20i++%29%20if%28aBlock%28self%5Bi%5D%29%29%20return%20self%5Bi%5D%3B%0D%0A%09return%20anotherBlock%28%29%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"reversed",0
,function (){var self=this;	var result = new Array();
	var len=self.length; var i=len;
	while(i--){result[len-i-1]= self[i];}
	return result;
;return self;}
,"copying",unescape("reversed%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order.%20%22%0D%0A%0D%0A%7B%27%09var%20result%20%3D%20new%20Array%28%29%3B%0D%0A%09var%20len%3Dself.length%3B%20var%20i%3Dlen%3B%0D%0A%09while%28i--%29%7Bresult%5Blen-i-1%5D%3D%20self%5Bi%5D%3B%7D%0D%0A%09return%20result%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"isEmpty",0
,function (){var self=this;	return (this.length)?false:true; ;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%0D%0A%09Note%3A%20%5Eself%20size%20%3D%200%20is%20slower%20than%20inlined%20impl.%0D%0A%09%22%0D%0A%0D%0A%7B%27%09return%20%28this.length%29%3Ffalse%3Atrue%3B%20%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"reverseDo:",0
,function (aBlock){var self=this;	var i=self.length;while(i--){aBlock(self[i]);} ;return self;}
,"enumerating",unescape("reverseDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order%20of%20iteration.%20%22%0D%0A%0D%0A%7B%27%09var%20i%3Dself.length%3Bwhile%28i--%29%7BaBlock%28self%5Bi%5D%29%3B%7D%20%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"includes:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isObject_(anObject)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.indexOf(anObject)._gt((-1));})();throw($s8Ret$)})();})());
	if (anObject.isNumber() && (self.indexOf(anObject) > -1)) return true;
	if (anObject.isString() && (self.indexOf(anObject) > -1)) return true;
	var i = self.length;
	while (i--) { if (anObject._eq(self[i])) { return true; } }
	return false; ;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20the%20receiver.%0D%0A%09Note%3A%20the%20indexOf%28%29%20function%20fail%20to%20search%20in%20case%20of%20string%20literals%20in%20Array%20contents.%0D%0A%09%22%0D%0A%0D%0A%09%28self%20isObject%3A%20anObject%29%20ifFalse%3A%20%5B%0D%0A%09%09%5E%28self%20%23indexOf%3A%20anObject%29%20%3E%20-1%0D%0A%09%5D.%0D%0A%7B%27%09if%20%28anObject.isNumber%28%29%20%26%26%20%28self.indexOf%28anObject%29%20%3E%20-1%29%29%20return%20true%3B%0D%0A%09if%20%28anObject.isString%28%29%20%26%26%20%28self.indexOf%28anObject%29%20%3E%20-1%29%29%20return%20true%3B%0D%0A%09var%20i%20%3D%20self.length%3B%0D%0A%09while%20%28i--%29%20%7B%20if%20%28anObject._eq%28self%5Bi%5D%29%29%20%7B%20return%20true%3B%20%7D%20%7D%0D%0A%09return%20false%3B%20%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"occurrencesOf:",0
,function (anObject){var self=this;	var i = self.length; var count = 0;
	while (i--) { if (self[i]._eq(anObject)) { count++; } }
	return count;
;return self;}
,"counting",unescape("occurrencesOf%3A%20anObject%0D%0A%09%22%20Return%20the%20occurrences%20of%20anObject%20in%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09var%20i%20%3D%20self.length%3B%20var%20count%20%3D%200%3B%0D%0A%09while%20%28i--%29%20%7B%20if%20%28self%5Bi%5D._eq%28anObject%29%29%20%7B%20count++%3B%20%7D%20%7D%0D%0A%09return%20count%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.SequenceableCollection,"first",0
,function (){var self=this;return self.at_((1));;return self;}
,"accessing",unescape("first%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%201"));
smalltalk.bind(smalltalk.SequenceableCollection,"fourth",0
,function (){var self=this;return self.at_((4));;return self;}
,"accessing",unescape("fourth%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%204"));
smalltalk.bind(smalltalk.SequenceableCollection,"last",0
,function (){var self=this;return self.at_(self.size());;return self;}
,"accessing",unescape("last%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%20self%20size"));
smalltalk.bind(smalltalk.SequenceableCollection,"second",0
,function (){var self=this;return self.at_((2));;return self;}
,"accessing",unescape("second%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%202"));
smalltalk.bind(smalltalk.SequenceableCollection,"third",0
,function (){var self=this;return self.at_((3));;return self;}
,"accessing",unescape("third%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%203"));
smalltalk.bind(smalltalk.SequenceableCollection,"removeLast",0
,function (){var self=this;return self.remove_(self.last());;return self;}
,"removing",unescape("removeLast%0D%0A%09%22%20Remove%20the%20last%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20remove%3A%20self%20last"));
smalltalk.bind(smalltalk.SequenceableCollection,"removeFirst",0
,function (){var self=this;return self.remove_(self.first());;return self;}
,"removing",unescape("removeFirst%0D%0A%09%22%20Remove%20the%20first%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20remove%3A%20self%20first"));
smalltalk.bind(smalltalk.SequenceableCollection,"addLast:",0
,function (anObject){var self=this;return self.add_(anObject);;return self;}
,"adding",unescape("addLast%3A%20anObject%0D%0A%09%22%20Add%20the%20object%20in%20the%20receiver%20%28at%20end%29.%20%22%0D%0A%0D%0A%09%5Eself%20add%3A%20anObject"));
smalltalk.bind(smalltalk.SequenceableCollection,"atAll:put:",0
,function (indices,anObject){var self=this;indices.do_((function(index){return self.at_put_(index, anObject);}));return self;}
,"accessing",unescape("atAll%3A%20indices%20put%3A%20anObject%0D%0A%09%22%20Return%20the%20receiver%20after%20replacing%20those%20elements%2C%20indexed%20by%20the%20indices%2C%20with%20anObject.%20%22%0D%0A%0D%0A%09indices%20do%3A%20%5B%20%3Aindex%20%7C%20self%20at%3A%20index%20put%3A%20anObject%20%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"atAllPut:",0
,function (anObject){var self=this;(1).to_(self.size()).do_((function(index){return self.at_put_(index, anObject);}));return self;}
,"accessing",unescape("atAllPut%3A%20anObject%0D%0A%09%22%20Replace%20all%20elements%20of%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%281%20to%3A%20self%20size%29%20do%3A%20%5B%20%3Aindex%20%7C%20self%20at%3A%20index%20put%3A%20anObject%20%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"withIndexDo:",0
,function (aBlock){var self=this;(1).to_(self.size()).do_((function(index){return aBlock.value_value_(self.at_(index), index);}));return self;}
,"enumerating",unescape("withIndexDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20all%20the%20index%20positions%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%281%20to%3A%20self%20size%29%20do%3A%20%5B%20%3Aindex%20%7C%0D%0A%09%09aBlock%20value%3A%20%28self%20at%3A%20index%29%20value%3A%20index%0D%0A%09%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"=","_eq"
,function (aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;(((self === aCollection)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
(((self.$klass === aCollection.$klass)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
index=self.size();
((index._no_eq(aCollection.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
(function(){while(!(function(){return index._lt_eq((0));})()){(function(){((self.at_(index)._eq(aCollection.at_(index))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());return index=index._minus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("%3D%20aCollection%0D%0A%09%22%20Return%20true%20if%20the%20elements%20contained%20by%20the%20receiver%20are%20equal%20to%20the%20elements%20contained%20in%20aCollection.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09self%20%3D%3D%20aCollection%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09self%20class%20%3D%3D%20aCollection%20class%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09index%20%3A%3D%20self%20size.%0D%0A%09index%20%7E%3D%20aCollection%20size%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5B%20index%20%3C%3D%200%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09%28self%20at%3A%20index%29%20%3D%20%28aCollection%20at%3A%20index%29%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%09index%20%3A%3D%20index%20-%201%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.SequenceableCollection,"beginsWith:",0
,function (aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;((self.size()._lt(aCollection.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
((self.size()._eq(aCollection.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aCollection._eq(self);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return aCollection._eq(self.copyFrom_to_((1), aCollection.size()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("beginsWith%3A%20aCollection%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20begins%20with%20aCollection.%20%22%0D%0A%0D%0A%09self%20size%20%3C%20aCollection%20size%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09self%20size%20%3D%20aCollection%20size%20ifTrue%3A%20%5B%20%5EaCollection%20%3D%20self%20%5D.%0D%0A%09%5EaCollection%20%3D%20%28self%20copyFrom%3A%201%20to%3A%20aCollection%20size%29"));
smalltalk.bind(smalltalk.SequenceableCollection,"endsWith:",0
,function (aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;((self.size()._lt(aCollection.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
((self.size()._eq(aCollection.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aCollection._eq(self);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return aCollection._eq(self.copyFrom_to_(self.size()._minus(aCollection.size())._plus((1)), self.size()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("endsWith%3A%20aCollection%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20ends%20with%20aCollection.%20%22%0D%0A%0D%0A%09self%20size%20%3C%20aCollection%20size%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09self%20size%20%3D%20aCollection%20size%20ifTrue%3A%20%5B%20%5EaCollection%20%3D%20self%20%5D.%0D%0A%09%5EaCollection%20%3D%20%28self%20copyFrom%3A%20self%20size%20-%20aCollection%20size%20+%201%20to%3A%20self%20size%29"));
smalltalk.bind(smalltalk.SequenceableCollection,"copyReplaceFrom:to:with:",0
,function (start,stop,aCollection){var self=this;return self.copyFrom_to_((1), start._minus((1)))._comma(aCollection)._comma(self.copyFrom_to_(stop._plus((1)), self.size()));;return self;}
,"copying",unescape("copyReplaceFrom%3A%20start%20to%3A%20stop%20with%3A%20aCollection%0D%0A%09%22%20Return%20a%20collection%20containing%20a%20copy%20of%20the%20receiver%20with%20the%20elements%20at%20index%20positions%20from%20start%20through%20stop%20replaced%20with%20the%20elements%20of%20aCollection.%20%22%0D%0A%0D%0A%09%5E%28self%20copyFrom%3A%201%20to%3A%20start%20-%201%29%0D%0A%09%09%2C%20aCollection%0D%0A%09%09%2C%20%28self%20copyFrom%3A%20stop%20+%201%20to%3A%20self%20size%29"));
smalltalk.bind(smalltalk.SequenceableCollection,"copyWithout:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.indexOf_ifAbsent_(anObject, (function(){return (function(){$s8Ret$.result=(function(){return self.copy();})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return self.copyFrom_to_((1), index._minus((1)))._comma(self.copyFrom_to_(index._plus((1)), self.size()).copyWithout_(anObject));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"copying",unescape("copyWithout%3A%20anObject%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20excluding%20anObject%2C%20if%20any.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20indexOf%3A%20anObject%20ifAbsent%3A%20%5B%20%5Eself%20copy%20%5D.%0D%0A%09%5E%28self%20copyFrom%3A%201%20to%3A%20index%20-%201%29%0D%0A%09%09%2C%28%28self%20copyFrom%3A%20index%20+%201%20to%3A%20self%20size%29%0D%0A%09%09%09copyWithout%3A%20anObject%29"));
smalltalk.bind(smalltalk.SequenceableCollection,"copyWithAll:",0
,function (aCollection){var self=this;return self._comma(aCollection);;return self;}
,"copying",unescape("copyWithAll%3A%20aCollection%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20all%20contents%20of%20aCollection.%20%22%0D%0A%0D%0A%09%5Eself%20%2C%20aCollection%20"));
smalltalk.bind(smalltalk.SequenceableCollection,"findFirst:",0
,function (aBlock){var self=this;return self.findFirst_ifAbsent_(aBlock, (function(){return self.errorAbsentObject();}));;return self;}
,"searching",unescape("findFirst%3A%20aBlock%0D%0A%09%22%20Return%20the%20index%20of%20the%20first%20element%20of%20the%20receiver%20that%20causes%20aBlock%20to%20evaluate%20to%20true.%0D%0A%20%20%20%20%20%20%20%20%20If%20no%20such%20element%20is%20found%2C%20report%20an%20error.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20findFirst%3A%20aBlock%20ifAbsent%3A%20%5B%20self%20errorAbsentObject%20%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"findFirst:ifAbsent:",0
,function (aBlock,absentBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;var size=nil;size=self.size();
index=(1);
(function(){while((function(){return index._lt_eq(size);})()){(function(){((aBlock.value_(self.at_(index))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return index;})();throw($s8Ret$)})();})() : nil);return index=index._plus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return absentBlock.value();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"searching",unescape("findFirst%3A%20aBlock%20ifAbsent%3A%20absentBlock%0D%0A%09%22%20Return%20the%20index%20of%20the%20first%20element%20of%20the%20receiver%20that%20causes%20aBlock%20to%20evaluate%20to%20true.%0D%0A%09If%20no%20such%20element%20is%20found%2C%20return%20the%20result%20of%20evaluating%20the%20argument%20block.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20index%20size%20%7C%0D%0A%09size%20%3A%3D%20self%20size.%0D%0A%09index%20%3A%3D%201.%0D%0A%09%5B%20index%20%3C%3D%20size%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09%28aBlock%20value%3A%20%28self%20at%3A%20index%29%29%20ifTrue%3A%20%5B%20%5Eindex%20%5D.%0D%0A%09%09index%20%3A%3D%20index%20+%201%0D%0A%09%5D.%0D%0A%09%5EabsentBlock%20value"));
smalltalk.bind(smalltalk.SequenceableCollection,"findLast:",0
,function (aBlock){var self=this;return self.findLast_ifAbsent_(aBlock, (function(){return self.errorAbsentObject();}));;return self;}
,"searching",unescape("findLast%3A%20aBlock%0D%0A%09%22%20Return%20the%20index%20of%20the%20last%20element%20of%20the%20receiver%20that%20causes%20aBlock%20to%20evaluate%20to%20true.%0D%0A%09If%20no%20such%20element%20is%20found%2C%20report%20an%20error.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20findLast%3A%20aBlock%20ifAbsent%3A%20%5B%20self%20errorAbsentObject%20%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"findLast:ifAbsent:",0
,function (aBlock,absentBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.size();
(function(){while((function(){return index._gt((0));})()){(function(){((aBlock.value_(self.at_(index))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return index;})();throw($s8Ret$)})();})() : nil);return index=index._minus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return absentBlock.value();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"searching",unescape("findLast%3A%20aBlock%20ifAbsent%3A%20absentBlock%0D%0A%09%22%20Return%20the%20index%20of%20the%20last%20element%20of%20the%20receiver%20that%20causes%20aBlock%20to%20evaluate%20to%20true.%0D%0A%09If%20no%20such%20element%20is%20found%2C%20return%20the%20result%20of%20evaluating%20the%20argument%20block.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20size.%0D%0A%09%5B%20index%20%3E%200%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09%28aBlock%20value%3A%20%28self%20at%3A%20index%29%29%20ifTrue%3A%20%5B%20%5Eindex%20%5D.%0D%0A%09%09index%20%3A%3D%20index%20-%201%0D%0A%09%5D.%0D%0A%09%5EabsentBlock%20value"));
smalltalk.bind(smalltalk.SequenceableCollection,"indexOfCollection:",0
,function (aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;var index1=nil;var index2=nil;var limit1=nil;var limit2=nil;limit2=aCollection.size();
limit1=self.size()._minus(limit2)._plus((1));
index1=(1);
(function(){while((function(){return index1._lt_eq(limit1);})()){(function(){((self.at_(index1)._eq(aCollection.at_((1)))).mustBeBoolean()==true ? (function(){index2=(2);(function(){while((function(){return index2._lt_eq(limit2).and_((function(){return self.at_(index1._plus(index2)._minus((1)))._eq(aCollection.at_(index2));}));})()){(function(){return index2=index2._plus((1));})()};return nil})();return ((index2._gt(limit2)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return index1;})();throw($s8Ret$)})();})() : nil);})() : nil);return index1=index1._plus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return (0);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"indexing",unescape("indexOfCollection%3A%20aCollection%0D%0A%09%22%20Return%20the%20index%20position%20of%20the%20first%20occurrence%20of%20aCollection%20in%20the%20receiver%20%28or%200%29.%20%22%0D%0A%0D%0A%09%7C%20index1%20index2%20limit1%20limit2%20%7C%0D%0A%09limit2%20%3A%3D%20aCollection%20size.%0D%0A%09limit1%20%3A%3D%20self%20size%20-%20limit2%20+%201.%0D%0A%09index1%20%3A%3D%201.%0D%0A%09%5B%20index1%20%3C%3D%20limit1%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09%28self%20at%3A%20index1%29%20%3D%20%28aCollection%20at%3A%201%29%20ifTrue%3A%20%5B%0D%0A%09%09%09index2%20%3A%3D%202.%0D%0A%09%09%09%5B%20index2%20%3C%3D%20limit2%20and%3A%20%5B%0D%0A%09%09%09%09%28self%20at%3A%20index1%20+%20index2%20-%201%29%20%3D%20%28aCollection%20at%3A%20index2%29%0D%0A%09%09%09%5D%20%5D%20whileTrue%3A%20%5B%20index2%20%3A%3D%20index2%20+%201%20%5D.%0D%0A%09%09index2%20%3E%20limit2%20ifTrue%3A%20%5B%20%5Eindex1%20%5D%0D%0A%09%09%5D.%0D%0A%09%09index1%20%3A%3D%20index1%20+%201%0D%0A%09%5D.%0D%0A%09%5E0"));
smalltalk.bind(smalltalk.SequenceableCollection,"replaceFrom:to:with:",0
,function (start,stop,aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;((stop._minus(start)._plus((1))._eq(aCollection.size())).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Replacement has wrong size");})();throw($s8Ret$)})();})());
self.replaceFrom_to_with_startingAt_(start, stop, aCollection, (1));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"replace",unescape("replaceFrom%3A%20start%20to%3A%20stop%20with%3A%20aCollection%0D%0A%09%22%20Return%20the%20receiver.%0D%0A%09Replace%20the%20elements%20of%20the%20receiver%20at%20index%20positions%20start%20through%20stop%2C%20with%20the%20elements%20of%20aCollection.%20%22%0D%0A%0D%0A%09stop%20-%20start%20+%201%20%3D%20aCollection%20size%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20%27Replacement%20has%20wrong%20size%27%0D%0A%09%5D.%0D%0A%09self%0D%0A%09%09replaceFrom%3A%20start%0D%0A%09%09to%3A%20stop%0D%0A%09%09with%3A%20aCollection%0D%0A%09%09startingAt%3A%201"));
smalltalk.bind(smalltalk.SequenceableCollection,"replaceFrom:to:with:startingAt:",0
,function (start,stop,aCollection,repStart){var $s8Ret$={name:"stReturn"};try{var self=this;var index1=nil;var index2=nil;(((self === aCollection).and_((function(){return repStart._lt(start);}))).mustBeBoolean()==true ? (function(){index2=repStart._plus(stop)._minus(start);index1=stop;(function(){while((function(){return start._lt_eq(index1);})()){(function(){self.at_put_(index1, aCollection.at_(index2));index1=index1._minus((1));return index2=index2._minus((1));})()};return nil})();return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
index2=repStart;
index1=start;
(function(){while((function(){return index1._lt_eq(stop);})()){(function(){self.at_put_(index1, aCollection.at_(index2));index1=index1._plus((1));return index2=index2._plus((1));})()};return nil})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"replace",unescape("replaceFrom%3A%20start%0D%0A%20%20%20%20to%3A%20stop%0D%0A%20%20%20%20with%3A%20aCollection%0D%0A%20%20%20%20startingAt%3A%20repStart%0D%0A%09%22%20Return%20the%20receiver.%0D%0A%09Replace%20the%20elements%20of%20the%20receiver%20at%20index%20positions%20start%20through%20stop%20with%20consecutive%0D%0A%20%20%20%20%20%20%20%20%20elements%20of%20aCollection%20beginning%20at%20index%20position%20repStart.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20index1%20index2%20%7C%0D%0A%09%28self%20%3D%3D%20aCollection%20and%3A%20%5B%20repStart%20%3C%20start%20%5D%29%20ifTrue%3A%20%5B%20%22do%20backward%20move%20for%20same%20object%22%0D%0A%09%09index2%20%3A%3D%20repStart%20+%20stop%20-%20start.%0D%0A%09%09index1%20%3A%3D%20stop.%0D%0A%09%09%5B%20start%20%3C%3D%20index1%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09%09self%20at%3A%20index1%20put%3A%20%28aCollection%20at%3A%20index2%29.%0D%0A%09%09%09index1%20%3A%3D%20index1%20-%201.%0D%0A%09%09%09index2%20%3A%3D%20index2%20-%201%0D%0A%09%09%5D.%0D%0A%09%09%5Eself%0D%0A%09%5D.%0D%0A%09index2%20%3A%3D%20repStart.%0D%0A%09index1%20%3A%3D%20start.%0D%0A%09%5B%20index1%20%3C%3D%20stop%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09self%20at%3A%20index1%20put%3A%20%28aCollection%20at%3A%20index2%29.%0D%0A%09%09index1%20%3A%3D%20index1%20+%201.%0D%0A%09%09index2%20%3A%3D%20index2%20+%201%0D%0A%09%5D"));
smalltalk.bind(smalltalk.SequenceableCollection,"replaceFrom:to:with:startingWith:",0
,function (start,stop,replacement,replacementStart){var self=this;return self.replaceFrom_to_with_startingAt_(start, stop, replacement, replacementStart);;return self;}
,"replace",unescape("replaceFrom%3A%20start%0D%0A%20%20%20%20to%3A%20stop%0D%0A%20%20%20%20with%3A%20replacement%0D%0A%20%20%20%20startingWith%3A%20replacementStart%0D%0A%09%22%20Replace%20the%20elements%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09replaceFrom%3A%20start%0D%0A%09%09to%3A%20stop%0D%0A%09%09with%3A%20replacement%0D%0A%09%09startingAt%3A%20replacementStart"));
smalltalk.bind(smalltalk.SequenceableCollection,"replaceFrom:to:withObject:",0
,function (start,stop,anObject){var self=this;var index=nil;index=start;
(function(){while((function(){return index._lt_eq(stop);})()){(function(){self.at_put_(index, anObject);return index=index._plus((1));})()};return nil})();
return anObject;;return self;}
,"replace",unescape("replaceFrom%3A%20start%20to%3A%20stop%20withObject%3A%20anObject%0D%0A%09%22Replace%20each%20of%20the%20elements%20of%20the%20receiver%20at%20index%20positions%20start%20through%20stop%20with%20anObject.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20start.%0D%0A%09%5B%20index%20%3C%3D%20stop%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09self%20at%3A%20index%20put%3A%20anObject.%0D%0A%09%09index%20%3A%3D%20index%20+%201%0D%0A%09%5D.%0D%0A%09%5EanObject"));
smalltalk.bind(smalltalk.SequenceableCollection,"with:do:",0
,function (aCollection,aBlock){var self=this;var first=nil;var second=nil;first=self.stream();
second=aCollection.stream();
(function(){while(!(function(){return first.atEnd().or_((function(){return second.atEnd();}));})()){(function(){return aBlock.value_value_(first.next(), second.next());})()};return nil})();return self;}
,"iterating",unescape("with%3A%20aCollection%20do%3A%20aBlock%0D%0A%09%22%20For%20each%20pair%20of%20elements%20evaluate%20aBlock%20with%20those%20elements%20as%20the%20arguments.%20%22%0D%0A%0D%0A%09%7C%20first%20second%20%7C%0D%0A%09first%09%3A%3D%20self%20stream.%0D%0A%09second%09%3A%3D%20aCollection%20stream.%0D%0A%09%5B%20first%20atEnd%20or%3A%20%5B%20second%20atEnd%20%5D%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09aBlock%20value%3A%20first%20next%20value%3A%20second%20next%0D%0A%09%5D."));
smalltalk.bind(smalltalk.SequenceableCollection,"asActionSequence",0
,function (){var self=this;return smalltalk.ActionSequence.withAll_(self);;return self;}
,"converting",unescape("asActionSequence%0D%0A%09%22%20Return%20an%20ActionSequence%20from%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EActionSequence%20withAll%3A%20self"));
smalltalk.bind(smalltalk.String.$klass,"streamClass",0
,function (){var self=this;return smalltalk.StringStream;;return self;}
,"accessing",unescape("streamClass%0D%0A%09%22%20Return%20the%20streamming%20support%20for%20the%20receiver%27s%20instances.%20%22%0D%0A%0D%0A%09%5EStringStream"));
smalltalk.bind(smalltalk.String.$klass,"fromString:",0
,function (aString){var self=this;	return new self.$fn(aString);;return self;}
,"instantiation",unescape("fromString%3A%20aString%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20new%20self.%24fn%28aString%29%3B%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"cr",0
,function (){var self=this;return "\r";;return self;}
,"accessing",unescape("cr%0D%0A%09%22%20Return%20the%20singular%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27%22%5Cr%22%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"lf",0
,function (){var self=this;return "\n";;return self;}
,"accessing",unescape("lf%0D%0A%09%22%20Return%20the%20singular%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27%22%5Cn%22%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"crlf",0
,function (){var self=this;return "\r\n";;return self;}
,"accessing",unescape("crlf%0D%0A%09%22%20Return%20the%20singular%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27%22%5Cr%5Cn%22%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"space",0
,function (){var self=this;return " ";;return self;}
,"accessing",unescape("space%0D%0A%09%22%20Return%20the%20singular%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27%22%20%22%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"tab",0
,function (){var self=this;return "\t";;return self;}
,"accessing",unescape("tab%0D%0A%09%22%20Return%20the%20singular%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27%22%5Ct%22%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"zero",0
,function (){var self=this;return "\0";;return self;}
,"accessing",unescape("zero%0D%0A%09%22%20Return%20the%20singular%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27%22%5C0%22%27%7D"));
smalltalk.bind(smalltalk.String.$klass,"with:",0
,function (aCharacter){var self=this;return aCharacter;;return self;}
,"instantiation",unescape("with%3A%20aCharacter%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EaCharacter"));
smalltalk.bind(smalltalk.String.$klass,"with:with:",0
,function (aCharacter,bCharacter){var self=this;return aCharacter._comma(bCharacter);;return self;}
,"instantiation",unescape("with%3A%20aCharacter%20with%3A%20bCharacter%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EaCharacter%20%2C%20bCharacter"));
smalltalk.bind(smalltalk.String.$klass,"with:with:with:",0
,function (aCharacter,bCharacter,cCharacter){var self=this;return aCharacter._comma(bCharacter)._comma(cCharacter);;return self;}
,"instantiation",unescape("with%3A%20aCharacter%20with%3A%20bCharacter%20with%3A%20cCharacter%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EaCharacter%20%2C%20bCharacter%20%2C%20cCharacter"));
smalltalk.bind(smalltalk.String.$klass,"with:with:with:with:",0
,function (aCharacter,bCharacter,cCharacter,dCharacter){var self=this;return aCharacter._comma(bCharacter)._comma(cCharacter)._comma(dCharacter);;return self;}
,"instantiation",unescape("with%3A%20aCharacter%20with%3A%20bCharacter%0D%0A%09with%3A%20cCharacter%20with%3A%20dCharacter%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EaCharacter%20%2C%20bCharacter%20%2C%20cCharacter%20%2C%20dCharacter"));
smalltalk.bind(smalltalk.String.$klass,"fromCharCode:",0
,function (anArrayOrNumber){var $s8Ret$={name:"stReturn"};try{var self=this;((anArrayOrNumber.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return String.fromCharCode(anArrayOrNumber);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return String.fromCharCode.apply(null, anArrayOrNumber.asArray());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"instantiation",unescape("fromCharCode%3A%20anArrayOrNumber%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09anArrayOrNumber%20isNumber%20ifTrue%3A%20%5B%0D%0A%09%09%5E%23%7BString%7D%20%23fromCharCode%3A%20anArrayOrNumber%0D%0A%09%5D.%0D%0A%09%5E%23%7BString%7D%23fromCharCode%0D%0A%09%09%23apply%3A%20%23%7Bnull%7D%0D%0A%09%09with%3A%20anArrayOrNumber%20asArray"));
smalltalk.bind(smalltalk.String.$klass,"doItSelector",0
,function (){var self=this;return "s8DoIt";;return self;}
,"doIt",unescape("doItSelector%0D%0A%09%22%20Return%20the%20selector%20to%20use%20for%20doIt%20evaluations.%0D%0A%09Warning%3A%20this%20selector%20will%20not%20be%20dump%20on%20image%20nor%20change%20log%20expressions.%0D%0A%09%22%0D%0A%0D%0A%09%5E%23s8DoIt"));
smalltalk.bind(smalltalk.String.$klass,"reservedWords",0
,function (){var self=this;return ["abstract", "as", "boolean", "break", "byte", "case", "catch", "char", "class", "continue", "const", "debugger", "default", "delete", "do", "double", "else", "enum", "export", "extends", false, "final", "finally", "float", "for", "function", "goto", "if", "implements", "import", "in", "instanceof", "int", "interface", "is", "long", "namespace", "native", "new", "null", "package", "private", "protected", "public", "return", "short", "static", "super", "switch", "synchronized", "this", "throw", "throws", "transient", true, "try", "typeof", "use", "var", "void", "volatile", "while", "with"];;return self;}
,"private",unescape("reservedWords%0D%0A%09%22%20Private%20-%20Return%20the%20reserved%20names%20of%20javascript%20language.%20%22%0D%0A%0D%0A%09%5E%23%28%0D%0A%09abstract%09as%09%09boolean%09%09break%09%09byte%0D%0A%09case%09%09catch%09%09char%09%09class%09%09continue%0D%0A%09const%09%09debugger%09default%09%09delete%09%09do%0D%0A%09double%09%09else%09%09enum%09%09export%09%09extends%0D%0A%09false%09%09final%09%09finally%09%09float%09%09for%0D%0A%09function%09goto%09%09if%09%09implements%09import%0D%0A%09in%09%09instanceof%09int%09%09interface%09is%0D%0A%09long%09%09namespace%09native%09%09new%09%09null%0D%0A%09package%09%09private%09%09protected%09public%09%09return%0D%0A%09short%09%09static%09%09super%09%09switch%09%09synchronized%0D%0A%09this%09%09throw%09%09throws%09%09transient%09true%0D%0A%09try%09%09typeof%09%09use%09%09var%09%09void%0D%0A%09volatile%09while%09%09with%0D%0A%09%29"));
smalltalk.bind(smalltalk.String,"=","_eq"
,function (anObject){var self=this;  if (nil.isNil_(anObject)) return false;
    if (!(anObject.isString)) return false;
    if (!(anObject.isString())) return false;
    if (self == anObject) return true;
    return ((""+self) == (""+anObject));
;return self;}
,"comparing",unescape("%3D%20anObject%0D%0A%20%20%20%20%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%7B%27%20%20if%20%28nil.isNil_%28anObject%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28%21%28anObject.isString%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28%21%28anObject.isString%28%29%29%29%20return%20false%3B%0D%0A%20%20%20%20if%20%28self%20%3D%3D%20anObject%29%20return%20true%3B%0D%0A%20%20%20%20return%20%28%28%22%22+self%29%20%3D%3D%20%28%22%22+anObject%29%29%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.String,"size",0
,function (){var self=this;return self.length;;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%23length"));
smalltalk.bind(smalltalk.String,"at:",0
,function (anIndex){var self=this;return self.charAt(anIndex._minus((1)));;return self;}
,"accessing",unescape("at%3A%20anIndex%0D%0A%09%22%20Return%20the%20receiver%20at%20anIndex.%20%22%0D%0A%0D%0A%09%5Eself%20%23charAt%3A%20anIndex%20-%201"));
smalltalk.bind(smalltalk.String,"at:put:",0
,function (anIndex,anObject){var self=this;return self.errorReadOnly();;return self;}
,"accessing",unescape("at%3A%20anIndex%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20receiver%20at%20anIndex.%20%22%0D%0A%0D%0A%09%5Eself%20errorReadOnly"));
smalltalk.bind(smalltalk.String,"at:ifAbsent:",0
,function (anIndex,aBlock){var self=this;return self.at_(anIndex).ifNil_(aBlock);;return self;}
,"accessing",unescape("at%3A%20anIndex%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20receiver%20at%20anIndex%20position%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5E%28self%20at%3A%20anIndex%29%20ifNil%3A%20aBlock"));
smalltalk.bind(smalltalk.String,"do:",0
,function (aBlock){var self=this;	for(var i=0;i<self.length;i++){aBlock(self.charAt(i));};return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7BaBlock%28self.charAt%28i%29%29%3B%7D%27%7D"));
smalltalk.bind(smalltalk.String,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;	for(var i = 0; i < self.length; i++)
		if(aBlock(self.charAt(i))) return self.charAt(i);
	return anotherBlock();;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20that%20return%20true%20when%20evaluated%20with%20aBlock%20or%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%20%3D%200%3B%20i%20%3C%20self.length%3B%20i++%29%0D%0A%09%09if%28aBlock%28self.charAt%28i%29%29%29%20return%20self.charAt%28i%29%3B%0D%0A%09return%20anotherBlock%28%29%3B%27%7D"));
smalltalk.bind(smalltalk.String,"includes:",0
,function (anObject){var self=this;return self.indexOf_(anObject)._gt((0));;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%5E%28self%20indexOf%3A%20anObject%29%20%3E%200"));
smalltalk.bind(smalltalk.String,"withIndexDo:",0
,function (aBlock){var self=this;	for(var i=0;i<self.length;i++){aBlock(self.charAt(i), i+1);};return self;}
,"enumerating",unescape("withIndexDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20all%20the%20index%20positions%20in%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7BaBlock%28self.charAt%28i%29%2C%20i+1%29%3B%7D%27%7D"));
smalltalk.bind(smalltalk.String,"copyWithout:",0
,function (anObject){var self=this;return self.replace_with_(anObject, "");;return self;}
,"copying",unescape("copyWithout%3A%20anObject%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20excluding%20anObject%2C%20if%20any.%20%22%0D%0A%0D%0A%09%5Eself%20replace%3A%20anObject%20with%3A%20%27%27"));
smalltalk.bind(smalltalk.String,"asSymbol",0
,function (){var self=this;return self;;return self;}
,"conversion",unescape("asSymbol%0D%0A%09%22%20Return%20a%20symbol%20with%20the%20same%20characters%20as%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%22we%20do%20not%20discriminate%20singular%20strings%22"));
smalltalk.bind(smalltalk.String,"argumentCount",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isEmpty().or_((function(){return self.first().isLetter();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.occurrencesOf_(":");})();throw($s8Ret$)})();})() : nil);
((unescape("%7C%26%5C%5C+*/%3D%3E%3C%2C@%25%7E-").includes_(self.first())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (1);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.occurrencesOf_(":");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"evaluating",unescape("argumentCount%0D%0A%09%22%20Return%20the%20number%20of%20arguments%20required%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09%28self%20isEmpty%20or%3A%20%5B%20self%20first%20isLetter%20%5D%29%20ifTrue%3A%20%5B%20%5Eself%20occurrencesOf%3A%20%24%3A%20%5D.%0D%0A%09%28%27%7C%26%5C%5C+*/%3D%3E%3C%2C@%25%7E-%27%20includes%3A%20self%20first%29%20ifTrue%3A%20%5B%20%5E1%20%5D.%0D%0A%09%5Eself%20occurrencesOf%3A%20%24%3A"));
smalltalk.bind(smalltalk.String,"isLiteral",0
,function (){var self=this;return (nil.isNil_(smalltalk.RegularExpression.fromString_(unescape("%5B%5Ea-zA-Z0-9_%3A%5D")).exec_(self)));;return self;}
,"testing",unescape("isLiteral%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20can%20be%20output%20using%20literal%20notation.%20%22%0D%0A%0D%0A%09%5E%28%28RegularExpression%20fromString%3A%20%27%5B%5Ea-zA-Z0-9_%3A%5D%27%29%20exec%3A%20self%29%20isNil"));
smalltalk.bind(smalltalk.String,"asLiteral",0
,function (){var self=this;return ((self.isLiteral()).mustBeBoolean()==true ? (function(){return unescape("%23")._comma(self);})() : (function(){return self.printString();})());;return self;}
,"converting",unescape("asLiteral%0D%0A%09%22%20Return%20the%20receiver%20in%20literal%20notation.%20%22%0D%0A%0D%0A%09%5Eself%20isLiteral%20ifTrue%3A%20%5B%20%24%23%20%2Cself%20%5D%20ifFalse%3A%20%5B%20self%20printString%20%5D"));
smalltalk.bind(smalltalk.String,"occurrencesOf:",0
,function (aString){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;var index=nil;((aString.isString()).mustBeBoolean()==true ? nil : (function(){result=self.match(aString);(((nil.isNil_(result))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (0);})();throw($s8Ret$)})();})() : nil);return (function(){$s8Ret$.result=(function(){return result.length;})();throw($s8Ret$)})();})());
((aString.size()._eq((1))).mustBeBoolean()==true ? (function(){result=self.match(smalltalk.RegularExpression.fromString_flag_(unescape("%5B")._comma(aString)._comma(unescape("%5D")), "g"));(((nil.isNil_(result))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (0);})();throw($s8Ret$)})();})() : nil);return (function(){$s8Ret$.result=(function(){return result.length;})();throw($s8Ret$)})();})() : nil);
result=(0);
index=(0);
(function(){while((function(){index=self.indexOf_startingAt_(aString, index._plus((1)));return index._gt((1));})()){(function(){return result=result._plus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("occurrencesOf%3A%20aString%0D%0A%09%22%20Return%20the%20times%20aString%20can%20be%20found%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20index%20%7C%0D%0A%09aString%20isString%20ifFalse%3A%20%5B%0D%0A%09%09result%20%3A%3D%20self%20%23match%3A%20aString.%0D%0A%09%09result%20isNil%20ifTrue%3A%20%5B%20%5E0%20%5D.%0D%0A%09%09%5Eresult%23length%0D%0A%09%5D.%0D%0A%09aString%20size%20%3D%201%20ifTrue%3A%20%5B%0D%0A%09%09result%20%3A%3D%20self%20%23match%3A%20%28RegularExpression%0D%0A%09%09%09%09fromString%3A%20%27%5B%27%2CaString%2C%27%5D%27%0D%0A%09%09%09%09flag%3A%20%27g%27%29.%0D%0A%09%09result%20isNil%20ifTrue%3A%20%5B%20%5E0%20%5D.%0D%0A%09%09%5Eresult%23length%0D%0A%09%5D.%0D%0A%09result%20%3A%3D%200.%20index%20%3A%3D%200.%0D%0A%09%5B%09index%20%3A%3D%20self%20indexOf%3A%20aString%20startingAt%3A%20index%20+%201.%0D%0A%09%09index%20%3E%201%20%5D%20whileTrue%3A%20%5B%20result%20%3A%3D%20result%20+%201%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.String,"escaped",0
,function (){var self=this;return escape(self);;return self;}
,"converting",unescape("escaped%0D%0A%09%22%20Return%20the%20receiver%20with%20escape%20codes.%20%22%0D%0A%0D%0A%09%5E%23%20%23escape%3A%20self"));
smalltalk.bind(smalltalk.String,"unescaped",0
,function (){var self=this;return unescape(self);;return self;}
,"converting",unescape("unescaped%0D%0A%09%22%20Return%20the%20receiver%20from%20escape%20codes.%20%22%0D%0A%0D%0A%09%5E%23%20%23unescape%3A%20self"));
smalltalk.bind(smalltalk.String,"escapedCode",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var escaped=nil;escaped=self.escaped();
((escaped._eq(self)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return unescape("%22")._comma(escaped)._comma(unescape("%22"));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return unescape("unescape%28%22")._comma(escaped)._comma(unescape("%22%29"));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("escapedCode%0D%0A%09%22%20Return%20the%20code%20to%20reproduce%20receiver%20from%20%28javascript%29%20code.%20%22%0D%0A%0D%0A%09%7C%20escaped%20%7C%0D%0A%09escaped%20%3A%3D%20self%20escaped.%0D%0A%09escaped%20%3D%20self%20ifTrue%3A%20%5B%20%5E%24%22%20%2Cescaped%20%2C%24%22%20%5D.%0D%0A%09%5E%27unescape%28%22%27%20%2Cescaped%20%2C%27%22%29%27"));
smalltalk.bind(smalltalk.String,"asEncodedURI",0
,function (){var self=this;return encodeURIComponent(self);;return self;}
,"converting",unescape("asEncodedURI%0D%0A%09%22%20Return%20the%20receiver%20encoded%20as%20an%20URI%20component.%0D%0A%09Encodes%20special%20characters%20and%20it%20encodes%20the%20following%20characters%3A%20%2C%20/%20%3F%20%3A%20@%20%26%20%3D%20+%20%24%20%23%0D%0A%09%22%0D%0A%0D%0A%09%5E%23%20%23encodeURIComponent%3A%20self"));
smalltalk.bind(smalltalk.String,"asDecodedURI",0
,function (){var self=this;return decodeURIComponent(self);;return self;}
,"converting",unescape("asDecodedURI%0D%0A%09%22%20Return%20the%20receiver%20decoded%20as%20an%20URI%20component.%20%22%0D%0A%0D%0A%09%5E%23%20%23decodeURIComponent%3A%20self"));
smalltalk.bind(smalltalk.String,"add:",0
,function (anObject){var self=this;return self.errorReadOnly();;return self;}
,"adding",unescape("add%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20errorReadOnly"));
smalltalk.bind(smalltalk.String,",","_comma"
,function (aString){var self=this;	if (nil.isNil_(aString)) return self+""; // we need this ugly patch for JSC under iOS
	return self + aString.toString();return self;}
,"copying",unescape("%2C%20aString%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20aString%20appended.%20%22%0D%0A%0D%0A%7B%27%09if%20%28nil.isNil_%28aString%29%29%20return%20self+%22%22%3B%20//%20we%20need%20this%20ugly%20patch%20for%20JSC%20under%20iOS%0D%0A%09return%20self%20+%20aString.toString%28%29%27%7D"));
smalltalk.bind(smalltalk.String,"copyWith:",0
,function (anObject){var self=this;	return self + anObject.toString();return self;}
,"copying",unescape("copyWith%3A%20anObject%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%7B%27%09return%20self%20+%20anObject.toString%28%29%27%7D"));
smalltalk.bind(smalltalk.String,"copyFrom:to:",0
,function (anIndex,anotherIndex){var self=this;return self.substring(anIndex._minus((1)), anotherIndex);;return self;}
,"copying",unescape("copyFrom%3A%20anIndex%20to%3A%20anotherIndex%0D%0A%09%22%20Return%20the%20receiver%20between%20limits.%20%22%0D%0A%0D%0A%09%5Eself%20%23substring%3A%20anIndex%20-%201%20to%3A%20anotherIndex"));
smalltalk.bind(smalltalk.String,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.String,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.String,"reversed",0
,function (){var self=this;var result=nil;result="";
self.reverseDo_((function(c){return result=result._comma(c);}));
return result;;return self;}
,"copying",unescape("reversed%0D%0A%09%22%20Return%20a%20string%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20%27%27.%0D%0A%09self%20reverseDo%3A%20%5B%3Ac%7C%20result%20%3A%3D%20result%20%2C%20c%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.String,"indexOf:",0
,function (aString){var self=this;return self.indexOf(aString)._plus((1));;return self;}
,"accessing",unescape("indexOf%3A%20aString%0D%0A%09%22%20Return%20the%20position%20of%20first%20occurrence%20of%20aString%20%28or%200%20if%20not%20present%29.%20%22%0D%0A%0D%0A%09%5E%28self%20%23indexOf%3A%20aString%29%20+%201"));
smalltalk.bind(smalltalk.String,"indexOf:ifAbsent:",0
,function (aString,aBlock){var self=this;var result=nil;result=self.indexOf_(aString);
return result._eq((0)).ifTrue_ifFalse_(aBlock, (function(){return result;}));;return self;}
,"accessing",unescape("indexOf%3A%20aString%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20position%20of%20first%20occurrence%20of%20aString%20%28or%20the%20result%20of%20evaluating%20aBlock%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20indexOf%3A%20aString.%0D%0A%09%5Eresult%20%3D%200%20ifTrue%3A%20aBlock%20ifFalse%3A%20%5B%20result%20%5D"));
smalltalk.bind(smalltalk.String,"indexOf:startingAt:",0
,function (aString,position){var self=this;return self.indexOf(aString, position._minus((1)))._plus((1));;return self;}
,"accessing",unescape("indexOf%3A%20aString%20startingAt%3A%20position%0D%0A%09%22%20Return%20the%20position%20of%20first%20occurrence%20of%20aString%20after%20position%20%28or%200%20if%20not%20present%29.%20%22%0D%0A%0D%0A%09%5E%28self%20%23indexOf%3A%20aString%20from%3A%20position%20-%201%29%20+%201"));
smalltalk.bind(smalltalk.String,"lastIndexOf:",0
,function (aString){var self=this;return self.lastIndexOf(aString)._plus((1));;return self;}
,"accessing",unescape("lastIndexOf%3A%20aString%0D%0A%09%22%20Return%20the%20position%20of%20last%20occurrence%20of%20aString%20%28or%200%20if%20not%20present%29.%20%22%0D%0A%0D%0A%09%5E%28self%20%23lastIndexOf%3A%20aString%29%20+%201"));
smalltalk.bind(smalltalk.String,"lastIndexOf:ifAbsent:",0
,function (aString,aBlock){var self=this;var result=nil;result=self.lastIndexOf_(aString);
return result._eq((0)).ifTrue_ifFalse_(aBlock, (function(){return result;}));;return self;}
,"accessing",unescape("lastIndexOf%3A%20aString%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20position%20of%20last%20occurrence%20of%20aString%20%28or%20the%20result%20of%20evaluating%20aBlock%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20lastIndexOf%3A%20aString.%0D%0A%09%5Eresult%20%3D%200%20ifTrue%3A%20aBlock%20ifFalse%3A%20%5B%20result%20%5D"));
smalltalk.bind(smalltalk.String,"lastIndexOf:startingAt:",0
,function (aString,position){var self=this;return self.lastIndexOf(aString, position._minus((1)))._plus((1));;return self;}
,"accessing",unescape("lastIndexOf%3A%20aString%20startingAt%3A%20position%0D%0A%09%22%20Return%20the%20position%20of%20last%20occurrence%20of%20aString%20before%20position%20%28or%200%20if%20not%20present%29.%20%22%0D%0A%0D%0A%09%5E%28self%20%23lastIndexOf%3A%20aString%20from%3A%20position%20-%201%29%20+%201"));
smalltalk.bind(smalltalk.String,"upTo:startingAt:",0
,function (aString,position){var self=this;var index=nil;index=self.indexOf_startingAt_(aString, position);
index=((index._eq((0))).mustBeBoolean()==true ? (function(){return self.size();})() : (function(){return index._minus((1));})());
return self.copyFrom_to_(position, index);;return self;}
,"accessing",unescape("upTo%3A%20aString%20startingAt%3A%20position%0D%0A%09%22%20Return%20the%20receiver%20upto%20first%20occurrence%20of%20aString%20after%20position.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20indexOf%3A%20aString%20startingAt%3A%20position.%0D%0A%09index%20%3A%3D%20index%20%3D%200%20ifTrue%3A%20%5B%20self%20size%20%5D%20ifFalse%3A%20%5B%20index%20-%201%20%5D.%0D%0A%09%5Eself%20copyFrom%3A%20position%20to%3A%20index"));
smalltalk.bind(smalltalk.String,"upTo:",0
,function (aCharacter){var self=this;return self.upTo_startingAt_(aCharacter, (1));;return self;}
,"accessing",unescape("upTo%3A%20aCharacter%0D%0A%09%22%20Return%20the%20receiver%20upto%20first%20occurrence%20of%20aCharacter.%20%22%0D%0A%0D%0A%09%5Eself%20upTo%3A%20aCharacter%20startingAt%3A%201"));
smalltalk.bind(smalltalk.String,"upToLast:",0
,function (aString){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.lastIndexOf_ifAbsent_(aString, (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return self.copyFrom_to_((1), index._minus((1)));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("upToLast%3A%20aString%0D%0A%09%22%20Return%20the%20receiver%20upto%20last%20occurrence%20of%20aString.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20lastIndexOf%3A%20aString%20ifAbsent%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%5Eself%20copyFrom%3A%201%20to%3A%20index%20-%201"));
smalltalk.bind(smalltalk.String,"fromLast:",0
,function (aString){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.lastIndexOf_ifAbsent_(aString, (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return self.copyFrom_to_(index._plus(aString.size()), self.size());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("fromLast%3A%20aString%0D%0A%09%22%20Return%20the%20receiver%20contents%20from%20last%20occurrence%20of%20aString.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20lastIndexOf%3A%20aString%20ifAbsent%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%5Eself%20copyFrom%3A%20index%20+%20aString%20size%20to%3A%20self%20size"));
smalltalk.bind(smalltalk.String,"asJavascriptName",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self.first()._eq("_")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
((smalltalk.String.reservedWords().includes_(self)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "$$"._comma(self);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asJavascriptName%0D%0A%09%22%20Private%20-%20Return%20the%20receiver%20as%20a%20valid%20javascript%20name.%20%22%0D%0A%0D%0A%09self%20first%20%3D%20%24_%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%28String%20reservedWords%20includes%3A%20self%29%20ifTrue%3A%20%5B%20%5E%27%24%24%27%2Cself%20%5D.%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.String,"asSelector",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var selector=nil;((self.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "$";})();throw($s8Ret$)})();})() : nil);
((self.match_(unescape("%5E%23"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.upTo_startingAt_(":", (2));})();throw($s8Ret$)})();})() : nil);
((self.isBackSlash()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "_bk";})();throw($s8Ret$)})();})() : nil);
	 return self
		.replace(/:/g,"_")
		.replace(/[+]/g,"_plus")
		.replace(/-/g,"_minus")
		.replace(/[*]/g,"_star")
		.replace(/[/]/g,"_slash")
		.replace(/[|]/g,"_bar")
		.replace(/[&]/g,"_amp")
		.replace(/>/g,"_gt")
		.replace(/</g,"_lt")
		.replace(/=/g,"_eq")
		.replace(/,/g,"_comma")
		.replace(/[@]/g,"_at")
		.replace(/~/g,"_no")
		.replace(/\\/g,"_bk")
		.asJavascriptName();
	;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asSelector%0D%0A%09%22%20Private%20-%20Return%20the%20receiver%20as%20a%20valid%20javascript%20selector.%20%22%0D%0A%0D%0A%09%7C%20selector%20%7C%0D%0A%09self%20isEmpty%20ifTrue%3A%20%5B%20%5E%27%24%27%20%5D.%0D%0A%09%28self%20match%3A%20%27%5E%23%27%29%20ifTrue%3A%20%5B%20%5Eself%20upTo%3A%20%24%3A%20startingAt%3A%202%20%5D.%0D%0A%09self%20isBackSlash%20ifTrue%3A%20%5B%20%5E%27_bk%27%20%5D.%0D%0A%7B%27%09%20return%20self%0D%0A%09%09.replace%28/%3A/g%2C%22_%22%29%0D%0A%09%09.replace%28/%5B+%5D/g%2C%22_plus%22%29%0D%0A%09%09.replace%28/-/g%2C%22_minus%22%29%0D%0A%09%09.replace%28/%5B*%5D/g%2C%22_star%22%29%0D%0A%09%09.replace%28/%5B/%5D/g%2C%22_slash%22%29%0D%0A%09%09.replace%28/%5B%7C%5D/g%2C%22_bar%22%29%0D%0A%09%09.replace%28/%5B%26%5D/g%2C%22_amp%22%29%0D%0A%09%09.replace%28/%3E/g%2C%22_gt%22%29%0D%0A%09%09.replace%28/%3C/g%2C%22_lt%22%29%0D%0A%09%09.replace%28/%3D/g%2C%22_eq%22%29%0D%0A%09%09.replace%28/%2C/g%2C%22_comma%22%29%0D%0A%09%09.replace%28/%5B@%5D/g%2C%22_at%22%29%0D%0A%09%09.replace%28/%7E/g%2C%22_no%22%29%0D%0A%09%09.replace%28/%5C%5C/g%2C%22_bk%22%29%0D%0A%09%09.asJavascriptName%28%29%3B%0D%0A%09%27%7D"));
smalltalk.bind(smalltalk.String,"asJavascript",0
,function (){var self=this;	 if(self.search(/^[a-zA-Z0-9_:.$ ]*$/) == -1)
			return "unescape(\"" + escape(self) + "\")";
		else
			return "\"" + self + "\""; ;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09%20if%28self.search%28/%5E%5Ba-zA-Z0-9_%3A.%24%20%5D*%24/%29%20%3D%3D%20-1%29%0D%0A%09%09%09return%20%22unescape%28%5C%22%22%20+%20escape%28self%29%20+%20%22%5C%22%29%22%3B%0D%0A%09%09else%0D%0A%09%09%09return%20%22%5C%22%22%20+%20self%20+%20%22%5C%22%22%3B%20%27%7D"));
smalltalk.bind(smalltalk.String,"replace:with:",0
,function (aString,anotherString){var self=this;return self.replaceRegexp_with_(smalltalk.RegularExpression.fromString_flag_(aString, "g"), anotherString);;return self;}
,unescape("regular%20expressions"),unescape("replace%3A%20aString%20with%3A%20anotherString%0D%0A%09%22%20Return%20the%20result%20of%20replacement%20of%20aString%20with%20anotherString%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09replaceRegexp%3A%20%28RegularExpression%20fromString%3A%20aString%20flag%3A%20%27g%27%29%0D%0A%09%09with%3A%20anotherString"));
smalltalk.bind(smalltalk.String,"replaceRegexp:with:",0
,function (aRegexp,aString){var self=this;return self.replace(aRegexp, aString);;return self;}
,unescape("regular%20expressions"),unescape("replaceRegexp%3A%20aRegexp%20with%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20replacement%20of%20aRegexp%20with%20aString%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23replace%3A%20aRegexp%20with%3A%20aString"));
smalltalk.bind(smalltalk.String,"tokenize:",0
,function (aString){var self=this;return self.split(aString);;return self;}
,"converting",unescape("tokenize%3A%20aString%0D%0A%09%22%20Return%20the%20split%20tokenization%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23split%3A%20aString"));
smalltalk.bind(smalltalk.String,"asArrayOfSubstrings",0
,function (){var self=this;var result=nil;var start=nil;var i=nil;result=smalltalk.Array.$$new();
i=(1);
self.do_((function(c){(((nil.isNil_(start))).mustBeBoolean()==true ? (function(){return ((c.isSeparator()).mustBeBoolean()==true ? nil : (function(){return start=i;})());})() : (function(){return ((c.isSeparator()).mustBeBoolean()==true ? (function(){result.add_(self.copyFrom_to_(start, i._minus((1))));return start=nil;})() : nil);})());return i=i._plus((1));}));
(((nil.isNil_(start)===false)).mustBeBoolean()==true ? (function(){return result.add_(self.copyFrom_to_(start, self.size()));})() : nil);
return result;;return self;}
,"converting",unescape("asArrayOfSubstrings%0D%0A%09%22%20Return%20an%20array%20of%20substrings%20from%20the%20receiver.%0D%0A%09The%20receiver%20is%20divided%20into%20substrings%20by%20one%20or%20more%20occurrences%20of%20separators.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20result%20start%20i%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%20i%20%3A%3D%201.%0D%0A%09self%20do%3A%20%5B%3Ac%7C%0D%0A%09%09start%20isNil%20ifTrue%3A%20%5B%20%22in%20separator%22%0D%0A%09%09%09c%20isSeparator%20ifFalse%3A%20%5B%20%22start%20of%20substring%22%0D%0A%09%09%09%09start%20%3A%3D%20i.%0D%0A%09%09%09%5D%0D%0A%09%09%5D%20ifFalse%3A%20%5B%20%22in%20word%22%0D%0A%09%09%09c%20isSeparator%20ifTrue%3A%20%5B%20%22end%20of%20substring%22%0D%0A%09%09%09%09result%20add%3A%20%28self%20copyFrom%3A%20start%20to%3A%20i%20-%201%29.%0D%0A%09%09%09%09start%20%3A%3D%20nil.%0D%0A%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%09i%20%3A%3D%20i%20+%201.%0D%0A%09%5D.%0D%0A%09start%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09result%20add%3A%20%28self%20copyFrom%3A%20start%20to%3A%20self%20size%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.String,"asArrayOfSubstringsSeparatedBy:",0
,function (aCharacter){var self=this;return self.tokenize_(aCharacter);;return self;}
,"converting",unescape("asArrayOfSubstringsSeparatedBy%3A%20aCharacter%0D%0A%09%22%20Return%20an%20array%20of%20substrings%20from%20the%20receiver.%0D%0A%09The%20receiver%20is%20divided%20into%20substrings%20by%20one%20or%20more%20occurrences%20of%20aCharacter.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20tokenize%3A%20aCharacter"));
smalltalk.bind(smalltalk.String,"match:",0
,function (aRegexp){var self=this;	return self.search(aRegexp) != -1;return self;}
,unescape("regular%20expressions"),unescape("match%3A%20aRegexp%0D%0A%09%22%20Return%20the%20match%20index%20of%20aRegexp%20in%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20self.search%28aRegexp%29%20%21%3D%20-1%27%7D"));
smalltalk.bind(smalltalk.String,"asString",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asString%0D%0A%09%22%20Return%20the%20text%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.String,"between:and:",0
,function (min,max){var self=this;return min._lt_eq(self).and_((function(){return self._lt_eq(max);}));;return self;}
,"testing",unescape("between%3A%20min%20and%3A%20max%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20greater%20than%20or%20equal%20to%20min%20and%20less%20than%20or%20equal%20to%20max.%20%22%0D%0A%0D%0A%09%5Emin%20%3C%3D%20self%20and%3A%20%5B%20self%20%3C%3D%20max%20%5D"));
smalltalk.bind(smalltalk.String,"isLetter",0
,function (){var self=this;return self.search(unescape("%5BA-Za-z%5D%24"))._eq((0));;return self;}
,"testing",unescape("isLetter%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20one%20character%20letter.%20%22%0D%0A%0D%0A%09%5E%28self%20%23search%3A%20%27%5BA-Za-z%5D%24%27%29%20%3D%200"));
smalltalk.bind(smalltalk.String,"isDigit",0
,function (){var self=this;return self.search(unescape("%5B0-9%5D%24"))._eq((0));;return self;}
,"testing",unescape("isDigit%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20one%20character%20numeric%20digit.%20%22%0D%0A%0D%0A%09%5E%28self%20%23search%3A%20%27%5B0-9%5D%24%27%29%20%3D%200"));
smalltalk.bind(smalltalk.String,"isAlphaNumeric",0
,function (){var self=this;return self.isDigit().or_((function(){return self.isLetter();}));;return self;}
,"testing",unescape("isAlphaNumeric%0D%0A%09%22Answer%20true%20if%20the%20receiver%20is%20an%20alphanumeric%20character.%20%22%0D%0A%0D%0A%09%5Eself%20isDigit%20or%3A%20%5Bself%20isLetter%5D"));
smalltalk.bind(smalltalk.String,"isUpperCase",0
,function (){var self=this;return self.match_(unescape("%5B%5EA-Z%5D")).not();;return self;}
,"testing",unescape("isUpperCase%0D%0A%09%22%20Return%20true%20if%20all%20the%20receiver%20characters%20are%20uppercase.%20%22%0D%0A%0D%0A%09%5E%28self%20match%3A%20%27%5B%5EA-Z%5D%27%29%20not"));
smalltalk.bind(smalltalk.String,"isLowerCase",0
,function (){var self=this;return self.match_(unescape("%5B%5Ea-z%5D")).not();;return self;}
,"testing",unescape("isLowerCase%0D%0A%09%22%20Return%20true%20if%20all%20the%20receiver%20characters%20are%20lowercase.%20%22%0D%0A%0D%0A%09%5E%28self%20match%3A%20%27%5B%5Ea-z%5D%27%29%20not"));
smalltalk.bind(smalltalk.String,"isUppercase",0
,function (){var self=this;return self.isUpperCase();;return self;}
,"testing",unescape("isUppercase%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20one%20character%20uppercase.%20%22%0D%0A%0D%0A%09%5Eself%20isUpperCase"));
smalltalk.bind(smalltalk.String,"isLowercase",0
,function (){var self=this;return self.isLowerCase();;return self;}
,"testing",unescape("isLowercase%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20one%20character%20lowercase.%20%22%0D%0A%0D%0A%09%5Eself%20isLowerCase"));
smalltalk.bind(smalltalk.String,"asUppercase",0
,function (){var self=this;return self.toUpperCase();;return self;}
,"converting",unescape("asUppercase%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20uppercase.%20%22%0D%0A%0D%0A%09%5Eself%20%23toUpperCase"));
smalltalk.bind(smalltalk.String,"asUpperCase",0
,function (){var self=this;return self.asUppercase();;return self;}
,"converting",unescape("asUpperCase%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20uppercase.%20%22%0D%0A%0D%0A%09%5Eself%20asUppercase"));
smalltalk.bind(smalltalk.String,"asLowercase",0
,function (){var self=this;return self.toLowerCase();;return self;}
,"converting",unescape("asLowercase%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20lowercase.%20%22%0D%0A%0D%0A%09%5Eself%20%23toLowerCase"));
smalltalk.bind(smalltalk.String,"asLowerCase",0
,function (){var self=this;return self.asLowercase();;return self;}
,"converting",unescape("asLowerCase%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20lowercase.%20%22%0D%0A%0D%0A%09%5Eself%20asLowercase"));
smalltalk.bind(smalltalk.String,"asSmalltalkName:",0
,function (upCase){var $s8Ret$={name:"stReturn"};try{var self=this;var up=nil;var result=nil;((upCase.not().and_((function(){return self.match_(unescape("%5Ba-z%5D")).not();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.asLowercase().asSmalltalkName_(upCase);})();throw($s8Ret$)})();})() : nil);
up=upCase;
result=self.inject_into_("", (function(result,each){return ((unescape("_%3A.%26%25%24%3F").includes_(each)).mustBeBoolean()==true ? (function(){up=true;return result;})() : (function(){return result._comma(((up).mustBeBoolean()==true ? (function(){up=false;return each.asUppercase();})() : (function(){return each;})()));})());}));
((result.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "_";})();throw($s8Ret$)})();})() : nil);
((upCase).mustBeBoolean()==true ? (function(){return ((result.first().isLowercase()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result.first().asUppercase()._comma(result.copyFrom_to_((2), result.size()));})();throw($s8Ret$)})();})() : nil);})() : (function(){return ((result.first().isUppercase()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result.first().asLowercase()._comma(result.copyFrom_to_((2), result.size()));})();throw($s8Ret$)})();})() : nil);})());
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asSmalltalkName%3A%20upCase%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20a%20smalltalk%20global%20name.%20%22%0D%0A%0D%0A%09%7C%20up%20result%20%7C%0D%0A%09%28upCase%20not%20and%3A%20%5B%20%28self%20match%3A%20%27%5Ba-z%5D%27%29%20not%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20asLowercase%20asSmalltalkName%3A%20upCase%0D%0A%09%5D.%0D%0A%09up%20%3A%3D%20upCase.%0D%0A%09result%20%3A%3D%20self%20inject%3A%20%27%27%20into%3A%20%5B%3Aresult%20%3Aeach%7C%0D%0A%09%09%28%27_%3A.%26%25%24%3F%27%20includes%3A%20each%29%20ifTrue%3A%20%5B%20up%20%3A%3D%20true.%20result%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20result%20%2C%20%28up%0D%0A%09%09%09ifTrue%3A%20%5B%20%20up%20%3A%3D%20false.%20each%20asUppercase%20%5D%0D%0A%09%09%09ifFalse%3A%20%5Beach%5D%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09result%20isEmpty%20ifTrue%3A%20%5B%20%5E%24_%20%5D.%0D%0A%09upCase%20ifTrue%3A%20%5B%0D%0A%09%09result%20first%20isLowercase%20ifTrue%3A%20%5B%0D%0A%09%09%09%5Eresult%20first%20asUppercase%20%2C%28result%20copyFrom%3A%202%20to%3A%20result%20size%29%0D%0A%09%09%5D%0D%0A%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09result%20first%20isUppercase%20ifTrue%3A%20%5B%0D%0A%09%09%09%5Eresult%20first%20asLowercase%20%2C%28result%20copyFrom%3A%202%20to%3A%20result%20size%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.String,"asGlobalName",0
,function (){var self=this;return self.asSmalltalkName_(true);;return self;}
,"converting",unescape("asGlobalName%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20a%20smalltalk%20global%20name.%20%22%0D%0A%0D%0A%09%5Eself%20asSmalltalkName%3A%20true"));
smalltalk.bind(smalltalk.String,"asLocalName",0
,function (){var self=this;return self.asSmalltalkName_(false);;return self;}
,"converting",unescape("asLocalName%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20converted%20to%20a%20smalltalk%20local%20name.%20%22%0D%0A%0D%0A%09%5Eself%20asSmalltalkName%3A%20false"));
smalltalk.bind(smalltalk.String,"digitValue",0
,function (){var self=this;return "0123456789ABCDEF".indexOf_(self)._minus((1)).max_((0)._minus((1)));;return self;}
,"converting",unescape("digitValue%0D%0A%09%22%20Return%20the%20digit%20value%20of%20the%20receiver%20%28or%20-1%29.%20%22%0D%0A%0D%0A%09%5E%28%270123456789ABCDEF%27%20indexOf%3A%20self%29%20-%201%20max%3A%200%20-%201"));
smalltalk.bind(smalltalk.String,"asNumber",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self.includes_("r")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Number.readFrom_(self.readStream());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return Number(self);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asNumber%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20Number.%20%22%0D%0A%0D%0A%09%28self%20includes%3A%20%22%24r%22%27r%27%29%20ifTrue%3A%20%5B%0D%0A%09%09%5ENumber%20readFrom%3A%20self%20readStream%0D%0A%09%5D.%0D%0A%09%5E%23%20%23Number%3A%20self"));
smalltalk.bind(smalltalk.String,"errorReadOnly",0
,function (){var self=this;return self.error_("Strings are inmutable. Attempt to change "._comma(self.printString()));;return self;}
,"error",unescape("errorReadOnly%0D%0A%09%22%20Private%20-%20The%20receiver%20is%20read-only%20instance.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Strings%20are%20inmutable.%20Attempt%20to%20change%20%27%2Cself%20printString"));
smalltalk.bind(smalltalk.String,"printString",0
,function (){var self=this;return unescape("%27")._comma(self)._comma(unescape("%27"));;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27%27%27%27%2C%20self%2C%20%27%27%27%27"));
smalltalk.bind(smalltalk.String,"isString",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20String.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.String,"isBackSlash",0
,function (){var self=this;return self._eq(unescape("%5C"));;return self;}
,"testing",unescape("isBackSlash%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20back-slash%20string.%20%22%0D%0A%0D%0A%09%5Eself%20%3D%20%24%5C%20"));
smalltalk.bind(smalltalk.String,">","_gt"
,function (aString){var self=this;	return String(self) > aString; ;return self;}
,"comparing",unescape("%3E%20aString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20greater%20than%20aString.%20%22%0D%0A%0D%0A%7B%27%09return%20String%28self%29%20%3E%20aString%3B%20%27%7D"));
smalltalk.bind(smalltalk.String,"<","_lt"
,function (aString){var self=this;	return String(self) < aString;return self;}
,"comparing",unescape("%3C%20aString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20smaller%20than%20aString.%20%22%0D%0A%0D%0A%7B%27%09return%20String%28self%29%20%3C%20aString%27%7D"));
smalltalk.bind(smalltalk.String,">=","_gt_eq"
,function (aString){var self=this;	return String(self) >= aString;return self;}
,"comparing",unescape("%3E%3D%20aString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20greater%20than%20or%20equal%20to%20aString.%20%22%0D%0A%0D%0A%7B%27%09return%20String%28self%29%20%3E%3D%20aString%27%7D"));
smalltalk.bind(smalltalk.String,"<=","_lt_eq"
,function (aString){var self=this;	return String(self) <= aString;return self;}
,"comparing",unescape("%3C%3D%20aString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20smaller%20than%20or%20equal%20to%20aString.%20%22%0D%0A%0D%0A%7B%27%09return%20String%28self%29%20%3C%3D%20aString%27%7D"));
smalltalk.bind(smalltalk.String,"remove:ifAbsent:",0
,function (anObject,aBlock){var self=this;return self.errorReadOnly();;return self;}
,"removing",unescape("remove%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20anObject%20from%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20errorReadOnly"));
smalltalk.bind(smalltalk.String,"asJSONObject",0
,function (){var self=this;return self._comma("");;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself%20%2C%20%27%27%0D%0A%22Note%3A%09we%20need%20to%20normalize%20result%20to%20do%20not%20destroy%20typeof%20checkings%0D%0A%09Do%20NOT%20modify%20this%20method%20if%20you%20do%20not%20know%20what%20you%20are%20doing.%0D%0A%09If%20you%20remove%20the%20%2C%27%27%20computation%2C%20the%20returned%20object%20will%20return%20%27object%27%20and%20not%20%27string%27%20as%20result%20of%20typeof%20operation.%0D%0A%22"));
smalltalk.bind(smalltalk.String,"isCharacter",0
,function (){var self=this;	 return self.length == 1; ;return self;}
,"testing",unescape("isCharacter%0D%0A%09%22%20Characters%20-%20Implemented%20to%20support%20Character%20protocoll%20for%20one-character%20Strings.%20%22%0D%0A%0D%0A%7B%27%09%20return%20self.length%20%3D%3D%201%3B%20%27%7D"));
smalltalk.bind(smalltalk.String,"asciiValue",0
,function (){var self=this;return self.charCodeAt((0));;return self;}
,"testing",unescape("asciiValue%0D%0A%09%22%20Characters%20-%20Return%20the%20number%20corresponding%20to%20the%20ASCII%20encoding%20of%20the%20first%20character%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23charCodeAt%3A%200"));
smalltalk.bind(smalltalk.String,"isSeparator",0
,function (){var self=this;	 return (new RegExp("\\s")).test(self); ;return self;}
,"testing",unescape("isSeparator%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20character%20is%20either%20a%20space%2C%20tab%2C%20carriage-return%2C%20line-feed%2C%20form-feed%20character%2C%20or%20double-byte%20space%2C%20else%20answer%20false.%22%0D%0A%0D%0A%7B%27%09%20return%20%28new%20RegExp%28%22%5C%5Cs%22%29%29.test%28self%29%3B%20%27%7D"));
smalltalk.bind(smalltalk.String,"asAsciiZ",0
,function (){var self=this;return self._comma(self.$klass.zero());;return self;}
,"converting",unescape("asAsciiZ%0D%0A%09%22%20Return%20the%20receiver%20with%20ascii%20zero%20appended.%20%22%0D%0A%0D%0A%09%5Eself%20%2C%20self%20class%20zero"));
smalltalk.bind(smalltalk.String,"trimFirst:last:",0
,function (firstBlock,lastBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var stop=nil;start=(1);
stop=self.size();
(function(){while((function(){((start._gt(stop)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.String.$$new();})();throw($s8Ret$)})();})() : nil);return firstBlock.value_(self.at_(start));})()){(function(){return start=start._plus((1));})()};return nil})();
(function(){while((function(){((stop._lt(start)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.String.$$new();})();throw($s8Ret$)})();})() : nil);return lastBlock.value_(self.at_(stop));})()){(function(){return stop=stop._minus((1));})()};return nil})();
(function(){$s8Ret$.result=(function(){return self.copyFrom_to_(start, stop);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"selecting",unescape("trimFirst%3A%20firstBlock%20last%3A%20lastBlock%0D%0A%09%22%20Return%20a%20String%20containing%20the%20result%20of%20trimming%20characters%20matching%20blocks%20from%20both%20sides%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20start%20stop%20%7C%0D%0A%09start%20%3A%3D%201.%20stop%20%3A%3D%20self%20size.%0D%0A%09%5B%09start%20%3E%20stop%20ifTrue%3A%20%5B%20%5EString%20new%20%5D.%0D%0A%09%09firstBlock%20value%3A%20%28self%20at%3A%20start%29%0D%0A%09%5D%20whileTrue%3A%20%5B%20start%20%3A%3D%20start%20+%201%20%5D.%0D%0A%09%5B%09stop%20%3C%20start%20ifTrue%3A%20%5B%20%5EString%20new%20%5D.%0D%0A%09%09lastBlock%20value%3A%20%28self%20at%3A%20stop%29%0D%0A%09%5D%20whileTrue%3A%20%5B%20stop%20%3A%3D%20stop%20-%201%20%5D.%0D%0A%09%5Eself%20copyFrom%3A%20start%20to%3A%20stop"));
smalltalk.bind(smalltalk.String,"trim:",0
,function (aBlock){var self=this;return self.trimFirst_last_(aBlock, aBlock);;return self;}
,"selecting",unescape("trim%3A%20aBlock%0D%0A%09%22%20Return%20a%20String%20containing%20the%20result%20of%20trimming%20characters%20matching%20aBlock%20from%20both%20sides%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20trimFirst%3A%20aBlock%20last%3A%20aBlock"));
smalltalk.bind(smalltalk.String,"trimFirst:",0
,function (aBlock){var self=this;return self.trimFirst_last_(aBlock, (function(c){return false;}));;return self;}
,"selecting",unescape("trimFirst%3A%20aBlock%0D%0A%09%22%20Return%20a%20String%20containing%20the%20result%20of%20trimming%20characters%20matching%20aBlock%20from%20start%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20trimFirst%3A%20aBlock%20last%3A%20%5B%3Ac%7C%20false%20%5D"));
smalltalk.bind(smalltalk.String,"trimLast:",0
,function (aBlock){var self=this;return self.trimFirst_last_((function(c){return false;}), aBlock);;return self;}
,"selecting",unescape("trimLast%3A%20aBlock%0D%0A%09%22%20Return%20a%20String%20containing%20the%20result%20of%20trimming%20characters%20matching%20aBlock%20from%20end%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20trimFirst%3A%20%5B%3Ac%7C%20false%20%5D%20last%3A%20aBlock"));
smalltalk.bind(smalltalk.String,"trimBlanks",0
,function (){var self=this;return self.trim_((function(c){return c.isSeparator();}));;return self;}
,"selecting",unescape("trimBlanks%0D%0A%09%22%20Return%20a%20String%20containing%20the%20receiver%20string%20with%20leading%20and%20trailing%20blanks%20removed.%20%22%0D%0A%0D%0A%09%5Eself%20trim%3A%20%5B%3Ac%7C%20c%20isSeparator%20%5D"));
smalltalk.bind(smalltalk.String,"yourself",0
,function (){var self=this;return self._comma("");;return self;}
,"identity",unescape("yourself%20%0D%0A%09%22%20Return%20the%20receiver.%0D%0A%09Note%3A%20do%20NOT%20modify/remove%20this%20method%20if%20you%20dont%20know%20what%20you%20are%20doing.%0D%0A%09Test%20the%20following%20expression%20after%20changing%20this%20code%3A%0D%0A%09%09%23new%20yourself%20%3D%3D%20%23new%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20%2C%27%27"));
smalltalk.bind(smalltalk.String,"evaluateFor:",0
,function (anObject){var self=this;return anObject.perform_(self);;return self;}
,"evaluating",unescape("evaluateFor%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%5EanObject%20perform%3A%20self"));
smalltalk.bind(smalltalk.String,"asParser",0
,function (){var self=this;return smalltalk.PPStringParser.$$new().string_(self);;return self;}
,"Compiler-converting",unescape("asParser%0D%0A%09%22%20Return%20a%20parser%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPStringParser%20new%20string%3A%20self"));
smalltalk.bind(smalltalk.String,"asChoiceParser",0
,function (){var self=this;return smalltalk.PPChoiceParser.withAll_(self.asArray().collect_((function(each){return each.asParser();})));;return self;}
,"Compiler-converting",unescape("asChoiceParser%0D%0A%09%22%20Return%20a%20parser%20of%20choices%20for%20each%20character%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPChoiceParser%20withAll%3A%20%28self%20asArray%20collect%3A%20%5B%3Aeach%20%7C%20each%20asParser%20%5D%29"));
smalltalk.bind(smalltalk.String,"asCharacterParser",0
,function (){var self=this;return smalltalk.PPCharacterParser.$$new().string_(self);;return self;}
,"Compiler-converting",unescape("asCharacterParser%0D%0A%09%22%20Return%20a%20parser%20on%20the%20characters%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPCharacterParser%20new%20string%3A%20self"));
smalltalk.bind(smalltalk.String,"showIt",0
,function (){var self=this;return self.print_(self.logEvaluate());;return self;}
,"Tools-evaluating",unescape("showIt%0D%0A%09%22%20Show/Print%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20print%3A%20self%20logEvaluate"));
smalltalk.bind(smalltalk.String,"logEvaluate",0
,function (){var self=this;return (function(){return self.evaluate();}).logEvaluate_(self);;return self;}
,"Tools-evaluating",unescape("logEvaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%0D%0A%09The%20source%20of%20evaluation%20will%20be%20logged.%0D%0A%09%22%0D%0A%0D%0A%09%5E%5B%20self%20evaluate%20%5D%20logEvaluate%3A%20self%20"));
smalltalk.bind(smalltalk.String,"evaluate",0
,function (){var self=this;return self.smalltalk().compilerSupport().evaluate_(self);;return self;}
,"Tools-evaluating",unescape("evaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20compilerSupport%20evaluate%3A%20self%20"));
smalltalk.bind(smalltalk.String,"evaluateIn:",0
,function (aReceiver){var self=this;return self.smalltalk().compilerSupport().evaluate_to_(self, aReceiver);;return self;}
,"Tools-evaluating",unescape("evaluateIn%3A%20aReceiver%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20in%20the%20context%20of%20aReceiver.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20compilerSupport%20evaluate%3A%20self%20to%3A%20aReceiver"));
smalltalk.bind(smalltalk.String,"doIt",0
,function (){var self=this;return self.smalltalk().compilerSupport().doIt_(self);;return self;}
,"Tools-evaluating",unescape("doIt%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20or%20the%20error%20occurred%20during%20compilation%20or%20evaluation.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20compilerSupport%20doIt%3A%20self"));
smalltalk.bind(smalltalk.String,"fileIn",0
,function (){var self=this;return self.stream().fileIn();;return self;}
,"Tools-fileIn",unescape("fileIn%0D%0A%09%22%20FileIn%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20stream%20fileIn"));
smalltalk.bind(smalltalk.String,"fileOut",0
,function (){var self=this;return smalltalk.Exporter.fileOut_(self);;return self;}
,"Tools-fileOut",unescape("fileOut%0D%0A%09%22%20FileOut%20the%20classes/categories%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EExporter%20fileOut%3A%20self"));
smalltalk.bind(smalltalk.String,"export","$$export"
,function (){var self=this;return smalltalk.Exporter.export_(self);;return self;}
,"Tools-fileOut",unescape("export%0D%0A%09%22%20Export%20the%20classes/categories%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EExporter%20export%3A%20self"));
smalltalk.bind(smalltalk.String,"senders",0
,function (){var self=this;return smalltalk.Smalltalk.sendersOf_(self);;return self;}
,"Tools-query",unescape("senders%0D%0A%09%22%20Return%20the%20senders%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20sendersOf%3A%20self"));
smalltalk.bind(smalltalk.String,"implementors",0
,function (){var self=this;return smalltalk.Smalltalk.implementorsOf_(self);;return self;}
,"Tools-query",unescape("implementors%0D%0A%09%22%20Return%20the%20implementors%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20implementorsOf%3A%20self"));
smalltalk.bind(smalltalk.String,"asStSelector",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var operations=nil;((self._eq("$")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "";})();throw($s8Ret$)})();})() : nil);
((self._eq("_bk")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return unescape("%5C");})();throw($s8Ret$)})();})() : nil);
((self.match_(unescape("%5E%5B%24%5D%5B%24%5D"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.copyFrom_to_((3), self.size()).asStSelector();})();throw($s8Ret$)})();})() : nil);
operations=[[unescape("+"), "_plus"], [unescape("-"), "_minus"], [unescape("*"), "_star"], [unescape("/"), "_slash"], [unescape("%7C"), "_bar"], [unescape("%26"), "_amp"], [unescape("%3E"), "_gt"], [unescape("%3C"), "_lt"], [unescape("%3D"), "_eq"], [unescape("%2C"), "_comma"], [unescape("@"), "_at"], [unescape("%7E"), "_no"], [unescape("%5C"), "_bk"]];
operations.do_((function(tuple){return ((self.match_(unescape("%5E")._comma(tuple.last()))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return operations.reversed().inject_into_(self, (function(result,each){return result.replace_with_(each.last(), each.first());}));})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return self.replace_with_("_", ":");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"Tools-converting",unescape("asStSelector%0D%0A%09%22%20Return%20a%20smalltalk%20selector%20from%20a%20javascript%20function%20name.%0D%0A%09Note%3A%20it%20must%20be%20the%20reverse%20operation%20of%20%23asSelector%0D%0A%09%22%0D%0A%0D%0A%09%7C%20operations%20%7C%0D%0A%09self%20%3D%20%27%24%27%20ifTrue%3A%20%5B%20%5E%27%27%20%5D.%0D%0A%09self%20%3D%20%27_bk%27%20ifTrue%3A%20%5B%20%5E%24%5C%20%5D.%0D%0A%09%28self%20match%3A%20%27%5E%5B%24%5D%5B%24%5D%27%29%20ifTrue%3A%20%5B%20%5E%28self%20copyFrom%3A%203%20to%3A%20self%20size%29%20asStSelector%20%5D.%0D%0A%09operations%20%3A%3D%20%23%28%0D%0A%09%09%23%28%20%24+%20%23_plus%20%29%0D%0A%09%09%23%28%20%24-%20%23_minus%20%29%0D%0A%09%09%23%28%20%24*%20%23_star%20%29%0D%0A%09%09%23%28%20%24/%20%23_slash%20%29%0D%0A%09%09%23%28%20%24%7C%20%23_bar%20%29%0D%0A%09%09%23%28%20%24%26%20%23_amp%20%29%0D%0A%09%09%23%28%20%24%3E%20%23_gt%20%29%0D%0A%09%09%23%28%20%24%3C%20%23_lt%20%29%0D%0A%09%09%23%28%20%24%3D%20%23_eq%20%29%0D%0A%09%09%23%28%20%24%2C%20%23_comma%20%29%0D%0A%09%09%23%28%20%24@%20%23_at%20%29%0D%0A%09%09%23%28%20%24%7E%20%23_no%20%29%0D%0A%09%09%23%28%20%24%5C%20%23_bk%20%29%0D%0A%09%29.%0D%0A%09operations%20do%3A%20%5B%3Atuple%7C%0D%0A%09%09%28self%20match%3A%20%24%5E%20%2C%20tuple%20last%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%5Eoperations%20reversed%20inject%3A%20self%20into%3A%20%5B%3Aresult%20%3Aeach%7C%0D%0A%09%09%09%09result%20replace%3A%20each%20last%20with%3A%20each%20first%0D%0A%09%09%09%5D%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Eself%20replace%3A%20%24_%20with%3A%20%24%3A"));
smalltalk.bind(smalltalk.String,"outputToFile:",0
,function (fileName){var self=this;return fileWrite(fileName, self, "wb");;return self;}
,"Snapshot-io",unescape("outputToFile%3A%20fileName%0D%0A%09%22%20Save%20the%20receiver%27s%20contents%20onto%20a%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09%5E%23%20%23fileWrite%3A%20fileName%20string%3A%20self%20mode%3A%20%27wb%27"));
smalltalk.bind(smalltalk.String,"appendToFile:",0
,function (fileName){var self=this;return fileWrite(fileName, self, "ab");;return self;}
,"Snapshot-io",unescape("appendToFile%3A%20fileName%0D%0A%09%22%20Append%20the%20receiver%27s%20contents%20onto%20a%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09%5E%23%20%23fileWrite%3A%20fileName%20string%3A%20self%20mode%3A%20%27ab%27"));
smalltalk.bind(smalltalk.Array.$klass,"new","$$new"
,function (){var self=this;return [];;return self;}
,"instantiation",unescape("new%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.Array.$klass,"basicNew:",0
,function (size){var self=this;	return new Array(size);return self;}
,"instantiation",unescape("basicNew%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%7B%27%09return%20new%20Array%28size%29%27%7D"));
smalltalk.bind(smalltalk.Array.$klass,"new:",0
,function (size){var self=this;return self.basicNew_(size).atAllPut_(nil);;return self;}
,"instantiation",unescape("new%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%09%5E%28self%20basicNew%3A%20size%29%20atAllPut%3A%20nil"));
smalltalk.bind(smalltalk.Array.$klass,"with:",0
,function (anObject){var self=this;	return [ anObject ];	;return self;}
,"instantiation",unescape("with%3A%20anObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20%5B%20anObject%20%5D%3B%09%27%7D"));
smalltalk.bind(smalltalk.Array.$klass,"with:with:",0
,function (anObject,anotherObject){var self=this;	return [ anObject, anotherObject ];	;return self;}
,"instantiation",unescape("with%3A%20anObject%20with%3A%20anotherObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20%5B%20anObject%2C%20anotherObject%20%5D%3B%09%27%7D"));
smalltalk.bind(smalltalk.Array.$klass,"with:with:with:",0
,function (firstObject,secondObject,thirdObject){var self=this;	return [ firstObject, secondObject, thirdObject ];	;return self;}
,"instantiation",unescape("with%3A%20firstObject%20with%3A%20secondObject%20with%3A%20thirdObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20%5B%20firstObject%2C%20secondObject%2C%20thirdObject%20%5D%3B%09%27%7D"));
smalltalk.bind(smalltalk.Array.$klass,"withAll:",0
,function (aCollection){var self=this;	return [].concat(aCollection.asArray());	;return self;}
,"instantiation",unescape("withAll%3A%20aCollection%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20%5B%5D.concat%28aCollection.asArray%28%29%29%3B%09%27%7D"));
smalltalk.bind(smalltalk.Array.$klass,"with:with:with:with:",0
,function (firstObject,secondObject,thirdObject,fourthObject){var self=this;	return [ firstObject, secondObject, thirdObject, fourthObject ];	;return self;}
,"instantiation",unescape("with%3A%20firstObject%20with%3A%20secondObject%20with%3A%20thirdObject%20with%3A%20fourthObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20%5B%20firstObject%2C%20secondObject%2C%20thirdObject%2C%20fourthObject%20%5D%3B%09%27%7D"));
smalltalk.bind(smalltalk.Array,"size",0
,function (){var self=this;return self.length;;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%23length"));
smalltalk.bind(smalltalk.Array,"at:put:",0
,function (anIndex,anObject){var self=this;	return self[anIndex - 1] = anObject;return self;}
,"accessing",unescape("at%3A%20anIndex%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20contents%20of%20the%20receiver%20at%20anIndex.%20%22%0D%0A%0D%0A%7B%27%09return%20self%5BanIndex%20-%201%5D%20%3D%20anObject%27%7D"));
smalltalk.bind(smalltalk.Array,"at:",0
,function (anIndex){var self=this;	var value = self[anIndex - 1];
	if(value === undefined) { return self.objectNotFoundAt_(anIndex); }
	return value;;return self;}
,"accessing",unescape("at%3A%20anIndex%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20at%20anIndex.%20%22%0D%0A%0D%0A%7B%27%09var%20value%20%3D%20self%5BanIndex%20-%201%5D%3B%0D%0A%09if%28value%20%3D%3D%3D%20undefined%29%20%7B%20return%20self.objectNotFoundAt_%28anIndex%29%3B%20%7D%0D%0A%09return%20value%3B%27%7D"));
smalltalk.bind(smalltalk.Array,"at:ifAbsent:",0
,function (anIndex,aBlock){var self=this;	var value = self[anIndex - 1];
	if(value === undefined) { return aBlock(); }
	return value;;return self;}
,"accessing",unescape("at%3A%20anIndex%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20at%20anIndex%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%7B%27%09var%20value%20%3D%20self%5BanIndex%20-%201%5D%3B%0D%0A%09if%28value%20%3D%3D%3D%20undefined%29%20%7B%20return%20aBlock%28%29%3B%20%7D%0D%0A%09return%20value%3B%27%7D"));
smalltalk.bind(smalltalk.Array,"do:",0
,function (aBlock){var self=this;	for(var i=0;i<self.length;i++){aBlock(self[i]);} ;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7BaBlock%28self%5Bi%5D%29%3B%7D%20%27%7D"));
smalltalk.bind(smalltalk.Array,"isArray",0
,function (){var self=this;return (self.$klass === smalltalk.Array);;return self;}
,"testing",unescape("isArray%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20an%20Array.%20%22%0D%0A%0D%0A%09%5Eself%20class%20%3D%3D%20Array"));
smalltalk.bind(smalltalk.Array,"addAll:",0
,function (aCollection){var self=this;self.push.apply(self, aCollection.asArray());
return aCollection;;return self;}
,"adding",unescape("addAll%3A%20aCollection%0D%0A%09%22%20Add%20objects%20in%20aCollection%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09self%23push%20%23apply%3A%20self%20with%3A%20aCollection%20asArray.%0D%0A%09%5EaCollection"));
smalltalk.bind(smalltalk.Array,"shallowCopy",0
,function (){var self=this;return self.slice((0));;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%23slice%3A%200"));
smalltalk.bind(smalltalk.Array,"deepCopy",0
,function (){var self=this;return self.collect_((function(each){return each.deepCopy();}));;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20collect%3A%20%5B%3Aeach%20%7C%20each%20deepCopy%20%5D"));
smalltalk.bind(smalltalk.Array,"copyFrom:to:",0
,function (anIndex,anotherIndex){var self=this;var result=nil;result=self.$klass.$$new();
anIndex.to_do_(anotherIndex, (function(each){return result.add_(self.at_(each));}));
return result;;return self;}
,"copying",unescape("copyFrom%3A%20anIndex%20to%3A%20anotherIndex%0D%0A%09%22%20Return%20the%20receiver%20contents%20in%20the%20interval.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09anIndex%20to%3A%20anotherIndex%20do%3A%20%5B%3Aeach%20%7C%20result%20add%3A%20%28self%20at%3A%20each%29%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Array,"copyWithAll:",0
,function (aCollection){var self=this;return self.concat(aCollection.asArray());;return self;}
,"copying",unescape("copyWithAll%3A%20aCollection%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20all%20contents%20of%20aCollection.%20%22%0D%0A%0D%0A%09%5Eself%20%23concat%3A%20aCollection%20asArray"));
smalltalk.bind(smalltalk.Array,",","_comma"
,function (aCollection){var self=this;return self.concat(aCollection.asArray());;return self;}
,"copying",unescape("%2C%20aCollection%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20all%20contents%20of%20aCollection.%20%22%0D%0A%0D%0A%09%5Eself%20%23concat%3A%20aCollection%20asArray"));
smalltalk.bind(smalltalk.Array,"join:",0
,function (aString){var self=this;return self.join(aString);;return self;}
,"enumerating",unescape("join%3A%20aString%0D%0A%09%22%20Return%20a%20string%20with%20the%20receiver%27s%20contents%20separated%20by%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20%23join%3A%20aString"));
smalltalk.bind(smalltalk.Array,"asJavascript",0
,function (){var self=this;return unescape("%5B")._comma(self.collect_((function(each){return each.asJavascript();})).join_(unescape("%2C%20")))._comma(unescape("%5D"));;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27%5B%27%2C%20%28%28self%20collect%3A%20%5B%3Aeach%20%7C%20each%20asJavascript%5D%29%20join%3A%20%27%2C%20%27%29%2C%20%20%27%5D%27"));
smalltalk.bind(smalltalk.Array,"sort:",0
,function (aBlock){var self=this;	return self.sort(function(a, b) {if(aBlock(a,b)) {return -1} else {return 1}}) ;return self;}
,"sorting",unescape("sort%3A%20aBlock%0D%0A%09%22%20Sort%20%28inplace%29%20the%20receiver%27s%20contents%20with%20aBlock.%20%22%0D%0A%0D%0A%7B%27%09return%20self.sort%28function%28a%2C%20b%29%20%7Bif%28aBlock%28a%2Cb%29%29%20%7Breturn%20-1%7D%20else%20%7Breturn%201%7D%7D%29%20%27%7D"));
smalltalk.bind(smalltalk.Array,"asArray",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asArray%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Array,"remove:ifAbsent:",0
,function (anObject,aBlock){var self=this;	for(var i=0;i<self.length;i++) {
		if(self[i] == anObject) {
			self.splice(i,1); return anObject;
		}
	}; return aBlock.value(); ;return self;}
,"removing",unescape("remove%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20anObject%20from%20the%20receiver.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20anObject%20is%20not%20in%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%20%7B%0D%0A%09%09if%28self%5Bi%5D%20%3D%3D%20anObject%29%20%7B%0D%0A%09%09%09self.splice%28i%2C1%29%3B%20return%20anObject%3B%0D%0A%09%09%7D%0D%0A%09%7D%3B%20return%20aBlock.value%28%29%3B%20%27%7D"));
smalltalk.bind(smalltalk.Array,"add:",0
,function (anObject){var self=this;self.push(anObject);
return anObject;;return self;}
,"adding",unescape("add%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23push%3A%20anObject.%0D%0A%09%5EanObject"));
smalltalk.bind(smalltalk.Array,"addLast:",0
,function (anObject){var self=this;self.push(anObject);
return anObject;;return self;}
,"adding",unescape("addLast%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23push%3A%20anObject.%0D%0A%09%5EanObject"));
smalltalk.bind(smalltalk.Array,"addFirst:",0
,function (anObject){var self=this;self.splice((0), (0), anObject);
return anObject;;return self;}
,"adding",unescape("addFirst%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23splice%3A%200%20remove%3A%200%20with%3A%20anObject.%0D%0A%09%5EanObject"));
smalltalk.bind(smalltalk.Array,"removeLast",0
,function (){var self=this;return self.pop();;return self;}
,"removing",unescape("removeLast%0D%0A%09%22%20Remove%20the%20last%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20pop"));
smalltalk.bind(smalltalk.Array,"removeFirst",0
,function (){var self=this;var result=nil;result=self.first();
self.splice((0), (1));
return result;;return self;}
,"removing",unescape("removeFirst%0D%0A%09%22%20Remove%20the%20first%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20first.%0D%0A%09self%20%23splice%3A%200%20count%3A%201.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Array,"removeAll",0
,function (){var self=this;self.splice((0), self.size());return self;}
,"removing",unescape("removeAll%0D%0A%09%22%20Remove%20all%20the%20objects%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20%23splice%3A%200%20count%3A%20self%20size."));
smalltalk.bind(smalltalk.Array,"removeIndex:",0
,function (index){var self=this;self.splice(index._minus((1)), (1));return self;}
,"removing",unescape("removeIndex%3A%20index%0D%0A%09%22%20Remove%20the%20element%20at%20index.%20%22%0D%0A%0D%0A%09self%20%23splice%3A%20index-1%20count%3A%201"));
smalltalk.bind(smalltalk.Array,"sorted",0
,function (){var self=this;return self.copy().sort();;return self;}
,"sorting",unescape("sorted%0D%0A%09%22%20Return%20a%20sorted%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20copy%20sort"));
smalltalk.bind(smalltalk.Array,"sorted:",0
,function (aBlock){var self=this;return self.copy().sort_(aBlock);;return self;}
,"sorting",unescape("sorted%3A%20aBlock%0D%0A%09%22%20Return%20a%20sorted%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20copy%20sort%3A%20aBlock"));
smalltalk.bind(smalltalk.Array,"atAllPut:",0
,function (anObject){var self=this;	for(var i=0;i<self.length;i++){ self[i] = anObject; };return self;}
,"accessing",unescape("atAllPut%3A%20anObject%0D%0A%09%22%20Replace%20all%20elements%20of%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7B%20self%5Bi%5D%20%3D%20anObject%3B%20%7D%27%7D"));
smalltalk.bind(smalltalk.Array,"first",0
,function (){var self=this;return (function(){var $1$ = self[(0)];if (typeof ($1$) == "undefined") return (function(){return self.at_((1));})(); return $1$;})();;return self;}
,"accessing",unescape("first%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%5B0%5D%20ifUndefined%3A%20%5Bself%20at%3A%201%5D"));
smalltalk.bind(smalltalk.Array,"second",0
,function (){var self=this;return (function(){var $1$ = self[(1)];if (typeof ($1$) == "undefined") return (function(){return self.at_((2));})(); return $1$;})();;return self;}
,"accessing",unescape("second%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%5B1%5D%20ifUndefined%3A%20%5Bself%20at%3A%202%5D"));
smalltalk.bind(smalltalk.Array,"third",0
,function (){var self=this;return (function(){var $1$ = self[(2)];if (typeof ($1$) == "undefined") return (function(){return self.at_((3));})(); return $1$;})();;return self;}
,"accessing",unescape("third%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%5B2%5D%20ifUndefined%3A%20%5Bself%20at%3A%203%5D"));
smalltalk.bind(smalltalk.Array,"fourth",0
,function (){var self=this;return (function(){var $1$ = self[(3)];if (typeof ($1$) == "undefined") return (function(){return self.at_((4));})(); return $1$;})();;return self;}
,"accessing",unescape("fourth%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%5B3%5D%20ifUndefined%3A%20%5Bself%20at%3A%204%5D"));
smalltalk.bind(smalltalk.Array,"withIndexDo:",0
,function (aBlock){var self=this;	for(var i=0;i<self.length;i++){aBlock(self[i], i+1);};return self;}
,"enumerating",unescape("withIndexDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20all%20the%20index%20positions%20in%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09for%28var%20i%3D0%3Bi%3Cself.length%3Bi++%29%7BaBlock%28self%5Bi%5D%2C%20i+1%29%3B%7D%27%7D"));
smalltalk.bind(smalltalk.Array,"printString",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;((self.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return unescape("%23%28%29");})();throw($s8Ret$)})();})() : nil);
result=unescape("%23%28%20");
self.do_((function(each){((result.size()._gt((10000))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result._comma(unescape("...%29"));})();throw($s8Ret$)})();})() : nil);return result=result._comma(((self.isObject_(each)).mustBeBoolean()==true ? (function(){return each.printString();})() : (function(){return each;})()))._comma(" ");}));
(function(){$s8Ret$.result=(function(){return result._comma(unescape("%29"));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"printing",unescape("printString%0D%0A%09%22%20DEBUG%20-%20Temporary%20printing%20method%20%28must%20check%20for%20recursion%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20isEmpty%20ifTrue%3A%20%5B%20%5E%27%23%28%29%27%20%5D.%0D%0A%09result%20%3A%3D%20%27%23%28%20%27.%0D%0A%09self%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09result%20size%20%3E%2010000%20ifTrue%3A%20%5B%20%5Eresult%2C%27...%29%27%20%5D.%0D%0A%09%09result%20%3A%3D%20result%20%2C%20%28%0D%0A%09%09%09%28self%20isObject%3A%20each%29%0D%0A%09%09%09ifTrue%3A%20%5B%20each%20printString%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20each%20%5D%29%20%2C%27%20%27%0D%0A%09%5D.%0D%0A%09%5Eresult%2C%27%29%27"));
smalltalk.bind(smalltalk.Array,"asLiteral",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;((self.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return unescape("%23%28%29");})();throw($s8Ret$)})();})() : nil);
result=unescape("%23%28%20");
self.do_((function(each){return result=result._comma(((self.isObject_(each)).mustBeBoolean()==true ? (function(){return each.asLiteral();})() : (function(){return each;})()))._comma(" ");}));
(function(){$s8Ret$.result=(function(){return result._comma(unescape("%29"));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asLiteral%0D%0A%09%22%20Return%20the%20receiver%20in%20literal%20notation.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20isEmpty%20ifTrue%3A%20%5B%20%5E%27%23%28%29%27%20%5D.%0D%0A%09result%20%3A%3D%20%27%23%28%20%27.%0D%0A%09self%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09result%20%3A%3D%20result%20%2C%20%28%0D%0A%09%09%09%28self%20isObject%3A%20each%29%0D%0A%09%09%09ifTrue%3A%20%5B%20each%20asLiteral%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20each%20%5D%29%20%2C%27%20%27%0D%0A%09%5D.%0D%0A%09%5Eresult%2C%27%29%27"));
smalltalk.bind(smalltalk.Array,"asJSONObject",0
,function (){var self=this;return self.collect_((function(each){return ((self.isObject_(each)).mustBeBoolean()==true ? (function(){return each.asJSONObject();})() : (function(){return each;})());}));;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20an%20Array%20with%20the%20contents%20of%20the%20receiver%20converted%20to%20JSON%20structures.%20%22%0D%0A%0D%0A%09%5Eself%20collect%3A%20%5B%3Aeach%7C%20%0D%0A%09%09%28self%20isObject%3A%20each%29%0D%0A%09%09ifTrue%3A%20%5B%20each%20asJSONObject%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20each%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Array,"json",0
,function (){var self=this;return self.collect_((function(each){return ((self.isObject_(each)).mustBeBoolean()==true ? (function(){return each.json();})() : (function(){return each;})());}));;return self;}
,"converting",unescape("json%0D%0A%09%22%20Return%20an%20Array%20with%20the%20contents%20of%20the%20receiver%20converted%20to%20JSON%20structures.%20%22%0D%0A%0D%0A%09%5Eself%20collect%3A%20%5B%3Aeach%7C%20%0D%0A%09%09%28self%20isObject%3A%20each%29%0D%0A%09%09ifTrue%3A%20%5B%20each%20json%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20each%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Array,"handles",0
,function (){var self=this;return self.collect_((function(each){return each.handle();}));;return self;}
,"Natives-converting",unescape("handles%0D%0A%09%22%20Return%20the%20result%20of%20collecting%20the%20handles%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20collect%3A%20%5B%3Aeach%7C%20each%20handle%20%5D"));
smalltalk.bind(smalltalk.ArrayedContents,"contents",0
,function (){var self=this;(((nil.isNil_(self['@contents']))).mustBeBoolean()==true ? (function(){return self['@contents']=smalltalk.Array.$$new();})() : nil);
return self['@contents'];;return self;}
,"private",unescape("contents%0D%0A%09%22%20Private%20-%20Return%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09contents%20isNil%20ifTrue%3A%20%5B%20contents%20%3A%3D%20Array%20new%20%5D.%0D%0A%09%5Econtents"));
smalltalk.bind(smalltalk.ArrayedContents,"add:",0
,function (anObject){var self=this;return self.contents().add_(anObject);;return self;}
,"adding",unescape("add%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20add%3A%20anObject"));
smalltalk.bind(smalltalk.ArrayedContents,"at:ifAbsent:",0
,function (anIndex,aBlock){var self=this;return self.contents().at_ifAbsent_(anIndex, aBlock);;return self;}
,"accessing",unescape("at%3A%20anIndex%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20at%20anIndex%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20at%3A%20anIndex%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.ArrayedContents,"at:put:",0
,function (anIndex,anObject){var self=this;return self.contents().at_put_(anIndex, anObject);;return self;}
,"accessing",unescape("at%3A%20anIndex%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20contents%20of%20the%20receiver%20at%20anIndex.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20at%3A%20anIndex%20put%3A%20anObject"));
smalltalk.bind(smalltalk.ArrayedContents,"atAllPut:",0
,function (anObject){var self=this;return self.contents().atAllPut_(anObject);;return self;}
,"accessing",unescape("atAllPut%3A%20anObject%0D%0A%09%22%20Replace%20all%20elements%20of%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20atAllPut%3A%20anObject"));
smalltalk.bind(smalltalk.ArrayedContents,"copyFrom:to:",0
,function (anIndex,anotherIndex){var self=this;var result=nil;result=self.$klass.$$new();
anIndex.to_do_(anotherIndex, (function(each){return result.add_(self.at_(each));}));
return result;;return self;}
,"copying",unescape("copyFrom%3A%20anIndex%20to%3A%20anotherIndex%0D%0A%09%22%20Return%20the%20receiver%20contents%20in%20the%20interval.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09anIndex%20to%3A%20anotherIndex%20do%3A%20%5B%3Aeach%20%7C%20result%20add%3A%20%28self%20at%3A%20each%29%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.ArrayedContents,"indexOf:ifAbsent:",0
,function (anObject,aBlock){var self=this;return self.contents().indexOf_ifAbsent_(anObject, aBlock);;return self;}
,"testing",unescape("indexOf%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20position%20of%20anObject%20in%20the%20receiver%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20indexOf%3A%20anObject%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.ArrayedContents,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;return self.contents().detect_ifNone_(aBlock, anotherBlock);;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20that%20return%20true%20when%20evaluated%20with%20aBlock%20or%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20detect%3A%20aBlock%20ifNone%3A%20anotherBlock"));
smalltalk.bind(smalltalk.ArrayedContents,"do:",0
,function (aBlock){var self=this;return self.contents().do_(aBlock);;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20do%3A%20aBlock"));
smalltalk.bind(smalltalk.ArrayedContents,"includes:",0
,function (anObject){var self=this;return self.contents().includes_(anObject);;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20includes%3A%20anObject"));
smalltalk.bind(smalltalk.ArrayedContents,"isEmpty",0
,function (){var self=this;return self.contents().isEmpty();;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20isEmpty"));
smalltalk.bind(smalltalk.ArrayedContents,"occurrencesOf:",0
,function (anObject){var self=this;return self.contents().occurrencesOf_(anObject);;return self;}
,"counting",unescape("occurrencesOf%3A%20anObject%0D%0A%09%22%20Return%20the%20occurrences%20of%20anObject%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20occurrencesOf%3A%20anObject"));
smalltalk.bind(smalltalk.ArrayedContents,"reverseDo:",0
,function (aBlock){var self=this;return self.contents().reverseDo_(aBlock);;return self;}
,"enumerating",unescape("reverseDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order%20of%20iteration.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20reverseDo%3A%20aBlock"));
smalltalk.bind(smalltalk.ArrayedContents,"reversed",0
,function (){var self=this;return self.$klass.withAll_(self.contents().reversed());;return self;}
,"copying",unescape("reversed%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20self%20contents%20reversed"));
smalltalk.bind(smalltalk.ArrayedContents,"remove:ifAbsent:",0
,function (anObject,aBlock){var self=this;return self.contents().remove_ifAbsent_(anObject, aBlock);;return self;}
,"removing",unescape("remove%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20anObject%20from%20the%20receiver.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20anObject%20is%20not%20in%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20contents%20remove%3A%20anObject%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.ArrayedContents,"removeAll",0
,function (){var self=this;self['@contents']=nil;return self;}
,"removing",unescape("removeAll%0D%0A%09%22%20Remove%20all%20the%20objects%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09contents%20%3A%3D%20nil"));
smalltalk.bind(smalltalk.ArrayedContents,"removeFirst",0
,function (){var self=this;return self.contents().removeFirst();;return self;}
,"removing",unescape("removeFirst%0D%0A%09%22%20Remove%20the%20first%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20removeFirst"));
smalltalk.bind(smalltalk.ArrayedContents,"removeLast",0
,function (){var self=this;return self.contents().removeLast();;return self;}
,"removing",unescape("removeLast%0D%0A%09%22%20Remove%20the%20last%20object%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20removeLast"));
smalltalk.bind(smalltalk.ArrayedContents,"removeIndex:",0
,function (index){var self=this;return self.contents().removeIndex_(index);;return self;}
,"removing",unescape("removeIndex%3A%20index%0D%0A%09%22%20Remove%20the%20element%20at%20index.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20removeIndex%3A%20index"));
smalltalk.bind(smalltalk.ArrayedContents,"size",0
,function (){var self=this;return self.contents().size();;return self;}
,"accesing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20size"));
smalltalk.bind(smalltalk.ArrayedContents,"withIndexDo:",0
,function (aBlock){var self=this;return self.contents().withIndexDo_(aBlock);;return self;}
,"enumerating",unescape("withIndexDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20all%20the%20index%20positions%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20contents%20withIndexDo%3A%20aBlock"));
smalltalk.bind(smalltalk.ComposedAssociations,",","_comma"
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;((anObject.isAssociation()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function($rec){$rec.add_(anObject);return $rec.yourself();})(self);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return (((nil.isNil_(anObject))).mustBeBoolean()==true ? (function(){return self;})() : (function(){return smalltalk.superImplementor(smalltalk.ComposedAssociations,'_comma').apply(self, [anObject]);})());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"composing",unescape("%2C%20anObject%0D%0A%09%22%20Compose%20the%20receiver%20with%20anObject%20%28anAssociation%2C%20aCollection%2C%20or%20nil%29.%0D%0A%09Return%20the%20composite%20result.%0D%0A%09%22%0D%0A%0D%0A%09anObject%20isAssociation%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20add%3A%20anObject%3B%20yourself%0D%0A%09%5D.%0D%0A%09%5EanObject%20isNil%20ifTrue%3A%20%5B%20self%20%5D%20ifFalse%3A%20%5B%20super%20%2C%20anObject%20%5D"));
smalltalk.bind(smalltalk.ComposedAssociations,"hashObject",0
,function (){var self=this;	return {}; ;return self;}
,"private",unescape("hashObject%0D%0A%09%22%20Private%20-%20Return%20an%20empty%20hash%20object.%20%22%0D%0A%0D%0A%7B%27%09return%20%7B%7D%3B%20%27%7D"));
smalltalk.bind(smalltalk.ComposedAssociations,"install:value:into:",0
,function (key,value,jsObject){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isObject_(key).and_((function(){return key.isArray();}))).mustBeBoolean()==true ? (function(){((key.size()._eq((1))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.install_value_into_(key.first(), value, jsObject);})();throw($s8Ret$)})();})() : nil);return ((key.size()._gt((1))).mustBeBoolean()==true ? (function(){var target=nil;target=((function(){var $1$=jsObject[key.first()];if(nil.isNil_($1$))return ((function(){return (jsObject[key.first().toString()]=(self.hashObject()));}).value());return $1$;})());return (function(){$s8Ret$.result=(function(){return self.install_value_into_(key.copyFrom_to_((2), key.size()), value, target);})();throw($s8Ret$)})();})() : nil);})() : nil);
(function(){$s8Ret$.result=(function(){return (jsObject[key.toString()]=(value));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("install%3A%20key%20value%3A%20value%20into%3A%20jsObject%0D%0A%09%22%20Private%20-%20Install%20a%20key/value%20pair%20into%20jsObject.%20%22%0D%0A%0D%0A%09%28%28self%20isObject%3A%20key%29%20and%3A%20%5B%20key%20isArray%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09key%20size%20%3D%201%20ifTrue%3A%20%5B%20%5Eself%20install%3A%20key%20first%20value%3A%20value%20into%3A%20jsObject%20%5D.%0D%0A%09%09key%20size%20%3E%201%20ifTrue%3A%20%5B%20%7C%20target%20%7C%0D%0A%09%09%09target%20%3A%3D%20jsObject%20basicAt%3A%20key%20first%20ifAbsent%3A%20%5B%0D%0A%09%09%09%09jsObject%20basicAt%3A%20key%20first%20toString%20put%3A%20self%20hashObject%0D%0A%09%09%09%5D.%0D%0A%09%09%09%5Eself%20install%3A%20%28key%20copyFrom%3A%202%20to%3A%20key%20size%29%20value%3A%20value%20into%3A%20target%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5EjsObject%0D%0A%09%09basicAt%3A%20key%20toString%20%22it%20is%20IMPORTANT%20to%20send%20%23toString%20here%20%28v8%7B4.7.0%7D%20bug%20will%20expose%20%7Bobject%7D%20instead%20of%20%7Bstring%7D%20Ale-14/oct/2015%29%22%0D%0A%09%09put%3A%20value"));
smalltalk.bind(smalltalk.ComposedAssociations,"asJSONObject",0
,function (){var self=this;return self.json();;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20a%20JSON%20structure%20with%20the%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%5Eself%20json"));
smalltalk.bind(smalltalk.ComposedAssociations,"json",0
,function (){var self=this;var result=nil;var value=nil;result=self.hashObject();
self.do_((function(assoc){value=((self.isObject_(assoc.value())).mustBeBoolean()==true ? (function(){return assoc.value().json();})() : (function(){return assoc.value();})());return self.install_value_into_(assoc.key(), value, result);}));
return result;;return self;}
,"converting",unescape("json%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20hash%20object.%20%22%0D%0A%0D%0A%09%7C%20result%20value%20%7C%0D%0A%09result%20%3A%3D%20self%20hashObject.%0D%0A%09self%20do%3A%20%5B%3Aassoc%20%7C%0D%0A%09%09value%20%3A%3D%20%28self%20isObject%3A%20assoc%20value%29%0D%0A%09%09%09ifTrue%3A%20%5B%20assoc%20value%20json%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20assoc%20value%20%5D.%0D%0A%09%09self%20install%3A%20assoc%20key%20value%3A%20value%20into%3A%20result%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.ComposedAssociations,"associationAt:ifAbsent:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;self.reverseDo_((function(assoc){var value=nil;((assoc.key()._eq(aKey)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return assoc;})();throw($s8Ret$)})();})() : nil);value=assoc.value();return ((self.isObject_(value).and_((function(){return smalltalk.is_kindOf_(value,(self.$klass));}))).mustBeBoolean()==true ? (function(){value=value.associationAt_ifAbsent_(aKey, (function(){return nil;}));return (((nil.isNil_(value)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return value;})();throw($s8Ret$)})();})() : nil);})() : nil);}));
(function(){$s8Ret$.result=(function(){return aBlock.evaluate();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("associationAt%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20association%20at%20aKey%20%28or%20the%20result%20of%20evaluating%20aBlock%29.%0D%0A%09Note%3A%20the%20search%20will%20introspect%20in%20case%20of%20composite%20values.%0D%0A%09%22%0D%0A%0D%0A%09self%20reverseDo%3A%20%5B%3Aassoc%7C%20%7C%20value%20%7C%0D%0A%09%09assoc%20key%20%3D%20aKey%20ifTrue%3A%20%5B%20%5Eassoc%20%5D.%0D%0A%09%09value%20%3A%3D%20assoc%20value.%0D%0A%09%09%28%28self%20isObject%3A%20value%29%20and%3A%20%5Bvalue%20isKindOf%3A%20self%20class%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09value%20%3A%3D%20value%20associationAt%3A%20aKey%20ifAbsent%3A%20%5B%5D.%0D%0A%09%09%09value%20notNil%20ifTrue%3A%20%5B%20%5Evalue%20%5D.%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5EaBlock%20evaluate"));
smalltalk.bind(smalltalk.ComposedAssociations,"@","_at"
,function (aKey){var $s8Ret$={name:"stReturn"};try{var self=this;var assoc=nil;assoc=self.associationAt_ifAbsent_(aKey, (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return assoc.value();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("@%20aKey%0D%0A%09%22%20Return%20the%20value%20at%20aKey%20%28or%20nil%29.%0D%0A%09Note%3A%20the%20search%20will%20introspect%20in%20case%20of%20composite%20values.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20assoc%20%7C%0D%0A%09assoc%20%3A%3D%20self%20associationAt%3A%20aKey%20ifAbsent%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5Eassoc%20value"));
smalltalk.bind(smalltalk.Set.$klass,"newContents:",0
,function (contents){var self=this;return self.basicNew().initialize_(contents);;return self;}
,"private",unescape("newContents%3A%20contents%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20initialized%20from%20given%20contents.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20initialize%3A%20contents"));
smalltalk.bind(smalltalk.Set.$klass,"basicNew:",0
,function (size){var self=this;return self.$$new();;return self;}
,"instantiation",unescape("basicNew%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%09%5Eself%20new"));
smalltalk.bind(smalltalk.Set,"initialize",0
,function (){var self=this;smalltalk.superImplementor(smalltalk.Set,'initialize').apply(self, []);
self['@contents']=[];return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09contents%20%3A%3D%20%23%28%29."));
smalltalk.bind(smalltalk.Set,"initialize:",0
,function (initializer){var self=this;self['@contents']=initializer;return self;}
,"initialize",unescape("initialize%3A%20initializer%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09contents%20%3A%3D%20initializer."));
smalltalk.bind(smalltalk.Set,"size",0
,function (){var self=this;return self['@contents'].size();;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Econtents%20size"));
smalltalk.bind(smalltalk.Set,"basicAdd:",0
,function (anObject){var self=this;self['@contents'].add_(anObject);
return anObject;;return self;}
,"private",unescape("basicAdd%3A%20anObject%0D%0A%09%22%20Private%20-%20Add%20anObject%20to%20the%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09contents%20add%3A%20anObject.%0D%0A%09%5EanObject"));
smalltalk.bind(smalltalk.Set,"includes:",0
,function (anObject){var self=this;return self['@contents'].includes_(anObject);;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%5Econtents%20includes%3A%20anObject"));
smalltalk.bind(smalltalk.Set,"add:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;((self.includes_(anObject)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return anObject;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.basicAdd_(anObject);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"adding",unescape("add%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%28self%20includes%3A%20anObject%29%20ifTrue%3A%20%5B%20%5EanObject%20%5D.%0D%0A%09%5Eself%20basicAdd%3A%20anObject"));
smalltalk.bind(smalltalk.Set,"remove:ifAbsent:",0
,function (anObject,aBlock){var self=this;return self['@contents'].remove_ifAbsent_(anObject, aBlock);;return self;}
,"removing",unescape("remove%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20anObject%20from%20the%20receiver.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20anObject%20is%20not%20in%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%5Econtents%20remove%3A%20anObject%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.Set,"copyFrom:to:",0
,function (anIndex,anotherIndex){var self=this;return self.shouldNotImplement_("copyFrom:to:");;return self;}
,"copying",unescape("copyFrom%3A%20anIndex%20to%3A%20anotherIndex%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20from%20anIndex%20to%20anotherIndex.%20%22%0D%0A%0D%0A%09%5Eself%20shouldNotImplement%3A%20%23copyFrom%3Ato%3A"));
smalltalk.bind(smalltalk.Set,"asJavascript",0
,function (){var self=this;return "smalltalk."._comma(self.$klass.name())._comma(unescape(".newContents_%28"))._comma(self['@contents'].asJavascript())._comma(unescape("%29"));;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27smalltalk.%27%2Cself%20class%20name%0D%0A%09%09%2C%27.newContents_%28%27%2C%20contents%20asJavascript%20%2C%27%29%27"));
smalltalk.bind(smalltalk.Set,"=","_eq"
,function (aSet){var $s8Ret$={name:"stReturn"};try{var self=this;((self.$klass._eq(aSet.$klass)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
((self.size()._eq(aSet.size())).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
self.do_((function(each){return ((aSet.includes_(each)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"comparing",unescape("%3D%20aSet%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20aSet.%20%22%0D%0A%0D%0A%09self%20class%20%3D%20aSet%20class%20ifFalse%3A%20%5B%5Efalse%5D.%0D%0A%09self%20size%20%3D%20aSet%20size%20ifFalse%3A%20%5B%5Efalse%5D.%0D%0A%09self%20do%3A%20%5B%3Aeach%20%7C%20%28aSet%20includes%3A%20each%29%20ifFalse%3A%20%5B%5Efalse%5D%20%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Set,"asArray",0
,function (){var self=this;return self['@contents'].copy();;return self;}
,"converting",unescape("asArray%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Econtents%20copy"));
smalltalk.bind(smalltalk.Set,"toString",0
,function (){var self=this;return self.$klass.name()._comma(" withAll: ")._comma(self.asArray().printString());;return self;}
,"converting",unescape("toString%0D%0A%09%22%20Convert%20the%20receiver%20to%20a%20String.%20%22%0D%0A%0D%0A%09%5Eself%20class%20name%2C%27%20withAll%3A%20%27%2Cself%20asArray%20printString"));
smalltalk.bind(smalltalk.Set,"sorted",0
,function (){var self=this;return self.asArray().sort();;return self;}
,"sorting",unescape("sorted%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20sorted.%20%22%0D%0A%0D%0A%09%5Eself%20asArray%20sort"));
smalltalk.bind(smalltalk.Set,"sorted:",0
,function (aBlock){var self=this;return self.asArray().sort_(aBlock);;return self;}
,"sorting",unescape("sorted%3A%20aBlock%0D%0A%09%22%20Return%20a%20sorted%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20asArray%20sort%3A%20aBlock"));
smalltalk.bind(smalltalk.Set,"do:",0
,function (aBlock){var self=this;return self['@contents'].do_(aBlock);;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Econtents%20do%3A%20aBlock"));
smalltalk.bind(smalltalk.Set,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;return self['@contents'].detect_ifNone_(aBlock, anotherBlock);;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20object%20in%20the%20receiver%20that%20return%20true%20when%20evaluated%20with%20aBlock%20or%20the%20result%20of%20evaluating%20anotherBlock.%20%22%0D%0A%0D%0A%09%5Econtents%20detect%3A%20aBlock%20ifNone%3A%20anotherBlock"));
smalltalk.bind(smalltalk.Set,"reverseDo:",0
,function (aBlock){var self=this;return self['@contents'].reverseDo_(aBlock);;return self;}
,"enumerating",unescape("reverseDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order%20of%20iteration.%20%22%0D%0A%0D%0A%09%5Econtents%20reverseDo%3A%20aBlock"));
smalltalk.bind(smalltalk.Set,"collect:",0
,function (aBlock){var self=this;return self.$klass.withAll_(self['@contents'].collect_(aBlock));;return self;}
,"enumerating",unescape("collect%3A%20aBlock%0D%0A%09%22%20Return%20a%20collection%20with%20the%20result%20of%20evaluating%20aBlock%20with%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28contents%20collect%3A%20aBlock%29"));
smalltalk.bind(smalltalk.Set,"do:separatedBy:",0
,function (aBlock,anotherBlock){var self=this;return self['@contents'].do_separatedBy_(aBlock, anotherBlock);;return self;}
,"enumerating",unescape("do%3A%20aBlock%20separatedBy%3A%20anotherBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20contents%20of%20the%20receiver%20evaluating%20anotherBlock%20inbetween%20aBlock%20evaluations.%20%22%0D%0A%0D%0A%09%5Econtents%20do%3A%20aBlock%20separatedBy%3A%20anotherBlock"));
smalltalk.bind(smalltalk.Set,"inject:into:",0
,function (anObject,aBlock){var self=this;return self['@contents'].inject_into_(anObject, aBlock);;return self;}
,"enumerating",unescape("inject%3A%20anObject%20into%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20result%20of%20previous%20evaluation%20and%20contents%20of%20the%20receiver.%0D%0A%09On%20first%20evaluation%20anObject%20is%20used%20as%20first%20argument%20to%20evaluate%20aBlock.%0D%0A%09%22%0D%0A%0D%0A%09%5Econtents%20inject%3A%20anObject%20into%3A%20aBlock"));
smalltalk.bind(smalltalk.Set,"select:",0
,function (aBlock){var self=this;return self.$klass.withAll_(self['@contents'].select_(aBlock));;return self;}
,"enumerating",unescape("select%3A%20aBlock%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20elements%20wich%20evaluates%20aBlock%20to%20true.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28contents%20select%3A%20aBlock%29"));
smalltalk.bind(smalltalk.Set,"reject:",0
,function (aBlock){var self=this;return self.$klass.withAll_(self['@contents'].reject_(aBlock));;return self;}
,"enumerating",unescape("reject%3A%20aBlock%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20wich%20evaluates%20aBlock%20to%20false.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28contents%20reject%3A%20aBlock%29"));
smalltalk.bind(smalltalk.Set,"reversed",0
,function (){var self=this;return self['@contents'].reversed();;return self;}
,"copying",unescape("reversed%0D%0A%09%22%20Return%20an%20array%20with%20the%20contents%20of%20the%20receiver%20in%20reverse%20order.%20%22%0D%0A%0D%0A%09%5Econtents%20reversed"));
smalltalk.bind(smalltalk.Set,"notEmpty",0
,function (){var self=this;return self['@contents'].notEmpty();;return self;}
,"testing",unescape("notEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20empty.%20%22%0D%0A%0D%0A%09%5Econtents%20notEmpty"));
smalltalk.bind(smalltalk.Set,"isEmpty",0
,function (){var self=this;return self['@contents'].isEmpty();;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Econtents%20isEmpty"));
smalltalk.bind(smalltalk.Set,"occurrencesOf:",0
,function (anObject){var self=this;return ((self.includes_(anObject)).mustBeBoolean()==true ? (function(){return (1);})() : (function(){return (0);})());;return self;}
,"counting",unescape("occurrencesOf%3A%20anObject%0D%0A%09%22%20Return%20the%20occurrences%20of%20anObject%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28self%20includes%3A%20anObject%29%20ifTrue%3A%20%5B%201%20%5D%20ifFalse%3A%20%5B%200%20%5D"));
smalltalk.bind(smalltalk.Set,"asSet",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asSet%0D%0A%09%22%20Return%20the%20receiver%20contents%20in%20a%20Set.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Set,"shallowCopy",0
,function (){var self=this;return self.$klass.newContents_(self['@contents'].copy());;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20newContents%3A%20contents%20copy"));
smalltalk.bind(smalltalk.Set,"deepCopy",0
,function (){var self=this;return self.$klass.newContents_(self['@contents'].deepCopy());;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20newContents%3A%20contents%20deepCopy"));
smalltalk.bind(smalltalk.HashedSet,"initialize",0
,function (){var self=this;smalltalk.superImplementor(smalltalk.HashedSet,'initialize').apply(self, []);
self.initializeHash();return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09self%20initializeHash."));
smalltalk.bind(smalltalk.HashedSet,"initialize:",0
,function (initializer){var self=this;self['@contents']=initializer;
self.rehash();return self;}
,"initialize",unescape("initialize%3A%20initializer%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09contents%20%3A%3D%20initializer.%0D%0A%09self%20rehash."));
smalltalk.bind(smalltalk.HashedSet,"initializeHash",0
,function (){var self=this;self['@hash']= {} ;return self;}
,"private",unescape("initializeHash%0D%0A%09%22%20Private%20-%20Initialize%20the%20hash%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09hash%20%3A%3D%20%7B%27%20%7B%7D%20%27%7D."));
smalltalk.bind(smalltalk.HashedSet,"rehash",0
,function (){var self=this;self.initializeHash();
self['@contents'].do_((function(each){return (self['@hash'][each]=(each));}));return self;}
,"private",unescape("rehash%0D%0A%09%22%20Private%20-%20Rehash%20the%20receiver%20contents.%20%22%0D%0A%0D%0A%09self%20initializeHash.%0D%0A%09contents%20do%3A%20%5B%3Aeach%7C%20hash%20basicAt%3A%20each%20put%3A%20each%20%5D"));
smalltalk.bind(smalltalk.HashedSet,"includes:",0
,function (anObject){var self=this;	return anObject in self["@hash"]; ;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%7B%27%09return%20anObject%20in%20self%5B%22@hash%22%5D%3B%20%27%7D"));
smalltalk.bind(smalltalk.HashedSet,"indexOf:ifAbsent:",0
,function (anObject,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;((self.includes_(anObject)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return self['@contents'].indexOf_ifAbsent_(anObject, aBlock);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("indexOf%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Private%2CInternal%20-%20Return%20the%20position%20of%20anObject%20in%20the%20receiver%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%28self%20includes%3A%20anObject%29%20ifFalse%3A%20%5B%20%5EaBlock%20value%20%5D.%0D%0A%09%5Econtents%20indexOf%3A%20anObject%20ifAbsent%3A%20aBlock"));
smalltalk.bind(smalltalk.HashedSet,"withIndexDo:",0
,function (aBlock){var self=this;return self['@contents'].withIndexDo_(aBlock);;return self;}
,"private",unescape("withIndexDo%3A%20aBlock%0D%0A%09%22%20Private%2CInternal%20-%20Evaluate%20aBlock%20with%20all%20the%20index%20positions%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Econtents%20withIndexDo%3A%20aBlock"));
smalltalk.bind(smalltalk.HashedSet,"removeIndex:",0
,function (index){var self=this;return self.remove_(self['@contents'].at_(index));;return self;}
,"private",unescape("removeIndex%3A%20index%0D%0A%09%22%20Private%2CInternal%20-%20Remove%20the%20element%20at%20index.%20%22%0D%0A%0D%0A%09%5Eself%20remove%3A%20%28contents%20at%3A%20index%29"));
smalltalk.bind(smalltalk.HashedSet,"add:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;((self.includes_(anObject)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return anObject;})();throw($s8Ret$)})();})() : nil);
(self['@hash'][anObject]=(anObject));
(function(){$s8Ret$.result=(function(){return self.basicAdd_(anObject);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"adding",unescape("add%3A%20anObject%0D%0A%09%22%20Add%20anObject%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%28self%20includes%3A%20anObject%29%20ifTrue%3A%20%5B%20%5EanObject%20%5D.%0D%0A%09hash%20basicAt%3AanObject%20put%3A%20anObject.%0D%0A%09%5Eself%20basicAdd%3A%20anObject"));
smalltalk.bind(smalltalk.HashedSet,"remove:ifAbsent:",0
,function (anObject,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;((self.includes_(anObject)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();})());
self['@contents'].remove_ifAbsent_(anObject, (function(){return nil;}));
	delete self["@hash"][anObject];
	return anObject;	;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"removing",unescape("remove%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20anObject%20from%20the%20receiver.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20anObject%20is%20not%20in%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%28self%20includes%3A%20anObject%29%20ifFalse%3A%20%5B%20%5EaBlock%20value%20%5D.%0D%0A%09contents%20remove%3A%20anObject%20ifAbsent%3A%20%5B%20%5D.%0D%0A%7B%27%09delete%20self%5B%22@hash%22%5D%5BanObject%5D%3B%0D%0A%09return%20anObject%3B%09%27%7D."));
smalltalk.bind(smalltalk.KeyedCollection.$klass,"basicNew:",0
,function (size){var self=this;return self.$$new();;return self;}
,"instantiation",unescape("basicNew%3A%20size%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20of%20specified%20size.%20%22%0D%0A%0D%0A%09%5Eself%20new"));
smalltalk.bind(smalltalk.KeyedCollection.$klass,"@","_at"
,function (jsObject){var self=this;var result=nil;result=self.$$new();
Object.getOwnPropertyNames(jsObject).do_((function(key){return result.at_put_(key, ((function(){var $1$=jsObject[key];if(nil.isNil_($1$))return nil;return $1$;})()));}));
return result;;return self;}
,"instantiation",unescape("@%20jsObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20with%20the%20properties%20owned%20by%20jsObject.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20new.%0D%0A%09%28%23%7BObject%7D%20%23getOwnPropertyNames%3A%20jsObject%29%20do%3A%20%5B%3Akey%7C%0D%0A%09%09result%20at%3A%20key%20put%3A%20%28jsObject%20basicAt%3A%20key%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection.$klass,"fromTuples:",0
,function (tuples){var self=this;return tuples.inject_into_(self.$$new(), (function(result,tuple){result.at_put_(tuple.first(), tuple.last());return result;}));;return self;}
,"instantiation",unescape("fromTuples%3A%20tuples%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Etuples%20inject%3A%20self%20new%20into%3A%20%5B%3Aresult%20%3Atuple%7C%0D%0A%09%09result%20at%3A%20tuple%20first%20put%3A%20tuple%20last.%0D%0A%09%09result%0D%0A%09%5D"));
smalltalk.bind(smalltalk.KeyedCollection,",","_comma"
,function (aCollection){var self=this;return self.shouldNotImplement_(unescape("%2C"));;return self;}
,"copying",unescape("%2C%20aCollection%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20aCollection%20appended.%20%22%0D%0A%0D%0A%09%5Eself%20shouldNotImplement%3A%20%23%2C"));
smalltalk.bind(smalltalk.KeyedCollection,"=","_eq"
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;((self.$klass._eq(anObject.$klass)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
((self.size()._eq(anObject.size())).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
self.keysAndValuesDo_((function(key,value){return ((anObject.at_ifAbsent_(key, (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();}))._eq(value)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"comparing",unescape("%3D%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anObject.%20%22%0D%0A%0D%0A%09self%20class%20%3D%20anObject%20class%20ifFalse%3A%20%5B%5Efalse%5D.%0D%0A%09self%20size%20%3D%20anObject%20size%20ifFalse%3A%20%5B%5Efalse%5D.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%0D%0A%09%09%28anObject%20at%3A%20key%20ifAbsent%3A%20%5B%5Efalse%5D%29%0D%0A%09%09%09%3D%20value%20ifFalse%3A%20%5B%5Efalse%5D%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.KeyedCollection,"add:",0
,function (anAssociation){var self=this;self.at_put_(anAssociation.key(), anAssociation.value());
return anAssociation;;return self;}
,"adding",unescape("add%3A%20anAssociation%0D%0A%09%22%20Bind%20anAssociation%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20at%3A%20anAssociation%20key%20put%3A%20anAssociation%20value.%0D%0A%09%5EanAssociation"));
smalltalk.bind(smalltalk.KeyedCollection,"addAll:",0
,function (aKeyedCollection){var self=this;smalltalk.superImplementor(smalltalk.KeyedCollection,'addAll_').apply(self, [aKeyedCollection.associations()]);
return aKeyedCollection;;return self;}
,"adding",unescape("addAll%3A%20aKeyedCollection%0D%0A%09%22%20Bind%20all%20associations%20in%20aKeyedCollection%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20addAll%3A%20aKeyedCollection%20associations.%0D%0A%09%5EaKeyedCollection"));
smalltalk.bind(smalltalk.KeyedCollection,"newHash",0
,function (){var self=this;return {};;return self;}
,"private",unescape("newHash%0D%0A%09%22%20Private%20-%20Return%20a%20new%20hash%20object.%20%22%0D%0A%0D%0A%09%5E%7B%27%7B%7D%27%7D"));
smalltalk.bind(smalltalk.KeyedCollection,"asJSONObject",0
,function (){var self=this;var result=nil;var value=nil;result=self.newHash();
self.keysAndValuesDo_((function(key,aValue){value=((self.isObject_(aValue)).mustBeBoolean()==true ? (function(){return aValue.asJSONObject();})() : (function(){return aValue;})());return (result[key]=(value));}));
return result;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%7C%20result%20value%20%7C%0D%0A%09result%20%3A%3D%20self%20newHash.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3AaValue%20%7C%0D%0A%09%09value%20%3A%3D%20%28self%20isObject%3A%20aValue%29%0D%0A%09%09%09ifTrue%3A%20%5B%20aValue%20asJSONObject%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20aValue%20%5D.%0D%0A%09%09result%20basicAt%3A%20key%20put%3A%20value%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"associations",0
,function (){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.associationsDo_((function(each){return result.add_(each);}));
return result;;return self;}
,"accessing",unescape("associations%0D%0A%09%22%20Return%20the%20associations%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20associationsDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"associationsDo:",0
,function (aBlock){var self=this;self.keysAndValuesDo_((function(key,value){return aBlock.value_(smalltalk.Association.key_value_(key, value));}));return self;}
,"enumerating",unescape("associationsDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20all%20the%20receiver%27s%20associations.%20%22%0D%0A%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%7C%0D%0A%09%09aBlock%20value%3A%20%28Association%20key%3A%20key%20value%3A%20value%29%0D%0A%09%5D."));
smalltalk.bind(smalltalk.KeyedCollection,"at:",0
,function (aKey){var self=this;return self.at_ifAbsent_(aKey, (function(){return self.objectNotFoundAt_(aKey);}));;return self;}
,"accessing",unescape("at%3A%20aKey%0D%0A%09%22%20Return%20the%20value%20at%20aKey.%0D%0A%09Signal%20an%20error%20if%20the%20key%20is%20not%20present.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20at%3A%20aKey%20ifAbsent%3A%20%5B%20self%20objectNotFoundAt%3A%20aKey%20%5D"));
smalltalk.bind(smalltalk.KeyedCollection,"at:ifAbsent:",0
,function (aKey,aBlock){var self=this;return self.implementedBySubclass_("at:ifAbsent:");;return self;}
,"accessing",unescape("at%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20at%20aKey%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23at%3AifAbsent%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"values",0
,function (){var self=this;return self.implementedBySubclass_("values");;return self;}
,"accessing",unescape("values%0D%0A%09%22%20Return%20the%20values%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23values"));
smalltalk.bind(smalltalk.KeyedCollection,"at:ifAbsentPut:",0
,function (aKey,aBlock){var self=this;return self.implementedBySubclass_("at:ifAbsentPut:");;return self;}
,"accessing",unescape("at%3A%20aKey%20ifAbsentPut%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20at%20aKey%2C%20or%20add%20the%20result%20of%20evaluating%20aBlock%20to%20the%20receiver%20if%20it%20is%20absent.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23at%3AifAbsentPut%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"at:put:",0
,function (aKey,aValue){var self=this;return self.implementedBySubclass_("at:put:");;return self;}
,"accessing",unescape("at%3A%20aKey%20put%3A%20aValue%0D%0A%09%22%20Set%20the%20value%20at%20aKey%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23at%3Aput%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;return self.implementedBySubclass_("detect:ifNone:");;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Detect%20the%20value%20who%20matches%20aBlock.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20no%20value%20matches%20detection%20block.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23detect%3AifNone%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"do:",0
,function (aBlock){var self=this;return self.implementedBySubclass_("do:");;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20for%20all%20values%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23do%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"includes:",0
,function (anObject){var self=this;return self.implementedBySubclass_("includes:");;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%27s%20values%20include%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23includes%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"keyForValue:ifAbsent:",0
,function (anObject,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;self.keysAndvaluesDo_((function(key,value){return ((anObject._eq(value)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return key;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("keyForValue%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20key%20in%20the%20receiver%20for%20value%20anObject%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09self%20keysAndvaluesDo%3A%20%5B%3Akey%20%3Avalue%7C%20anObject%20%3D%20value%20ifTrue%3A%20%5B%20%5Ekey%20%5D%20%5D.%0D%0A%09%5EaBlock%20value"));
smalltalk.bind(smalltalk.KeyedCollection,"keys",0
,function (){var self=this;return self.implementedBySubclass_("keys");;return self;}
,"accessing",unescape("keys%0D%0A%09%22%20Return%20the%20keys%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23keys"));
smalltalk.bind(smalltalk.KeyedCollection,"keysAndValuesDo:",0
,function (aBlock){var self=this;return self.implementedBySubclass_("keysAndValuesDo:");;return self;}
,"enumerating",unescape("keysAndValuesDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20key/value%20pairs%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23keysAndValuesDo%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"keysDo:",0
,function (aBlock){var self=this;return self.implementedBySubclass_("keysDo:");;return self;}
,"enumerating",unescape("keysDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20keys%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23keysDo%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"includesKey:",0
,function (aKey){var self=this;return self.implementedBySubclass_("includesKey:");;return self;}
,"testing",unescape("includesKey%3A%20aKey%0D%0A%09%22%20Return%20true%20if%20the%20receiver%27s%20keys%20include%20aKey.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23includesKey%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"removeKey:ifAbsent:",0
,function (aKey,aBlock){var self=this;return self.implementedBySubclass_("removeKey:ifAbsent:");;return self;}
,"removing",unescape("removeKey%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass%3A%20%23removeKey%3AifAbsent%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"isEmpty",0
,function (){var self=this;return self.size()._eq((0));;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Eself%20size%20%3D%200"));
smalltalk.bind(smalltalk.KeyedCollection,"at:ifPresent:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var aValue=nil;aValue=self.at_ifAbsent_(aKey, (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return aBlock.value_(aValue);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("at%3A%20aKey%20ifPresent%3A%20aBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20there%20is%20a%20value%20at%20aKey%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20aValue%20%7C%0D%0A%09aValue%20%3A%3D%20self%20at%3A%20aKey%20ifAbsent%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5EaBlock%20value%3A%20aValue"));
smalltalk.bind(smalltalk.KeyedCollection,"at:ifPresent:ifAbsent:",0
,function (aKey,aBlock,anotherBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var aValue=nil;aValue=self.at_ifAbsent_(aKey, (function(){return (function(){$s8Ret$.result=(function(){return anotherBlock.value();})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return aBlock.value_(aValue);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("at%3A%20aKey%20ifPresent%3A%20aBlock%20ifAbsent%3A%20anotherBlock%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20aBlock%20if%20there%20is%20a%20value%20at%20aKey%20%28or%20the%20result%20of%20evaluating%20anotherBlock%29.%20%22%0D%0A%0D%0A%09%7C%20aValue%20%7C%0D%0A%09aValue%20%3A%3D%20self%20at%3A%20aKey%20ifAbsent%3A%20%5B%20%5EanotherBlock%20value%20%5D.%0D%0A%09%5EaBlock%20value%3A%20aValue"));
smalltalk.bind(smalltalk.KeyedCollection,"collect:",0
,function (aBlock){var self=this;var result=nil;result=self.$klass.$$new();
self.keysAndValuesDo_((function(key,value){return result.at_put_(key, aBlock.value_(value));}));
return result;;return self;}
,"enumerating",unescape("collect%3A%20aBlock%0D%0A%09%22%20Return%20aKeyedCollection%20with%20keys%20and%20result%20of%20evaluating%20aBlock%20with%20value.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%0D%0A%09%09result%20at%3A%20key%20put%3A%20%28aBlock%20value%3A%20value%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"select:",0
,function (aBlock){var self=this;var result=nil;result=self.$klass.$$new();
self.keysAndValuesDo_((function(key,value){return ((aBlock.value_(value)).mustBeBoolean()==true ? (function(){return result.at_put_(key, value);})() : nil);}));
return result;;return self;}
,"enumerating",unescape("select%3A%20aBlock%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20wich%20evaluates%20aBlock%20to%20true.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%0D%0A%09%09%28aBlock%20value%3A%20value%29%20ifTrue%3A%20%5B%20result%20at%3A%20key%20put%3A%20value%20%5D%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"shallowCopy",0
,function (){var self=this;var result=nil;result=self.$klass.$$new();
self.keysAndValuesDo_((function(key,value){return result.at_put_(key, value);}));
return result;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%20result%20at%3A%20key%20put%3A%20value%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"tuples",0
,function (){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.keysAndValuesDo_((function(key,value){return result.add_(smalltalk.Array.with_with_(key, value));}));
return result;;return self;}
,"accessing",unescape("tuples%0D%0A%09%22%20Return%20an%20array%20of%20tuples%20built%20from%20the%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%7C%0D%0A%09%09result%20add%3A%20%28Array%20with%3A%20key%20with%3A%20value%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"copyFrom:to:",0
,function (anIndex,anotherIndex){var self=this;return self.shouldNotImplement_("copyFrom:to:");;return self;}
,"copying",unescape("copyFrom%3A%20anIndex%20to%3A%20anotherIndex%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20from%20anIndex%20to%20anotherIndex.%20%22%0D%0A%0D%0A%09%5Eself%20shouldNotImplement%3A%20%23copyFrom%3Ato%3A"));
smalltalk.bind(smalltalk.KeyedCollection,"deepCopy",0
,function (){var self=this;var result=nil;result=self.$klass.$$new();
self.keysAndValuesDo_((function(key,value){return result.at_put_(key, value.deepCopy());}));
return result;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20class%20new.%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%0D%0A%09%09result%20at%3A%20key%20put%3A%20value%20deepCopy%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.KeyedCollection,"remove:",0
,function (aKey){var self=this;self.removeKey_(aKey);return self;}
,"removing",unescape("remove%3A%20aKey%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%20%22%0D%0A%0D%0A%09self%20removeKey%3A%20aKey"));
smalltalk.bind(smalltalk.KeyedCollection,"removeKey:",0
,function (aKey){var self=this;return self.removeKey_ifAbsent_(aKey, (function(){return self.objectNotFoundAt_(aKey);}));;return self;}
,"removing",unescape("removeKey%3A%20aKey%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%0D%0A%09Signal%20an%20error%20if%20the%20key%20is%20not%20present.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20removeKey%3A%20aKey%20ifAbsent%3A%20%5B%20self%20objectNotFoundAt%3A%20aKey%20%5D"));
smalltalk.bind(smalltalk.KeyedCollection,"isDictionary",0
,function (){var self=this;return true;;return self;}
,"query",unescape("isDictionary%0D%0A%09%22%20Returns%20true%20if%20the%20receiver%20is%20a%20dictionary.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Dictionary.$klass,"fromKeys:and:",0
,function (keys,values){var self=this;return self.basicNew().initializeKeys_values_(keys, values);;return self;}
,"instantiation",unescape("fromKeys%3A%20keys%20and%3A%20values%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20initializeKeys%3A%20keys%20values%3A%20values"));
smalltalk.bind(smalltalk.Dictionary,"initialize",0
,function (){var self=this;smalltalk.superImplementor(smalltalk.Dictionary,'initialize').apply(self, []);
self['@keys']=smalltalk.HashedSet.$$new();
self['@values']=[];return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09keys%20%3A%3D%20HashedSet%20new.%0D%0A%09values%20%3A%3D%20%23%28%29."));
smalltalk.bind(smalltalk.Dictionary,"initializeKeys:values:",0
,function (privateKeys,privateValues){var self=this;smalltalk.superImplementor(smalltalk.Dictionary,'initialize').apply(self, []);
self['@keys']=smalltalk.HashedSet.newContents_(privateKeys);
self['@values']=privateValues.asArray();return self;}
,"initialize",unescape("initializeKeys%3A%20privateKeys%20values%3A%20privateValues%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09keys%20%3A%3D%20HashedSet%20newContents%3A%20privateKeys.%0D%0A%09values%20%3A%3D%20privateValues%20asArray."));
smalltalk.bind(smalltalk.Dictionary,"size",0
,function (){var self=this;return self['@keys'].size();;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ekeys%20size"));
smalltalk.bind(smalltalk.Dictionary,"isEmpty",0
,function (){var self=this;return self['@keys'].isEmpty();;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Ekeys%20isEmpty"));
smalltalk.bind(smalltalk.Dictionary,"lookUpKey:",0
,function (aKey){var self=this;return self['@keys'].indexOf_ifAbsent_(aKey, (function(){return nil;}));;return self;}
,"private",unescape("lookUpKey%3A%20aKey%0D%0A%09%22%20Private%20-%20Return%20the%20index%20where%20aKey%20is%20found%2C%20or%20nil.%20%22%0D%0A%0D%0A%09%5Ekeys%20indexOf%3A%20aKey%20ifAbsent%3A%20%5B%20nil%20%5D"));
smalltalk.bind(smalltalk.Dictionary,"keysAndValuesDo:",0
,function (aBlock){var self=this;self['@keys'].withIndexDo_((function(aKey,index){return aBlock.value_value_(aKey, self['@values'].at_(index));}));return self;}
,"enumerating",unescape("keysAndValuesDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20key/value%20pairs%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09keys%20withIndexDo%3A%20%5B%3AaKey%20%3Aindex%20%7C%20aBlock%20value%3A%20aKey%20value%3A%20%28values%20at%3A%20index%29%20%5D"));
smalltalk.bind(smalltalk.Dictionary,"keys",0
,function (){var self=this;return self['@keys'].copy();;return self;}
,"accessing",unescape("keys%0D%0A%09%22%20Return%20the%20keys%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ekeys%20copy"));
smalltalk.bind(smalltalk.Dictionary,"keysDo:",0
,function (aBlock){var self=this;self['@keys'].do_(aBlock);return self;}
,"enumerating",unescape("keysDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20keys%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09keys%20do%3A%20aBlock"));
smalltalk.bind(smalltalk.Dictionary,"values",0
,function (){var self=this;return self['@values'].copy();;return self;}
,"accessing",unescape("values%0D%0A%09%22%20Return%20the%20values%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Evalues%20copy"));
smalltalk.bind(smalltalk.Dictionary,"at:put:",0
,function (aKey,aValue){var self=this;var index=nil;index=self.lookUpKey_(aKey);
(((nil.isNil_(index))).mustBeBoolean()==true ? (function(){self['@keys'].add_(aKey);return self['@values'].add_(aValue);})() : (function(){return self['@values'].at_put_(index, aValue);})());
return aValue;;return self;}
,"accessing",unescape("at%3A%20aKey%20put%3A%20aValue%0D%0A%09%22%20Set%20the%20value%20at%20aKey%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20lookUpKey%3A%20aKey.%0D%0A%09index%20isNil%0D%0A%09%09ifTrue%3A%20%5B%20keys%20add%3A%20aKey.%20values%20add%3A%20aValue.%5D%0D%0A%09%09ifFalse%3A%20%5B%20values%20at%3A%20index%20put%3A%20aValue%20%5D.%0D%0A%09%5EaValue"));
smalltalk.bind(smalltalk.Dictionary,"at:ifAbsent:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.lookUpKey_(aKey);
(((nil.isNil_(index))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@values'].at_(index);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("at%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20at%20aKey%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20lookUpKey%3A%20aKey.%0D%0A%09index%20isNil%20ifTrue%3A%20%5B%20%5EaBlock%20value%20%5D.%0D%0A%09%5Evalues%20at%3A%20index"));
smalltalk.bind(smalltalk.Dictionary,"at:ifAbsentPut:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.lookUpKey_(aKey);
(((nil.isNil_(index))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.at_put_(aKey, aBlock.value());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@values'].at_(index);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("at%3A%20aKey%20ifAbsentPut%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20at%20aKey%2C%20or%20add%20the%20result%20of%20evaluating%20aBlock%20to%20the%20receiver%20if%20it%20is%20absent.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20lookUpKey%3A%20aKey.%0D%0A%09index%20isNil%20ifTrue%3A%20%5B%20%5Eself%20at%3A%20aKey%20put%3A%20aBlock%20value%20%5D.%0D%0A%09%5Evalues%20at%3A%20index"));
smalltalk.bind(smalltalk.Dictionary,"do:",0
,function (aBlock){var self=this;return self['@values'].do_(aBlock);;return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20for%20all%20values%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Evalues%20do%3A%20aBlock"));
smalltalk.bind(smalltalk.Dictionary,"detect:ifNone:",0
,function (aBlock,anotherBlock){var self=this;return self['@values'].detect_ifNone_(aBlock, anotherBlock);;return self;}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Detect%20the%20value%20who%20matches%20aBlock.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20no%20value%20matches%20detection%20block.%0D%0A%09%22%0D%0A%0D%0A%09%5Evalues%20detect%3A%20aBlock%20ifNone%3A%20anotherBlock"));
smalltalk.bind(smalltalk.Dictionary,"includes:",0
,function (anObject){var self=this;return self['@values'].includes_(anObject);;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%27s%20values%20include%20anObject.%20%22%0D%0A%0D%0A%09%5Evalues%20includes%3A%20anObject"));
smalltalk.bind(smalltalk.Dictionary,"includesKey:",0
,function (aKey){var self=this;return self['@keys'].includes_(aKey);;return self;}
,"enumerating",unescape("includesKey%3A%20aKey%0D%0A%09%22%20Return%20true%20if%20the%20receiver%27s%20keys%20include%20aKey.%20%22%0D%0A%0D%0A%09%5Ekeys%20includes%3A%20aKey"));
smalltalk.bind(smalltalk.Dictionary,"removeKey:ifAbsent:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;index=self.lookUpKey_(aKey);
(((nil.isNil_(index))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();})() : nil);
self['@keys'].removeIndex_(index);
self['@values'].removeIndex_(index);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"removing",unescape("removeKey%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09index%20%3A%3D%20self%20lookUpKey%3A%20aKey.%0D%0A%09index%20isNil%20ifTrue%3A%20%5B%20%5EaBlock%20value%20%5D.%0D%0A%09keys%20removeIndex%3A%20index.%0D%0A%09values%20removeIndex%3A%20index."));
smalltalk.bind(smalltalk.Dictionary,"keyForValue:ifAbsent:",0
,function (anObject,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;self.keysAndvaluesDo_((function(key,aValue){return (((anObject === aValue)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return key;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("keyForValue%3A%20anObject%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20key%20in%20the%20receiver%20for%20value%20anObject%2C%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09self%20keysAndvaluesDo%3A%20%5B%3Akey%20%3AaValue%7C%20anObject%20%3D%3D%20aValue%20ifTrue%3A%20%5B%20%5Ekey%20%5D%20%5D.%0D%0A%09%5EaBlock%20value"));
smalltalk.bind(smalltalk.Dictionary,"asJavascript",0
,function (){var self=this;return "smalltalk."._comma(self.$klass.name())._comma(unescape(".fromKeys_and_%28"))._comma(self['@keys'].asArray().asJavascript())._comma(unescape("%2C"))._comma(self['@values'].asJavascript())._comma(unescape("%29"));;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27smalltalk.%27%2Cself%20class%20name%0D%0A%09%09%2C%27.fromKeys_and_%28%27%20%2Ckeys%20asArray%20asJavascript%0D%0A%09%09%09%2C%27%2C%27%20%2Cvalues%20asJavascript%20%2C%27%29%27"));
smalltalk.bind(smalltalk.PoolDictionary,"initialize",0
,function (){var self=this;smalltalk.superImplementor(smalltalk.PoolDictionary,'initialize').apply(self, []);
self['@hash']=self.newHash();return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09hash%20%3A%3D%20self%20newHash."));
smalltalk.bind(smalltalk.PoolDictionary,"at:put:",0
,function (aKey,value){var self=this;self['@size']=nil;
return (self['@hash'][aKey]=(value));;return self;}
,"accessing",unescape("at%3A%20aKey%20put%3A%20value%0D%0A%09%22%20Set%20the%20value%20at%20aKey%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%22%28self%20typeOf%3A%20aKey%29%20%3D%20%23string%20ifFalse%3A%20%5B%20%5Eself%20error%3A%20%27Invalid%20key%20%28must%20be%20aString%29.%27%20%5D.%22%0D%0A%09size%20%3A%3D%20nil.%0D%0A%09%5Ehash%20basicAt%3A%20aKey%20put%3A%20value"));
smalltalk.bind(smalltalk.PoolDictionary,"removeKey:ifAbsent:",0
,function (aKey,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;((self.includesKey_(aKey)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return aBlock.value();})();throw($s8Ret$)})();})());
self['@size']=nil;
	delete self["@hash"][aKey];	;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"removing",unescape("removeKey%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Remove%20the%20binding%20at%20aKey.%20%22%0D%0A%0D%0A%09%28self%20includesKey%3A%20aKey%29%20ifFalse%3A%20%5B%20%5EaBlock%20value%20%5D.%0D%0A%09size%20%3A%3D%20nil.%0D%0A%7B%27%09delete%20self%5B%22@hash%22%5D%5BaKey%5D%3B%09%27%7D"));
smalltalk.bind(smalltalk.PoolDictionary,"size",0
,function (){var self=this;(((nil.isNil_(self['@size']))).mustBeBoolean()==true ? (function(){return self['@size']=self.keys().size();})() : nil);
return self['@size'];;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09size%20isNil%20ifTrue%3A%20%5B%20size%20%3A%3D%20self%20keys%20size%20%5D.%0D%0A%09%5Esize"));
smalltalk.bind(smalltalk.PoolDictionary,"at:ifAbsent:",0
,function (aKey,aBlock){var self=this;	var value = self["@hash"][aKey];
	if(value === undefined) { return aBlock(); }
	return value;;return self;}
,"accessing",unescape("at%3A%20aKey%20ifAbsent%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20at%20aKey%20or%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%7B%27%09var%20value%20%3D%20self%5B%22@hash%22%5D%5BaKey%5D%3B%0D%0A%09if%28value%20%3D%3D%3D%20undefined%29%20%7B%20return%20aBlock%28%29%3B%20%7D%0D%0A%09return%20value%3B%27%7D."));
smalltalk.bind(smalltalk.PoolDictionary,"includesKey:",0
,function (aKey){var $s8Ret$={name:"stReturn"};try{var self=this;self.at_ifAbsent_(aKey, (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("includesKey%3A%20aKey%0D%0A%09%22%20Return%20true%20if%20the%20receiver%27s%20keys%20include%20aKey.%20%22%0D%0A%0D%0A%09self%20at%3A%20aKey%20ifAbsent%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.PoolDictionary,"keysAndValuesDo:",0
,function (aBlock){var self=this;self.keys().do_((function(key){return aBlock.value_value_(key, ((function(){var $1$=self['@hash'][key];if(nil.isNil_($1$))return nil;return $1$;})()));}));return self;}
,"enumerating",unescape("keysAndValuesDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20key/value%20pairs%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20keys%20do%3A%20%5B%3Akey%20%7C%20aBlock%20value%3A%20key%20value%3A%20%28hash%20basicAt%3A%20key%29%20%5D"));
smalltalk.bind(smalltalk.PoolDictionary,"keys",0
,function (){var self=this;	return Object.getOwnPropertyNames(self["@hash"]); ;return self;}
,"accessing",unescape("keys%0D%0A%09%22%20Return%20the%20keys%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20Object.getOwnPropertyNames%28self%5B%22@hash%22%5D%29%3B%20%27%7D."));
smalltalk.bind(smalltalk.PoolDictionary,"values",0
,function (){var self=this;return self.keys().collect_((function(key){return ((function(){var $1$=self['@hash'][key];if(nil.isNil_($1$))return nil;return $1$;})());}));;return self;}
,"accessing",unescape("values%0D%0A%09%22%20Return%20the%20values%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20keys%20collect%3A%20%5B%3Akey%7C%20hash%20basicAt%3A%20key%20%5D"));
smalltalk.bind(smalltalk.PoolDictionary,"asJavascript",0
,function (){var self=this;return "smalltalk."._comma(self.$klass.name())._comma(unescape(".fromTuples_%28"))._comma(self.tuples().asJavascript())._comma(unescape("%29"));;return self;}
,"converting",unescape("asJavascript%0D%0A%09%22%20Return%20the%20javascript%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27smalltalk.%27%2Cself%20class%20name%0D%0A%09%09%2C%27.fromTuples_%28%27%20%2Cself%20tuples%20asJavascript%20%2C%27%29%27"));
smalltalk.bind(smalltalk.PoolDictionary,"at:ifAbsentPut:",0
,function (aKey,aBlock){var self=this;return self.at_ifAbsent_(aKey, (function(){return self.at_put_(aKey, aBlock.value());}));;return self;}
,"accessing",unescape("at%3A%20aKey%20ifAbsentPut%3A%20aBlock%0D%0A%09%22%20Return%20the%20value%20at%20aKey%2C%20or%20add%20the%20result%20of%20evaluating%20aBlock%20to%20the%20receiver%20if%20it%20is%20absent.%20%22%0D%0A%0D%0A%09%5Eself%20at%3A%20aKey%20ifAbsent%3A%20%5B%20self%20at%3A%20aKey%20put%3A%20aBlock%20value%20%5D"));
smalltalk.bind(smalltalk.PoolDictionary,"detect:ifNone:",0
,function (aBlock,anotherBlock){var $s8Ret$={name:"stReturn"};try{var self=this;self.keysAndValuesDo_((function(key,value){return ((aBlock.value_(value)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return value;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return anotherBlock.value();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"enumerating",unescape("detect%3A%20aBlock%20ifNone%3A%20anotherBlock%0D%0A%09%22%20Detect%20the%20value%20who%20matches%20aBlock.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock%20if%20no%20value%20matches%20detection%20block.%0D%0A%09%22%0D%0A%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%0D%0A%09%09%28aBlock%20value%3A%20value%29%20ifTrue%3A%20%5B%20%5Evalue%20%5D%0D%0A%09%5D.%0D%0A%09%5EanotherBlock%20value"));
smalltalk.bind(smalltalk.PoolDictionary,"do:",0
,function (aBlock){var self=this;self.keysAndValuesDo_((function(key,value){return aBlock.value_(value);}));return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20for%20all%20values%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%20aBlock%20value%3A%20value%20%5D"));
smalltalk.bind(smalltalk.PoolDictionary,"includes:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;self.keysAndValuesDo_((function(key,value){return ((anObject._eq(value)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20receiver%27s%20values%20include%20anObject.%20%22%0D%0A%0D%0A%09self%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%20%7C%0D%0A%09%09anObject%20%3D%20value%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.PoolDictionary,"keysDo:",0
,function (aBlock){var self=this;self.keys().do_(aBlock);return self;}
,"enumerating",unescape("keysDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20with%20the%20keys%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20keys%20do%3A%20aBlock"));
smalltalk.bind(smalltalk.RegularExpression.$klass,"fromString:flag:",0
,function (aString,anotherString){var self=this;	return new RegExp(aString, anotherString);;return self;}
,"instantiation",unescape("fromString%3A%20aString%20flag%3A%20anotherString%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09return%20new%20RegExp%28aString%2C%20anotherString%29%3B%27%7D"));
smalltalk.bind(smalltalk.RegularExpression.$klass,"fromString:",0
,function (aString){var self=this;return self.fromString_flag_(aString, "");;return self;}
,"instantiation",unescape("fromString%3A%20aString%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%20%20%20%20%5Eself%20fromString%3A%20aString%20flag%3A%20%27%27"));
smalltalk.bind(smalltalk.RegularExpression,"compile:",0
,function (aString){var self=this;return self.compile(aString);;return self;}
,"evaluating",unescape("compile%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20compilation%20of%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20%23compile%3A%20aString"));
smalltalk.bind(smalltalk.RegularExpression,"exec:",0
,function (aString){var self=this;return self.exec(aString);;return self;}
,"evaluating",unescape("exec%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20excecution%20of%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20%23exec%3A%20aString"));
smalltalk.bind(smalltalk.RegularExpression,"test:",0
,function (aString){var self=this;return self.test(aString);;return self;}
,"evaluating",unescape("test%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20testing%20of%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20%23test%3A%20aString"));
smalltalk.bind(smalltalk.RegularExpression,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.RegularExpression,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.RegularExpression,"asJSONObject",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asJSONObject%0D%0A%09%22%20Return%20the%20mapping%20of%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Exception,"nativeException",0
,function (){var self=this;return ((function(){var $1$=self[unescape("@nativeException")];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"private",unescape("nativeException%0D%0A%09%22%20Private%2C%20Internal%20-%20Return%20the%20native%20exception%20associated%20with%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27@nativeException%27"));
smalltalk.bind(smalltalk.Exception,"nativeException:",0
,function ($$native){var self=this;return (self[unescape("@nativeException")]=($$native));;return self;}
,"private",unescape("nativeException%3A%20native%0D%0A%09%22%20Private%2C%20Internal%20-%20Set%20the%20native%20exception%20associated%20with%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27@nativeException%27%20put%3A%20native"));
smalltalk.bind(smalltalk.Exception,"stack",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var $$native=nil;$$native=self.nativeException();
(((nil.isNil_($$native))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "";})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return ($$native.stack || "");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"stack",unescape("stack%0D%0A%09%22%20Return%20a%20stack%20trace%20string.%20%22%0D%0A%0D%0A%09%7C%20native%20%7C%0D%0A%09native%20%3A%3D%20self%20nativeException.%0D%0A%09native%20isNil%20ifTrue%3A%20%5B%20%5E%27%27%20%5D.%0D%0A%09%5Enative%23stack%20%7C%7C%20%27%27"));
smalltalk.bind(smalltalk.Exception,"toString",0
,function (){var self=this;var txt=nil;var stk=nil;txt=self.messageText();
(((nil.isNil_(txt))).mustBeBoolean()==true ? (function(){return txt="";})() : nil);
stk=self.stack();
(((nil.isNil_(stk))).mustBeBoolean()==true ? (function(){return stk="";})() : (function(){return stk=unescape("%0D%0A")._comma(stk);})());
return unescape("%7Bst%3Aa")._comma(self.$klass.name())._comma(unescape("%20-%20"))._comma(txt)._comma(unescape("%7D"))._comma(stk);;return self;}
,"converting",unescape("toString%0D%0A%09%22%20Convert%20the%20receiver%20to%20a%20String.%20%22%0D%0A%0D%0A%09%7C%20txt%20stk%20%7C%0D%0A%09txt%20%3A%3D%20self%20messageText.%20txt%20isNil%20ifTrue%3A%20%5B%20txt%20%3A%3D%20%27%27%20%5D.%0D%0A%09stk%20%3A%3D%20self%20stack.%0D%0A%09stk%20isNil%20ifTrue%3A%20%5B%20stk%20%3A%3D%20%27%27%20%5D%20ifFalse%3A%20%5B%20stk%20%3A%3D%20%27%0D%0A%27%2Cstk%20%5D.%0D%0A%09%5E%27%7Bst%3Aa%27%20%2Cself%20class%20name%20%2C%27%20-%20%27%20%2Ctxt%20%2C%24%7D%20%2Cstk"));
smalltalk.bind(smalltalk.Exception,"messageText",0
,function (){var self=this;return self['@messageText'];;return self;}
,"accessing",unescape("messageText%0D%0A%09%22%20Return%20the%20messageText%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EmessageText"));
smalltalk.bind(smalltalk.Exception,"description",0
,function (){var self=this;return self.messageText().asString();;return self;}
,"accessing",unescape("description%0D%0A%09%22%20Return%20the%20description%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20messageText%20asString"));
smalltalk.bind(smalltalk.Exception,"messageText:",0
,function (aString){var self=this;self['@messageText']=aString;return self;}
,"accessing",unescape("messageText%3A%20aString%0D%0A%09%22%20set%20the%20messageText%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09messageText%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.Exception,"signal",0
,function (){var self=this;self.print_(self.$klass.name()._comma(": ")._comma(self.description()));
throw(self);return self;}
,"signaling",unescape("signal%0D%0A%09%22%20Signal/throw%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20print%3A%20self%20class%20name%20%2C%27%3A%20%27%20%2Cself%20description.%0D%0A%09%23%20%23throw%3A%20self"));
smalltalk.bind(smalltalk.Error.$klass,"signal:",0
,function (aString){var self=this;return (function($rec){$rec.messageText_(aString);return $rec.signal();})(self.$$new());;return self;}
,"instantiation",unescape("signal%3A%20aString%0D%0A%09%22%20Signal%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09messageText%3A%20aString%3B%0D%0A%09%09signal"));
smalltalk.bind(smalltalk.MessageNotUnderstood,"message",0
,function (){var self=this;return self['@message'];;return self;}
,"accessing",unescape("message%0D%0A%09%22%20Return%20the%20message%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Emessage"));
smalltalk.bind(smalltalk.MessageNotUnderstood,"message:",0
,function (aMessage){var self=this;self['@message']=aMessage;return self;}
,"accessing",unescape("message%3A%20aMessage%0D%0A%09%22%20Set%20the%20message%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09message%20%3A%3D%20aMessage"));
smalltalk.bind(smalltalk.MessageNotUnderstood,"receiver",0
,function (){var self=this;return self['@receiver'];;return self;}
,"accessing",unescape("receiver%0D%0A%09%22%20Return%20the%20receiver%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ereceiver"));
smalltalk.bind(smalltalk.MessageNotUnderstood,"receiver:",0
,function (anObject){var self=this;self['@receiver']=anObject;return self;}
,"accessing",unescape("receiver%3A%20anObject%0D%0A%09%22%20Set%20the%20receiver%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09receiver%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.MessageNotUnderstood,"messageText",0
,function (){var self=this;return self.receiver().asString()._comma(unescape("%20does%20not%20understand%20%23"))._comma(self.message().selector());;return self;}
,"accessing",unescape("messageText%0D%0A%09%22%20Return%20the%20message%20text%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20receiver%20asString%2C%20%27%20does%20not%20understand%20%23%27%2C%20self%20message%20selector"));
smalltalk.bind(smalltalk.Association.$klass,"key:",0
,function (aKey){var self=this;return self.$$new().key_(aKey);;return self;}
,"instantiation",unescape("key%3A%20aKey%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20key%3A%20aKey"));
smalltalk.bind(smalltalk.Association.$klass,"key:value:",0
,function (aKey,aValue){var self=this;return self.key_(aKey).value_(aValue);;return self;}
,"instantiation",unescape("key%3A%20aKey%20value%3A%20aValue%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28self%20key%3A%20aKey%29%20value%3A%20aValue"));
smalltalk.bind(smalltalk.Association,"=","_eq"
,function (anAssociation){var self=this;return self.$klass._eq(anAssociation.$klass).and_((function(){return self.key()._eq(anAssociation.key()).and_((function(){return self.value()._eq(anAssociation.value());}));}));;return self;}
,"comparing",unescape("%3D%20anAssociation%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20anAssociation.%20%22%0D%0A%0D%0A%09%5Eself%20class%20%3D%20anAssociation%20class%20and%3A%20%5B%0D%0A%09%20%20%20%20self%20key%20%3D%20anAssociation%20key%20and%3A%20%5B%0D%0A%09%09self%20value%20%3D%20anAssociation%20value%5D%5D"));
smalltalk.bind(smalltalk.Association,"key:",0
,function (aKey){var self=this;self['@key']=aKey;return self;}
,"accessing",unescape("key%3A%20aKey%0D%0A%09%22%20Set%20the%20key%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09key%20%3A%3D%20aKey"));
smalltalk.bind(smalltalk.Association,"key",0
,function (){var self=this;return self['@key'];;return self;}
,"accessing",unescape("key%0D%0A%09%22%20Return%20the%20key%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ekey"));
smalltalk.bind(smalltalk.Association,"value:",0
,function (aValue){var self=this;self['@value']=aValue;return self;}
,"accessing",unescape("value%3A%20aValue%0D%0A%09%22%20Set%20the%20value%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09value%20%3A%3D%20aValue"));
smalltalk.bind(smalltalk.Association,"value",0
,function (){var self=this;return self['@value'];;return self;}
,"accessing",unescape("value%0D%0A%09%22%20Return%20the%20value%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Evalue"));
smalltalk.bind(smalltalk.Association,",","_comma"
,function (anAssociation){var self=this;return smalltalk.ComposedAssociations.with_with_(self, anAssociation);;return self;}
,"composing",unescape("%2C%20anAssociation%0D%0A%09%22%20Return%20the%20receiver%20composed%20with%20anAssociation.%20%22%0D%0A%0D%0A%09%5EComposedAssociations%20with%3A%20self%20with%3A%20anAssociation"));
smalltalk.bind(smalltalk.Association,"json",0
,function (){var self=this;return smalltalk.ComposedAssociations.with_(self).json();;return self;}
,"converting",unescape("json%0D%0A%09%22%20Return%20the%20receiver%20copied%20to%20a%20hash%20object.%20%22%0D%0A%0D%0A%09%5E%28ComposedAssociations%20with%3A%20self%29%20json"));
smalltalk.bind(smalltalk.Association,"isAssociation",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isAssociation%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20anAssociation.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Association,"toString",0
,function (){var self=this;var literal=nil;literal=((self.isObject_(self.key())).mustBeBoolean()==true ? (function(){return self.key().asLiteral();})() : (function(){return self.key().toString();})());
return unescape("%28")._comma(literal)._comma(unescape("%20-%3E%20"))._comma(self.value().toString())._comma(unescape("%29"));;return self;}
,"printing",unescape("toString%0D%0A%09%22%20Return%20a%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20literal%20%7C%0D%0A%09literal%20%3A%3D%20%28self%20isObject%3A%20self%20key%29%0D%0A%09%09ifTrue%3A%20%5B%20self%20key%20asLiteral%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20key%20toString%20%5D.%0D%0A%09%5E%27%28%27%2C%20literal%20%2C%27%20-%3E%20%27%20%2Cself%20value%20toString%20%2C%27%29%27"));
smalltalk.bind(smalltalk.ClassBuilder,"superclass:subclass:",0
,function (aClass,aString){var self=this;return self.superclass_subclass_instanceVariableNames_category_(aClass, aString, "", nil);;return self;}
,"instantiation",unescape("superclass%3A%20aClass%20subclass%3A%20aString%0D%0A%09%22%20Create/Register%20a%20new%20class%20in%20the%20system.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09superclass%3A%20aClass%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09category%3A%20nil"));
smalltalk.bind(smalltalk.ClassBuilder,"superclass:subclass:instanceVariableNames:classVariableNames:poolDictionaries:category:",0
,function (aClass,aString,aString2,classVarNames,poolVarNames,aString3){var self=this;var result=nil;var aCategory=nil;aCategory=(((nil.isNil_(aString3))).mustBeBoolean()==true ? (function(){return (((nil.isNil_(aClass))).mustBeBoolean()==true ? (function(){return "unclassified";})() : (function(){return aClass.category();})());})() : (function(){return aString3;})());
result=self.addSubclassOf_named_instanceVariableNames_(aClass, aString, self.instanceVariableNamesFor_(aString2));
self.setupClass_(result);
(function($rec){$rec.classVariableNames_(classVarNames);$rec.poolDictionaryNames_(poolVarNames);return $rec.category_(aCategory);})(result);
(((nil.isNil_(aClass)===false).and_((function(){return smalltalk.Smalltalk.includesKey_("Exporter");}))).mustBeBoolean()==true ? (function(){return self.print_(smalltalk.Exporter.$$new().exportNew_(result));})() : nil);
return result;;return self;}
,"instantiation",unescape("superclass%3A%20aClass%0D%0A%09subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09classVariableNames%3A%20classVarNames%0D%0A%09poolDictionaries%3A%20poolVarNames%0D%0A%09category%3A%20aString3%0D%0A%09%22%20Create/Register%20a%20new%20class%20in%20the%20system.%20%22%0D%0A%0D%0A%09%7C%20result%20aCategory%20%7C%0D%0A%09aCategory%20%3A%3D%20aString3%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09%09aClass%20isNil%20ifTrue%3A%20%5B%20%23unclassified%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20aClass%20category%20%5D%0D%0A%09%09%5D%20ifFalse%3A%20%5B%20aString3%20%5D.%0D%0A%09result%20%3A%3D%20self%0D%0A%09%09addSubclassOf%3A%20aClass%20named%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20%28self%20instanceVariableNamesFor%3A%20aString2%29.%0D%0A%09self%20setupClass%3A%20result.%0D%0A%09result%20%0D%0A%09%09classVariableNames%3A%20classVarNames%3B%0D%0A%09%09poolDictionaryNames%3A%20poolVarNames%3B%0D%0A%09%09category%3A%20aCategory.%0D%0A%09%28aClass%20notNil%20and%3A%20%5B%20Smalltalk%20includesKey%3A%20%23Exporter%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20print%3A%20%28Exporter%20new%20exportNew%3A%20result%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.ClassBuilder,"superclass:subclass:instanceVariableNames:category:",0
,function (aClass,aString,aString2,aString3){var self=this;return self.superclass_subclass_instanceVariableNames_classVariableNames_poolDictionaries_category_(aClass, aString, aString2, "", "", aString3);;return self;}
,"instantiation",unescape("superclass%3A%20aClass%0D%0A%09subclass%3A%20aString%0D%0A%09instanceVariableNames%3A%20aString2%0D%0A%09category%3A%20aString3%0D%0A%09%22%20Create/Register%20a%20new%20class%20in%20the%20system.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09superclass%3A%20aClass%0D%0A%09%09subclass%3A%20aString%0D%0A%09%09instanceVariableNames%3A%20aString2%0D%0A%09%09classVariableNames%3A%20%27%27%0D%0A%09%09poolDictionaries%3A%20%27%27%0D%0A%09%09category%3A%20aString3"));
smalltalk.bind(smalltalk.ClassBuilder,"basicClass:instanceVariableNames:",0
,function (aMetaClass,anArray){var self=this;return self.smalltalk().metaVarNames(aMetaClass, anArray);;return self;}
,"private",unescape("basicClass%3A%20aMetaClass%20instanceVariableNames%3A%20anArray%0D%0A%09%22%20Private%20-%20Register%20instance%20variables%20onto%20aMetaClass.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20%23metaVarNames%3A%20aMetaClass%20array%3A%20anArray"));
smalltalk.bind(smalltalk.ClassBuilder,"class:instanceVariableNames:",0
,function (aMetaClass,aString){var $s8Ret$={name:"stReturn"};try{var self=this;var varNames=nil;((aMetaClass.isMetaclass()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_(aMetaClass.name()._comma(" is not a metaclass"));})();throw($s8Ret$)})();})());
varNames=self.instanceVariableNamesFor_(aString);
((self.basicClass_instanceVariableNames_(aMetaClass, varNames)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})());
self.setupClass_(aMetaClass);
((smalltalk.Smalltalk.includesKey_("Exporter")).mustBeBoolean()==true ? (function(){return self.print_(smalltalk.Exporter.$$new().exportMetaDefinitionOf_(aMetaClass.instanceClass()));})() : nil);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"metaclass",unescape("class%3A%20aMetaClass%20instanceVariableNames%3A%20aString%0D%0A%09%22%20Register%20instance%20variable%20names%20onto%20aMetaClass.%20%22%0D%0A%0D%0A%09%7C%20varNames%20%7C%0D%0A%09aMetaClass%20isMetaclass%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20aMetaClass%20name%2C%20%27%20is%20not%20a%20metaclass%27%0D%0A%09%5D.%0D%0A%09varNames%20%3A%3D%20self%20instanceVariableNamesFor%3A%20aString.%0D%0A%09%28self%20basicClass%3A%20aMetaClass%20instanceVariableNames%3A%20varNames%29%20ifFalse%3A%20%5B%20%5Eself%20%5D.%0D%0A%09self%20setupClass%3A%20aMetaClass.%0D%0A%09%28Smalltalk%20includesKey%3A%20%23Exporter%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20print%3A%20%28Exporter%20new%20exportMetaDefinitionOf%3A%20aMetaClass%20instanceClass%29%0D%0A%09%5D."));
smalltalk.bind(smalltalk.ClassBuilder,"instanceVariableNamesFor:",0
,function (aString){var self=this;return aString.tokenize_(" ").reject_((function(each){return each.isEmpty();}));;return self;}
,"private",unescape("instanceVariableNamesFor%3A%20aString%0D%0A%09%22%20Private%20-%20Return%20the%20instance%20variable%20names%20string.%20%22%0D%0A%0D%0A%09%5E%28aString%20tokenize%3A%20%27%20%27%29%20reject%3A%20%5B%3Aeach%20%7C%20each%20isEmpty%20%5D"));
smalltalk.bind(smalltalk.ClassBuilder,"addSubclassOf:named:instanceVariableNames:",0
,function (aClass,aString,aCollection){var self=this;	 smalltalk.addClass(aString, aClass, aCollection);
	return smalltalk[aString];return self;}
,"private",unescape("addSubclassOf%3A%20aClass%20named%3A%20aString%20instanceVariableNames%3A%20aCollection%0D%0A%09%22%20Private%20-%20Add%20the%20subclass%20to%20system.%20%22%0D%0A%0D%0A%7B%27%09%20smalltalk.addClass%28aString%2C%20aClass%2C%20aCollection%29%3B%0D%0A%09return%20smalltalk%5BaString%5D%27%7D"));
smalltalk.bind(smalltalk.ClassBuilder,"setupClass:",0
,function (aClass){var self=this;return self;}
,"private",unescape("setupClass%3A%20aClass%0D%0A%09%22%20Private%20-%20Bind/initialize%20the%20class%20delegation%20chain.%20%22%0D%0A%0D%0A%22OBSOLETE%20-%09self%20smalltalk%20%23init%3A%20aClass%22"));
smalltalk.bind(smalltalk.Stream.$klass,"on:",0
,function (aCollection){var self=this;return (function($rec){$rec.collection_(aCollection);$rec.readLimit_(aCollection.size());return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("on%3A%20aCollection%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20%0D%0A%09%09collection%3A%20aCollection%3B%0D%0A%09%09readLimit%3A%20aCollection%20size%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Stream,"collection",0
,function (){var self=this;return self['@collection'];;return self;}
,"accessing",unescape("collection%0D%0A%09%22%20Private%20-%20Return%20the%20collection%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ecollection"));
smalltalk.bind(smalltalk.Stream,"collection:",0
,function (aCollection){var self=this;self['@collection']=aCollection;return self;}
,"accessing",unescape("collection%3A%20aCollection%0D%0A%09%22%20Private%20-%20Set%20the%20collection%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09collection%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.Stream,"setCollection:",0
,function (aCollection){var self=this;self.collection_(aCollection);return self;}
,"accessing",unescape("setCollection%3A%20aCollection%0D%0A%09%22%20Private%20-%20Set%20the%20receiver%20stream%20collection%20to%20aCollection.%20%22%0D%0A%0D%0A%09self%20collection%3A%20aCollection"));
smalltalk.bind(smalltalk.Stream,"initialize",0
,function (){var self=this;smalltalk.superImplementor(smalltalk.Stream,'initialize').apply(self, []);
self['@position']=(0);return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09position%20%3A%3D%200."));
smalltalk.bind(smalltalk.Stream,"position",0
,function (){var self=this;return self['@position'];;return self;}
,"accessing",unescape("position%0D%0A%09%22%20Return%20the%20position%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eposition"));
smalltalk.bind(smalltalk.Stream,"position:",0
,function (anInteger){var self=this;self['@position']=anInteger;return self;}
,"accessing",unescape("position%3A%20anInteger%0D%0A%09%22%20Set%20the%20position%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09position%20%3A%3D%20anInteger"));
smalltalk.bind(smalltalk.Stream,"readLimit",0
,function (){var self=this;(((self['@readLimit'] === nil)).mustBeBoolean()==true ? (function(){return self['@readLimit']=self.collection().size();})() : nil);
return self['@readLimit'];;return self;}
,"accessing",unescape("readLimit%0D%0A%09%22%20Private%20-%20Return%20the%20read%20limit%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09readLimit%20%3D%3D%20nil%20ifTrue%3A%20%5B%20readLimit%20%3A%3D%20self%20collection%20size%20%5D.%0D%0A%09%5EreadLimit"));
smalltalk.bind(smalltalk.Stream,"readLimit:",0
,function (anInteger){var self=this;self['@readLimit']=anInteger;return self;}
,"accessing",unescape("readLimit%3A%20anInteger%0D%0A%09%22%20Private%20-%20Set%20the%20stream%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09readLimit%20%3A%3D%20anInteger"));
smalltalk.bind(smalltalk.Stream,"contents",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=self.collection();
((self.readLimit()._eq(result.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return result.copyFrom_to_((1), self.readLimit());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("contents%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20collection.%0D%0A%09self%20readLimit%20%3D%20result%20size%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%5Eresult%20copyFrom%3A%201%20to%3A%20self%20readLimit"));
smalltalk.bind(smalltalk.Stream,"size",0
,function (){var self=this;return self.readLimit();;return self;}
,"accessing",unescape("size%0D%0A%09%22%20Return%20the%20size%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20readLimit"));
smalltalk.bind(smalltalk.Stream,"reset",0
,function (){var self=this;self.position_((0));return self;}
,"actions",unescape("reset%0D%0A%09%22%20Reset%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20position%3A%200"));
smalltalk.bind(smalltalk.Stream,"close",0
,function (){var self=this;return self;}
,"actions",unescape("close%0D%0A%09%22%20Close%20the%20receiver.%20%22"));
smalltalk.bind(smalltalk.Stream,"flush",0
,function (){var self=this;return self;}
,"io",unescape("flush%0D%0A%09%22%20OBSOLETE%20-%20Flush%20the%20receiver.%20%22"));
smalltalk.bind(smalltalk.Stream,"resetContents",0
,function (){var self=this;(function($rec){$rec.reset();return $rec.readLimit_((0));})(self);return self;}
,"actions",unescape("resetContents%0D%0A%09%22%20Reset%20the%20receiver%20contents.%20%22%0D%0A%0D%0A%09self%20reset%3B%20readLimit%3A%200"));
smalltalk.bind(smalltalk.Stream,"do:",0
,function (aBlock){var self=this;(function(){while(!(function(){return self.atEnd();})()){(function(){return aBlock.value_(self.next());})()};return nil})();return self;}
,"enumerating",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluates%20aBlock%20streaming%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5B%20self%20atEnd%20%5D%20whileFalse%3A%20%5B%20aBlock%20value%3A%20self%20next%20%5D"));
smalltalk.bind(smalltalk.Stream,"setToEnd",0
,function (){var self=this;self.position_(self.size());return self;}
,"positioning",unescape("setToEnd%0D%0A%09%22%20Position%20the%20receiver%20at%20end.%20%22%0D%0A%0D%0A%09self%20position%3A%20self%20size"));
smalltalk.bind(smalltalk.Stream,"skip:",0
,function (anInteger){var self=this;self.position_(anInteger._plus(self.position()).min_(self.size()).max_((0)));return self;}
,"positioning",unescape("skip%3A%20anInteger%0D%0A%09%22%20Skip%20next%20anInteger%20readable%20elements%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20position%3A%20%28%28anInteger%20+%20self%20position%20min%3A%20self%20size%29%20max%3A%200%29"));
smalltalk.bind(smalltalk.Stream,"next",0
,function (){var self=this;self.position_(self.position()._plus((1)));
return self['@collection'].at_(self.position());;return self;}
,"reading",unescape("next%0D%0A%09%22%20Return%20the%20next%20readable%20element%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20position%3A%20self%20position%20+%201.%20%0D%0A%09%5Ecollection%20at%3A%20self%20position"));
smalltalk.bind(smalltalk.Stream,"next:",0
,function (anInteger){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=self.collection().$klass.$$new();
(function(){for(var $1$=anInteger;$1$>0;$1$--){(function(){((self.atEnd()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);return result.add_(self.next());})()};return nil})();
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("next%3A%20anInteger%0D%0A%09%22%20Return%20the%20next%20anInteger%20elements%20read%20from%20the%20receiver.%0D%0A%09If%20the%20receiver%20reach%20its%20end%2C%20the%20returned%20collection%20has%20less%20elements.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20collection%20class%20new.%0D%0A%09anInteger%20timesRepeat%3A%20%5B%0D%0A%09%09self%20atEnd%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%09result%20add%3A%20self%20next.%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Stream,"nextPut:",0
,function (anObject){var self=this;self.position_(self.position()._plus((1)));
self.collection().at_put_(self.position(), anObject);
self.readLimit_(self.readLimit().max_(self.position()));return self;}
,"writing",unescape("nextPut%3A%20anObject%0D%0A%09%22%20Put%20anObject%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20position%3A%20self%20position%20+%201.%0D%0A%09self%20collection%20at%3A%20self%20position%20put%3A%20anObject.%0D%0A%09self%20readLimit%3A%20%28self%20readLimit%20max%3A%20self%20position%29"));
smalltalk.bind(smalltalk.Stream,"nextPutAll:",0
,function (aCollection){var self=this;aCollection.do_((function(each){return self.nextPut_(each);}));return self;}
,"writing",unescape("nextPutAll%3A%20aCollection%0D%0A%09%22%20Put%20aCollection%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09aCollection%20do%3A%20%5B%3Aeach%20%7C%20self%20nextPut%3A%20each%20%5D"));
smalltalk.bind(smalltalk.Stream,"cr",0
,function (){var self=this;self.nextPutAll_(smalltalk.String.crlf());return self;}
,"writing",unescape("cr%0D%0A%09%22%20Put%20a%20line%20break%20sequence%20onto%20the%20receiver.%0D%0A%09Note%3A%20this%20implementation%20MUST%20be%20consistent%20with%20%23nextLine%0D%0A%09%22%0D%0A%0D%0A%09self%20nextPutAll%3A%20String%20crlf"));
smalltalk.bind(smalltalk.Stream,"space",0
,function (){var self=this;self.nextPutAll_(smalltalk.String.space());return self;}
,"writing",unescape("space%0D%0A%09%22%20Put%20a%20space%20sequence%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20nextPutAll%3A%20String%20space"));
smalltalk.bind(smalltalk.Stream,"tab",0
,function (){var self=this;self.nextPutAll_(smalltalk.String.tab());return self;}
,"writing",unescape("tab%0D%0A%09%22%20Put%20a%20tab%20sequence%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20nextPutAll%3A%20String%20tab"));
smalltalk.bind(smalltalk.Stream,"peek",0
,function (){var self=this;return ((self.atEnd()).mustBeBoolean()==true ? nil : (function(){return self.collection().at_(self.position()._plus((1)));})());;return self;}
,"reading",unescape("peek%0D%0A%09%22%20Return%20the%20next%20readable%20element%20from%20the%20receiver%20without%20advancing%20the%20receiver%3B%20or%20nil.%20%22%0D%0A%0D%0A%09%5Eself%20atEnd%20ifFalse%3A%20%5B%0D%0A%09%20%20%20%20self%20collection%20at%3A%20self%20position%20+%201%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Stream,"peekFor:",0
,function (anObject){var self=this;return anObject._eq(self.peek()).and_((function(){((self.atEnd()).mustBeBoolean()==true ? nil : (function(){return self.next();})());return true;}));;return self;}
,"reading",unescape("peekFor%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20the%20next%20readable%20element%20from%20the%20receiver%20equals%20anObject.%0D%0A%09Advance%20the%20receiver%20if%20the%20result%20is%20true.%0D%0A%09%22%0D%0A%0D%0A%09%5EanObject%20%3D%20self%20peek%20and%3A%20%5B%0D%0A%09%09self%20atEnd%20ifFalse%3A%20%5B%20self%20next%20%5D.%0D%0A%09%09true%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Stream,"peekForAll:",0
,function (aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;var back=nil;back=self.position();
aCollection.do_((function(each){return ((self.peekFor_(each)).mustBeBoolean()==true ? nil : (function(){self.position_(back);return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("peekForAll%3A%20aCollection%0D%0A%09%22%20Return%20true%20if%20the%20next%20readable%20elements%20from%20the%20receiver%20matches%20aCollection.%0D%0A%09Advance%20the%20receiver%20if%20the%20result%20is%20true.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20back%20%7C%0D%0A%09back%20%3A%3D%20self%20position.%0D%0A%09aCollection%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28self%20peekFor%3A%20each%29%20ifFalse%3A%20%5B%0D%0A%09%09%09self%20position%3A%20back.%0D%0A%09%09%09%5Efalse%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Stream,"atEnd",0
,function (){var self=this;return self.position()._gt_eq(self.size());;return self;}
,"testing",unescape("atEnd%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20at%20end.%20%22%0D%0A%0D%0A%09%5Eself%20position%20%3E%3D%20self%20size"));
smalltalk.bind(smalltalk.Stream,"atStart",0
,function (){var self=this;return self.position()._eq((0));;return self;}
,"testing",unescape("atStart%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20at%20start%20position.%20%22%0D%0A%0D%0A%09%5Eself%20position%20%3D%200"));
smalltalk.bind(smalltalk.Stream,"isEmpty",0
,function (){var self=this;return self.size()._eq((0));;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Eself%20size%20%3D%200"));
smalltalk.bind(smalltalk.Stream,"upTo:",0
,function (anObject){var self=this;var result=nil;result=self.collection().$klass.$$new();
(function(){while(!(function(){return self.atEnd().or_((function(){return self.peek()._eq(anObject);}));})()){(function(){return result.add_(self.next());})()};return nil})();
((self.atEnd()).mustBeBoolean()==true ? nil : (function(){return self.next();})());
return result;;return self;}
,"reading",unescape("upTo%3A%20anObject%0D%0A%09%22%20Return%20the%20elements%20read%20from%20the%20receiver%20upto%20anObject%20%28or%20end%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20collection%20class%20new.%0D%0A%09%5B%20self%20atEnd%20or%3A%20%5B%20self%20peek%20%3D%20anObject%20%5D%5D%20whileFalse%3A%20%5B%0D%0A%09%20%20%20%20result%20add%3A%20self%20next%0D%0A%09%5D.%0D%0A%09self%20atEnd%20ifFalse%3A%20%5B%20self%20next%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Stream,"upToEnd",0
,function (){var self=this;var result=nil;result=self.collection().copyFrom_to_(self.position()._plus((1)), self.readLimit());
self.setToEnd();
return result;;return self;}
,"reading",unescape("upToEnd%0D%0A%09%22%20Return%20the%20contents%20of%20the%20receiver%20upto%20end.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20collection%20copyFrom%3A%20self%20position%20+%201%20to%3A%20self%20readLimit.%0D%0A%09self%20setToEnd.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Stream,"nextLine",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;var start=nil;start=self.position();
result=self.upTo_(smalltalk.String.cr());
((result.includes_(smalltalk.String.lf())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function($rec){$rec.position_(start);return $rec.upTo_(smalltalk.String.lf());})(self);})();throw($s8Ret$)})();})() : nil);
((self.peek()._eq(smalltalk.String.lf())).mustBeBoolean()==true ? (function(){return self.next();})() : nil);
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("nextLine%0D%0A%09%22%20Return%20the%20characters%20read%20from%20the%20receiver%20up%20to%20the%20line%20delimiter.%20%22%0D%0A%0D%0A%09%7C%20result%20start%20%7C%0D%0A%09start%20%3A%3D%20self%20position.%0D%0A%09result%20%3A%3D%20self%20upTo%3A%20String%20cr.%0D%0A%09%28result%20includes%3A%20String%20lf%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20position%3A%20start%3B%20upTo%3A%20String%20lf%0D%0A%09%5D.%0D%0A%09%28self%20peek%20%3D%20String%20lf%29%20ifTrue%3A%20%5B%20self%20next%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Stream,"skipTo:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;(function(){while(!(function(){return self.atEnd();})()){(function(){return ((self.next()._eq(anObject)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);})()};return nil})();
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("skipTo%3A%20anObject%0D%0A%09%22%20Advance%20the%20receiver%20upto%20anObject%20%28or%20end%29.%20%22%0D%0A%0D%0A%09%5B%20self%20atEnd%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09self%20next%20%3D%20anObject%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Stream,"skipSeparators",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(function(){while((function(){((self.atEnd()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);return self.peek().isSeparator();})()){(function(){return self.next();})()};return nil})();
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("skipSeparators%0D%0A%09%22%20Advance%20the%20receiver%20upto%20a%20non-separator%20%28or%20end%29.%0D%0A%09Return%20true%20%20if%20a%20non-separator%20contents%20is%20found%2C%0D%0A%09return%20false%20if%20run%20upto%20end%20of%20stream.%0D%0A%09%22%0D%0A%0D%0A%09%5B%20self%20atEnd%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%20%20self%20peek%20isSeparator%0D%0A%09%5D%20whileTrue%3A%20%5B%20self%20next%20%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Stream,"nextChunk",0
,function (){var self=this;var result=nil;result=self.upTo_(unescape("%21"));
(function(){while((function(){return self.peek()._eq(unescape("%21"));})()){(function(){self.next();return result=result._comma(unescape("%21"))._comma(self.upTo_(unescape("%21")));})()};return nil})();
return result.trimFirst_((function(c){return c.asciiValue()._lt_eq((32));}));;return self;}
,"Tools-fileIn",unescape("nextChunk%0D%0A%09%22%20FileIn%20-%20Return%20the%20next%20chunk%20read%20from%20the%20receiver.%0D%0A%09Trailing%20non-printing%20characters%20are%20skipped.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20upTo%3A%20%24%21.%0D%0A%09%5B%20self%20peek%20%3D%20%24%21%20%5D%20whileTrue%3A%20%5B%0D%0A%09%09self%20next.%0D%0A%09%09result%20%3A%3D%20result%2C%20%27%21%27%2C%20%28self%20upTo%3A%20%24%21%29%0D%0A%09%5D.%0D%0A%09%5Eresult%20trimFirst%3A%20%5B%3Ac%7C%20c%20asciiValue%20%3C%3D%2032%20%5D"));
smalltalk.bind(smalltalk.Stream,"fileInto:",0
,function (aReceiver){var self=this;var scanner=nil;(function(){while(!(function(){return self.atEnd();})()){(function(){(((nil.isNil_(scanner))).mustBeBoolean()==true ? (function(){return scanner=aReceiver;})() : nil);return scanner=scanner.scanFrom_(self);})()};return nil})();
return scanner;;return self;}
,"Tools-fileIn",unescape("fileInto%3A%20aReceiver%0D%0A%09%22%20FileIn%20-%20FileIn%20the%20receiver%27s%20contents%20%28in%20chunk%20format%29%20using%20aReceiver%20as%20default%20scanner.%20%22%0D%0A%0D%0A%09%7C%20scanner%20%7C%0D%0A%09%5Bself%20atEnd%5D%20whileFalse%3A%20%5B%0D%0A%09%09scanner%20isNil%20ifTrue%3A%20%5B%20scanner%20%3A%3D%20aReceiver%20%5D.%0D%0A%09%09scanner%20%3A%3D%20scanner%20scanFrom%3A%20self%0D%0A%09%5D.%0D%0A%09%5Escanner"));
smalltalk.bind(smalltalk.Stream,"fileIn",0
,function (){var self=this;return self.fileInto_(nil);;return self;}
,"Tools-fileIn",unescape("fileIn%0D%0A%09%22%20FileIn%20-%20FileIn%20the%20receiver%27s%20contents%20%28in%20chunk%20format%29.%20%22%0D%0A%0D%0A%09%5Eself%20fileInto%3A%20nil"));
smalltalk.bind(smalltalk.Stream,"nextChunkPut:",0
,function (aString){var self=this;var eoc=nil;var parts=nil;eoc=unescape("%21");
(((nil.isNil_(aString)===false).and_((function(){return aString.notEmpty();}))).mustBeBoolean()==true ? (function(){return aString.asArrayOfSubstringsSeparatedBy_(eoc).do_separatedBy_((function(each){return self.nextPutAll_(each);}), (function(){return self.nextPutAll_(eoc._comma(eoc));}));})() : (function(){return self.nextPut_(" ");})());
self.nextPut_(eoc);
return aString;;return self;}
,"Tools-fileOut",unescape("nextChunkPut%3A%20aString%0D%0A%09%22%20Output%20aString%20in%20chunk%20format.%20%22%0D%0A%0D%0A%09%7C%20eoc%20parts%20%7C%0D%0A%09eoc%20%3A%3D%20%24%21.%0D%0A%09%28aString%20notNil%20and%3A%20%5BaString%20notEmpty%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%28aString%20asArrayOfSubstringsSeparatedBy%3A%20eoc%29%0D%0A%09%09%09do%3A%20%5B%3Aeach%7C%20self%20nextPutAll%3A%20each%20%5D%0D%0A%09%09%09separatedBy%3A%20%5B%20self%20nextPutAll%3A%20eoc%2Ceoc%20%5D.%0D%0A%09%5D%20ifFalse%3A%20%5B%20self%20nextPut%3A%20%24%20%5D.%0D%0A%09self%20nextPut%3A%20eoc.%0D%0A%09%5EaString"));
smalltalk.bind(smalltalk.StringStream,"next:",0
,function (anInteger){var self=this;var start=nil;var result=nil;var stop=nil;start=self.position();
stop=start._plus(anInteger).min_(self.readLimit());
result=self.collection().copyFrom_to_(start._plus((1)), stop);
self.position_(stop);
return result;;return self;}
,"reading",unescape("next%3A%20anInteger%0D%0A%09%22%20Return%20the%20next%20anInteger%20elements%20read%20from%20the%20receiver.%0D%0A%09If%20the%20receiver%20reach%20its%20end%2C%20the%20returned%20collection%20has%20less%20elements.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20start%20result%20stop%20%7C%0D%0A%09start%20%3A%3D%20self%20position.%0D%0A%09stop%20%3A%3D%20start%20+%20anInteger%20min%3A%20self%20readLimit.%0D%0A%09result%20%3A%3D%20self%20collection%20copyFrom%3A%20start%20+%201%20to%3A%20stop.%0D%0A%09self%20position%3A%20stop.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.StringStream,"nextPut:",0
,function (aString){var self=this;self.nextPutAll_(aString);return self;}
,"writing",unescape("nextPut%3A%20aString%0D%0A%09%22%20Put%20aString%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20nextPutAll%3A%20aString"));
smalltalk.bind(smalltalk.StringStream,"nextPutAll:",0
,function (aString){var self=this;var result=nil;((self.position()._eq(self.collection().size())).mustBeBoolean()==true ? (function(){return result=self.collection()._comma(aString);})() : (function(){var substring=nil;substring=self.collection().copyFrom_to_((1), self.position());result=((substring.isEmpty()).mustBeBoolean()==true ? (function(){return aString;})() : (function(){return substring._comma(aString);})());substring=self.collection().copyFrom_to_(self.position()._plus((1))._plus(aString.size()), self.collection().size());return result=((substring.isEmpty()).mustBeBoolean()==true ? (function(){return result;})() : (function(){return result._comma(substring);})());})());
self.collection_(result);
self.position_(self.position()._plus(aString.size()));
self.readLimit_(self.readLimit().max_(self['@position']));return self;}
,"writing",unescape("nextPutAll%3A%20aString%0D%0A%09%22%20Put%20aString%20onto%20the%20receiver%20at%20current%20position%3B%20expanding%20internal%20contents.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20position%20%3D%20self%20collection%20size%0D%0A%09ifTrue%3A%20%5B%20result%20%3A%3D%20self%20collection%20%2C%20aString%20%5D%0D%0A%09ifFalse%3A%20%5B%20%7C%20substring%20%7C%0D%0A%09%09substring%20%3A%3D%20self%20collection%20copyFrom%3A%201%20to%3A%20self%20position.%0D%0A%09%09result%20%3A%3D%20substring%20isEmpty%20ifTrue%3A%20%5B%20aString%20%5D%20ifFalse%3A%20%5B%20substring%20%2C%20aString%20%5D.%0D%0A%09%09substring%20%3A%3D%20self%20collection%0D%0A%09%09%09copyFrom%3A%20self%20position%20+%201%20+%20aString%20size%0D%0A%09%09%09to%3A%20self%20collection%20size.%0D%0A%09%09result%20%3A%3D%20substring%20isEmpty%20ifTrue%3A%20%5B%20result%20%5D%20ifFalse%3A%20%5B%20result%20%2C%20substring%20%5D.%0D%0A%09%5D.%0D%0A%09self%20collection%3A%20result.%0D%0A%09self%20position%3A%20self%20position%20+%20aString%20size.%0D%0A%09self%20readLimit%3A%20%28self%20readLimit%20max%3A%20position%29"));
smalltalk.bind(smalltalk.StringStream,"skipTo:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;var index=nil;((anObject.isString()).mustBeBoolean()==true ? nil : (function(){self.setToEnd();return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
index=self.collection().indexOf_startingAt_(anObject, self.position()._plus((1)));
((index.between_and_(self.position()._plus((1)), self.readLimit())).mustBeBoolean()==true ? (function(){self.position_(index._plus(anObject.size())._minus((1)));return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
self.setToEnd();
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("skipTo%3A%20anObject%0D%0A%09%22%20Advance%20the%20receiver%20upto%20anObject%20%28or%20end%29.%20%22%0D%0A%0D%0A%09%7C%20index%20%7C%0D%0A%09anObject%20isString%20ifFalse%3A%20%5B%20self%20setToEnd.%20%5Efalse%20%5D.%0D%0A%09index%20%3A%3D%20self%20collection%20indexOf%3A%20anObject%20startingAt%3A%20self%20position%20+%201.%0D%0A%09%28index%20between%3A%20self%20position%20+%201%20and%3A%20self%20readLimit%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20position%3A%20index%20+%20anObject%20size%20-%201.%0D%0A%09%09%5Etrue%0D%0A%09%5D.%0D%0A%09self%20setToEnd.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.StringStream,"upTo:",0
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var found=nil;((anObject.isString()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.upToEnd();})();throw($s8Ret$)})();})());
start=self.position()._plus((1));
found=((self.skipTo_(anObject)).mustBeBoolean()==true ? (function(){return anObject.size();})() : (function(){return (0);})());
(function(){$s8Ret$.result=(function(){return self.collection().copyFrom_to_(start, self.position()._minus(found));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("upTo%3A%20anObject%0D%0A%09%22%20Return%20the%20elements%20read%20from%20the%20receiver%20upto%20anObject%20%28or%20end%29.%20%22%0D%0A%0D%0A%09%7C%20start%20found%20%7C%0D%0A%09anObject%20isString%20ifFalse%3A%20%5B%20%5Eself%20upToEnd%20%5D.%0D%0A%09start%20%3A%3D%20self%20position%20+%201.%0D%0A%09found%20%3A%3D%20%28self%20skipTo%3A%20anObject%29%20ifTrue%3A%20%5B%20anObject%20size%20%5D%20ifFalse%3A%20%5B%200%20%5D.%0D%0A%09%5Eself%20collection%20copyFrom%3A%20start%20to%3A%20self%20position%20-%20found"));
smalltalk.bind(smalltalk.StringStream,"peek",0
,function (){var self=this;return (self['@collection'].charAt(self.position()) || nil);;return self;}
,"reading",unescape("peek%0D%0A%09%22%20Return%20the%20next%20readable%20element%20from%20the%20receiver%20without%20advancing%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5E%28collection%20%23charAt%3A%20self%20position%29%20%7C%7C%20nil"));
smalltalk.bind(smalltalk.StringStream,"next",0
,function (){var self=this;var result=nil;result=self.peek();
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){return self['@position']=self['@position']._plus((1));})() : nil);
return result;;return self;}
,"reading",unescape("next%0D%0A%09%22%20Return%20the%20next%20readable%20element%20in%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20peek.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%20position%20%3A%3D%20position%20+%201%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.StringStream,"peekForAll:",0
,function (aCollection){var $s8Ret$={name:"stReturn"};try{var self=this;((aCollection.isString()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.StringStream,'peekForAll_').apply(self, [aCollection]);})();throw($s8Ret$)})();})());
	var start = self.position();
	for (var i=0;i<aCollection.length; i++){
		if (self["@collection"].charCodeAt(start+i) != aCollection.charCodeAt(i)) return false;
	}
;
self['@position']=self['@position']._plus(aCollection.length);
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("peekForAll%3A%20aCollection%0D%0A%09%22%20Return%20true%20if%20the%20next%20readable%20elements%20from%20the%20receiver%20matches%20aCollection.%0D%0A%09Advance%20the%20receiver%20if%20the%20result%20is%20true.%0D%0A%09%22%0D%0A%0D%0A%09aCollection%20isString%20ifFalse%3A%20%5B%20%5Esuper%20peekForAll%3A%20aCollection%20%5D.%0D%0A%7B%27%09var%20start%20%3D%20self.position%28%29%3B%0D%0A%09for%20%28var%20i%3D0%3Bi%3CaCollection.length%3B%20i++%29%7B%0D%0A%09%09if%20%28self%5B%22@collection%22%5D.charCodeAt%28start+i%29%20%21%3D%20aCollection.charCodeAt%28i%29%29%20return%20false%3B%0D%0A%09%7D%0D%0A%27%7D.%09position%20%3A%3D%20position%20+%20aCollection%23length.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.StringStream,"upToSeparator",0
,function (){var self=this;var start=nil;start=self.position()._plus((1));
(function(){while((function(){return self.atEnd().not().and_((function(){return self.peek().isSeparator().not();}));})()){(function(){return self.next();})()};return nil})();
return self.collection().copyFrom_to_(start, self.position());;return self;}
,"reading",unescape("upToSeparator%0D%0A%09%22%20Return%20the%20elements%20read%20from%20the%20receiver%20upto%20a%20separator%20%28or%20end%29.%20%22%0D%0A%0D%0A%09%7C%20start%20%7C%0D%0A%09start%20%3A%3D%20self%20position%20+%201.%0D%0A%09%5Bself%20atEnd%20not%20and%3A%20%5Bself%20peek%20isSeparator%20not%5D%5D%20whileTrue%3A%20%5B%0D%0A%09%09self%20next%0D%0A%09%5D.%0D%0A%09%5Eself%20collection%20copyFrom%3A%20start%20to%3A%20self%20position"));
smalltalk.bind(smalltalk.StringStream,"nextMessagePattern",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var part=nil;var selector=nil;var args=nil;args=[];
self.skipSeparators();
selector=self.upToSeparator();
((selector.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
((selector.argumentCount()._gt((0))).mustBeBoolean()==true ? (function(){var part=nil;return (function(){while((function(){self.skipSeparators();args.add_(self.upToSeparator());self.skipSeparators();part=((self.peek()._eq(unescape("%22"))).mustBeBoolean()==true ? (function(){return "";})() : (function(){return self.upToSeparator();})());return part.notEmpty().and_((function(){return part.last()._eq(":");}));})()){(function(){return selector=selector._comma(part);})()};return nil})();})() : nil);
part=smalltalk.Message.selector_arguments_(selector, args);
self.skipSeparators();
((self.peek()._eq(unescape("%22"))).mustBeBoolean()==true ? (function(){return part.comment_((function($rec){$rec.next();return $rec.upTo_(unescape("%22"));})(self).trimBlanks());})() : nil);
(function(){$s8Ret$.result=(function(){return part;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"tools",unescape("nextMessagePattern%0D%0A%09%22%20Return%20a%20message%20pattern%20read%20from%20the%20receiver%20%28or%20nil%29.%0D%0A%09Note%3A%20it%20is%20assumed%20that%20there%20is%20a%20correct%20message%20header%20in%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20part%20selector%20args%20%7C%0D%0A%09args%20%3A%3D%20%23%28%29.%0D%0A%09self%20skipSeparators.%0D%0A%09selector%20%3A%3D%20self%20upToSeparator.%0D%0A%09selector%20isEmpty%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09selector%20argumentCount%20%3E%200%20ifTrue%3A%20%5B%20%7C%20part%20%7C%0D%0A%09%09%5B%20self%20skipSeparators.%0D%0A%09%09%20%20args%20add%3A%20self%20upToSeparator.%0D%0A%09%09%20%20self%20skipSeparators.%0D%0A%09%09%20%20part%20%3A%3D%20self%20peek%20%3D%20%24%22%20ifTrue%3A%20%5B%20%27%27%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20self%20upToSeparator%20%5D.%0D%0A%09%09%20%20part%20notEmpty%20and%3A%20%5B%20part%20last%20%3D%20%24%3A%20%5D%0D%0A%09%09%5D%20whileTrue%3A%20%5B%0D%0A%09%09%20%20selector%20%3A%3D%20selector%20%2C%20part%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09part%20%3A%3D%20Message%20selector%3A%20selector%20arguments%3A%20args.%0D%0A%09self%20skipSeparators.%0D%0A%09self%20peek%20%3D%20%24%22%20ifTrue%3A%20%5B%0D%0A%09%09part%20comment%3A%20%28self%20next%3B%20upTo%3A%20%24%22%29%20trimBlanks%0D%0A%09%5D.%0D%0A%09%5Epart"));
smalltalk.bind(smalltalk.Random,"next",0
,function (){var self=this;return Math.random();;return self;}
,"accessing",unescape("next%0D%0A%09%22%20Return%20the%20next%20random%20number.%20%22%0D%0A%0D%0A%09%5E%23%7BMath%7D%20random"));
smalltalk.bind(smalltalk.Random,"next:",0
,function (anInteger){var self=this;return (1).to_(anInteger).collect_((function(each){return self.next();}));;return self;}
,"accessing",unescape("next%3A%20anInteger%0D%0A%09%22%20Return%20the%20next%20anInteger%20random%20numbers.%20%22%0D%0A%0D%0A%09%5E%281%20to%3A%20anInteger%29%20collect%3A%20%5B%3Aeach%20%7C%20self%20next%20%5D"));
smalltalk.bind(smalltalk.Point.$klass,"x:y:",0
,function (x,y){var self=this;return (function($rec){$rec.x_(x);return $rec.y_(y);})(self.basicNew());;return self;}
,"instantiation",unescape("x%3A%20x%20y%3A%20y%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20x%3A%20x%3B%20y%3A%20y"));
smalltalk.bind(smalltalk.Point.$klass,"zero",0
,function (){var self=this;return (function($rec){$rec.x_((0));return $rec.y_((0));})(self.basicNew());;return self;}
,"instantiation",unescape("zero%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20x%3A%200%3B%20y%3A%200"));
smalltalk.bind(smalltalk.Point,"x",0
,function (){var self=this;return self['@x'];;return self;}
,"accessing",unescape("x%0D%0A%09%22%20Return%20the%20x%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ex"));
smalltalk.bind(smalltalk.Point,"y",0
,function (){var self=this;return self['@y'];;return self;}
,"accessing",unescape("y%0D%0A%09%22%20Return%20the%20y%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ey"));
smalltalk.bind(smalltalk.Point,"y:",0
,function (aNumber){var self=this;self['@y']=(((nil.isNil_(aNumber))).mustBeBoolean()==true ? (function(){return (0);})() : (function(){return aNumber;})());return self;}
,"accessing",unescape("y%3A%20aNumber%0D%0A%09%22%20Set%20the%20y%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09y%20%3A%3D%20aNumber%20isNil%20ifTrue%3A%20%5B%200%20%5D%20ifFalse%3A%20%5B%20aNumber%20%5D"));
smalltalk.bind(smalltalk.Point,"x:",0
,function (aNumber){var self=this;self['@x']=(((nil.isNil_(aNumber))).mustBeBoolean()==true ? (function(){return (0);})() : (function(){return aNumber;})());return self;}
,"accessing",unescape("x%3A%20aNumber%0D%0A%09%22%20Set%20the%20x%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09x%20%3A%3D%20aNumber%20isNil%20ifTrue%3A%20%5B%200%20%5D%20ifFalse%3A%20%5B%20aNumber%20%5D"));
smalltalk.bind(smalltalk.Point,"*","_star"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@x']._star(aPoint)._at(self['@y']._star(aPoint));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Point.x_y_(self['@x']._star(aPoint.asPoint().x()), self['@y']._star(aPoint.asPoint().y()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("*%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Ex%20*%20aPoint%20@%20%28y%20*%20aPoint%29%20%5D.%0D%0A%09%5EPoint%09x%3A%20x%20*%20aPoint%20asPoint%20x%0D%0A%09%09y%3A%20y%20*%20aPoint%20asPoint%20y"));
smalltalk.bind(smalltalk.Point,"+","_plus"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@x']._plus(aPoint)._at(self['@y']._plus(aPoint));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Point.x_y_(self['@x']._plus(aPoint.asPoint().x()), self['@y']._plus(aPoint.asPoint().y()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("+%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Ex%20+%20aPoint%20@%20%28y%20+%20aPoint%29%20%5D.%0D%0A%09%5EPoint%09x%3A%20x%20+%20aPoint%20asPoint%20x%0D%0A%09%09y%3A%20y%20+%20aPoint%20asPoint%20y"));
smalltalk.bind(smalltalk.Point,"-","_minus"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@x']._minus(aPoint)._at(self['@y']._minus(aPoint));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Point.x_y_(self['@x']._minus(aPoint.asPoint().x()), self['@y']._minus(aPoint.asPoint().y()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("-%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Ex%20-%20aPoint%20@%20%28y%20-%20aPoint%29%20%5D.%0D%0A%09%5EPoint%09x%3A%20x%20-%20aPoint%20asPoint%20x%0D%0A%09%09y%3A%20y%20-%20aPoint%20asPoint%20y"));
smalltalk.bind(smalltalk.Point,"/","_slash"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@x']._slash(aPoint)._at(self['@y']._slash(aPoint));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Point.x_y_(self['@x']._slash(aPoint.asPoint().x()), self['@y']._slash(aPoint.asPoint().y()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("/%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Ex%20/%20aPoint%20@%20%28y%20/%20aPoint%29%20%5D.%0D%0A%09%5EPoint%09x%3A%20x%20/%20aPoint%20asPoint%20x%0D%0A%09%09y%3A%20y%20/%20aPoint%20asPoint%20y"));
smalltalk.bind(smalltalk.Point,"//","_slash_slash"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@x']._slash_slash(aPoint)._at(self['@y']._slash_slash(aPoint));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Point.x_y_(self['@x']._slash_slash(aPoint.asPoint().x()), self['@y']._slash_slash(aPoint.asPoint().y()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("//%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Ex%20//%20aPoint%20@%20%28y%20//%20aPoint%29%20%5D.%0D%0A%09%5EPoint%09x%3A%20x%20//%20aPoint%20asPoint%20x%0D%0A%09%09y%3A%20y%20//%20aPoint%20asPoint%20y"));
smalltalk.bind(smalltalk.Point,unescape("%5C%5C"),"_bk_bk"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@x']._bk_bk(aPoint)._at(self['@y']._bk_bk(aPoint));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Point.x_y_(self['@x']._bk_bk(aPoint.asPoint().x()), self['@y']._bk_bk(aPoint.asPoint().y()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"arithmetic",unescape("%5C%5C%5C%5C%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Ex%20%5C%5C%20aPoint%20@%20%28y%20%5C%5C%20aPoint%29%20%5D.%0D%0A%09%5EPoint%09x%3A%20x%20%5C%5C%20aPoint%20asPoint%20x%0D%0A%09%09y%3A%20y%20%5C%5C%20aPoint%20asPoint%20y"));
smalltalk.bind(smalltalk.Point,"<","_lt"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self._lt(aPoint.asPoint());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@x']._lt(aPoint.x()).and_((function(){return self['@y']._lt(aPoint.y());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"comparing",unescape("%3C%20aPoint%0D%0A%09%22%20Return%20true%20if%20the%20x%20and%20y%20coordinates%20of%20the%20receiver%20are%20less%20than%20the%20x%20and%20y%20coordinates%20of%20aPoint%2C%20respectively.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Eself%20%3C%20aPoint%20asPoint%20%5D.%0D%0A%09%5Ex%20%3C%20aPoint%20x%20and%3A%20%5B%20y%20%3C%20aPoint%20y%20%5D"));
smalltalk.bind(smalltalk.Point,"<=","_lt_eq"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self._lt_eq(aPoint.asPoint());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@x']._lt_eq(aPoint.x()).and_((function(){return self['@y']._lt_eq(aPoint.y());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"comparing",unescape("%3C%3D%20aPoint%0D%0A%09%22%20Return%20true%20if%20the%20x%20and%20y%20coordinates%20of%20the%20receiver%20are%20less%20than%20or%20equal%20to%20the%20x%20and%20y%20coordinates%20of%20aPoint%2C%20respectively.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Eself%20%3C%3D%20aPoint%20asPoint%20%5D.%0D%0A%09%5Ex%20%3C%3D%20aPoint%20x%20and%3A%20%5B%20y%20%3C%3D%20aPoint%20y%20%5D"));
smalltalk.bind(smalltalk.Point,">","_gt"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self._gt(aPoint.asPoint());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@x']._gt(aPoint.x()).and_((function(){return self['@y']._gt(aPoint.y());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"comparing",unescape("%3E%20aPoint%0D%0A%09%22%20Return%20true%20if%20the%20x%20and%20y%20coordinates%20of%20the%20receiver%20are%20greater%20than%20the%20x%20and%20y%20coordinates%20of%20aPoint%2C%20respectively.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Eself%20%3E%20aPoint%20asPoint%20%5D.%0D%0A%09%5Ex%20%3E%20aPoint%20x%20and%3A%20%5B%20y%20%3E%20aPoint%20y%20%5D"));
smalltalk.bind(smalltalk.Point,">=","_gt_eq"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self._gt_eq(aPoint.asPoint());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@x']._gt_eq(aPoint.x()).and_((function(){return self['@y']._gt_eq(aPoint.y());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"comparing",unescape("%3E%3D%20aPoint%0D%0A%09%22%20Return%20true%20if%20the%20x%20and%20y%20coordinates%20of%20the%20receiver%20are%20greater%20than%20or%20equal%20to%20the%20x%20and%20y%20coordinates%20of%20aPoint%2C%20respectively.%20%22%0D%0A%0D%0A%09aPoint%20isNumber%20ifTrue%3A%20%5B%20%5Eself%20%3E%3D%20aPoint%20asPoint%20%5D.%0D%0A%09%5Ex%20%3E%3D%20aPoint%20x%20and%3A%20%5B%20y%20%3E%3D%20aPoint%20y%20%5D"));
smalltalk.bind(smalltalk.Point,"rounded",0
,function (){var self=this;return self['@x'].rounded()._at(self['@y'].rounded());;return self;}
,"converting",unescape("rounded%0D%0A%09%22%20Return%20the%20receiver%20rounded.%20%22%0D%0A%0D%0A%09%5Ex%20rounded%20@%20y%20rounded"));
smalltalk.bind(smalltalk.Point,"truncated",0
,function (){var self=this;return self['@x'].truncated()._at(self['@y'].truncated());;return self;}
,"converting",unescape("truncated%0D%0A%09%22%20Return%20the%20receiver%20truncated.%20%22%0D%0A%0D%0A%09%5Ex%20truncated%20@%20y%20truncated"));
smalltalk.bind(smalltalk.Point,"asPoint",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asPoint%0D%0A%09%22%20Return%20the%20receiver%20as%20a%20Point.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Point,"printString",0
,function (){var self=this;return self['@x'].asString()._comma(unescape("%20@%20"))._comma(self['@y'].asString());;return self;}
,"printing",unescape("printString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ex%20asString%20%2C%27%20@%20%27%20%2Cy%20asString"));
smalltalk.bind(smalltalk.Point,"toString",0
,function (){var self=this;return self['@x'].toString()._comma(unescape("@"))._comma(self['@y'].toString());;return self;}
,"printing",unescape("toString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ex%20toString%20%2C%27@%27%20%2Cy%20toString"));
smalltalk.bind(smalltalk.Point,"shallowCopy",0
,function (){var self=this;return self.$klass.x_y_(self.x(), self.y());;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20x%3A%20self%20x%20y%3A%20self%20y"));
smalltalk.bind(smalltalk.Point,"=","_eq"
,function (aPoint){var $s8Ret$={name:"stReturn"};try{var self=this;((aPoint.isMemberOf_(self.$klass)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return aPoint.asPoint()._eq(self);})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return self['@x']._eq(aPoint.x()).and_((function(){return self['@y']._eq(aPoint.y());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("%3D%20aPoint%0D%0A%09%22%20Return%20the%20result%20of%20operation%20with%20aPoint.%20%22%0D%0A%0D%0A%09%28aPoint%20isMemberOf%3A%20self%20class%29%20ifFalse%3A%20%5B%0D%0A%09%09%5EaPoint%20asPoint%20%3D%20self%0D%0A%09%5D.%0D%0A%09%5Ex%20%3D%20aPoint%20x%20and%3A%20%5B%20y%20%3D%20aPoint%20y%20%5D"));
smalltalk.bind(smalltalk.Point,"min:",0
,function (aPoint){var self=this;return self['@x'].min_(aPoint.x())._at(self['@y'].min_(aPoint.y()));;return self;}
,"magnitude",unescape("min%3A%20aPoint%0D%0A%09%22%20Return%20the%20minimum%20of%20the%20receiver%20and%20aPoint.%20%22%0D%0A%0D%0A%09%5E%28x%20min%3A%20aPoint%20x%29%20@%20%28y%20min%3A%20aPoint%20y%29"));
smalltalk.bind(smalltalk.Point,"max:",0
,function (aPoint){var self=this;return self['@x'].max_(aPoint.x())._at(self['@y'].max_(aPoint.y()));;return self;}
,"magnitude",unescape("max%3A%20aPoint%0D%0A%09%22%20Return%20the%20maximum%20of%20the%20receiver%20and%20aPoint.%20%22%0D%0A%0D%0A%09%5E%28x%20max%3A%20aPoint%20x%29%20@%20%28y%20max%3A%20aPoint%20y%29"));
smalltalk.bind(smalltalk.Point,"extent:",0
,function (extent){var self=this;return smalltalk.Rectangle.leftTop_rightBottom_(self, self._plus(extent));;return self;}
,"converting",unescape("extent%3A%20extent%0D%0A%09%22%20Return%20a%20Rectangle%20from%20the%20receiver%20with%20specified%20extent.%20%22%0D%0A%0D%0A%09%5ERectangle%20leftTop%3A%20self%20rightBottom%3A%20self%20+%20extent"));
smalltalk.bind(smalltalk.Point,"rightBottom:",0
,function (rightBottom){var self=this;return smalltalk.Rectangle.leftTop_rightBottom_(self, rightBottom);;return self;}
,"converting",unescape("rightBottom%3A%20rightBottom%0D%0A%09%22%20Return%20a%20Rectangle%20from%20the%20receiver%20to%20rightBottom.%20%22%0D%0A%0D%0A%09%5ERectangle%20leftTop%3A%20self%20rightBottom%3A%20rightBottom"));
smalltalk.bind(smalltalk.Point,"to:",0
,function (rightBottom){var self=this;return smalltalk.Rectangle.leftTop_rightBottom_(self, rightBottom);;return self;}
,"converting",unescape("to%3A%20rightBottom%0D%0A%09%22%20Return%20a%20Rectangle%20from%20the%20receiver%20to%20rightBottom.%20%22%0D%0A%0D%0A%09%5ERectangle%20leftTop%3A%20self%20rightBottom%3A%20rightBottom"));
smalltalk.bind(smalltalk.Rectangle.$klass,"leftTop:extent:",0
,function (leftTop,extent){var self=this;return self.$$new().leftTop_rightBottom_(leftTop, leftTop._plus(extent));;return self;}
,"instantiation",unescape("leftTop%3A%20leftTop%20extent%3A%20extent%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20leftTop%3A%20leftTop%20rightBottom%3A%20leftTop%20+%20extent"));
smalltalk.bind(smalltalk.Rectangle.$klass,"leftTop:rightBottom:",0
,function (leftTop,rightBottom){var self=this;return self.$$new().leftTop_rightBottom_(leftTop, rightBottom);;return self;}
,"instantiation",unescape("leftTop%3A%20leftTop%20rightBottom%3A%20rightBottom%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20leftTop%3A%20leftTop%20rightBottom%3A%20rightBottom"));
smalltalk.bind(smalltalk.Rectangle,"=","_eq"
,function (aRectangle){var self=this;return aRectangle.isRectangle().and_((function(){return self['@leftTop']._eq(aRectangle.leftTop()).and_((function(){return self['@rightBottom']._eq(aRectangle.rightBottom());}));}));;return self;}
,"testing",unescape("%3D%20aRectangle%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20equal%20to%20the%20aRectangle.%20%22%0D%0A%0D%0A%09%5EaRectangle%20isRectangle%0D%0A%09and%3A%20%5B%20leftTop%20%3D%20aRectangle%20leftTop%0D%0A%09and%3A%20%5B%20rightBottom%20%3D%20aRectangle%20rightBottom%20%5D%5D"));
smalltalk.bind(smalltalk.Rectangle,"area",0
,function (){var self=this;return self.height()._star(self.width());;return self;}
,"accessing",unescape("area%0D%0A%09%22%20Return%20the%20area%20of%20the%20receiver.%22%0D%0A%0D%0A%09%5Eself%20height%20*%20self%20width"));
smalltalk.bind(smalltalk.Rectangle,"areasOutside:",0
,function (aRectangle){var $s8Ret$={name:"stReturn"};try{var self=this;((self.intersects_(aRectangle)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Array.with_(self);})();throw($s8Ret$)})();})());
((aRectangle.containsPoint_(self.topLeft()).and_((function(){return aRectangle.containsPoint_(self.bottomRight());}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Array.with_with_with_with_(((aRectangle.top()._gt(self.top())).mustBeBoolean()==true ? (function(){return self.topLeft().rightBottom_(self.right()._at(aRectangle.top()));})() : nil), ((aRectangle.bottom()._lt(self.bottom())).mustBeBoolean()==true ? (function(){return self.left()._at(aRectangle.bottom()).rightBottom_(self.bottomRight());})() : nil), ((aRectangle.left()._gt(self.left())).mustBeBoolean()==true ? (function(){return self.left()._at(self.top().max_(aRectangle.top())).rightBottom_(aRectangle.left()._at(self.bottom().min_(aRectangle.bottom())));})() : nil), ((aRectangle.right()._lt(self.right())).mustBeBoolean()==true ? (function(){return aRectangle.right()._at(self.top().max_(aRectangle.top())).rightBottom_(self.right()._at(self.bottom().min_(aRectangle.bottom())));})() : nil)).select_((function(each){return (nil.isNil_(each)===false);}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("areasOutside%3A%20aRectangle%0D%0A%09%22Return%20a%20collection%20of%20rectangles%20where%20the%20receiver%20do%20not%20intersect%20aRectangle.%20%22%0D%0A%0D%0A%09%28self%20intersects%3A%20aRectangle%29%20ifFalse%3A%20%5B%20%5EArray%20with%3A%20self%20%5D.%0D%0A%09%28%28aRectangle%20containsPoint%3A%20self%20topLeft%29%0D%0A%09and%3A%20%5BaRectangle%20containsPoint%3A%20self%20bottomRight%5D%29%0D%0A%20%20%20%20%20%20%20%20ifTrue%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09%5E%28Array%0D%0A%09with%3A%20%28aRectangle%20top%20%3E%20self%20top%20ifTrue%3A%20%5B%20self%20topLeft%20rightBottom%3A%20self%20right%20@%20aRectangle%20top%5D%29%0D%0A%09with%3A%20%28aRectangle%20bottom%20%3C%20self%20bottom%20ifTrue%3A%20%5B%20self%20left%20@%20aRectangle%20bottom%20rightBottom%3A%20self%20bottomRight%5D%29%0D%0A%09with%3A%20%28aRectangle%20left%20%3E%20self%20left%20ifTrue%3A%20%5B%20self%20left%20@%20%28self%20top%20max%3A%20aRectangle%20top%29%20rightBottom%3A%20aRectangle%20left%20@%20%28self%20bottom%20min%3A%20aRectangle%20bottom%29%20%5D%29%0D%0A%09with%3A%20%28aRectangle%20right%20%3C%20self%20right%20ifTrue%3A%20%5B%20aRectangle%20right%20@%20%28self%20top%20max%3A%20aRectangle%20top%29%20rightBottom%3A%20self%20right%20@%20%28self%20bottom%20min%3A%20aRectangle%20bottom%29%20%5D%29%0D%0A%09%29%20select%3A%20%5B%3Aeach%7C%20each%20notNil%20%5D"));
smalltalk.bind(smalltalk.Rectangle,"bottom",0
,function (){var self=this;return self['@rightBottom'].y();;return self;}
,"accessing",unescape("bottom%0D%0A%09%22%20Return%20the%20bottom%20of%20the%20receiver.%22%0D%0A%0D%0A%09%5ErightBottom%20y"));
smalltalk.bind(smalltalk.Rectangle,"bottomCenter",0
,function (){var self=this;return self.center().x()._at(self.bottom());;return self;}
,"accessing",unescape("bottomCenter%0D%0A%09%22%20Return%20the%20center%20of%20the%20bottom%20edge%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20center%20x%20@%20self%20bottom"));
smalltalk.bind(smalltalk.Rectangle,"bottomLeft",0
,function (){var self=this;return self.left()._at(self.bottom());;return self;}
,"accessing",unescape("bottomLeft%0D%0A%09%22%20Return%20the%20bottom-left%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20left%20@%20self%20bottom"));
smalltalk.bind(smalltalk.Rectangle,"bottomRight",0
,function (){var self=this;return self['@rightBottom'];;return self;}
,"accessing",unescape("bottomRight%0D%0A%09%22%20Return%20the%20bottom-right%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ErightBottom"));
smalltalk.bind(smalltalk.Rectangle,"center",0
,function (){var self=this;return self['@leftTop']._plus(self['@rightBottom'])._slash_slash((2));;return self;}
,"accessing",unescape("center%0D%0A%09%22%20Return%20the%20center%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EleftTop%20+%20rightBottom%20//%202"));
smalltalk.bind(smalltalk.Rectangle,"centerTop",0
,function (){var self=this;return self.right()._plus(self.left())._slash_slash((2))._at(self.top());;return self;}
,"accessing",unescape("centerTop%0D%0A%09%22%20Return%20the%20center%20top%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20right%20+%20self%20left%20//%202%20@%20self%20top"));
smalltalk.bind(smalltalk.Rectangle,"contains:",0
,function (aRectangle){var self=this;return self.left()._lt_eq(aRectangle.left()).and_((function(){return aRectangle.right()._lt_eq(self.right()).and_((function(){return self.bottom()._gt_eq(aRectangle.bottom()).and_((function(){return aRectangle.top()._gt_eq(self.top());}));}));}));;return self;}
,"testing",unescape("contains%3A%20aRectangle%0D%0A%09%22%20Return%20true%20if%20aRectangle%20lies%20completely%20within%20or%20on%20the%20edge%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20left%20%3C%3D%20aRectangle%20left%0D%0A%09and%3A%20%5B%20aRectangle%20right%20%3C%3D%20self%20right%0D%0A%09and%3A%20%5B%20self%20bottom%20%3E%3D%20aRectangle%20bottom%0D%0A%09and%3A%20%5B%20aRectangle%20top%20%3E%3D%20self%20top%20%5D%5D%5D"));
smalltalk.bind(smalltalk.Rectangle,"containsPoint:",0
,function (aPoint){var self=this;return self.left()._lt_eq(aPoint.x()).and_((function(){return aPoint.x()._lt(self.right()).and_((function(){return self.bottom()._gt(aPoint.y()).and_((function(){return aPoint.y()._gt_eq(self.top());}));}));}));;return self;}
,"testing",unescape("containsPoint%3A%20aPoint%0D%0A%09%22%20Return%20true%20if%20aPoint%20is%20contained%20within%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28self%20left%20%3C%3D%20aPoint%20x%29%0D%0A%09and%3A%20%5B%20aPoint%20x%20%3C%20self%20right%0D%0A%09and%3A%20%5B%20self%20bottom%20%3E%20aPoint%20y%0D%0A%09and%3A%20%5B%20aPoint%20y%20%3E%3D%20self%20top%20%5D%5D%5D"));
smalltalk.bind(smalltalk.Rectangle,"expandBy:",0
,function (delta){var $s8Ret$={name:"stReturn"};try{var self=this;((delta.isRectangle()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@leftTop']._minus(delta.leftTop()).rightBottom_(self['@rightBottom']._plus(delta.rightBottom()));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@leftTop']._minus(delta).rightBottom_(self['@rightBottom']._plus(delta));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("expandBy%3A%20delta%0D%0A%09%22%20Return%20a%20Rectangle%20obtained%20from%20the%20receiver%20expanded%20by%20delta.%20%22%0D%0A%0D%0A%09delta%20isRectangle%20ifTrue%3A%20%5B%0D%0A%20%20%20%20%20%20%20%20%20%20%20%20%5EleftTop%20-%20delta%20leftTop%20rightBottom%3A%20rightBottom%20+%20delta%20rightBottom%0D%0A%09%5D.%0D%0A%09%5EleftTop%20-%20delta%20rightBottom%3A%20rightBottom%20+%20delta"));
smalltalk.bind(smalltalk.Rectangle,"extent",0
,function (){var self=this;return self.width()._at(self.height());;return self;}
,"accessing",unescape("extent%0D%0A%09%22%20Return%20receiver%27s%20width%20and%20height.%22%0D%0A%0D%0A%09%5Eself%20width%20@%20self%20height"));
smalltalk.bind(smalltalk.Rectangle,"extent:",0
,function (aPoint){var self=this;self.width_(aPoint.x());
self.height_(aPoint.y());return self;}
,"accessing",unescape("extent%3A%20aPoint%0D%0A%09%22%20Set%20the%20extent%20of%20receiver%20to%20aPoint.%20%22%0D%0A%0D%0A%09self%20width%3A%20aPoint%20x.%0D%0A%09self%20height%3A%20aPoint%20y"));
smalltalk.bind(smalltalk.Rectangle,"height",0
,function (){var self=this;return self['@leftTop'].y()._minus(self['@rightBottom'].y()).abs();;return self;}
,"accessing",unescape("height%0D%0A%09%22%20Return%20the%20height%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28leftTop%20y%20-%20rightBottom%20y%29%20abs"));
smalltalk.bind(smalltalk.Rectangle,"height:",0
,function (aNumber){var self=this;self['@rightBottom'].y_(self['@leftTop'].y()._plus(aNumber));return self;}
,"accessing",unescape("height%3A%20aNumber%0D%0A%09%22%20Change%20the%20height%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09rightBottom%20y%3A%20leftTop%20y%20+%20aNumber"));
smalltalk.bind(smalltalk.Rectangle,"insetBy:",0
,function (delta){var $s8Ret$={name:"stReturn"};try{var self=this;((delta.isRectangle()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@leftTop']._plus(delta.leftTop()).rightBottom_(self['@rightBottom']._minus(delta.rightBottom()));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@leftTop']._plus(delta).rightBottom_(self['@rightBottom']._minus(delta));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("insetBy%3A%20delta%0D%0A%09%22%20Return%20the%20receiver%20inset%20by%20delta.%20%22%0D%0A%0D%0A%09delta%20isRectangle%20ifTrue%3A%20%5B%0D%0A%20%20%20%20%20%20%20%20%20%20%20%20%5EleftTop%20+%20delta%20leftTop%20rightBottom%3A%20rightBottom%20-%20delta%20rightBottom%0D%0A%09%5D.%0D%0A%09%5EleftTop%20+%20delta%20rightBottom%3A%20rightBottom%20-%20delta"));
smalltalk.bind(smalltalk.Rectangle,"intersect:",0
,function (aRectangle){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(aRectangle))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@leftTop'].max_(aRectangle.leftTop()).rightBottom_(self['@rightBottom'].min_(aRectangle.rightBottom()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("intersect%3A%20aRectangle%0D%0A%09%22%20Return%20the%20rectangle%20in%20which%20the%20receiver%20and%20aRectangle%20overlap.%20%22%0D%0A%0D%0A%09aRectangle%20isNil%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%5E%28leftTop%20max%3A%20aRectangle%20leftTop%29%0D%0A%20%20%20%20%20%20%20%20rightBottom%3A%20%28rightBottom%20min%3A%20aRectangle%20rightBottom%29"));
smalltalk.bind(smalltalk.Rectangle,"intersects:",0
,function (aRectangle){var self=this;return self['@leftTop']._lt(aRectangle.rightBottom()).and_((function(){return aRectangle.leftTop()._lt(self['@rightBottom']);}));;return self;}
,"accessing",unescape("intersects%3A%20aRectangle%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20and%20aRectangle%20have%20any%20area%20in%20common.%20%22%0D%0A%0D%0A%09%5EleftTop%20%3C%20aRectangle%20rightBottom%0D%0A%09and%3A%20%5B%20aRectangle%20leftTop%20%3C%20rightBottom%20%5D"));
smalltalk.bind(smalltalk.Rectangle,"isRectangle",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isRectangle%0D%0A%09%22%20Return%20true%20if%20receiver%20is%20a%20Rectangle.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Rectangle,"left",0
,function (){var self=this;return self['@leftTop'].x();;return self;}
,"accessing",unescape("left%0D%0A%09%22%20Return%20the%20left%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EleftTop%20x"));
smalltalk.bind(smalltalk.Rectangle,"leftBottom",0
,function (){var self=this;return self.left()._at(self.bottom());;return self;}
,"accessing",unescape("leftBottom%0D%0A%09%22%20Return%20the%20left%20bottom%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20left%20@%20self%20bottom"));
smalltalk.bind(smalltalk.Rectangle,"leftCenter",0
,function (){var self=this;return self.left()._at(self.center().y());;return self;}
,"accessing",unescape("leftCenter%0D%0A%09%22%20Return%20the%20center%20of%20the%20left%20edge%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20left%20@%20self%20center%20y"));
smalltalk.bind(smalltalk.Rectangle,"leftTop",0
,function (){var self=this;return self['@leftTop'];;return self;}
,"accessing",unescape("leftTop%0D%0A%09%22%20Return%20the%20left%20top%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EleftTop"));
smalltalk.bind(smalltalk.Rectangle,"leftTop:",0
,function (aPoint){var self=this;self['@leftTop']=aPoint;return self;}
,"accessing",unescape("leftTop%3A%20aPoint%0D%0A%09%22%20Set%20the%20leftTop%20of%20the%20receiver.%22%0D%0A%0D%0A%09leftTop%20%3A%3D%20aPoint"));
smalltalk.bind(smalltalk.Rectangle,"leftTop:rightBottom:",0
,function (leftTopPoint,rightBottomPoint){var self=this;self['@leftTop']=leftTopPoint;
self['@rightBottom']=rightBottomPoint;return self;}
,"accessing",unescape("leftTop%3A%20leftTopPoint%20rightBottom%3A%20rightBottomPoint%0D%0A%09%22Set%20the%20receiver%27s%20coordinates.%20%22%0D%0A%0D%0A%09leftTop%20%3A%3D%20leftTopPoint.%0D%0A%09rightBottom%20%3A%3D%20rightBottomPoint."));
smalltalk.bind(smalltalk.Rectangle,"merge:",0
,function (aRectangle){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(aRectangle))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@leftTop'].min_(aRectangle.leftTop()).rightBottom_(self['@rightBottom'].max_(aRectangle.rightBottom()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("merge%3A%20aRectangle%0D%0A%09%22%20Return%20a%20Rectangle%20representing%20the%20area%20in%20which%20the%20receiver%20and%20aRectangle%20merged%20together.%20%22%0D%0A%0D%0A%09aRectangle%20isNil%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%5E%28leftTop%20min%3A%20aRectangle%20leftTop%29%20rightBottom%3A%20%28rightBottom%20max%3A%20aRectangle%20rightBottom%29"));
smalltalk.bind(smalltalk.Rectangle,"moveBy:",0
,function (aPoint){var self=this;self['@leftTop']=self['@leftTop']._plus(aPoint);
self['@rightBottom']=self['@rightBottom']._plus(aPoint);return self;}
,"accessing",unescape("moveBy%3A%20aPoint%0D%0A%09%22%20Move%20the%20receiver%20by%20aPoint.%20%22%0D%0A%0D%0A%09leftTop%20%3A%3D%20leftTop%20+%20aPoint.%0D%0A%09rightBottom%20%3A%3D%20rightBottom%20+%20aPoint"));
smalltalk.bind(smalltalk.Rectangle,"moveTo:",0
,function (aPoint){var self=this;self.moveBy_(aPoint._minus(self['@leftTop']));return self;}
,"accessing",unescape("moveTo%3A%20aPoint%0D%0A%09%22%20Move%20the%20receiver%20to%20aPoint.%20%22%0D%0A%0D%0A%09self%20moveBy%3A%20aPoint%20-%20leftTop"));
smalltalk.bind(smalltalk.Rectangle,"moveToLeftTop:",0
,function (aPoint){var self=this;self.moveBy_(aPoint._minus(self.leftTop()));return self;}
,"accessing",unescape("moveToLeftTop%3A%20aPoint%0D%0A%09%22%20Move%20the%20receiver%20to%20leftTop.%20%22%0D%0A%0D%0A%09self%20moveBy%3A%20aPoint%20-%20self%20leftTop"));
smalltalk.bind(smalltalk.Rectangle,"nonIntersections:",0
,function (aRectangle){var $s8Ret$={name:"stReturn"};try{var self=this;var areas=nil;((self.intersects_(aRectangle)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Array.with_(self);})();throw($s8Ret$)})();})());
((aRectangle.containsPoint_(self['@leftTop']).and_((function(){return aRectangle.containsPoint_(self['@rightBottom']);}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Array.with_with_with_with_(((aRectangle.top()._gt(self.top())).mustBeBoolean()==true ? (function(){return self['@leftTop'].rightBottom_(self['@rightBottom'].x()._at(aRectangle.top()));})() : nil), ((aRectangle.bottom()._lt(self.bottom())).mustBeBoolean()==true ? (function(){return self['@leftTop'].x()._at(aRectangle.bottom()).rightBottom_(self['@rightBottom']);})() : nil), ((aRectangle.left()._gt(self.left())).mustBeBoolean()==true ? (function(){return self['@leftTop'].x()._at(self['@leftTop'].y().max_(aRectangle.top())).rightBottom_(aRectangle.left()._at(self['@rightBottom'].y().min_(aRectangle.bottom())));})() : nil), ((aRectangle.right()._lt(self.right())).mustBeBoolean()==true ? (function(){return aRectangle.right()._at(self['@leftTop'].y().max_(aRectangle.top())).rightBottom_(self['@rightBottom'].x()._at(self['@rightBottom'].y().min_(aRectangle.bottom())));})() : nil)).select_((function(each){return (nil.isNil_(each)===false);}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("nonIntersections%3A%20aRectangle%0D%0A%09%22%20Return%20the%20rectangles%20describing%20areas%20of%20the%20receiver%20outside%20aRectangle.%20%22%0D%0A%0D%0A%09%7C%20areas%20%7C%0D%0A%09%28self%20intersects%3A%20aRectangle%29%20ifFalse%3A%20%5B%20%5EArray%20with%3A%20self%20%5D.%0D%0A%09%28%28aRectangle%20containsPoint%3A%20leftTop%29%0D%0A%09%09and%3A%20%5B%20aRectangle%20containsPoint%3A%20rightBottom%20%5D%29%0D%0A%09%09ifTrue%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09%5E%28Array%0D%0A%09with%3A%20%28aRectangle%20top%20%3E%20self%20top%20ifTrue%3A%20%5B%20leftTop%20rightBottom%3A%20rightBottom%20x%20@%20aRectangle%20top%20%5D%29%0D%0A%09with%3A%20%28aRectangle%20bottom%20%3C%20self%20bottom%20ifTrue%3A%20%5B%20leftTop%20x%20@%20aRectangle%20bottom%20rightBottom%3A%20rightBottom%20%5D%29%0D%0A%09with%3A%20%28aRectangle%20left%20%3E%20self%20left%20ifTrue%3A%20%5B%20leftTop%20x%20@%20%28leftTop%20y%20max%3A%20aRectangle%20top%29%0D%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20rightBottom%3A%20aRectangle%20left%20@%20%28rightBottom%20y%20min%3A%20aRectangle%20bottom%29%20%5D%29%0D%0A%09with%3A%20%28aRectangle%20right%20%3C%20self%20right%20ifTrue%3A%20%5B%20aRectangle%20right%20@%20%28leftTop%20y%20max%3A%20aRectangle%20top%29%0D%0A%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20%20rightBottom%3A%20rightBottom%20x%20@%20%28rightBottom%20y%20min%3A%20aRectangle%20bottom%29%20%5D%29%0D%0A%09%29%20select%3A%20%5B%3Aeach%7C%20each%20notNil%20%5D"));
smalltalk.bind(smalltalk.Rectangle,"toString",0
,function (){var self=this;return self['@leftTop'].toString()._comma(" to: ")._comma(self['@rightBottom'].toString());;return self;}
,"printing",unescape("toString%0D%0A%09%22%20Return%20the%20printable%20representation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EleftTop%20toString%20%2C%27%20to%3A%20%27%20%2CrightBottom%20toString"));
smalltalk.bind(smalltalk.Rectangle,"relativeTo:",0
,function (aRectangle){var $s8Ret$={name:"stReturn"};try{var self=this;var extent=nil;extent=aRectangle.extent();
((aRectangle.extent().x()._eq((0)).or_((function(){return aRectangle.extent().y()._eq((0));}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@leftTop']._minus(aRectangle.leftTop())._slash(extent).extent_(self.extent()._slash(extent));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("relativeTo%3A%20aRectangle%0D%0A%09%22%20Return%20a%20Rectangle%20proportionally%20relative%20to%20aRectangle.%20%22%0D%0A%0D%0A%09%7C%20extent%20%7C%0D%0A%09extent%20%3A%3D%20aRectangle%20extent.%0D%0A%09%28aRectangle%20extent%20x%20%3D%200%20or%3A%20%5B%20aRectangle%20extent%20y%20%3D%200%20%5D%29%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%5EleftTop%20-%20aRectangle%20leftTop%20/%20extent%20extent%3A%20self%20extent%20/%20extent"));
smalltalk.bind(smalltalk.Rectangle,"right",0
,function (){var self=this;return self['@rightBottom'].x();;return self;}
,"accessing",unescape("right%0D%0A%09%22%20Return%20the%20receiver%27s%20right%20side.%20%22%0D%0A%0D%0A%09%5ErightBottom%20x"));
smalltalk.bind(smalltalk.Rectangle,"rightBottom",0
,function (){var self=this;return self['@rightBottom'];;return self;}
,"accessing",unescape("rightBottom%0D%0A%09%22%20Return%20the%20right%20bottom%20corner.%20%22%0D%0A%0D%0A%09%5ErightBottom"));
smalltalk.bind(smalltalk.Rectangle,"rightBottom:",0
,function (aPoint){var self=this;self['@rightBottom']=aPoint;return self;}
,"accessing",unescape("rightBottom%3A%20aPoint%0D%0A%09%22%20Set%20the%20right%20bottom%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09rightBottom%20%3A%3D%20aPoint"));
smalltalk.bind(smalltalk.Rectangle,"rightCenter",0
,function (){var self=this;return self.right()._at(self.center().y());;return self;}
,"accessing",unescape("rightCenter%0D%0A%09%22%20Return%20the%20center%20of%20the%20right%20edge%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20right%20@%20self%20center%20y"));
smalltalk.bind(smalltalk.Rectangle,"rightTop",0
,function (){var self=this;return self.right()._at(self.top());;return self;}
,"accessing",unescape("rightTop%0D%0A%20%20%20%20%20%20%20%20%22%20Return%20the%20right%20top%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20right%20@%20self%20top"));
smalltalk.bind(smalltalk.Rectangle,"rounded",0
,function (){var self=this;self['@leftTop']=self['@leftTop'].rounded();
self['@rightBottom']=self['@rightBottom'].rounded();return self;}
,"accessing",unescape("rounded%0D%0A%09%22%20Set%20the%20receiver%20with%20coordinates%20rounded%20to%20integers.%20%22%0D%0A%0D%0A%09leftTop%20%3A%3D%20leftTop%20rounded.%0D%0A%09rightBottom%20%3A%3D%20rightBottom%20rounded."));
smalltalk.bind(smalltalk.Rectangle,"scaleBy:",0
,function (delta){var self=this;return self['@leftTop']._star(delta).rightBottom_(self['@rightBottom']._star(delta));;return self;}
,"accessing",unescape("scaleBy%3A%20delta%0D%0A%09%22%20Return%20the%20receiver%20multiplied%20by%20delta.%20%22%0D%0A%0D%0A%09%5EleftTop%20*%20delta%20rightBottom%3A%20rightBottom%20*%20delta"));
smalltalk.bind(smalltalk.Rectangle,"scaleTo:",0
,function (aRectangle){var self=this;return aRectangle.scaleBy_(self.extent()).truncated().moveBy_(self.leftTop());;return self;}
,"accessing",unescape("scaleTo%3A%20aRectangle%0D%0A%09%22%20Return%20a%20Rectangle%20whose%20size%20is%20proportional%20to%20the%20receiver%20with%20ratios%20specified%20by%20aRectangle.%20%22%0D%0A%0D%0A%09%5E%28aRectangle%20scaleBy%3A%20self%20extent%29%20truncated%20moveBy%3A%20self%20leftTop"));
smalltalk.bind(smalltalk.Rectangle,"top",0
,function (){var self=this;return self['@leftTop'].y();;return self;}
,"accessing",unescape("top%0D%0A%09%22%20Return%20the%20top%20side%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EleftTop%20y"));
smalltalk.bind(smalltalk.Rectangle,"topCenter",0
,function (){var self=this;return self.center().x()._at(self.top());;return self;}
,"accessing",unescape("topCenter%0D%0A%09%22%20Return%20the%20center%20of%20the%20top%20edge%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20center%20x%20@%20self%20top"));
smalltalk.bind(smalltalk.Rectangle,"topLeft",0
,function (){var self=this;return self['@leftTop'];;return self;}
,"accessing",unescape("topLeft%0D%0A%09%22%20Return%20the%20top-left%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EleftTop"));
smalltalk.bind(smalltalk.Rectangle,"topLeft:",0
,function (aPoint){var self=this;self['@leftTop']=aPoint;return self;}
,"accessing",unescape("topLeft%3A%20aPoint%0D%0A%09%22Set%20the%20top%20left%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09leftTop%20%3A%3D%20aPoint"));
smalltalk.bind(smalltalk.Rectangle,"topRight",0
,function (){var self=this;return self.right()._at(self.top());;return self;}
,"accessing",unescape("topRight%0D%0A%09%22%20Return%20the%20top-right%20corner%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20right%20@%20self%20top"));
smalltalk.bind(smalltalk.Rectangle,"translateBy:",0
,function (delta){var self=this;return self['@leftTop']._plus(delta).rightBottom_(self['@rightBottom']._plus(delta));;return self;}
,"accessing",unescape("translateBy%3A%20delta%0D%0A%09%22%20Return%20the%20receiver%20with%20position%20incremented%20by%20delta.%20%22%0D%0A%0D%0A%09%5EleftTop%20+%20delta%20rightBottom%3A%20rightBottom%20+%20delta"));
smalltalk.bind(smalltalk.Rectangle,"truncated",0
,function (){var self=this;self['@leftTop']=self['@leftTop'].truncated();
self['@rightBottom']=self['@rightBottom'].truncated();return self;}
,"accessing",unescape("truncated%0D%0A%09%22%20Set%20the%20receiver%20with%20the%20coordinates%20truncated%20to%20integers.%20%22%0D%0A%0D%0A%09leftTop%20%3A%3D%20leftTop%20truncated.%0D%0A%09rightBottom%20%3A%3D%20rightBottom%20truncated."));
smalltalk.bind(smalltalk.Rectangle,"width",0
,function (){var self=this;return self['@rightBottom'].x()._minus(self['@leftTop'].x()).abs();;return self;}
,"accessing",unescape("width%0D%0A%09%22%20Return%20the%20width%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28rightBottom%20x%20-%20leftTop%20x%29%20abs"));
smalltalk.bind(smalltalk.Rectangle,"width:",0
,function (anInteger){var self=this;self['@rightBottom'].x_(self['@leftTop'].x()._plus(anInteger));return self;}
,"accessing",unescape("width%3A%20anInteger%0D%0A%09%22%20Set%20the%20width%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09rightBottom%20x%3A%20leftTop%20x%20+%20anInteger"));
smalltalk.bind(smalltalk.EvaluableAction,",","_comma"
,function (anAction){var self=this;return smalltalk.ActionSequence.with_with_(self, anAction);;return self;}
,"composing",unescape("%2C%20anAction%0D%0A%09%22%20Return%20an%20action%20composed%20with%20the%20receiver%20and%20anAction.%20%22%0D%0A%0D%0A%09%5EActionSequence%20with%3A%20self%20with%3A%20anAction"));
smalltalk.bind(smalltalk.Message.$klass,"selector:arguments:",0
,function (aString,anArray){var self=this;return (function($rec){$rec.selector_(aString);$rec.arguments_(anArray);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("selector%3A%20aString%20arguments%3A%20anArray%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09selector%3A%20aString%3B%0D%0A%09%09arguments%3A%20anArray%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Message.$klass,"receiver:selector:arguments:",0
,function (anObject,aString,anArray){var self=this;return (function($rec){$rec.receiver_(anObject);$rec.selector_(aString);$rec.arguments_(anArray);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("receiver%3A%20anObject%20selector%3A%20aString%20arguments%3A%20anArray%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09receiver%3A%20anObject%3B%0D%0A%09%09selector%3A%20aString%3B%0D%0A%09%09arguments%3A%20anArray%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Message,"selector",0
,function (){var self=this;return self['@selector'];;return self;}
,"accessing",unescape("selector%0D%0A%09%22%20Return%20the%20selector%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eselector"));
smalltalk.bind(smalltalk.Message,"selector:",0
,function (aString){var self=this;self['@selector']=aString;return self;}
,"accessing",unescape("selector%3A%20aString%0D%0A%09%22%20Set%20the%20selector%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09selector%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.Message,"arguments:",0
,function (anArray){var self=this;self['@arguments']=anArray;return self;}
,"accessing",unescape("arguments%3A%20anArray%0D%0A%09%22%20Set%20the%20arguments%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09arguments%20%3A%3D%20anArray"));
smalltalk.bind(smalltalk.Message,"arguments",0
,function (){var self=this;return self['@arguments'];;return self;}
,"accessing",unescape("arguments%0D%0A%09%22%20Return%20the%20arguments%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Earguments"));
smalltalk.bind(smalltalk.Message,"receiver",0
,function (){var self=this;return self['@receiver'];;return self;}
,"accessing",unescape("receiver%0D%0A%09%22%20Return%20the%20receiver%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ereceiver"));
smalltalk.bind(smalltalk.Message,"receiver:",0
,function (anObject){var self=this;self['@receiver']=anObject;return self;}
,"accessing",unescape("receiver%3A%20anObject%0D%0A%09%22%20Set%20the%20receiver%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09receiver%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.Message,"comment",0
,function (){var self=this;return ((function(){var $1$=self[unescape("@comment")];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("comment%0D%0A%09%22%20Return%20the%20comment%20of%20the%20receiver%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27@comment%27"));
smalltalk.bind(smalltalk.Message,"comment:",0
,function (aString){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(aString))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.basicDelete_(unescape("@comment"));})();throw($s8Ret$)})();})() : nil);
(self[unescape("@comment")]=(aString));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("comment%3A%20aString%0D%0A%09%22%20Set%20the%20comment%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09aString%20isNil%20ifTrue%3A%20%5B%20%5Eself%20basicDelete%3A%20%27@comment%27%20%5D.%0D%0A%09self%20basicAt%3A%20%27@comment%27%20put%3A%20aString"));
smalltalk.bind(smalltalk.Message,"perform",0
,function (){var self=this;return self.receiver().perform_withArguments_(self.selector(), self.arguments());;return self;}
,"private",unescape("perform%0D%0A%09%22%20Return%20the%20result%20of%20sending%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20receiver%0D%0A%09%09perform%3A%20self%20selector%0D%0A%09%09withArguments%3A%20self%20arguments"));
smalltalk.bind(smalltalk.Message,"performDeferred",0
,function (){var self=this;(function(){return self.perform();}).valueDeferred();return self;}
,"evaluating",unescape("performDeferred%0D%0A%09%22%20Evaluate%20the%20receiver%20deferred%20in%20time.%0D%0A%09Return%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%5B%20self%20perform%20%5D%20valueDeferred."));
smalltalk.bind(smalltalk.Message,"evaluate",0
,function (){var self=this;return self.perform();;return self;}
,"evaluating",unescape("evaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20perform"));
smalltalk.bind(smalltalk.Message,"evaluateFor:",0
,function (anObject){var self=this;return self.evaluateWithArguments_(smalltalk.Array.with_(anObject));;return self;}
,"evaluating",unescape("evaluateFor%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20evaluateWithArguments%3A%20%28Array%20with%3A%20anObject%29"));
smalltalk.bind(smalltalk.Message,"evaluateWithArguments:",0
,function (anArray){var self=this;return self.receiver().perform_withArguments_(self.selector(), self.collectArguments_(anArray));;return self;}
,"evaluating",unescape("evaluateWithArguments%3A%20anArray%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20receiver%0D%0A%09%09perform%3A%20self%20selector%0D%0A%09%09withArguments%3A%20%28self%20collectArguments%3A%20anArray%29"));
smalltalk.bind(smalltalk.Message,"initializeArguments",0
,function (){var self=this;self['@arguments']=smalltalk.Array.new_(self.selector().argumentCount());return self;}
,"private",unescape("initializeArguments%0D%0A%09%22%20Private%20-%20Initialize%20the%20arguments%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09arguments%20%3A%3D%20Array%20new%3A%20self%20selector%20argumentCount"));
smalltalk.bind(smalltalk.Message,"argumentCount",0
,function (){var self=this;(((nil.isNil_(self['@arguments']))).mustBeBoolean()==true ? (function(){return self.initializeArguments();})() : nil);
return self['@arguments'].size();;return self;}
,"private",unescape("argumentCount%0D%0A%09%22%20Return%20the%20number%20of%20arguments%20required%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09arguments%20isNil%20ifTrue%3A%20%5B%20self%20initializeArguments%20%5D.%0D%0A%09%5Earguments%20size"));
smalltalk.bind(smalltalk.Message,"collectArguments:",0
,function (evaluationArguments){var $s8Ret$={name:"stReturn"};try{var self=this;((self['@arguments'].size()._eq(evaluationArguments.size())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return evaluationArguments;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return evaluationArguments.copyFrom_to_((1), self.argumentCount().min_(evaluationArguments.size()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("collectArguments%3A%20evaluationArguments%0D%0A%09%22%20Private%20-%20Return%20the%20arguments%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09arguments%20size%20%3D%20evaluationArguments%20size%20ifTrue%3A%20%5B%20%5EevaluationArguments%20%5D.%0D%0A%09%5EevaluationArguments%20copyFrom%3A%201%20to%3A%20%28self%20argumentCount%20min%3A%20evaluationArguments%20size%29"));
smalltalk.bind(smalltalk.Message,"isMessage",0
,function (){var self=this;return true;;return self;}
,"query",unescape("isMessage%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20message.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.LinkMessage,"resultAction",0
,function (){var self=this;return self['@resultAction'];;return self;}
,"accessing",unescape("resultAction%0D%0A%09%22%20Return%20the%20resultAction%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EresultAction"));
smalltalk.bind(smalltalk.LinkMessage,"resultAction:",0
,function (anObject){var self=this;self['@resultAction']=anObject;return self;}
,"accessing",unescape("resultAction%3A%20anObject%0D%0A%09%22%20Set%20the%20resultAction%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09resultAction%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.LinkMessage,"evaluate",0
,function (){var self=this;return self.evaluateWithArguments_([]);;return self;}
,"evaluating",unescape("evaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20evaluateWithArguments%3A%20%23%28%29"));
smalltalk.bind(smalltalk.LinkMessage,"collectArguments:",0
,function (evaluationArguments){var self=this;return self.arguments().collect_((function(each){return each.evaluateWithArguments_(evaluationArguments);}));;return self;}
,"evaluating",unescape("collectArguments%3A%20evaluationArguments%0D%0A%09%22%20Private%20-%20Return%20the%20arguments%20to%20evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20arguments%20collect%3A%20%5B%3Aeach%7C%20each%20evaluateWithArguments%3A%20evaluationArguments%20%5D"));
smalltalk.bind(smalltalk.ActionSequence.$klass,"withAll:",0
,function (aCollection){var self=this;return (function($rec){$rec.contents_(aCollection);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("withAll%3A%20aCollection%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09contents%3A%20aCollection%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.ActionSequence.$klass,"with:",0
,function (anObject){var self=this;return self.withAll_(smalltalk.Array.with_(anObject));;return self;}
,"instantiation",unescape("with%3A%20anObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20withAll%3A%20%28Array%20with%3A%20anObject%29"));
smalltalk.bind(smalltalk.ActionSequence.$klass,"with:with:",0
,function (anObject,bObject){var self=this;return self.withAll_(smalltalk.Array.with_with_(anObject, bObject));;return self;}
,"instantiation",unescape("with%3A%20anObject%20with%3A%20bObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20withAll%3A%20%28Array%20with%3A%20anObject%20with%3A%20bObject%29"));
smalltalk.bind(smalltalk.ActionSequence.$klass,"with:with:with:",0
,function (anObject,bObject,cObject){var self=this;return self.withAll_(smalltalk.Array.with_with_with_(anObject, bObject, cObject));;return self;}
,"instantiation",unescape("with%3A%20anObject%20with%3A%20bObject%20with%3A%20cObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20withAll%3A%20%28Array%20with%3A%20anObject%20with%3A%20bObject%20with%3A%20cObject%29"));
smalltalk.bind(smalltalk.ActionSequence,"contents:",0
,function (aCollection){var self=this;self['@contents']=aCollection;return self;}
,"private",unescape("contents%3A%20aCollection%0D%0A%09%22%20Private%20-%20Set%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09contents%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.ActionSequence,"contents",0
,function (){var self=this;(((nil.isNil_(self['@contents']))).mustBeBoolean()==true ? (function(){return self['@contents']=smalltalk.Array.$$new();})() : nil);
return self['@contents'];;return self;}
,"private",unescape("contents%0D%0A%09%22%20Private%20-%20Return%20the%20contents%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09contents%20isNil%20ifTrue%3A%20%5B%20contents%20%3A%3D%20Array%20new%20%5D.%0D%0A%09%5Econtents"));
smalltalk.bind(smalltalk.ActionSequence,"isEmpty",0
,function (){var self=this;return (nil.isNil_(self['@contents'])).or_((function(){return self['@contents'].isEmpty();}));;return self;}
,"testing",unescape("isEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20empty.%20%22%0D%0A%0D%0A%09%5Econtents%20isNil%20or%3A%20%5B%20contents%20isEmpty%20%5D"));
smalltalk.bind(smalltalk.ActionSequence,"notEmpty",0
,function (){var self=this;return (nil.isNil_(self['@contents'])===false).and_((function(){return self['@contents'].notEmpty();}));;return self;}
,"testing",unescape("notEmpty%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20not%20empty.%20%22%0D%0A%0D%0A%09%5Econtents%20notNil%20and%3A%20%5B%20contents%20notEmpty%20%5D"));
smalltalk.bind(smalltalk.ActionSequence,"asArray",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@contents'].asArray();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asArray%0D%0A%09%22Return%20an%20Array%20containing%20all%20the%20elements%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20isEmpty%20ifTrue%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09%5Econtents%20asArray"));
smalltalk.bind(smalltalk.ActionSequence,"asActionSequence",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asActionSequence%0D%0A%09%22%20Return%20an%20ActionSequence%20from%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.ActionSequence,",","_comma"
,function (anAction){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return anAction.asActionSequence();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.$klass.withAll_(self.contents()._comma(anAction.asActionSequence().contents()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("%2C%20anAction%0D%0A%09%22%20Return%20an%20action%20composed%20with%20the%20receiver%20and%20anAction.%20%22%0D%0A%0D%0A%09self%20isEmpty%20ifTrue%3A%20%5B%20%5EanAction%20asActionSequence%20%5D.%0D%0A%09%5Eself%20class%20withAll%3A%20self%20contents%20%2C%20anAction%20asActionSequence%20contents"));
smalltalk.bind(smalltalk.ActionSequence,"copyWith:",0
,function (anObject){var self=this;return self.$klass.withAll_(self.contents().copyWith_(anObject));;return self;}
,"converting",unescape("copyWith%3A%20anObject%0D%0A%09%22%20Return%20an%20action%20composed%20with%20the%20receiver%20and%20anObject.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28self%20contents%20copyWith%3A%20anObject%29"));
smalltalk.bind(smalltalk.ActionSequence,"do:",0
,function (aBlock){var self=this;return ((self.notEmpty()).mustBeBoolean()==true ? (function(){return self.contents().do_(aBlock);})() : nil);;return self;}
,"converting",unescape("do%3A%20aBlock%0D%0A%09%22%20Evaluate%20aBlock%20for%20each%20object%20in%20the%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%5Eself%20notEmpty%20ifTrue%3A%20%5B%20self%20contents%20do%3A%20aBlock%20%5D"));
smalltalk.bind(smalltalk.ActionSequence,"includes:",0
,function (anObject){var self=this;return self.notEmpty().and_((function(){return self.contents().includes_(anObject);}));;return self;}
,"testing",unescape("includes%3A%20anObject%0D%0A%09%22%20Return%20true%20if%20anObject%20is%20in%20receiver%27s%20contents.%20%22%0D%0A%0D%0A%09%5Eself%20notEmpty%20and%3A%20%5B%20self%20contents%20includes%3A%20anObject%20%5D"));
smalltalk.bind(smalltalk.ActionSequence,"select:",0
,function (aBlock){var self=this;return self.$klass.withAll_(self.asArray().select_(aBlock));;return self;}
,"enumerating",unescape("select%3A%20aBlock%0D%0A%09%22%20Return%20the%20a%20copy%20of%20the%20receiver%20with%20elements%20wich%20evaluates%20aBlock%20to%20true.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28self%20asArray%20select%3A%20aBlock%29"));
smalltalk.bind(smalltalk.ActionSequence,"reject:",0
,function (aBlock){var self=this;return self.$klass.withAll_(self.asArray().reject_(aBlock));;return self;}
,"enumerating",unescape("reject%3A%20aBlock%0D%0A%09%22%20Return%20the%20a%20copy%20of%20the%20receiver%20with%20elements%20wich%20evaluates%20aBlock%20to%20false.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28self%20asArray%20reject%3A%20aBlock%29"));
smalltalk.bind(smalltalk.ActionSequence,"evaluate",0
,function (){var self=this;var result=nil;self.do_((function(each){return result=each.evaluate();}));
return result;;return self;}
,"evaluating",unescape("evaluate%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20do%3A%20%5B%3Aeach%7C%20result%20%3A%3D%20each%20evaluate%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.ActionSequence,"evaluateWithArguments:",0
,function (anArray){var self=this;var result=nil;self.do_((function(each){return result=each.evaluateWithArguments_(anArray);}));
return result;;return self;}
,"evaluating",unescape("evaluateWithArguments%3A%20anArray%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20do%3A%20%5B%3Aeach%7C%20result%20%3A%3D%20each%20evaluateWithArguments%3A%20anArray%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.ActionSequence,"evaluateFor:",0
,function (anObject){var self=this;var result=nil;self.do_((function(each){return result=each.evaluateFor_(anObject);}));
return result;;return self;}
,"evaluating",unescape("evaluateFor%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20anObject.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20do%3A%20%5B%3Aeach%7C%20result%20%3A%3D%20each%20evaluateFor%3A%20anObject%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.ActionSequence,"reduced",0
,function (){var self=this;return ((self.notEmpty()).mustBeBoolean()==true ? (function(){return ((self['@contents'].size()._eq((1))).mustBeBoolean()==true ? (function(){return self['@contents'].first();})() : (function(){return self;})());})() : nil);;return self;}
,"events",unescape("reduced%0D%0A%09%22%20Return%20the%20receiver%20reduced%20to%20minimal%20evaluable%20expression.%20%22%0D%0A%0D%0A%09%5Eself%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09contents%20size%20%3D%201%0D%0A%09%09ifTrue%3A%20%5B%20contents%20first%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.ActionSequence,"evaluateWithSelector:withArguments:",0
,function (aSelector,array){var self=this;var result=nil;self.do_((function(each){return result=each.receiver().perform_withArguments_(aSelector, array);}));
return result;;return self;}
,"changes",unescape("evaluateWithSelector%3A%20aSelector%20withArguments%3A%20array%0D%0A%09%22%20Private%20-%20Return%20the%20result%20of%20evaluating%20the%20receiver%20with%20aSelector%20and%20arguments%20array.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20do%3A%20%5B%3Aeach%7C%20result%20%3A%3D%20each%20receiver%20perform%3A%20aSelector%20withArguments%3A%20array%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.EventManager.$klass,"eventsTriggered",0
,function (){var self=this;(((nil.isNil_(self['@eventsTriggered']))).mustBeBoolean()==true ? (function(){return self.initializeEventsTriggered();})() : nil);
return self['@eventsTriggered'];;return self;}
,"events",unescape("eventsTriggered%0D%0A%09%22%20Return%20all%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09eventsTriggered%20isNil%20ifTrue%3A%20%5B%20self%20initializeEventsTriggered%20%5D.%0D%0A%09%5EeventsTriggered"));
smalltalk.bind(smalltalk.EventManager.$klass,"eventsTriggered:",0
,function (aCollection){var self=this;self['@eventsTriggered']=aCollection;return self;}
,"events",unescape("eventsTriggered%3A%20aCollection%0D%0A%09%22%20Set%20all%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09eventsTriggered%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.EventManager.$klass,"initializeEventsTriggered",0
,function (){var self=this;self.eventsTriggered_(self.constructEventsTriggered());return self;}
,"events",unescape("initializeEventsTriggered%0D%0A%09%22%20Private%20-%20Initialize%20all%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20eventsTriggered%3A%20self%20constructEventsTriggered"));
smalltalk.bind(smalltalk.EventManager,"eventTable",0
,function (){var self=this;return (((nil.isNil_(self['@handlers']))).mustBeBoolean()==true ? (function(){return self.eventTableCreate();})() : (function(){return self['@handlers'];})());;return self;}
,"events",unescape("eventTable%0D%0A%09%22%20Private%20-%20Returns%20the%20mapping%20event%20names%20to%20actions%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ehandlers%20isNil%0D%0A%09%09ifTrue%3A%20%5B%20self%20eventTableCreate%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20handlers%20%5D"));
smalltalk.bind(smalltalk.EventManager,"eventTableForEdit",0
,function (){var self=this;(((nil.isNil_(self['@handlers']))).mustBeBoolean()==true ? (function(){return self['@handlers']=self.eventTableCreate();})() : nil);
return self['@handlers'];;return self;}
,"events",unescape("eventTableForEdit%0D%0A%09%22%20Private%20-%20Returns%20the%20mapping%20event%20names%20to%20actions%20of%20the%20receiver.%0D%0A%09Set%20the%20internal%20map%20if%20not%20present.%0D%0A%09%22%0D%0A%0D%0A%09handlers%20isNil%20ifTrue%3A%20%5B%20handlers%20%3A%3D%20self%20eventTableCreate%20%5D.%0D%0A%09%5Ehandlers"));
smalltalk.bind(smalltalk.EventManager,"releaseEventTable",0
,function (){var self=this;self['@handlers']=nil;return self;}
,"events",unescape("releaseEventTable%0D%0A%09%22%20Private%20-%20Release%20the%20event%20table.%20%22%0D%0A%0D%0A%09handlers%20%3A%3D%20nil"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visit:",0
,function (aNode){var self=this;aNode.accept_(self);return self;}
,"visiting",unescape("visit%3A%20aNode%0D%0A%09aNode%20accept%3A%20self"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"ignore:",0
,function (aNode){var self=this;return self;}
,"visiting",unescape("ignore%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitNode:",0
,function (aNode){var self=this;self.ignore_(aNode);return self;}
,"visiting",unescape("visitNode%3A%20aNode%0D%0A%09self%20ignore%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitMethodNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitMethodNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitSequenceNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitSequenceNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitBlockSequenceNode:",0
,function (aNode){var self=this;self.visitSequenceNode_(aNode);return self;}
,"visiting",unescape("visitBlockSequenceNode%3A%20aNode%0D%0A%09self%20visitSequenceNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitBlockNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitBlockNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitReturnNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitReturnNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitSendNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitSendNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitCascadeNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitCascadeNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitValueNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitValueNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitVariableNode:",0
,function (aNode){var self=this;self.ignore_(aNode);return self;}
,"visiting",unescape("visitVariableNode%3A%20aNode%0D%0A%09self%20ignore%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitAssignmentNode:",0
,function (aNode){var self=this;self.visitNode_(aNode);return self;}
,"visiting",unescape("visitAssignmentNode%3A%20aNode%0D%0A%09self%20visitNode%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNodeVisitor,"visitMacroAssignment:to:",0
,function (aVariableNode,anExpressionNode){var self=this;return false;;return self;}
,"visiting",unescape("visitMacroAssignment%3A%20aVariableNode%20to%3A%20anExpressionNode%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20generated%20code%20to%20a%20macro%20assignment%20to%20aVariableNode.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler.$klass,"evaluate:",0
,function (smalltalkExpression){var self=this;return self.$$new().evaluate_(smalltalkExpression);;return self;}
,"evaluation",unescape("evaluate%3A%20smalltalkExpression%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20smalltalk%20expression%20in%20a%20global%20context.%20%22%0D%0A%0D%0A%09%5Eself%20new%20evaluate%3A%20smalltalkExpression"));
smalltalk.bind(smalltalk.Compiler.$klass,"evaluate:in:to:",0
,function (expression,aClass,aReceiver){var self=this;return aClass.compiler().evaluate_in_to_(expression, aClass, aReceiver);;return self;}
,"evaluation",unescape("evaluate%3A%20expression%20in%3A%20aClass%20to%3A%20aReceiver%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20expression%20with%20aReceiver.%20%22%0D%0A%0D%0A%09%5EaClass%20compiler%20evaluate%3A%20expression%20in%3A%20aClass%20to%3A%20aReceiver"));
smalltalk.bind(smalltalk.Compiler.$klass,"evaluate:to:",0
,function (expression,aReceiver){var self=this;return self.evaluate_in_to_(expression, aReceiver.$klass, aReceiver);;return self;}
,"evaluation",unescape("evaluate%3A%20expression%20to%3A%20aReceiver%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20expression%20with%20aReceiver.%20%22%0D%0A%0D%0A%09%5Eself%20evaluate%3A%20expression%20in%3A%20aReceiver%20class%20to%3A%20aReceiver"));
smalltalk.bind(smalltalk.Compiler.$klass,"doIt:to:",0
,function (smalltalkExpression,aReceiver){var self=this;var result=nil;(function(){return result=(((nil.isNil_(aReceiver))).mustBeBoolean()==true ? (function(){return self.evaluate_(smalltalkExpression);})() : (function(){return self.evaluate_to_(smalltalkExpression, aReceiver);})());}).on_do_(smalltalk.Error, (function(error){((smalltalk.Smalltalk.isObject_(error).not().or_((function(){return error.isString();}))).mustBeBoolean()==true ? (function(){return result=error;})() : (function(){return result=error.$klass.name()._comma(": ")._comma(error.messageText().asString());})());return self.print_(unescape("//%20")._comma(result));}));
return result;;return self;}
,"evaluation",unescape("doIt%3A%20smalltalkExpression%20to%3A%20aReceiver%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20smalltalk%20expression%20in%20the%20context%20of%20aReceiver%20or%20a%20description%20of%20an%20error%20situation%20occurred%20evaluating%20the%20code.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09%5B%20result%20%3A%3D%20aReceiver%20isNil%0D%0A%09%09%09ifTrue%3A%20%20%5B%20self%20evaluate%3A%20smalltalkExpression%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20self%20evaluate%3A%20smalltalkExpression%20to%3A%20aReceiver%20%5D%0D%0A%09%5D%20on%3A%20Error%20do%3A%20%5B%3Aerror%7C%0D%0A%09%09%28%28Smalltalk%20isObject%3A%20error%29%20not%20or%3A%20%5B%20error%20isString%20%5D%29%0D%0A%09%09ifTrue%3A%20%5B%20result%20%3A%3D%20error%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20result%20%3A%3D%20error%20class%20name%2C%27%3A%20%27%2C%20error%20messageText%20asString%20%5D.%0D%0A%09%09self%20print%3A%20%27//%20%27%2C%20result%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Compiler.$klass,"doIt:",0
,function (smalltalkExpression){var self=this;return self.doIt_to_(smalltalkExpression, nil);;return self;}
,"evaluation",unescape("doIt%3A%20smalltalkExpression%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20smalltalk%20expression%20in%20the%20global%20context%20or%20a%20description%20of%20an%20error%20situation%20occurred%20evaluating%20the%20code.%20%22%0D%0A%0D%0A%09%5Eself%20doIt%3A%20smalltalkExpression%20to%3A%20nil"));
smalltalk.bind(smalltalk.Compiler.$klass,"for:",0
,function (aBehavior){var self=this;return (function($rec){$rec.currentClass_(aBehavior);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("for%3A%20aBehavior%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09currentClass%3A%20aBehavior%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Compiler.$klass,"smalltalkNameFor:",0
,function (aClass){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(aClass))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "undefined";})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return "smalltalk."._comma(((aClass.isMetaclass()).mustBeBoolean()==true ? (function(){return aClass.instanceClass().name()._comma(".$klass");})() : (function(){return aClass.name();})()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("smalltalkNameFor%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20the%20global%20name%20of%20aClass%20%28can%20be%20nil%29.%20%22%0D%0A%0D%0A%09aClass%20isNil%20ifTrue%3A%20%5B%20%5E%23undefined%20%5D.%0D%0A%09%5E%27smalltalk.%27%2C%20%28aClass%20isMetaclass%0D%0A%09%20%20%20%20ifTrue%3A%20%5B%20aClass%20instanceClass%20name%2C%20%27.%24klass%27%20%5D%0D%0A%09%20%20%20%20ifFalse%3A%20%5B%20aClass%20name%20%5D%29"));
smalltalk.bind(smalltalk.Compiler.$klass,"constructEventsTriggered",0
,function (){var self=this;return ["needsCookie:", "startVisit:", "endVisit:", "startMethod:", "enterMethod:", "endMethod:", "startFunction:with:", "startFunctionName:", "startFunctionBody:with:", "endFunction:", "aboutReturn:", "return:", "returned:early:", "aboutSend:", "send:", "aboutOperation:", "operation:", "aboutCascade:", "cascade:", "aboutToCompile:", "setTransformers:", "needsParser", "aboutToParse:", "aboutToRecompile:", "recompiled:", "startCompiling:", "endCompiling:", "needsOptimizationMap", "customizeOptimizations", "unknownVariable:", "acceptAssignmentTo:", "invalidAssignment:"]._comma(smalltalk.superImplementor(smalltalk.Compiler.$klass,'constructEventsTriggered').apply(self, []));;return self;}
,"events",unescape("constructEventsTriggered%0D%0A%09%22%20Private%20-%20Return%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%09%23needsCookie%3A%20%23startVisit%3A%20%23endVisit%3A%0D%0A%09%09%23startMethod%3A%20%23enterMethod%3A%20%23endMethod%3A%0D%0A%09%09%23startFunction%3Awith%3A%20%23startFunctionName%3A%20%23startFunctionBody%3Awith%3A%20%23endFunction%3A%0D%0A%09%09%23aboutReturn%3A%20%23return%3A%20%23returned%3Aearly%3A%0D%0A%09%09%23aboutSend%3A%20%23send%3A%0D%0A%09%09%23aboutOperation%3A%20%23operation%3A%0D%0A%09%09%23aboutCascade%3A%20%23cascade%3A%0D%0A%09%09%23aboutToCompile%3A%20%23setTransformers%3A%0D%0A%09%09%23needsParser%20%23aboutToParse%3A%0D%0A%09%09%23aboutToRecompile%3A%20%23recompiled%3A%0D%0A%09%09%23startCompiling%3A%20%23endCompiling%3A%0D%0A%09%09%23needsOptimizationMap%0D%0A%09%09%23customizeOptimizations%0D%0A%09%09%23unknownVariable%3A%0D%0A%09%09%23acceptAssignmentTo%3A%20%23invalidAssignment%3A%0D%0A%09%29%20%2Csuper%20constructEventsTriggered"));
smalltalk.bind(smalltalk.Compiler.$klass,"debugInfo:",0
,function (aMethod){var self=this;return aMethod.basicAt_ifAbsentPut_("$debugInfo", (function(){return self.debugInfo_forClass_(aMethod.source(), aMethod.classField());}));;return self;}
,"debug",unescape("debugInfo%3A%20aMethod%0D%0A%09%22%20Return%20the%20debug%20information%20of%20aMethod.%20%22%0D%0A%0D%0A%09%5EaMethod%20basicAt%3A%20%27%24debugInfo%27%20ifAbsentPut%3A%20%5B%0D%0A%09%09self%20debugInfo%3A%20aMethod%20source%20forClass%3A%20aMethod%20classField%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler.$klass,"getInfo:",0
,function (aString){var $s8Ret$={name:"stReturn"};try{var self=this;var stream=nil;var aClass=nil;var selector=nil;var source=nil;var aMethod=nil;stream=aString.stream();
aClass=stream.nextChunk().doIt();
selector=stream.nextChunk();
source=stream.nextChunk();
aMethod=aClass._gt_gt(selector);
(((nil.isNil_(aMethod)===false).and_((function(){return source.trimBlanks().isEmpty().or_((function(){return aMethod.source()._eq(source);}));}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.debugInfo_(aMethod);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.debugInfo_forClass_(source, aClass);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"debug",unescape("getInfo%3A%20aString%0D%0A%09%22%20Private%20-%20Return%20the%20information%20of%20compiling%20aString%20as%20a%20chunked%20spec.%20%22%0D%0A%0D%0A%09%7C%20stream%20aClass%20selector%20source%20aMethod%20%7C%0D%0A%09stream%20%3A%3D%20aString%20stream.%0D%0A%09aClass%20%3A%3D%20stream%20nextChunk%20doIt.%0D%0A%09selector%20%3A%3D%20stream%20nextChunk.%0D%0A%09source%20%3A%3D%20stream%20nextChunk.%0D%0A%09aMethod%20%3A%3D%20aClass%20%3E%3E%20selector.%0D%0A%09%28aMethod%20notNil%20and%3A%20%5B%20source%20trimBlanks%20isEmpty%20or%3A%20%5B%0D%0A%09%09aMethod%20source%20%3D%20source%20%5D%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20debugInfo%3A%20aMethod%0D%0A%09%5D.%0D%0A%09%5Eself%20debugInfo%3A%20source%20forClass%3A%20aClass"));
smalltalk.bind(smalltalk.Compiler.$klass,"debugInfoFrom:",0
,function (aString){var self=this;return self.debugInfoFromStream_(aString.stream());;return self;}
,"debug",unescape("debugInfoFrom%3A%20aString%0D%0A%09%22%20Private%20-%20Return%20the%20debug%20information%20decoding%20aString%20contents.%0D%0A%09Note%3A%20aString%20must%20be%20result%20of%20sending%20%23getInfo%3A%20to%20the%20receiver.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20debugInfoFromStream%3A%20aString%20stream"));
smalltalk.bind(smalltalk.Compiler.$klass,"debugInfoFromStream:",0
,function (aStream){var self=this;return smalltalk.Array.with_with_with_with_(aStream.nextChunk(), aStream.nextChunk(), aStream.nextChunk(), self.debugCookiesFrom_(aStream));;return self;}
,"private",unescape("debugInfoFromStream%3A%20aStream%0D%0A%09%22%20Private%20-%20Return%20the%20debug%20information%20encoded%20in%20aStream.%20%22%0D%0A%0D%0A%09%5EArray%09%22ref.%20%23debugInfo%3AforClass%3A%20%22%0D%0A%09%09with%3A%20aStream%20nextChunk%0D%0A%09%09with%3A%20aStream%20nextChunk%0D%0A%09%09with%3A%20aStream%20nextChunk%0D%0A%09%09with%3A%20%28self%20debugCookiesFrom%3A%20aStream%29"));
smalltalk.bind(smalltalk.Compiler.$klass,"debugCookiesFrom:",0
,function (aStream){var self=this;var result=nil;var cookie=nil;result=smalltalk.Array.$$new();
(function(){while(!(function(){return (function($rec){$rec.skipSeparators();return $rec.atEnd();})(aStream);})()){(function(){cookie=self.debugCookieFrom_(aStream);return (((nil.isNil_(cookie)===false)).mustBeBoolean()==true ? (function(){return result.add_(cookie);})() : nil);})()};return nil})();
return result;;return self;}
,"private",unescape("debugCookiesFrom%3A%20aStream%0D%0A%09%22%20Private%20-%20Return%20the%20debug%20cookies%20encoded%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20result%20cookie%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09%5B%20aStream%20skipSeparators%3B%20atEnd%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09cookie%20%3A%3D%20self%20debugCookieFrom%3A%20aStream.%0D%0A%09%09cookie%20notNil%20ifTrue%3A%20%5B%20result%20add%3A%20cookie%20%5D.%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Compiler.$klass,"debugCookieFrom:",0
,function (aStream){var self=this;var nextOffset=nil;nextOffset=(function(){return aStream.nextChunk().asNumber();});
return smalltalk.Array.with_with_with_with_(aStream.nextChunk(), nextOffset.value()._at(nextOffset.value()), nextOffset.value()._at(nextOffset.value()), aStream.nextChunk().asArrayOfSubstrings());;return self;}
,"private",unescape("debugCookieFrom%3A%20aStream%0D%0A%09%22%20Private%20-%20Return%20the%20next%20debug%20cookie%20encoded%20in%20aStream%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20nextOffset%20%7C%0D%0A%09nextOffset%20%3A%3D%20%5B%20aStream%20nextChunk%20asNumber%20%5D.%0D%0A%09%5EArray%09%22ref.%20%23debugInfo%3AforClass%3A%20%22%0D%0A%09%09with%3A%20aStream%20nextChunk%0D%0A%09%09with%3A%20nextOffset%20value%20@%20nextOffset%20value%0D%0A%09%09with%3A%20nextOffset%20value%20@%20nextOffset%20value%0D%0A%09%09with%3A%20aStream%20nextChunk%20asArrayOfSubstrings"));
smalltalk.bind(smalltalk.Compiler.$klass,"debugInfo:forClass:",0
,function (aString,aClass){var self=this;var compiler=nil;var output=nil;var cookies=nil;var aNode=nil;output="".stream();
cookies=[];
compiler=self.$$new();
(function($rec){$rec.when_do_("needsCookie:", (function(aNode){return cookies.add_(smalltalk.Array.with_with_(aNode, compiler.position()));}));return $rec.when_do_("endVisit:", (function(cookie){return cookie.add_(compiler.position());}));})(compiler);
(function($rec){$rec.nextChunkPut_(aClass.name());$rec.nextChunkPut_(aString);$rec.nextChunkPut_(compiler.compile_forClass_(aString, aClass));return $rec.yourself();})(output);
cookies.do_((function(tuple){aNode=tuple.first();(function($rec){$rec.nextChunkPut_(aNode.$klass.name());$rec.nextChunkPut_(aNode.start().asString());$rec.nextChunkPut_(aNode.end().asString());$rec.nextChunkPut_(tuple.second().asString());$rec.nextChunkPut_(tuple.third().asString());return $rec.yourself();})(output);aNode.bindings().do_((function(each){return output.nextPutAll_(" "._comma(each));}));return output.nextChunkPut_(" ");}));
return output.contents();;return self;}
,"debug",unescape("debugInfo%3A%20aString%20forClass%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20aString%20with%20information%20of%20compiling%20aString%20as%20a%20method%20implemented%20in%20aClass.%20%22%0D%0A%0D%0A%09%7C%20compiler%20output%20cookies%20aNode%20%7C%0D%0A%09output%20%3A%3D%20%27%27%20stream.%0D%0A%09cookies%20%3A%3D%20%23%28%29.%0D%0A%09compiler%20%3A%3D%20self%20new.%0D%0A%09compiler%0D%0A%09%09when%3A%20%23needsCookie%3A%20do%3A%20%5B%3AaNode%7C%20cookies%20add%3A%20%28Array%20with%3A%20aNode%20with%3A%20compiler%20position%29%20%5D%3B%0D%0A%09%09when%3A%20%23endVisit%3A%20do%3A%20%5B%3Acookie%7C%20cookie%20add%3A%20compiler%20position%20%5D.%0D%0A%09output%0D%0A%09%09nextChunkPut%3A%20aClass%20name%3B%0D%0A%09%09nextChunkPut%3A%20aString%3B%0D%0A%09%09nextChunkPut%3A%20%28compiler%20compile%3A%20aString%20forClass%3A%20aClass%29%3B%0D%0A%09%09yourself.%0D%0A%09cookies%20do%3A%20%5B%3Atuple%7C%0D%0A%09%09aNode%20%3A%3D%20tuple%20first.%0D%0A%09%09output%0D%0A%09%09%09nextChunkPut%3A%20aNode%20class%20name%3B%0D%0A%09%09%09nextChunkPut%3A%20aNode%20start%20asString%3B%0D%0A%09%09%09nextChunkPut%3A%20aNode%20end%20asString%3B%0D%0A%09%09%09nextChunkPut%3A%20tuple%20second%20asString%3B%0D%0A%09%09%09nextChunkPut%3A%20tuple%20third%20asString%3B%0D%0A%09%09%09yourself.%0D%0A%09%09aNode%20bindings%20do%3A%20%5B%3Aeach%7C%20output%20nextPutAll%3A%20%27%20%27%20%2Ceach%20%5D.%0D%0A%09%09output%09nextChunkPut%3A%20%27%20%27.%0D%0A%09%5D.%0D%0A%09%5Eoutput%20contents"));
smalltalk.bind(smalltalk.Compiler.$klass,"unknownVariable:in:",0
,function (aNode,aCompiler){var self=this;self.print_(unescape("//%3E%3E%3E%20Unknown%20variable%3A%20")._comma(aNode.value().asString()));
return self.error_("Missing reference "._comma(aNode.value()));;return self;}
,"unknown",unescape("unknownVariable%3A%20aNode%20in%3A%20aCompiler%0D%0A%09%22%20Private%20-%20aCompiler%20has%20found%20an%20unknown%20name%20reference.%0D%0A%09The%20default%20action%20will%20thrown%20an%20error%20%28stop%20compilation%29%2C%0D%0A%09%20this%20method%20can%20be%20refined/changed%20to%20silently%20ignore%20the%0D%0A%09%20unknown%20to%20let%20the%20compiler%20produce%20code%20to%20refer%20code%0D%0A%09%20in%20outer%20javascript%20contexts.%0D%0A%09%22%0D%0A%0D%0Aself%20print%3A%20%27//%3E%3E%3E%20Unknown%20variable%3A%20%27%20%2CaNode%20value%20asString.%0D%0A%09%5Eself%20error%3A%20%27Missing%20reference%20%27%2CaNode%20value"));
smalltalk.bind(smalltalk.Compiler,"visit:doing:",0
,function (aNode,aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var cookie=nil;var result=nil;cookie=self.triggerEvent_with_ifNotHandled_("needsCookie:", aNode, (function(){return (function(){$s8Ret$.result=(function(){return aBlock.evaluate();})();throw($s8Ret$)})();}));
self.triggerEvent_with_("startVisit:", cookie);
result=aBlock.evaluate();
self.triggerEvent_with_("endVisit:", cookie);
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visit%3A%20aNode%20doing%3A%20aBlock%0D%0A%09%7C%20cookie%20result%20%7C%0D%0A%09cookie%20%3A%3D%20self%0D%0A%09%09triggerEvent%3A%20%23needsCookie%3A%20with%3A%20aNode%0D%0A%09%09ifNotHandled%3A%20%5B%20%5EaBlock%20evaluate%20%5D.%0D%0A%09self%20triggerEvent%3A%20%23startVisit%3A%20with%3A%20cookie.%0D%0A%09result%20%3A%3D%20aBlock%20evaluate.%0D%0A%09self%20triggerEvent%3A%20%23endVisit%3A%20with%3A%20cookie.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Compiler,"visit:",0
,function (aNode){var self=this;return self.visit_doing_(aNode, (function(){return smalltalk.superImplementor(smalltalk.Compiler,'visit_').apply(self, [aNode]);}));;return self;}
,"visiting",unescape("visit%3A%20aNode%0D%0A%09%5Eself%20visit%3A%20aNode%20doing%3A%20%5B%20super%20visit%3A%20aNode%20%5D"));
smalltalk.bind(smalltalk.Compiler,"currentClass",0
,function (){var self=this;return self['@currentClass'];;return self;}
,"accessing",unescape("currentClass%0D%0A%09%22%20Return%20the%20current%20class%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EcurrentClass"));
smalltalk.bind(smalltalk.Compiler,"currentClass:",0
,function (aClass){var self=this;self['@currentClass']=aClass;return self;}
,"accessing",unescape("currentClass%3A%20aClass%0D%0A%09%22%20Set%20the%20current%20class%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09currentClass%20%3A%3D%20aClass"));
smalltalk.bind(smalltalk.Compiler,"transformers",0
,function (){var self=this;(((nil.isNil_(self['@transformers']))).mustBeBoolean()==true ? (function(){self['@transformers']=smalltalk.Array.$$new();return self.triggerEvent_with_("setTransformers:", self['@transformers']);})() : nil);
return self['@transformers'];;return self;}
,"accessing",unescape("transformers%0D%0A%09%22%20Return%20the%20node%20transformers%20installed%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09transformers%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09transformers%20%3A%3D%20Array%20new.%0D%0A%09%09self%20triggerEvent%3A%20%23setTransformers%3A%20with%3A%20transformers.%0D%0A%09%5D.%0D%0A%09%5Etransformers"));
smalltalk.bind(smalltalk.Compiler,"optimizationMap:",0
,function (aSpec){var self=this;self['@optimizationMap']=aSpec;return self;}
,"accessing",unescape("optimizationMap%3A%20aSpec%0D%0A%09%22%20Set%20the%20current%20optimizationMap%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09optimizationMap%20%3A%3D%20aSpec"));
smalltalk.bind(smalltalk.Compiler,"recompile:",0
,function (aClass){var self=this;self.triggerEvent_with_("aboutToRecompile:", aClass);
aClass.methodDictionary().do_((function(each){return self.compile_forClass_category_(each.source(), aClass, each.category());}));
self.triggerEvent_with_("recompiled:", aClass);
((aClass.isMetaclass()).mustBeBoolean()==true ? nil : (function(){return self.recompile_(aClass.$klass);})());return self;}
,"compiling",unescape("recompile%3A%20aClass%0D%0A%09%22%20Re-compile%20all%20the%20methods%20defined%20by%20aClass.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23aboutToRecompile%3A%20with%3A%20aClass.%0D%0A%09aClass%20methodDictionary%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09self%20compile%3A%20each%20source%20forClass%3A%20aClass%20category%3A%20each%20category%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23recompiled%3A%20with%3A%20aClass.%0D%0A%09aClass%20isMetaclass%20ifFalse%3A%20%5B%20self%20recompile%3A%20aClass%20class%20%5D."));
smalltalk.bind(smalltalk.Compiler,"compile:forClass:category:",0
,function (aString,aClass,category){var $s8Ret$={name:"stReturn"};try{var self=this;var method=nil;(((nil.isNil_(aString)).or_((function(){return aString.isEmpty();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
method=self.load_forClass_(aString, aClass);
method.category_(category);
aClass.addCompiledMethod_(method);
(function(){$s8Ret$.result=(function(){return method;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"compiling",unescape("compile%3A%20aString%20forClass%3A%20aClass%20category%3A%20category%0D%0A%09%22%20Return%20the%20compiled%20method%20result%20of%20installing%20a%20new%20method%20compiled%20from%20aString%20in%20aClass.%20%22%0D%0A%0D%0A%09%7C%20method%20%7C%0D%0A%09%28aString%20isNil%20or%3A%20%5B%20aString%20isEmpty%20%5D%29%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09method%20%3A%3D%20self%20load%3A%20aString%20forClass%3A%20aClass.%0D%0A%09method%20category%3A%20category.%0D%0A%09aClass%20addCompiledMethod%3A%20method.%0D%0A%09%5Emethod"));
smalltalk.bind(smalltalk.Compiler,"load:forClass:",0
,function (aString,aClass){var self=this;var jsSource=nil;jsSource=self.compile_forClass_(aString, aClass);
return self.eval_(jsSource);;return self;}
,"compiling",unescape("load%3A%20aString%20forClass%3A%20aClass%0D%0A%09%22%20Return%20the%20CompiledMethod%20result%20of%20compiling%20aString%20as%20a%20method%20implemented%20in%20aClass.%20%22%0D%0A%0D%0A%09%7C%20jsSource%20%7C%0D%0A%09jsSource%20%3A%3D%20self%20compile%3A%20aString%20forClass%3A%20aClass.%0D%0A%09%5Eself%20eval%3A%20jsSource"));
smalltalk.bind(smalltalk.Compiler,"compile:forClass:",0
,function (aString,aClass){var self=this;self.currentClass_(aClass);
return self.compile_(aString);;return self;}
,"compiling",unescape("compile%3A%20aString%20forClass%3A%20aClass%0D%0A%09%22%20Return%20the%20javascript%20code%20result%20of%20compiling%20aString%20as%20a%20method%20implemented%20in%20aClass.%20%22%0D%0A%0D%0A%09self%20currentClass%3A%20aClass.%0D%0A%09%5Eself%20compile%3A%20aString"));
smalltalk.bind(smalltalk.Compiler,"eval:",0
,function (jsExpression){var self=this;return smalltalk.Smalltalk.current().eval_(jsExpression);;return self;}
,"evaluation",unescape("eval%3A%20jsExpression%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20a%20javascript%20expression%20in%20global%20context.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20current%20eval%3A%20jsExpression"));
smalltalk.bind(smalltalk.Compiler,"eval:as:",0
,function (jsExpression,aState){var self=this;return smalltalk.Smalltalk.current().eval_as_(jsExpression, aState);;return self;}
,"evaluation",unescape("eval%3A%20jsExpression%20as%3A%20aState%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20a%20javascript%20expression%20in%20global%20context.%0D%0A%09The%20state%20of%20the%20system%20change%20to%20state%20while%20evaluating%20the%20expression.%0D%0A%09%22%0D%0A%0D%0A%09%5ESmalltalk%20current%20eval%3A%20jsExpression%20as%3A%20aState"));
smalltalk.bind(smalltalk.Compiler,"parseCode:",0
,function (aString){var self=this;var result=nil;self.triggerEvent_with_("aboutToParse:", aString);
result=self.parser().parse_(aString.readStream());
smalltalk.Smalltalk.gc();
return result;;return self;}
,"parsing",unescape("parseCode%3A%20aString%0D%0A%09%22%20Parse%20the%20S8%20code%20in%20aString.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20triggerEvent%3A%20%23aboutToParse%3A%20with%3A%20aString.%0D%0A%09result%20%3A%3D%20self%20parser%20parse%3A%20aString%20readStream.%0D%0A%09Smalltalk%20gc.%22%0D%0A%09%09Our%20parser%20generate%20a%20lot%20of%20garbage%2C%0D%0A%09%09it%20is%20a%20good%20time%20to%20collect.%0D%0A%09%09Apps%20like%20JSC%20based%20apps%20can%20crash%20reporting%0D%0A%09%09%20%27memory%20issues%27%20if%20we%20do%20not%20GC%20asap.%0D%0A%09%22%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Compiler,"compile:",0
,function (aString){var self=this;var aNode=nil;aNode=self.parseCode_(aString);
self.triggerEvent_with_("aboutToCompile:", aNode);
return self.compileNode_(aNode);;return self;}
,"private",unescape("compile%3A%20aString%0D%0A%09%22%20Private%20-%20Return%20the%20javascript%20code%20result%20of%20compiling%20aString%20for%20currentClass.%20%22%0D%0A%0D%0A%09%7C%20aNode%20%7C%0D%0A%09aNode%20%3A%3D%20self%20parseCode%3A%20aString.%0D%0A%09self%20triggerEvent%3A%20%23aboutToCompile%3A%20with%3A%20aNode.%0D%0A%09%5Eself%20compileNode%3A%20aNode"));
smalltalk.bind(smalltalk.Compiler,"initialize",0
,function (){var self=this;smalltalk.superImplementor(smalltalk.Compiler,'initialize').apply(self, []);
self['@unknownVariables']=[];
self['@tempVariables']=[];return self;}
,"initialize",unescape("initialize%0D%0A%09%22%20Private%20-%20Initialize%20the%20receiver.%20%22%0D%0A%0D%0A%09super%20initialize.%0D%0A%09unknownVariables%20%3A%3D%20%23%28%29.%0D%0A%09tempVariables%20%3A%3D%20%23%28%29"));
smalltalk.bind(smalltalk.Compiler,"smalltalkNameFor:",0
,function (aClass){var self=this;return self.$klass.smalltalkNameFor_(aClass);;return self;}
,"private",unescape("smalltalkNameFor%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20the%20global%20name%20of%20aClass%20%28can%20be%20nil%29.%20%22%0D%0A%0D%0A%09%5Eself%20class%20smalltalkNameFor%3A%20aClass"));
smalltalk.bind(smalltalk.Compiler,"parser",0
,function (){var self=this;return self.triggerEvent_ifNotHandled_("needsParser", (function(){return smalltalk.SmalltalkParser.$$new();}));;return self;}
,"private",unescape("parser%0D%0A%09%22%20Private%20-%20Return%20the%20parser%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%09triggerEvent%3A%20%23needsParser%0D%0A%09%09ifNotHandled%3A%20%5B%20SmalltalkParser%20new%20%5D"));
smalltalk.bind(smalltalk.Compiler,"stream",0
,function (){var self=this;return self['@stream'];;return self;}
,"accessing",unescape("stream%0D%0A%09%22%20Return%20the%20current%20stream%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Estream"));
smalltalk.bind(smalltalk.Compiler,"position",0
,function (){var self=this;return self['@stream'].position()._plus(self['@startOffset']);;return self;}
,"accessing",unescape("position%0D%0A%09%22%20Return%20the%20current%20position%20in%20output%20stream.%20%22%0D%0A%0D%0A%09%5Estream%20position%20+%20startOffset"));
smalltalk.bind(smalltalk.Compiler,"emmitedCode",0
,function (){var self=this;return (((nil.isNil_(self['@stream'])===false)).mustBeBoolean()==true ? (function(){return self['@stream'].contents();})() : nil);;return self;}
,"results",unescape("emmitedCode%0D%0A%09%22%20Return%20the%20emmited%20code%20during%20compilation%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Estream%20notNil%20ifTrue%3A%20%5B%20stream%20contents%20%5D"));
smalltalk.bind(smalltalk.Compiler,"startCompiling:",0
,function (aNode){var self=this;self['@stream']="".writeStream();
self['@startOffset']=self['@stream'].position();
self.triggerEvent_with_("startCompiling:", aNode);return self;}
,"private",unescape("startCompiling%3A%20aNode%0D%0A%09%22%20Private%20-%20Set%20the%20receiver%20to%20start%20emmiting%20code%20for%20aNode.%20%22%0D%0A%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09startOffset%20%3A%3D%20stream%20position.%0D%0A%09self%20triggerEvent%3A%20%23startCompiling%3A%20with%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"prepare:",0
,function (aNode){var self=this;self.transformers().do_((function(each){return each.visit_(aNode);}));return self;}
,"private",unescape("prepare%3A%20aNode%0D%0A%09%22%20Private%20-%20Apply%20tranformations/optimization%20to%20aNode.%20%22%0D%0A%0D%0A%09self%20transformers%20do%3A%20%5B%3Aeach%7C%20each%20visit%3A%20aNode%20%5D."));
smalltalk.bind(smalltalk.Compiler,"endCompiling:",0
,function (aNode){var self=this;self.triggerEvent_with_("endCompiling:", aNode);return self;}
,"private",unescape("endCompiling%3A%20aNode%0D%0A%09%22%20Private%20-%20Finish%20emmiting%20code%20for%20aNode.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23endCompiling%3A%20with%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"compileNode:",0
,function (aNode){var self=this;return (function($rec){$rec.startCompiling_(aNode);$rec.prepare_(aNode);$rec.visit_(aNode);$rec.endCompiling_(aNode);return $rec.emmitedCode();})(self);;return self;}
,"private",unescape("compileNode%3A%20aNode%0D%0A%09%22%20Private%20-%20Compile%20aNode.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09startCompiling%3A%20aNode%3B%0D%0A%09%09prepare%3A%20aNode%3B%0D%0A%09%09visit%3A%20aNode%3B%0D%0A%09%09endCompiling%3A%20aNode%3B%0D%0A%09%09emmitedCode"));
smalltalk.bind(smalltalk.Compiler,"localName:",0
,function (aName){var $s8Ret$={name:"stReturn"};try{var self=this;((self.pseudoVariables().includes_(aName)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aName;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return aName.asSelector();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("localName%3A%20aName%0D%0A%09%22%20Private%20-%20Return%20a%20valid%20%28javascript%29%20name%20for%20local%20name.%20%22%0D%0A%0D%0A%09%28self%20pseudoVariables%20includes%3A%20aName%29%20ifTrue%3A%20%5B%20%5EaName%20%5D.%0D%0A%09%5EaName%20asSelector"));
smalltalk.bind(smalltalk.Compiler,"visitLocalAssignment:",0
,function (aNode){var self=this;self['@stream'].nextPutAll_(unescape("%28"));
self.visit_(aNode);
self['@stream'].nextPutAll_(unescape("%29"));return self;}
,"visiting",unescape("visitLocalAssignment%3A%20aNode%0D%0A%09%22%20Private%20-%20Visit%20a%20node%20that%20is%20an%20assignment%20in%20a%20local%20expression.%20%22%0D%0A%0D%0A%09stream%20nextPutAll%3A%20%24%28.%0D%0A%09self%20visit%3A%20aNode.%0D%0A%09stream%20nextPutAll%3A%20%24%29."));
smalltalk.bind(smalltalk.Compiler,"visitArgument:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((aNode.isAssignment()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitLocalAssignment_(aNode);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.visit_(aNode);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitArgument%3A%20aNode%0D%0A%09%22%20Private%20-%20Visit%20the%20argument%20emmitting%20output.%20%22%0D%0A%0D%0A%09aNode%20isAssignment%20ifTrue%3A%20%5B%20%5Eself%20visitLocalAssignment%3A%20aNode.%20%5D.%0D%0A%09%5Eself%20visit%3A%20aNode"));
smalltalk.bind(smalltalk.Compiler,"visitReceiver:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((aNode.isAssignment()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitLocalAssignment_(aNode);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.visit_(aNode);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitReceiver%3A%20aNode%0D%0A%09%22%20Private%20-%20Visit%20the%20node%20%28as%20receiver%29%20emmitting%20output.%20%22%0D%0A%0D%0A%09aNode%20isAssignment%20ifTrue%3A%20%5B%20%5Eself%20visitLocalAssignment%3A%20aNode.%20%5D.%0D%0A%09%5Eself%20visit%3A%20aNode"));
smalltalk.bind(smalltalk.Compiler,"generatedCodeFor:while:",0
,function (aNode,aBlock){var self=this;var backup=nil;var result=nil;backup=smalltalk.Array.with_with_(self['@stream'], self['@startOffset']);
self['@startOffset']=self['@stream'].position();
self['@stream']="".writeStream();
self.visit_doing_(aNode, aBlock);
result=self['@stream'].contents();
self['@stream']=backup.first();
self['@startOffset']=backup.last();
return result;;return self;}
,"generation",unescape("generatedCodeFor%3A%20aNode%20while%3A%20aBlock%0D%0A%09%22%20Private%20-%20Return%20the%20code%20generated%20during%20evaluation%20of%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20backup%20result%20%7C%0D%0A%09backup%20%3A%3D%20Array%20with%3A%20stream%20with%3A%20startOffset.%0D%0A%09startOffset%20%3A%3D%20stream%20position.%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20visit%3A%20aNode%20doing%3A%20aBlock.%0D%0A%09result%20%3A%3D%20stream%20contents.%0D%0A%09stream%20%3A%3D%20backup%20first.%0D%0A%09startOffset%20%3A%3D%20backup%20last.%0D%0A%09%5Eresult%20"));
smalltalk.bind(smalltalk.Compiler,"emmitFunctionDoing:",0
,function (aBlock){var self=this;return self.emmitFunction_arguments_doing_("", "", aBlock);;return self;}
,"generation",unescape("emmitFunctionDoing%3A%20aBlock%0D%0A%09%22%20Private%20-%20Emmit%20function%20on%20receiver%27s%20code%20stream.%20%22%0D%0A%0D%0A%09%5Eself%20emmitFunction%3A%20%27%27%20arguments%3A%20%27%27%20doing%3A%20aBlock"));
smalltalk.bind(smalltalk.Compiler,"emmitFunction:arguments:doing:",0
,function (fName,argList,aBlock){var self=this;self.triggerEvent_withArguments_ifNotHandled_("startFunction:with:", smalltalk.Array.with_with_(fName, argList), (function(){self['@stream'].nextPutAll_("function");self.triggerEvent_with_("startFunctionName:", fName);return self['@stream'].nextPutAll_(unescape("%28")._comma(argList)._comma(unescape("%29")));}));
self['@stream'].nextPutAll_(unescape("%7B"));
self.triggerEvent_withArguments_("startFunctionBody:with:", smalltalk.Array.with_with_(fName, argList));
aBlock.evaluate();
self['@stream'].nextPutAll_(unescape("%7D"));
self.triggerEvent_with_("endFunction:", fName);return self;}
,"generation",unescape("emmitFunction%3A%20fName%20arguments%3A%20argList%20doing%3A%20aBlock%0D%0A%09%22%20Private%20-%20Emmit%20function%20on%20receiver%27s%20code%20stream.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09triggerEvent%3A%20%23startFunction%3Awith%3A%0D%0A%09%09withArguments%3A%20%28Array%20with%3A%20fName%20with%3A%20argList%29%0D%0A%09%09ifNotHandled%3A%20%5B%0D%0A%09%09%09stream%20nextPutAll%3A%20%27function%27.%0D%0A%09%09%09self%20triggerEvent%3A%20%23startFunctionName%3A%20with%3A%20fName.%0D%0A%09%09%09stream%20nextPutAll%3A%20%27%28%27%20%2CargList%20%2C%24%29%0D%0A%09%09%5D.%0D%0A%09stream%20nextPutAll%3A%20%24%7B.%0D%0A%09self%09triggerEvent%3A%20%23startFunctionBody%3Awith%3A%0D%0A%09%09withArguments%3A%20%28Array%20with%3A%20fName%20with%3A%20argList%29.%0D%0A%09aBlock%20evaluate.%0D%0A%09stream%20nextPutAll%3A%20%24%7D.%0D%0A%09self%20triggerEvent%3A%20%23endFunction%3A%20with%3A%20fName."));
smalltalk.bind(smalltalk.Compiler,"emmitFunction:node:arguments:doing:",0
,function (fName,aNode,argumentsArray,aBlock){var self=this;var args=nil;args="".writeStream();
argumentsArray.do_separatedBy_((function(each){self['@tempVariables'].add_(each);return args.nextPutAll_(self.localName_(each));}), (function(){return args.nextPutAll_(unescape("%2C"));}));
self.emmitFunction_arguments_doing_(fName, args.contents(), aBlock);return self;}
,"generation",unescape("emmitFunction%3A%20fName%20node%3A%20aNode%20arguments%3A%20argumentsArray%20doing%3A%20aBlock%0D%0A%09%22%20Private%20-%20Generate%20function%20for%20aNode.%20%22%0D%0A%0D%0A%09%7C%20args%20%7C%0D%0A%09args%20%3A%3D%20%27%27%20writeStream.%0D%0A%09argumentsArray%20do%3A%20%5B%3Aeach%20%7C%20%0D%0A%09%09tempVariables%20add%3A%20each.%0D%0A%09%09args%20nextPutAll%3A%20%28self%20localName%3A%20each%29%20%5D%0D%0A%09%20%20%20%20separatedBy%3A%20%5B%20args%20nextPutAll%3A%20%27%2C%27%20%5D.%0D%0A%09self%09emmitFunction%3A%20fName%0D%0A%09%09arguments%3A%20args%20contents%0D%0A%09%09doing%3A%20aBlock"));
smalltalk.bind(smalltalk.Compiler,"emmitFunction:node:doing:",0
,function (fName,aNode,aBlock){var self=this;return self.emmitFunction_node_arguments_doing_(fName, aNode, aNode.arguments(), aBlock);;return self;}
,"generation",unescape("emmitFunction%3A%20fName%20node%3A%20aNode%20doing%3A%20aBlock%0D%0A%09%22%20Private%20-%20Generate%20function%20for%20aNode.%20%22%0D%0A%0D%0A%09%5Eself%09emmitFunction%3A%20fName%0D%0A%09%09node%3A%20aNode%20arguments%3A%20aNode%20arguments%0D%0A%09%09doing%3A%20aBlock"));
smalltalk.bind(smalltalk.Compiler,"emmitEnterMethod:",0
,function (aNode){var self=this;self['@stream'].nextPutAll_(unescape("var%20self%3Dthis%3B"));return self;}
,"generation",unescape("emmitEnterMethod%3A%20aNode%0D%0A%09%22%20Private%20-%20Generate%20local%20definitions%20for%20aNode.%20%22%0D%0A%0D%0A%09stream%20nextPutAll%3A%20%27var%20self%3Dthis%3B%27"));
smalltalk.bind(smalltalk.Compiler,"emmitReturn:early:",0
,function (aBlockOrString,early){var self=this;self.triggerEvent_with_("aboutReturn:", aBlockOrString);
self['@stream'].nextPutAll_("return ");
self.triggerEvent_with_("return:", aBlockOrString);
((aBlockOrString.isString()).mustBeBoolean()==true ? (function(){return self['@stream'].nextPutAll_(aBlockOrString);})() : (function(){return aBlockOrString.evaluate();})());
(((nil.isNil_(aBlockOrString)===false)).mustBeBoolean()==true ? (function(){self.triggerEvent_withArguments_("returned:early:", smalltalk.Array.with_with_(aBlockOrString, early));return self['@stream'].nextPutAll_(unescape("%3B"));})() : nil);return self;}
,"generation",unescape("emmitReturn%3A%20aBlockOrString%20early%3A%20early%0D%0A%09%22%20Private%20-%20Generate%20return%20code.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23aboutReturn%3A%20with%3A%20aBlockOrString.%0D%0A%09stream%20nextPutAll%3A%20%27return%20%27.%0D%0A%09self%20triggerEvent%3A%20%23return%3A%20with%3A%20aBlockOrString.%0D%0A%09aBlockOrString%20isString%0D%0A%09%09ifTrue%3A%20%5B%20stream%20nextPutAll%3A%20aBlockOrString%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20aBlockOrString%20evaluate%20%5D.%0D%0A%09aBlockOrString%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09self%09triggerEvent%3A%20%23returned%3Aearly%3A%0D%0A%09%09%09withArguments%3A%20%28Array%20with%3A%20aBlockOrString%20with%3A%20early%29.%0D%0A%09%09stream%20nextPutAll%3A%20%24%3B.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"emmitReturn:",0
,function (aBlockOrString){var self=this;return self.emmitReturn_early_(aBlockOrString, false);;return self;}
,"generation",unescape("emmitReturn%3A%20aBlockOrString%0D%0A%09%22%20Private%20-%20Generate%20return%20code.%20%22%0D%0A%0D%0A%09%5Eself%20emmitReturn%3A%20aBlockOrString%20early%3A%20false"));
smalltalk.bind(smalltalk.Compiler,"emmitMethod:",0
,function (aNode){var self=this;var code=nil;self['@functionName']=aNode.selector().asSelector();
self.emmitFunction_node_doing_(self['@functionName'], aNode, (function(){self.triggerEvent_with_("startMethod:", aNode);code=self.generatedCodeFor_while_(aNode, (function(){self.triggerEvent_withArguments_ifNotHandled_("enterMethod:", smalltalk.Array.with_(aNode), (function(){return self.emmitEnterMethod_(aNode);}));aNode.nodes().do_((function(each){return self.visit_(each);}));return self.emmitReturn_("self");}));self.generate_early_return_(self['@functionName'], self['@earlyReturn'], code);return self.triggerEvent_with_("endMethod:", aNode);}));return self;}
,"generation",unescape("emmitMethod%3A%20aNode%0D%0A%09%22%20Private%20-%20Generate%20code%20of%20method%20aNode.%20%22%0D%0A%0D%0A%09%7C%20code%20%7C%0D%0A%09functionName%20%3A%3D%20aNode%20selector%20asSelector.%0D%0A%09self%20emmitFunction%3A%20functionName%20node%3A%20aNode%20doing%3A%20%5B%0D%0A%09%09self%20triggerEvent%3A%20%23startMethod%3A%20with%3A%20aNode.%0D%0A%09%09code%20%3A%3D%20self%20generatedCodeFor%3A%20aNode%20while%3A%20%5B%0D%0A%09%09%09self%09triggerEvent%3A%20%23enterMethod%3A%20withArguments%3A%20%28Array%20with%3A%20aNode%29%0D%0A%09%09%09%09ifNotHandled%3A%20%5B%09self%20emmitEnterMethod%3A%20aNode%20%5D.%0D%0A%09%09%09aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%20self%20visit%3A%20each%20%5D.%0D%0A%09%09%09self%20emmitReturn%3A%20%23self.%0D%0A%09%09%5D.%0D%0A%09%09self%20generate%3A%20functionName%20early%3A%20earlyReturn%20return%3A%20code.%0D%0A%09%09self%20triggerEvent%3A%20%23endMethod%3A%20with%3A%20aNode.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"includeSourceCode",0
,function (){var self=this;return true;;return self;}
,"generation",unescape("includeSourceCode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20source%20code%20is%20included%20as%20method%20argument.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Compiler,"newMethodFunctionName",0
,function (){var self=this;return "smalltalk.newMethod";;return self;}
,"generation",unescape("newMethodFunctionName%0D%0A%09%22%20Private%20-%20Return%20the%20function%20to%20call%20when%20installing%20a%20new%20method.%20%22%0D%0A%0D%0A%09%5E%27smalltalk.newMethod%27"));
smalltalk.bind(smalltalk.Compiler,"generate:early:return:",0
,function (fName,early,code){var $s8Ret$={name:"stReturn"};try{var self=this;((early).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self['@stream'].nextPutAll_(code);})();throw($s8Ret$)})();})());
(function($rec){$rec.nextPutAll_(unescape("var%20%24s8Ret%24%3D%7Bname%3A%22stReturn%22%7D%3Btry%7B"));return $rec.nextPutAll_(code);})(self['@stream']);
self['@stream'].nextPutAll_(unescape("%7D%20catch%28%24%24ex%29%20%7Bif%28%24%24ex%20%3D%3D%3D%20%24s8Ret%24%29%7B"));
self.emmitReturn_early_("$$ex.result", true);
self['@stream'].nextPutAll_(unescape("%7D%20throw%28%24%24ex%29%3B%7D"));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"generation",unescape("generate%3A%20fName%20early%3A%20early%20return%3A%20code%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20catch%20early%20return%20of%20code%20expression%20in%20fName.%20%22%0D%0A%0D%0A%09early%20ifFalse%3A%20%5B%20%5Estream%20nextPutAll%3A%20code%20%5D.%0D%0A%09stream%20nextPutAll%3A%20%27var%20%24s8Ret%24%3D%7Bname%3A%22stReturn%22%7D%3Btry%7B%27%3B%20nextPutAll%3A%20code.%0D%0A%09stream%20nextPutAll%3A%20%27%7D%20catch%28%24%24ex%29%20%7Bif%28%24%24ex%20%3D%3D%3D%20%24s8Ret%24%29%7B%27.%0D%0A%09self%20emmitReturn%3A%20%27%24%24ex.result%27%20early%3A%20true.%0D%0A%09stream%20nextPutAll%3A%20%27%7D%20throw%28%24%24ex%29%3B%7D%27"));
smalltalk.bind(smalltalk.Compiler,"visitReturnNode:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;var theReturn=nil;((self['@nestedBlocks']._gt((0))).mustBeBoolean()==true ? (function(){return self['@earlyReturn']=true;})() : nil);
theReturn=(function(){return self.emmitReturn_((function(){return aNode.nodes().do_((function(each){return self.visit_(each);}));}));});
((self['@earlyReturn']).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return theReturn.value();})();throw($s8Ret$)})();})());
self['@stream'].nextPutAll_(unescape("%28"));
self.emmitFunctionDoing_((function(){self['@stream'].nextPutAll_(unescape("%24s8Ret%24.result%3D%28"));self.emmitFunctionDoing_(theReturn);return self['@stream'].nextPutAll_(unescape("%29%28%29%3Bthrow%28%24s8Ret%24%29"));}));
self['@stream'].nextPutAll_(unescape("%29%28%29"));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitReturnNode%3A%20aNode%0D%0A%0D%0A%09%7C%20theReturn%20%7C%0D%0A%09nestedBlocks%20%3E%200%20ifTrue%3A%20%5B%20earlyReturn%20%3A%3D%20true%20%5D.%0D%0A%09theReturn%20%3A%3D%20%5B%0D%0A%09%09self%20emmitReturn%3A%20%5B%0D%0A%09%09%09aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%20self%20visit%3A%20each%20%5D%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09earlyReturn%20ifFalse%3A%20%5B%20%5EtheReturn%20value%20%5D.%0D%0A%09stream%20nextPutAll%3A%20%24%28.%0D%0A%09self%20emmitFunctionDoing%3A%20%5B%0D%0A%09%09stream%20nextPutAll%3A%20%27%24s8Ret%24.result%3D%28%27.%0D%0A%09%09self%20emmitFunctionDoing%3A%20theReturn.%0D%0A%09%09stream%20nextPutAll%3A%20%27%29%28%29%3Bthrow%28%24s8Ret%24%29%27%0D%0A%09%5D.%0D%0A%09stream%20nextPutAll%3A%20%27%29%28%29%27."));
smalltalk.bind(smalltalk.Compiler,"visitMethodNode:",0
,function (aNode){var self=this;self['@nestedBlocks']=(0);
self['@earlyReturn']=false;
self['@unknownVariables']=[];
self['@tempVariables']=[];
(function($rec){$rec.nextPutAll_(self.newMethodFunctionName()._comma(unescape("%28")));$rec.nextPutAll_(self.smalltalkNameFor_(self['@currentClass']));$rec.nextPutAll_(unescape("%2C%22")._comma(aNode.selector())._comma(unescape("%22%2C")));return $rec.cr();})(self['@stream']);
self.emmitMethod_(aNode);
((self.includeSourceCode()).mustBeBoolean()==true ? (function(){return (function($rec){$rec.cr();return $rec.nextPutAll_(unescape("%2C")._comma(aNode.source().escapedCode()));})(self['@stream']);})() : nil);
self['@stream'].nextPutAll_(unescape("%29"));return self;}
,"visiting",unescape("visitMethodNode%3A%20aNode%0D%0A%09nestedBlocks%20%3A%3D%200.%0D%0A%09earlyReturn%20%3A%3D%20false.%0D%0A%09unknownVariables%20%3A%3D%20%23%28%29.%0D%0A%09tempVariables%20%3A%3D%20%23%28%29.%0D%0A%09stream%20%0D%0A%09%09nextPutAll%3A%20self%20newMethodFunctionName%2C%20%27%28%27%3B%0D%0A%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20currentClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27%2C%22%27%2C%20aNode%20selector%2C%20%27%22%2C%27%3B%20cr.%0D%0A%09self%20emmitMethod%3A%20aNode.%0D%0A%09self%20includeSourceCode%20ifTrue%3A%20%5B%0D%0A%09%09stream%09cr%3B%20%22warning%3A%20this%20cr%20is%20important%20for%20debugger%22%0D%0A%09%09%09nextPutAll%3A%20%27%2C%27%20%2CaNode%20source%20escapedCode%0D%0A%09%5D.%0D%0A%09stream%20nextPutAll%3A%20%27%29%27"));
smalltalk.bind(smalltalk.Compiler,"visitBlockNode:",0
,function (aNode){var self=this;self['@stream'].nextPutAll_(unescape("%28"));
self.emmitFunction_node_arguments_doing_("", aNode, aNode.parameters(), (function(){return aNode.nodes().do_((function(each){return self.visit_(each);}));}));
self['@stream'].nextPutAll_(unescape("%29"));return self;}
,"visiting",unescape("visitBlockNode%3A%20aNode%0D%0A%09stream%20nextPutAll%3A%20%24%28.%0D%0A%09self%09emmitFunction%3A%20%27%27%20node%3A%20aNode%0D%0A%09%09arguments%3A%20aNode%20parameters%0D%0A%09%09doing%3A%20%5B%20aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%20self%20visit%3A%20each%20%5D%20%5D.%0D%0A%09stream%20nextPutAll%3A%20%24%29."));
smalltalk.bind(smalltalk.Compiler,"visitSequenceNode:",0
,function (aNode){var self=this;aNode.temps().do_((function(each){self['@tempVariables'].add_(each);return self['@stream'].nextPutAll_("var "._comma(self.localName_(each))._comma(unescape("%3Dnil%3B")));}));
aNode.nodes().do_separatedBy_((function(each){self.visit_(each);return self['@stream'].nextPutAll_(unescape("%3B"));}), (function(){return self['@stream'].cr();}));return self;}
,"visiting",unescape("visitSequenceNode%3A%20aNode%0D%0A%09aNode%20temps%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09tempVariables%20add%3A%20each.%0D%0A%09%09stream%20nextPutAll%3A%20%27var%20%27%2C%20%28self%20localName%3A%20each%29%2C%20%27%3Dnil%3B%27%0D%0A%09%5D.%0D%0A%09aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09self%20visit%3A%20each.%0D%0A%09%09stream%20nextPutAll%3A%20%27%3B%27%0D%0A%09%5D%20separatedBy%3A%20%5Bstream%20cr%5D"));
smalltalk.bind(smalltalk.Compiler,"visitExtendedSequenceNode:",0
,function (aNode){var self=this;(((nil.isNil_(aNode.directive())===false)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextPutAll_(aNode.directive().asJavascript_for_on_(self['@functionName'], self, self['@stream']));return $rec.cr();})(self['@stream']);})() : nil);
return self.visitSequenceNode_(aNode);;return self;}
,"visiting",unescape("visitExtendedSequenceNode%3A%20aNode%0D%0A%09%22%20Private%20-%20Visit%20a%20directive%20node.%20%22%0D%0A%0D%0A%09aNode%20directive%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09stream%20nextPutAll%3A%20%28aNode%20directive%0D%0A%09%09%09asJavascript%3A%20functionName%0D%0A%09%09%09for%3A%20self%20on%3A%20stream%29%3B%20cr.%0D%0A%09%5D.%0D%0A%09%5Eself%20visitSequenceNode%3A%20aNode"));
smalltalk.bind(smalltalk.Compiler,"visitBlockSequenceNode:",0
,function (aNode){var self=this;var index=nil;self['@nestedBlocks']=self['@nestedBlocks']._plus((1));
((aNode.nodes().isEmpty()).mustBeBoolean()==true ? (function(){return self.emmitReturn_("nil");})() : (function(){aNode.temps().do_((function(each){self['@tempVariables'].add_(each);return self['@stream'].nextPutAll_("var "._comma(self.localName_(each))._comma(unescape("%3Dnil%3B")));}));index=(0);return aNode.nodes().do_((function(each){index=index._plus((1));return ((index._eq(aNode.nodes().size())).mustBeBoolean()==true ? (function(){return self.emmitReturn_((function(){return self.visit_(each);}));})() : (function(){self.visit_(each);return self['@stream'].nextPutAll_(unescape("%3B"));})());}));})());
self['@nestedBlocks']=self['@nestedBlocks']._minus((1));return self;}
,"visiting",unescape("visitBlockSequenceNode%3A%20aNode%0D%0A%09%7C%20index%20%7C%0D%0A%09nestedBlocks%20%3A%3D%20nestedBlocks%20+%201.%0D%0A%09aNode%20nodes%20isEmpty%0D%0A%09%20%20%20%20ifTrue%3A%20%5B%20self%20emmitReturn%3A%20%23nil%20%5D%0D%0A%09%20%20%20%20ifFalse%3A%20%5B%0D%0A%09%09aNode%20temps%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09%20%20%20%20tempVariables%20add%3A%20each.%0D%0A%09%09%20%20%20%20stream%20nextPutAll%3A%20%27var%20%27%2C%20%28self%20localName%3A%20each%29%2C%20%27%3Dnil%3B%27%0D%0A%09%09%5D.%0D%0A%09%09index%20%3A%3D%200.%0D%0A%09%09aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09%20%20%20%20index%20%3A%3D%20index%20+%201.%0D%0A%09%09%20%20%20%20index%20%3D%20aNode%20nodes%20size%0D%0A%09%09%09ifTrue%3A%20%5B%20self%20emmitReturn%3A%20%5B%20self%20visit%3A%20each%20%5D%20%5D%0D%0A%09%09%20%20%20%20%09ifFalse%3A%20%5B%20self%20visit%3A%20each.%20stream%20nextPutAll%3A%20%24%3B%20%5D%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09nestedBlocks%20%3A%3D%20nestedBlocks%20-%201"));
smalltalk.bind(smalltalk.Compiler,"visitGlobalReferenceNode:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;var aName=nil;var aClass=nil;var lookupPools=nil;aName=aNode.value();
aClass=self.currentClass().instanceClass();
aClass.classVariableNamesDo_((function(each){return ((each._eq(aName)).mustBeBoolean()==true ? (function(){(function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass));$rec.nextPutAll_(unescape(".classVariableAt_%28%22"));$rec.nextPutAll_(aName);return $rec.nextPutAll_(unescape("%22%29"));})(self['@stream']);return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);}));
aClass.sharedPoolsAndNamesDo_((function(poolName,pool){return ((pool.includesKey_(aName)).mustBeBoolean()==true ? (function(){(function($rec){$rec.nextPutAll_(unescape("smalltalk.poolDictionary_%28%22"));$rec.nextPutAll_(poolName);$rec.nextPutAll_(unescape("%22%29.at_%28%22"));$rec.nextPutAll_(aName);return $rec.nextPutAll_(unescape("%22%29"));})(self['@stream']);return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);}));
(function($rec){$rec.nextPutAll_("smalltalk.");return $rec.nextPutAll_(aNode.value());})(self['@stream']);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitGlobalReferenceNode%3A%20aNode%0D%0A%0D%0A%09%7C%20aName%20aClass%20lookupPools%20%7C%0D%0A%09aName%20%3A%3D%20aNode%20value.%0D%0A%09aClass%20%3A%3D%20self%20currentClass%20instanceClass.%0D%0A%09aClass%20classVariableNamesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20%3D%20aName%20ifTrue%3A%20%5B%0D%0A%09%09%09stream%0D%0A%09%09%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%29%3B%0D%0A%09%09%09%09nextPutAll%3A%20%27.classVariableAt_%28%22%27%3B%0D%0A%09%09%09%09nextPutAll%3A%20aName%3B%0D%0A%09%09%09%09nextPutAll%3A%20%27%22%29%27.%0D%0A%09%09%09%5Eself%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09aClass%20sharedPoolsAndNamesDo%3A%20%5B%3ApoolName%20%3Apool%7C%0D%0A%09%09%28pool%20includesKey%3A%20aName%29%20ifTrue%3A%20%5B%0D%0A%09%09%09stream%0D%0A%09%09%09%09nextPutAll%3A%20%27smalltalk.poolDictionary_%28%22%27%3B%0D%0A%09%09%09%09nextPutAll%3A%20poolName%3B%0D%0A%09%09%09%09nextPutAll%3A%20%27%22%29.at_%28%22%27%3B%0D%0A%09%09%09%09nextPutAll%3A%20aName%3B%0D%0A%09%09%09%09nextPutAll%3A%20%27%22%29%27.%0D%0A%09%09%09%5Eself%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09stream%20%0D%0A%09%09nextPutAll%3A%20%27smalltalk.%27%3B%0D%0A%09%09nextPutAll%3A%20aNode%20value."));
smalltalk.bind(smalltalk.Compiler,"acceptAssignment:to:",0
,function (aNode,assignee){var self=this;return self.triggerEvent_with_ifNotHandled_("acceptAssignmentTo:", assignee, (function(){return true;}));;return self;}
,"assignment",unescape("acceptAssignment%3A%20aNode%20to%3A%20assignee%0D%0A%09%22%20Private%20-%20Returns%20true%20if%20aNode%20expression%20can%20eb%20assigned%20to%20assignee%20%28aVariableNode%29.%20%22%0D%0A%0D%0A%09%5Eself%09triggerEvent%3A%20%23acceptAssignmentTo%3A%0D%0A%09%09with%3A%20assignee%0D%0A%09%09ifNotHandled%3A%20%5B%20true%20%5D"));
smalltalk.bind(smalltalk.Compiler,"hasBlockArguments:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;aNode.arguments().do_((function(each){return ((smalltalk.is_kindOf_(each,(smalltalk.BlockNode))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"optimization",unescape("hasBlockArguments%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20arguments%20of%20aNode%20are%20blocks.%20%22%0D%0A%0D%0A%09aNode%20arguments%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28each%20isKindOf%3A%20BlockNode%29%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Compiler,"hasBlockNoArguments:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((self.hasBlockArguments_(aNode)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
aNode.arguments().do_((function(each){return ((each.parameters().isEmpty()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"optimization",unescape("hasBlockNoArguments%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20arguments%20of%20aNode%20are%20blocks%20with%20no%20parameters.%20%22%0D%0A%0D%0A%09%28self%20hasBlockArguments%3A%20aNode%29%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09aNode%20arguments%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20parameters%20isEmpty%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Compiler,"hasBlockOneArguments:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((self.hasBlockArguments_(aNode)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
aNode.arguments().do_((function(each){return ((each.parameters().size()._eq((1))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"optimization",unescape("hasBlockOneArguments%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20arguments%20of%20aNode%20are%20blocks%20with%20ONE%20parameter.%20%22%0D%0A%0D%0A%09%28self%20hasBlockArguments%3A%20aNode%29%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09aNode%20arguments%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20parameters%20size%20%3D%201%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Compiler,"hasNumber:",0
,function (aNode){var self=this;return self.receiverHasNumber_(aNode).or_((function(){return self.argumentsHasNumber_(aNode);}));;return self;}
,"optimization",unescape("hasNumber%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20or%20arguments%20in%20aNode%20has%20numeric%20value.%20%22%0D%0A%0D%0A%09%5E%28self%20receiverHasNumber%3A%20aNode%29%20or%3A%20%5B%0D%0A%09%09self%20argumentsHasNumber%3A%20aNode%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"hasString:",0
,function (aNode){var self=this;return self.receiverHasString_(aNode).or_((function(){return self.argumentsHasString_(aNode);}));;return self;}
,"optimization",unescape("hasString%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20or%20arguments%20in%20aNode%20has%20string%20value.%20%22%0D%0A%0D%0A%09%5E%28self%20receiverHasString%3A%20aNode%29%20or%3A%20%5B%0D%0A%09%09self%20argumentsHasString%3A%20aNode%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"receiverHasNumber:",0
,function (aNode){var self=this;return aNode.receiver().hasNumber();;return self;}
,"optimization",unescape("receiverHasNumber%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20of%20aNode%20is%20a%20number%20literal.%20%22%0D%0A%0D%0A%09%5EaNode%20receiver%20hasNumber"));
smalltalk.bind(smalltalk.Compiler,"receiverHasString:",0
,function (aNode){var self=this;return aNode.receiver().hasString();;return self;}
,"optimization",unescape("receiverHasString%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20of%20aNode%20is%20a%20string%20literal.%20%22%0D%0A%0D%0A%09%5EaNode%20receiver%20hasString"));
smalltalk.bind(smalltalk.Compiler,"argumentsHasNumber:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;aNode.arguments().do_((function(each){return ((each.hasNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"optimization",unescape("argumentsHasNumber%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20any%20argument%20of%20aNode%20is%20a%20number%20literal.%20%22%0D%0A%0D%0A%09aNode%20arguments%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20hasNumber%20ifTrue%3A%20%5B%20%5Etrue%20%5D%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler,"argumentsHasString:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;aNode.arguments().do_((function(each){return ((each.hasString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"optimization",unescape("argumentsHasString%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20any%20argument%20of%20aNode%20is%20a%20string%20literal.%20%22%0D%0A%0D%0A%09aNode%20arguments%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20hasString%20ifTrue%3A%20%5B%20%5Etrue%20%5D%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler,"arg1HasNumber:",0
,function (aNode){var self=this;return aNode.arguments().at_((1)).hasNumber();;return self;}
,"optimization",unescape("arg1HasNumber%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20argument%20of%20aNode%20is%20a%20number%20literal.%20%22%0D%0A%0D%0A%09%5E%28aNode%20arguments%20at%3A%201%29%20hasNumber"));
smalltalk.bind(smalltalk.Compiler,"arg2HasNumber:",0
,function (aNode){var self=this;return aNode.arguments().at_((2)).hasNumber();;return self;}
,"optimization",unescape("arg2HasNumber%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20argument%20of%20aNode%20is%20a%20number%20literal.%20%22%0D%0A%0D%0A%09%5E%28aNode%20arguments%20at%3A%202%29%20hasNumber"));
smalltalk.bind(smalltalk.Compiler,"arg3HasNumber:",0
,function (aNode){var self=this;return aNode.arguments().at_((3)).hasNumber();;return self;}
,"optimization",unescape("arg3HasNumber%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20argument%20of%20aNode%20is%20a%20number%20literal.%20%22%0D%0A%0D%0A%09%5E%28aNode%20arguments%20at%3A%203%29%20hasNumber"));
smalltalk.bind(smalltalk.Compiler,"receiverIsBlockNoArguments:",0
,function (aNode){var self=this;return smalltalk.is_kindOf_(aNode.receiver(),(smalltalk.BlockNode)).and_((function(){return aNode.receiver().parameters().isEmpty();}));;return self;}
,"optimization",unescape("receiverIsBlockNoArguments%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20receiver%20of%20aNode%20is%20block%20with%20no%20arguments.%20%22%0D%0A%0D%0A%09%5E%28aNode%20receiver%20isKindOf%3A%20BlockNode%29%20and%3A%20%5B%0D%0A%09%09aNode%20receiver%20parameters%20isEmpty%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"allBlockNoArguments:",0
,function (aNode){var self=this;return self.receiverIsBlockNoArguments_(aNode).and_((function(){return self.hasBlockNoArguments_(aNode);}));;return self;}
,"optimization",unescape("allBlockNoArguments%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20receiver%20and%20arguments%20of%20aNode%20are%20blocks%20with%20no%20arguments.%20%22%0D%0A%0D%0A%09%5E%28self%20receiverIsBlockNoArguments%3A%20aNode%29%20and%3A%20%5B%0D%0A%09%09self%20hasBlockNoArguments%3A%20aNode%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"matchOptimizedCondition:with:",0
,function (condition,aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((["hasNumber:", "receiverHasNumber:", "argumentsHasNumber:", "hasString:", "receiverHasString:", "argumentsHasString:", "arg1HasNumber:", "arg2HasNumber:", "arg3HasNumber:", "hasBlockArguments:", "hasBlockNoArguments:", "hasBlockOneArguments:", "allBlockNoArguments:", "receiverIsBlockNoArguments:"].includes_(condition)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.perform_withArguments_(condition, smalltalk.Array.with_(aNode));})();throw($s8Ret$)})();})() : nil);
((condition._eq("true")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
((condition._eq("false")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
((condition.isMemberOf_(smalltalk.Array)).mustBeBoolean()==true ? (function(){condition.detect_ifNone_((function(one){return false._eq(self.matchOptimizedCondition_with_(one, aNode));}), (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();}));return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
self.print_(unescape("%3E%3E%3E%20unknown%20optimize-condition%3A%20")._comma(condition.asString()));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"optimization",unescape("matchOptimizedCondition%3A%20condition%20with%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20aNode%20matches%20the%20condition.%20%22%0D%0A%0D%0A%09%28%23%28%0D%0A%09%23hasNumber%3A%20%23receiverHasNumber%3A%20%23argumentsHasNumber%3A%0D%0A%09%23hasString%3A%20%20%23receiverHasString%3A%20%23argumentsHasString%3A%0D%0A%09%23arg1HasNumber%3A%20%23arg2HasNumber%3A%20%23arg3HasNumber%3A%0D%0A%09%23hasBlockArguments%3A%20%23hasBlockNoArguments%3A%20%23hasBlockOneArguments%3A%0D%0A%09%23allBlockNoArguments%3A%20%23receiverIsBlockNoArguments%3A%0D%0A%09%29%20includes%3A%20condition%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20perform%3A%20condition%20withArguments%3A%20%28Array%20with%3A%20aNode%29%0D%0A%09%5D.%0D%0A%09condition%20%3D%20%23true%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09condition%20%3D%20%23false%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%28condition%20isMemberOf%3A%20Array%29%20ifTrue%3A%20%5B%0D%0A%09%09condition%20detect%3A%20%5B%3Aone%7C%0D%0A%09%09%09false%20%3D%20%28self%20matchOptimizedCondition%3A%20one%20with%3A%20aNode%29%0D%0A%09%09%5D%20ifNone%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%09%5Efalse%0D%0A%09%5D.%0D%0A%09self%20print%3A%20%27%3E%3E%3E%20unknown%20optimize-condition%3A%20%27%2Ccondition%20asString.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler,"defaultOptimizationMap",0
,function (){var self=this;return [[(0), [["class", unescape("%25receiver%25.%24klass")], ["isNil", unescape("%28nil.isNil_%28%25receiver%25%29%29")], ["notNil", unescape("%28nil.isNil_%28%25receiver%25%29%3D%3D%3Dfalse%29")], ["whileTrue", "receiverIsBlockNoArguments:", unescape("%28function%28%29%7Bwhile%28%25receiver%25%28%29%29%7B%7D%3Breturn%20nil%7D%29%28%29")], ["whileFalse", "receiverIsBlockNoArguments:", unescape("%28function%28%29%7Bwhile%28%21%25receiver%25%28%29%29%7B%7D%3Breturn%20nil%7D%29%28%29")], ["basicValueOrNil", unescape("%28function%28%29%7Bvar%20%241%24%3Breturn%20%28nil.isNil_%28%241%24%20%3D%20%25receiver%25%29%29%20%3F%20nil%20%3A%20%241%24%3B%7D%29%28%29")]]], [(1), [["ifTrue:", "hasBlockNoArguments:", unescape("%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20%25arg1%25%28%29%20%3A%20nil%29")], ["ifFalse:", "hasBlockNoArguments:", unescape("%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20nil%20%3A%20%25arg1%25%28%29%29")], ["whileTrue:", "allBlockNoArguments:", unescape("%28function%28%29%7Bwhile%28%25receiver%25%28%29%29%7B%25arg1%25%28%29%7D%3Breturn%20nil%7D%29%28%29")], ["whileFalse:", "allBlockNoArguments:", unescape("%28function%28%29%7Bwhile%28%21%25receiver%25%28%29%29%7B%25arg1%25%28%29%7D%3Breturn%20nil%7D%29%28%29")], ["ifNil:", "hasBlockArguments:", unescape("%28function%28%29%7Bvar%20%241%24%3Breturn%20%28nil.isNil_%28%241%24%20%3D%20%25receiver%25%29%29%20%3F%20%25arg1%25%28%29%20%3A%20%241%24%3B%7D%29%28%29")], ["ifNotNil:", "hasBlockArguments:", unescape("%28function%28%29%7Bvar%20%241%24%3Breturn%20%28nil.isNil_%28%241%24%20%3D%20%25receiver%25%29%3D%3D%3Dfalse%29%20%3F%20%25arg1%25%28%29%20%3A%20%241%24%3B%7D%29%28%29")], [unescape("%3D%3D"), unescape("%28%25receiver%25%20%3D%3D%3D%20%25arg1%25%29")], [unescape("%3D%3D%3D"), unescape("%28%25receiver%25%20%3D%3D%3D%20%25arg1%25%29")], [unescape("%7C%7C"), unescape("%28%25receiver%25%20%7C%7C%20%25arg1%25%29")], ["basicAt:", unescape("%28%28function%28%29%7Bvar%20%241%24%3D%25receiver%25%5B%25arg1%25%5D%3Bif%28nil.isNil_%28%241%24%29%29return%20nil%3Breturn%20%241%24%3B%7D%29%28%29%29")], ["ifUndefined:", "hasBlockNoArguments:", unescape("%28function%28%29%7Bvar%20%241%24%20%3D%20%25receiver%25%3Bif%20%28typeof%20%28%241%24%29%20%3D%3D%20%22undefined%22%29%20return%20%25arg1%25%28%29%3B%20return%20%241%24%3B%7D%29%28%29")], ["timesRepeat:", "hasBlockNoArguments:", unescape("%28function%28%29%7Bfor%28var%20%241%24%3D%25receiver%25%3B%241%24%3E0%3B%241%24--%29%7B%25arg1%25%28%29%7D%3Breturn%20nil%7D%29%28%29")], ["isKindOf:", unescape("smalltalk.is_kindOf_%28%25receiver%25%2C%28%25arg1%25%29%29")], ["respondsTo:", unescape("smalltalk.responds_to_%28%25receiver%25%2C%28%25arg1%25%29%29")]]], [(2), [["ifTrue:ifFalse:", "hasBlockNoArguments:", unescape("%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20%25arg1%25%28%29%20%3A%20%25arg2%25%28%29%29")], ["ifFalse:ifTrue:", "hasBlockNoArguments:", unescape("%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20%25arg2%25%28%29%20%3A%20%25arg1%25%28%29%29")], ["ifNil:ifNotNil:", "hasBlockNoArguments:", unescape("%28nil.isNil_%28%25receiver%25%29%29%20%3F%20%25arg1%25%28%29%20%3A%20%25arg2%25%28%29")], ["ifNotNil:ifNil:", "hasBlockNoArguments:", unescape("%28nil.isNil_%28%25receiver%25%29%3D%3D%3Dfalse%29%20%3F%20%25arg1%25%28%29%20%3A%20%25arg2%25%28%29")], ["basicAt:ifAbsent:", unescape("%28%28function%28%29%7Bvar%20%241%24%3D%25receiver%25%5B%25arg1%25%5D%3Bif%28nil.isNil_%28%241%24%29%29return%20%28%25arg2%25.value%28%29%29%3Breturn%20%241%24%3B%7D%29%28%29%29")], ["basicAt:put:", unescape("%28%25receiver%25%5B%25arg1%25%5D%3D%28%25arg2%25%29%29")]]]];;return self;}
,"optimization",unescape("defaultOptimizationMap%0D%0A%09%22%20Private%20-%20Return%20the%20default%20message%20optimization%20specification.%20%22%0D%0A%0D%0A%09%5E%23%28%0D%0A%09%09%23%28%200%20%23%28%20%22selectors%20without%20arguments%22%0D%0A%09%09%09%23%28%20%23class%09%27%25receiver%25.%24klass%27%20%29%0D%0A%09%09%09%23%28%20%23isNil%09%27%28nil.isNil_%28%25receiver%25%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23notNil%09%27%28nil.isNil_%28%25receiver%25%29%3D%3D%3Dfalse%29%27%20%29%0D%0A%09%09%09%23%28%20%23whileTrue%20%23receiverIsBlockNoArguments%3A%20%27%28function%28%29%7Bwhile%28%25receiver%25%28%29%29%7B%7D%3Breturn%20nil%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23whileFalse%20%23receiverIsBlockNoArguments%3A%20%27%28function%28%29%7Bwhile%28%21%25receiver%25%28%29%29%7B%7D%3Breturn%20nil%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23basicValueOrNil%20%27%28function%28%29%7Bvar%20%241%24%3Breturn%20%28nil.isNil_%28%241%24%20%3D%20%25receiver%25%29%29%20%3F%20nil%20%3A%20%241%24%3B%7D%29%28%29%27%20%29%0D%0A%09%09%29%20%29%0D%0A%09%09%23%28%201%20%23%28%20%22one%20argument%20selectors%20and%20operations%22%0D%0A%09%09%09%23%28%20%23ifTrue%3A%20%23hasBlockNoArguments%3A%20%27%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20%25arg1%25%28%29%20%3A%20nil%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifFalse%3A%20%23hasBlockNoArguments%3A%20%27%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20nil%20%3A%20%25arg1%25%28%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23whileTrue%3A%20%23allBlockNoArguments%3A%20%27%28function%28%29%7Bwhile%28%25receiver%25%28%29%29%7B%25arg1%25%28%29%7D%3Breturn%20nil%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23whileFalse%3A%20%23allBlockNoArguments%3A%20%27%28function%28%29%7Bwhile%28%21%25receiver%25%28%29%29%7B%25arg1%25%28%29%7D%3Breturn%20nil%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifNil%3A%20%23hasBlockArguments%3A%20%27%28function%28%29%7Bvar%20%241%24%3Breturn%20%28nil.isNil_%28%241%24%20%3D%20%25receiver%25%29%29%20%3F%20%25arg1%25%28%29%20%3A%20%241%24%3B%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifNotNil%3A%20%23hasBlockArguments%3A%20%27%28function%28%29%7Bvar%20%241%24%3Breturn%20%28nil.isNil_%28%241%24%20%3D%20%25receiver%25%29%3D%3D%3Dfalse%29%20%3F%20%25arg1%25%28%29%20%3A%20%241%24%3B%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23%3D%3D%09%27%28%25receiver%25%20%3D%3D%3D%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23%3D%3D%3D%09%27%28%25receiver%25%20%3D%3D%3D%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23%7C%7C%09%27%28%25receiver%25%20%7C%7C%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23basicAt%3A%09%27%28%28function%28%29%7Bvar%20%241%24%3D%25receiver%25%5B%25arg1%25%5D%3Bif%28nil.isNil_%28%241%24%29%29return%20nil%3Breturn%20%241%24%3B%7D%29%28%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifUndefined%3A%20%23hasBlockNoArguments%3A%20%27%28function%28%29%7Bvar%20%241%24%20%3D%20%25receiver%25%3Bif%20%28typeof%20%28%241%24%29%20%3D%3D%20%22undefined%22%29%20return%20%25arg1%25%28%29%3B%20return%20%241%24%3B%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23timesRepeat%3A%20%23hasBlockNoArguments%3A%20%27%28function%28%29%7Bfor%28var%20%241%24%3D%25receiver%25%3B%241%24%3E0%3B%241%24--%29%7B%25arg1%25%28%29%7D%3Breturn%20nil%7D%29%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23isKindOf%3A%20%27smalltalk.is_kindOf_%28%25receiver%25%2C%28%25arg1%25%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23respondsTo%3A%20%27smalltalk.responds_to_%28%25receiver%25%2C%28%25arg1%25%29%29%27%20%29%0D%0A%22%09%09%09%23%28%20%23%3E%20%23hasNumber%3A%20%27%28%25receiver%25%20%3E%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23%3C%20%23hasNumber%3A%20%27%28%25receiver%25%20%3C%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23%3E%3D%20%23hasNumber%3A%20%27%28%25receiver%25%20%3E%3D%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23%3C%3D%20%23hasNumber%3A%20%27%28%25receiver%25%20%3C%3D%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23+%20%23hasNumber%3A%20%27%28%25receiver%25%20+%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23-%20%23hasNumber%3A%20%27%28%25receiver%25%20-%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23*%20%23hasNumber%3A%20%27%28%25receiver%25%20*%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23/%20%23hasNumber%3A%20%27%28%25receiver%25%20/%20%25arg1%25%29%27%20%29%0D%0A%09%09%09%23%28%20%23%3D%20%20%23hasNumber%3A%20%27%28%25receiver%25%20%3D%3D%20%25arg1%25%29%27%20%29%0D%0A%22%09%09%29%20%29%0D%0A%09%09%23%28%202%20%23%28%20%22two%20argument%20messages%20and%20operations%22%0D%0A%09%09%09%23%28%20%23ifTrue%3AifFalse%3A%20%23hasBlockNoArguments%3A%20%27%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20%25arg1%25%28%29%20%3A%20%25arg2%25%28%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifFalse%3AifTrue%3A%20%23hasBlockNoArguments%3A%20%27%28%28%25receiver%25%29.mustBeBoolean%28%29%3D%3Dtrue%20%3F%20%25arg2%25%28%29%20%3A%20%25arg1%25%28%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifNil%3AifNotNil%3A%20%23hasBlockNoArguments%3A%20%27%28nil.isNil_%28%25receiver%25%29%29%20%3F%20%25arg1%25%28%29%20%3A%20%25arg2%25%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23ifNotNil%3AifNil%3A%20%23hasBlockNoArguments%3A%20%27%28nil.isNil_%28%25receiver%25%29%3D%3D%3Dfalse%29%20%3F%20%25arg1%25%28%29%20%3A%20%25arg2%25%28%29%27%20%29%0D%0A%09%09%09%23%28%20%23basicAt%3AifAbsent%3A%20%27%28%28function%28%29%7Bvar%20%241%24%3D%25receiver%25%5B%25arg1%25%5D%3Bif%28nil.isNil_%28%241%24%29%29return%20%28%25arg2%25.value%28%29%29%3Breturn%20%241%24%3B%7D%29%28%29%29%27%20%29%0D%0A%09%09%09%23%28%20%23basicAt%3Aput%3A%20%27%28%25receiver%25%5B%25arg1%25%5D%3D%28%25arg2%25%29%29%27%20%29%0D%0A%09%09%29%20%29%0D%0A%29"));
smalltalk.bind(smalltalk.Compiler,"optimizationMap",0
,function (){var self=this;(((nil.isNil_(self['@optimizationMap']))).mustBeBoolean()==true ? (function(){self['@optimizationMap']=self.triggerEvent_ifNotHandled_("needsOptimizationMap", (function(){return self.defaultOptimizationMap();}));return self.triggerEvent_("customizeOptimizations");})() : nil);
return self['@optimizationMap'];;return self;}
,"accessing",unescape("optimizationMap%0D%0A%09%22%20Return%20the%20message%20send%20optimization%20map%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09optimizationMap%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09optimizationMap%20%20%3A%3D%20self%0D%0A%09%09%09triggerEvent%3A%20%23needsOptimizationMap%0D%0A%09%09%09ifNotHandled%3A%20%5B%20self%20defaultOptimizationMap%20%5D.%0D%0A%09%09self%20triggerEvent%3A%20%23customizeOptimizations%0D%0A%09%5D.%0D%0A%09%5EoptimizationMap"));
smalltalk.bind(smalltalk.Compiler,"optimize:macro:",0
,function (aNode,template){var self=this;var input=nil;input=template.readStream();
input.do_((function($$char){return (($$char._eq(unescape("%25"))).mustBeBoolean()==true ? (function(){return self.visitMacroIn_with_(input, aNode);})() : (function(){return self['@stream'].nextPutAll_($$char.asString());})());}));return self;}
,"optimization",unescape("optimize%3A%20aNode%20macro%3A%20template%0D%0A%09%22%20Private%20-%20Generate%20the%20code%20for%20aNode%20using%20a%20macro%20template.%0D%0A%09Dump%20code%20expanding%20variables%20in%20macro%20template.%0D%0A%09Variables%20are%20defined%20between%20%25%25%0D%0A%09%22%0D%0A%0D%0A%09%7C%20input%20%7C%0D%0A%09input%20%3A%3D%20template%20readStream.%0D%0A%09input%20do%3A%20%5B%3Achar%7C%0D%0A%09%09char%20%3D%20%24%25%0D%0A%09%09ifTrue%3A%20%5B%20self%20visitMacroIn%3A%20input%20with%3A%20aNode%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20stream%20nextPutAll%3A%20char%20asString%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"isOperation:",0
,function (aNode){var self=this;return aNode.arguments().size()._eq((1)).and_((function(){return aNode.selector().size()._gt((1)).and_((function(){return aNode.selector().first()._eq(unescape("%23")).and_((function(){return unescape("%7C%26%5C%5C+*/%3D%3E%3C%2C@%25%7E-").includes_(aNode.selector().at_((2)));}));}));}));;return self;}
,"operations",unescape("isOperation%3A%20aNode%0D%0A%09%22%20Private%20-%20Return%20true%20if%20aNode%20is%20an%20operation.%20%22%0D%0A%0D%0A%09%5EaNode%20arguments%20size%20%3D%201%20and%3A%20%5B%0D%0A%09%09aNode%20selector%20size%20%3E%201%20and%3A%20%5B%0D%0A%09%09aNode%20selector%20first%20%3D%20%24%23%20and%3A%20%5B%0D%0A%09%09%27%7C%26%5C%5C+*/%3D%3E%3C%2C@%25%7E-%27%20includes%3A%20%28aNode%20selector%20at%3A%202%29%0D%0A%09%09%5D%5D%5D"));
smalltalk.bind(smalltalk.Compiler,"visitNormalSend:",0
,function (aNode){var self=this;self.triggerEvent_with_("aboutSend:", aNode);
self.visitReceiver_(aNode.receiver());
(function($rec){$rec.nextPutAll_(aNode.receiver().messageSendConnector());$rec.nextPutAll_(aNode.selector().asSelector());return $rec.nextPutAll_(unescape("%28"));})(self['@stream']);
self.visitSendArguments_(aNode);
self['@stream'].nextPutAll_(unescape("%29"));
self.triggerEvent_with_("send:", aNode);return self;}
,"visiting",unescape("visitNormalSend%3A%20aNode%0D%0A%09%22%20Generate%20code%20for%20direct/inlined%20message%20send.%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23aboutSend%3A%20with%3A%20aNode.%0D%0A%09self%20visitReceiver%3A%20aNode%20receiver.%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20aNode%20receiver%20messageSendConnector%3B%0D%0A%09%09nextPutAll%3A%20aNode%20selector%20asSelector%3B%0D%0A%09%09nextPutAll%3A%20%27%28%27.%0D%0A%09self%20visitSendArguments%3A%20aNode.%0D%0A%09stream%09nextPutAll%3A%20%27%29%27.%0D%0A%09self%20triggerEvent%3A%20%23send%3A%20with%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"visitInlined:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((smalltalk.is_kindOf_(aNode,(smalltalk.BlockNode))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20block%20node%20%28")._comma(aNode.asString())._comma(unescape("%29.")));})();throw($s8Ret$)})();})());
aNode.nodes().do_((function(each){return self.visit_(each);}));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitInlined%3A%20aNode%0D%0A%09%22%20Private%20-%20Encode%20aNode%20as%20inlined%20sequence%20of%20statements.%20%22%0D%0A%0D%0A%09%28aNode%20isKindOf%3A%20BlockNode%29%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20%27Invalid%20block%20node%20%28%27%2CaNode%20asString%2C%27%29.%27%0D%0A%09%5D.%0D%0A%09aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%20self%20visit%3A%20each%20%5D."));
smalltalk.bind(smalltalk.Compiler,"visitMacroIn:with:",0
,function (input,aNode){var $s8Ret$={name:"stReturn"};try{var self=this;var varName=nil;var $$char=nil;var args=nil;varName=smalltalk.String.$$new();
(function(){while(!(function(){$$char=input.next();return $$char._eq(unescape("%25"));})()){(function(){return varName=varName._comma($$char.asString());})()};return nil})();
((varName._eq("receiver")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitReceiver_(aNode.receiver());})();throw($s8Ret$)})();})() : nil);
((varName.size()._gt((3)).and_((function(){return varName.copyFrom_to_((1), (3))._eq("arg");}))).mustBeBoolean()==true ? (function(){args=aNode.arguments();return (1).to_do_(args.size(), (function(i){return (("arg"._comma(i.asString())._eq(varName)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visit_(args.at_(i));})();throw($s8Ret$)})();})() : nil);}));})() : nil);
((varName._eq("inlinedReceiver")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitInlined_(aNode.receiver());})();throw($s8Ret$)})();})() : nil);
((varName.size()._gt((7)).and_((function(){return varName.copyFrom_to_((1), (7))._eq("inlined");}))).mustBeBoolean()==true ? (function(){args=aNode.arguments();return (1).to_do_(args.size(), (function(i){return (("inlined"._comma(i.asString())._eq(varName)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitInlined_(args.at_(i));})();throw($s8Ret$)})();})() : nil);}));})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20macro%20variable%5B")._comma(varName)._comma(unescape("%5D.")));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitMacroIn%3A%20input%20with%3A%20aNode%0D%0A%09%22%20Private%20-%20Dump%20the%20value%20of%20next%20variable%20defined%20in%20input%20onto%20receiver%27s%20stream.%20%22%0D%0A%0D%0A%09%7C%20varName%20char%20args%20%7C%0D%0A%09varName%20%3A%3D%20String%20new.%0D%0A%09%5B%20char%20%3A%3D%20input%20next.%20char%20%3D%20%24%25%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09varName%20%3A%3D%20varName%20%2C%20char%20asString%0D%0A%09%5D.%0D%0A%0D%0A%09varName%20%3D%20%27receiver%27%20ifTrue%3A%20%5B%20%5Eself%20visitReceiver%3A%20aNode%20receiver%20%5D.%0D%0A%09%28varName%20size%20%3E%203%20and%3A%20%5B%20%28varName%20copyFrom%3A%201%20to%3A%203%29%20%3D%20%27arg%27%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09args%20%3A%3D%20aNode%20arguments.%0D%0A%09%091%20to%3A%20args%20size%20do%3A%20%5B%3Ai%7C%0D%0A%09%09%09%27arg%27%2Ci%20asString%20%3D%20varName%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%5Eself%20visit%3A%20%28args%20at%3A%20i%29%0D%0A%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09varName%20%3D%20%27inlinedReceiver%27%20ifTrue%3A%20%5B%20%5Eself%20visitInlined%3A%20aNode%20receiver%20%5D.%0D%0A%09%28varName%20size%20%3E%207%20and%3A%20%5B%20%28varName%20copyFrom%3A%201%20to%3A%207%29%20%3D%20%27inlined%27%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09args%20%3A%3D%20aNode%20arguments.%0D%0A%09%091%20to%3A%20args%20size%20do%3A%20%5B%3Ai%7C%0D%0A%09%09%09%27inlined%27%2Ci%20asString%20%3D%20varName%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%5Eself%20visitInlined%3A%20%28args%20at%3A%20i%29%0D%0A%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20macro%20variable%5B%27%2CvarName%2C%27%5D.%27"));
smalltalk.bind(smalltalk.Compiler,"visitOptimizedNode:as:",0
,function (aNode,mapping){var $s8Ret$={name:"stReturn"};try{var self=this;((mapping.size()._eq((2)).and_((function(){return mapping.last().isString();}))).mustBeBoolean()==true ? (function(){self.optimize_macro_(aNode, mapping.last());return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
((mapping.size()._eq((3)).and_((function(){return mapping.last().isString();}))).mustBeBoolean()==true ? (function(){((self.matchOptimizedCondition_with_(mapping.at_((2)), aNode)).mustBeBoolean()==true ? (function(){return self.optimize_macro_(aNode, mapping.last());})() : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
self.print_(unescape("%3E%3E%3E%20compiler%20optimization")._comma(unescape("%20for%20%23"))._comma(aNode.selector())._comma(unescape("%20-%20not%20implemented%20yet.%20Mapping%3D"))._comma(mapping.asString()));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitOptimizedNode%3A%20aNode%20as%3A%20mapping%0D%0A%09%22%20Private%20-%20Generate%20the%20code%20for%20aNode%20using%20custom%20mapping.%0D%0A%09Return%20true%20if%20the%20code%20can%20be%20generated.%0D%0A%09If%20the%20optimization%20fails%2C%20the%20receiver%27s%20stream%20MUST%20be%20leaved%20intact%20to%20ensure%20correct%20code%20generation.%0D%0A%09%22%0D%0A%0D%0A%09%28mapping%20size%20%3D%202%20and%3A%20%5Bmapping%20last%20isString%5D%29%20ifTrue%3A%20%5B%20%22%28selector%20macro%29%22%0D%0A%09%09self%20optimize%3A%20aNode%20macro%3A%20mapping%20last.%0D%0A%09%09%5Etrue%0D%0A%09%5D.%0D%0A%09%28mapping%20size%20%3D%203%20and%3A%20%5Bmapping%20last%20isString%5D%29%20ifTrue%3A%20%5B%22%28selector%20condition%20macro%29%22%0D%0A%09%09%28self%20matchOptimizedCondition%3A%20%28mapping%20at%3A2%29%20with%3A%20aNode%29%0D%0A%09%09%09ifTrue%3A%20%5B%20self%20optimize%3A%20aNode%20macro%3A%20mapping%20last%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%09%5Etrue%0D%0A%09%5D.%0D%0A%0D%0A%09self%20print%3A%20%27%3E%3E%3E%20compiler%20optimization%27%0D%0A%09%09%2C%27%20for%20%23%27%2CaNode%20selector%0D%0A%09%09%2C%27%20-%20not%20implemented%20yet.%20Mapping%3D%27%0D%0A%09%09%2Cmapping%20asString.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler,"visitOptimizedSend:with:",0
,function (aNode,mapping){var $s8Ret$={name:"stReturn"};try{var self=this;var argCount=nil;argCount=aNode.arguments().size();
mapping.do_((function(tuple){return ((tuple.first().isNumber().and_((function(){return tuple.first()._eq(argCount);}))).mustBeBoolean()==true ? (function(){return ((self.visitOptimizedSend_with_(aNode, tuple.last())).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);})() : (function(){return ((tuple.first()._eq(aNode.selector())).mustBeBoolean()==true ? (function(){return ((self.visitOptimizedNode_as_(aNode, tuple)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);})() : nil);})());}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitOptimizedSend%3A%20aNode%20with%3A%20mapping%0D%0A%09%22%20Private%20-%20Generate%20optimal%20code%20for%20aNode%20using%20mapping.%0D%0A%09Return%20true%20if%20the%20code%20has%20been%20generated.%0D%0A%09Leave%20the%20code%20stream%20intact%20if%20the%20optimization%20do%20not%20apply.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20argCount%20%7C%0D%0A%09argCount%20%3A%3D%20aNode%20arguments%20size.%0D%0A%09mapping%20do%3A%20%5B%3Atuple%7C%0D%0A%09%09%28tuple%20first%20isNumber%20and%3A%20%5B%20tuple%20first%20%3D%20argCount%20%5D%29%20ifTrue%3A%20%5B%20%22arguments%20size%20match%22%0D%0A%09%09%09%28self%20visitOptimizedSend%3A%20aNode%20with%3A%20tuple%20last%29%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09tuple%20first%20%3D%20aNode%20selector%20ifTrue%3A%20%5B%20%22selector%20match%22%0D%0A%09%09%09%09%28self%20visitOptimizedNode%3A%20aNode%20as%3A%20tuple%29%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler,"visitOptimizedSend:",0
,function (aNode){var self=this;return self.visitOptimizedSend_with_(aNode, self.optimizationMap());;return self;}
,"visiting",unescape("visitOptimizedSend%3A%20aNode%0D%0A%09%22%20Private%20-%20Generate%20optimal%20code%20for%20aNode%20using%20optimization%20map.%0D%0A%09Return%20true%20if%20optimization%20was%20successfull.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20visitOptimizedSend%3A%20aNode%20with%3A%20self%20optimizationMap"));
smalltalk.bind(smalltalk.Compiler,"visitSendArguments:",0
,function (aNode){var self=this;aNode.arguments().do_separatedBy_((function(each){return self.visitArgument_(each);}), (function(){return self['@stream'].nextPutAll_(unescape("%2C%20"));}));return self;}
,"visiting",unescape("visitSendArguments%3A%20aNode%0D%0A%09aNode%20arguments%20%0D%0A%09%20%20%20%20do%3A%20%5B%3Aeach%20%7C%20self%20visitArgument%3A%20each%20%5D%0D%0A%09%20%20%20%20separatedBy%3A%20%5B%20stream%20nextPutAll%3A%20%27%2C%20%27%20%5D."));
smalltalk.bind(smalltalk.Compiler,"visitSendToSuper:",0
,function (aNode){var self=this;self.triggerEvent_with_("aboutSend:", aNode);
self['@stream'].nextPutAll_(unescape("smalltalk.superImplementor%28")._comma(self.smalltalkNameFor_(self['@currentClass']))._comma(unescape("%2C%27"))._comma(aNode.selector().asSelector())._comma(unescape("%27%29.apply%28self%2C%20%5B")));
self.visitSendArguments_(aNode);
self['@stream'].nextPutAll_(unescape("%5D%29"));
self.triggerEvent_with_("send:", aNode);return self;}
,"visiting",unescape("visitSendToSuper%3A%20aNode%0D%0A%09self%20triggerEvent%3A%20%23aboutSend%3A%20with%3A%20aNode.%0D%0A%09stream%20%0D%0A%09%09nextPutAll%3A%20%27smalltalk.superImplementor%28%27%0D%0A%09%09%09%2C%28self%20smalltalkNameFor%3A%20currentClass%29%0D%0A%09%09%09%2C%27%2C%27%27%27%2CaNode%20selector%20asSelector%0D%0A%09%09%09%2C%27%27%27%29.apply%28self%2C%20%5B%27.%0D%0A%09self%20visitSendArguments%3A%20aNode.%0D%0A%09stream%20nextPutAll%3A%20%27%5D%29%27.%0D%0A%09self%20triggerEvent%3A%20%23send%3A%20with%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"visitOperation:",0
,function (aNode){var self=this;self.triggerEvent_with_("aboutOperation:", aNode);
self['@stream'].nextPutAll_(unescape("%28"));
self.visitReceiver_(aNode.receiver());
self['@stream'].nextPutAll_(unescape("%29"));
self['@stream'].nextPutAll_(aNode.selector().asSelector());
self.visitSendArguments_(aNode);
self.triggerEvent_with_("operation:", aNode);return self;}
,"visiting",unescape("visitOperation%3A%20aNode%0D%0A%09%22%20Private%20-%20aNode%20is%20an%20operation%20and%20selector%20is%20mapped%20to%20target%20operation.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23aboutOperation%3A%20with%3A%20aNode.%0D%0A%09stream%20nextPutAll%3A%20%24%28.%0D%0A%09self%20visitReceiver%3A%20aNode%20receiver.%0D%0A%09stream%20nextPutAll%3A%20%24%29.%0D%0A%09stream%20nextPutAll%3A%20aNode%20selector%20asSelector.%0D%0A%09self%20visitSendArguments%3A%20aNode.%0D%0A%09self%20triggerEvent%3A%20%23operation%3A%20with%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"visitSendNode:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;((aNode.receiver().isSuper()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitSendToSuper_(aNode);})();throw($s8Ret$)})();})() : nil);
((self.visitOptimizedSend_(aNode)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
((self.isOperation_(aNode)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.visitOperation_(aNode);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.visitNormalSend_(aNode);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitSendNode%3A%20aNode%0D%0A%09aNode%20receiver%20isSuper%20ifTrue%3A%20%5B%20%5Eself%20visitSendToSuper%3A%20aNode%20%5D.%0D%0A%09%28self%20visitOptimizedSend%3A%20aNode%29%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09%28self%20isOperation%3A%20aNode%29%20ifTrue%3A%20%5B%20%5Eself%20visitOperation%3A%20aNode%20%5D.%0D%0A%09%5Eself%20visitNormalSend%3A%20aNode"));
smalltalk.bind(smalltalk.Compiler,"visitCascadeNode:",0
,function (aNode){var self=this;((self['@tempVariables'].includes_("$rec")).mustBeBoolean()==true ? nil : (function(){return self['@tempVariables'].add_("$rec");})());
self.triggerEvent_with_("aboutCascade:", aNode);
self['@stream'].nextPutAll_(unescape("%28"));
self.emmitFunction_arguments_doing_("", "$rec", (function(){var index=nil;var rec=nil;index=(0);return aNode.nodes().do_((function(each){index=index._plus((1));((index._eq(aNode.nodes().size())).mustBeBoolean()==true ? (function(){return self.emmitReturn_(nil);})() : nil);rec=smalltalk.VariableNode.$$new();(function($rec){$rec.value_("$rec");return $rec.start_end_(each.start(), each.start());})(rec);each.receiver_(rec);self.visit_(each);((index._eq(aNode.nodes().size())).mustBeBoolean()==true ? (function(){return self.triggerEvent_withArguments_("returned:early:", smalltalk.Array.with_with_(nil, false));})() : nil);return self['@stream'].nextPutAll_(unescape("%3B"));}));}));
self['@stream'].nextPutAll_(unescape("%29%28"));
self.visit_(aNode.receiver());
self['@stream'].nextPutAll_(unescape("%29"));
self.triggerEvent_with_("cascade:", aNode);return self;}
,"visiting",unescape("visitCascadeNode%3A%20aNode%0D%0A%09%28tempVariables%20includes%3A%20%27%24rec%27%29%20ifFalse%3A%20%5B%20tempVariables%20add%3A%20%27%24rec%27%20%5D.%0D%0A%09self%20triggerEvent%3A%20%23aboutCascade%3A%20with%3A%20aNode.%0D%0A%09stream%20nextPutAll%3A%20%24%28.%0D%0A%09self%20emmitFunction%3A%20%27%27%20arguments%3A%20%27%24rec%27%20doing%3A%20%5B%20%7C%20index%20rec%20%7C%0D%0A%09%09index%20%3A%3D%200.%0D%0A%09%09aNode%20nodes%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09%20%20%20%20index%20%3A%3D%20index%20+%201.%0D%0A%09%09%20%20%20%20index%20%3D%20aNode%20nodes%20size%20ifTrue%3A%20%5B%20self%20emmitReturn%3A%20nil%20%5D.%0D%0A%09%09%20%20%20%20rec%20%3A%3D%20VariableNode%20new.%0D%0A%09%09%20%20%20%20rec%20value%3A%20%27%24rec%27%3B%20start%3A%20each%20start%20end%3A%20each%20start.%0D%0A%09%09%20%20%20%20each%20receiver%3A%20rec.%0D%0A%09%09%20%20%20%20self%20visit%3A%20each.%0D%0A%09%09%20%20%20%20index%20%3D%20aNode%20nodes%20size%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20triggerEvent%3A%20%23returned%3Aearly%3A%20withArguments%3A%20%28Array%20with%3A%20nil%20with%3A%20false%29%0D%0A%09%09%20%20%20%20%5D.%0D%0A%09%09%20%20%20%20stream%20nextPutAll%3A%20%27%3B%27%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09stream%20nextPutAll%3A%20%27%29%28%27.%0D%0A%09self%20visit%3A%20aNode%20receiver.%0D%0A%09stream%20nextPutAll%3A%20%24%29.%0D%0A%09self%20triggerEvent%3A%20%23cascade%3A%20with%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"visitValueNode:",0
,function (aNode){var self=this;self['@stream'].nextPutAll_(aNode.value().asJavascript());return self;}
,"visiting",unescape("visitValueNode%3A%20aNode%0D%0A%09stream%20nextPutAll%3A%20aNode%20value%20asJavascript"));
smalltalk.bind(smalltalk.Compiler,"visitInlineNode:",0
,function (aNode){var self=this;self['@stream'].nextPutAll_(aNode.source().value().replace_with_(unescape("%27%27"), unescape("%27")));return self;}
,"visiting",unescape("visitInlineNode%3A%20aNode%0D%0A%09stream%20nextPutAll%3A%20%28aNode%20source%20value%20replace%3A%20%27%27%27%27%27%27%20with%3A%20%27%27%27%27%29"));
smalltalk.bind(smalltalk.Compiler,"visitMacroAssignment:",0
,function (aNode){var self=this;return aNode.left().acceptMacroAssignment_with_(aNode.right(), self);;return self;}
,"visiting",unescape("visitMacroAssignment%3A%20aNode%0D%0A%09%5EaNode%20left%20acceptMacroAssignment%3A%20aNode%20right%20with%3A%20self"));
smalltalk.bind(smalltalk.Compiler,"visitAssignmentNode:",0
,function (aNode){var $s8Ret$={name:"stReturn"};try{var self=this;var assignee=nil;((self.visitMacroAssignment_(aNode)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
assignee=aNode.left();
((self.acceptAssignment_to_(aNode.right(), assignee)).mustBeBoolean()==true ? (function(){self.visit_(assignee);self['@stream'].nextPutAll_(unescape("%3D"));return self.visit_(aNode.right());})() : (function(){return self.triggerEvent_with_ifNotHandled_("invalidAssignment:", aNode, (function(){return self.error_("Invalid assignment to "._comma(assignee.value()));}));})());return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitAssignmentNode%3A%20aNode%0D%0A%0D%0A%09%7C%20assignee%20%7C%0D%0A%09%28self%20visitMacroAssignment%3A%20aNode%29%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09assignee%20%3A%3D%20aNode%20left.%0D%0A%09%28self%20acceptAssignment%3A%20aNode%20right%20to%3A%20assignee%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20visit%3A%20assignee.%0D%0A%09%09stream%20nextPutAll%3A%20%27%3D%27.%0D%0A%09%09self%20visit%3A%20aNode%20right%0D%0A%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09self%09triggerEvent%3A%20%23invalidAssignment%3A%20with%3A%20aNode%0D%0A%09%09%09ifNotHandled%3A%20%5B%20self%20error%3A%20%27Invalid%20assignment%20to%20%27%20%2Cassignee%20value%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Compiler,"visitClassVariableAssignment:in:to:",0
,function (aClassVariableName,aClass,anExpressionNode){var self=this;(function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass));$rec.nextPutAll_(unescape(".classVariableAt_put_%28%22"));$rec.nextPutAll_(aClassVariableName);return $rec.nextPutAll_(unescape("%22%2C"));})(self['@stream']);
self.visit_(anExpressionNode);
self['@stream'].nextPutAll_(unescape("%29"));return self;}
,"visiting",unescape("visitClassVariableAssignment%3A%20aClassVariableName%20in%3A%20aClass%20to%3A%20anExpressionNode%0D%0A%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27.classVariableAt_put_%28%22%27%3B%0D%0A%09%09nextPutAll%3A%20aClassVariableName%3B%20nextPutAll%3A%20%27%22%2C%27.%0D%0A%09self%20visit%3A%20anExpressionNode.%0D%0A%09stream%09nextPutAll%3A%20%27%29%27"));
smalltalk.bind(smalltalk.Compiler,"visitPoolVariableAssignment:in:to:",0
,function (aName,poolName,anExpressionNode){var self=this;(function($rec){$rec.nextPutAll_(unescape("smalltalk.poolDictionary_%28%22"));$rec.nextPutAll_(poolName);$rec.nextPutAll_(unescape("%22%29.at_put_%28%22"));$rec.nextPutAll_(aName);return $rec.nextPutAll_(unescape("%22%2C"));})(self['@stream']);
self.visit_(anExpressionNode);
self['@stream'].nextPutAll_(unescape("%29"));return self;}
,"visiting",unescape("visitPoolVariableAssignment%3A%20aName%20in%3A%20poolName%20to%3A%20anExpressionNode%0D%0A%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20%27smalltalk.poolDictionary_%28%22%27%3B%0D%0A%09%09nextPutAll%3A%20poolName%3B%20nextPutAll%3A%20%27%22%29.at_put_%28%22%27%3B%0D%0A%09%09nextPutAll%3A%20aName%3B%20nextPutAll%3A%20%27%22%2C%27.%0D%0A%09self%20visit%3A%20anExpressionNode.%0D%0A%09stream%09nextPutAll%3A%20%27%29%27"));
smalltalk.bind(smalltalk.Compiler,"visitMacroAssignment:to:",0
,function (aVariableNode,anExpressionNode){var $s8Ret$={name:"stReturn"};try{var self=this;var aName=nil;var aClass=nil;((aVariableNode.indices().notEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
aName=aVariableNode.value();
aClass=self.currentClass().instanceClass();
aClass.classVariableNamesDo_((function(each){return ((each._eq(aName)).mustBeBoolean()==true ? (function(){self.visitClassVariableAssignment_in_to_(each, aClass, anExpressionNode);return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
aClass.sharedPoolsAndNamesDo_((function(poolName,pool){return ((pool.includesKey_(aName)).mustBeBoolean()==true ? (function(){self.visitPoolVariableAssignment_in_to_(aName, poolName, anExpressionNode);return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitMacroAssignment%3A%20aVariableNode%20to%3A%20anExpressionNode%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20generated%20code%20to%20a%20macro%20assignment%20to%20aVariableNode.%20%22%0D%0A%0D%0A%09%7C%20aName%20aClass%20%7C%0D%0A%09aVariableNode%20indices%20notEmpty%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09aName%20%3A%3D%20aVariableNode%20value.%0D%0A%09aClass%20%3A%3D%20self%20currentClass%20instanceClass.%0D%0A%09aClass%20classVariableNamesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20%3D%20aName%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20visitClassVariableAssignment%3A%20each%0D%0A%09%09%09%09in%3A%20aClass%0D%0A%09%09%09%09to%3A%20anExpressionNode.%0D%0A%09%09%09%5Etrue%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09aClass%20sharedPoolsAndNamesDo%3A%20%5B%3ApoolName%20%3Apool%7C%0D%0A%09%09%28pool%20includesKey%3A%20aName%29%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20visitPoolVariableAssignment%3A%20aName%0D%0A%09%09%09%09in%3A%20poolName%0D%0A%09%09%09%09to%3A%20anExpressionNode.%0D%0A%09%09%09%5Etrue%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.Compiler,"codeToAccessProperty:",0
,function (aName){var self=this;return unescape("self%5B%27")._comma(aName)._comma(unescape("%27%5D"));;return self;}
,"generation",unescape("codeToAccessProperty%3A%20aName%0D%0A%09%22%20Private%20-%20Return%20the%20source%20code%20to%20access%20property%20aName.%20%22%0D%0A%0D%0A%09%5E%27self%5B%27%27%27%2CaName%2C%27%27%27%5D%27"));
smalltalk.bind(smalltalk.Compiler,"codeToAccessInstanceVariable:",0
,function (aName){var self=this;return self.codeToAccessProperty_(unescape("@")._comma(aName));;return self;}
,"generation",unescape("codeToAccessInstanceVariable%3A%20aName%0D%0A%09%22%20Private%20-%20Return%20the%20source%20code%20to%20access%20instance%20variable%20aName.%20%22%0D%0A%0D%0A%09%5Eself%20codeToAccessProperty%3A%20%27@%27%2C%20aName"));
smalltalk.bind(smalltalk.Compiler,"visitNode:index:",0
,function (aNode,index){var $s8Ret$={name:"stReturn"};try{var self=this;var selector=nil;((index.isMemberOf_(smalltalk.ValueNode).and_((function(){return index.hasString();}))).mustBeBoolean()==true ? (function(){selector=index.value().asSelector();return ((selector.includes_(" ").or_((function(){return selector.includes_("_");}))).mustBeBoolean()==true ? nil : (function(){(function($rec){$rec.nextPutAll_(".");return $rec.nextPutAll_(selector);})(self['@stream']);return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})());})() : nil);
self['@stream'].nextPutAll_(unescape("%5B"));
self.visit_(index);
self['@stream'].nextPutAll_(unescape("%5D"));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"visiting",unescape("visitNode%3A%20aNode%20index%3A%20index%0D%0A%09%22%20Private%20-%20Generate%20code%20for%20direct%20property%20access.%20%22%0D%0A%0D%0A%09%7C%20selector%20%7C%0D%0A%09%28%28index%20isMemberOf%3A%20ValueNode%29%20and%3A%20%5B%20index%20hasString%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09selector%20%3A%3D%20index%20value%20asSelector.%0D%0A%09%09%28%28selector%20includes%3A%20%24%20%29%20or%3A%20%5B%20selector%20includes%3A%20%24_%20%5D%29%20ifFalse%3A%20%5B%0D%0A%09%09%09stream%20nextPutAll%3A%20%27.%27%3B%20nextPutAll%3A%20selector.%0D%0A%09%09%09%5Eself%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09stream%20nextPutAll%3A%20%27%5B%27.%0D%0A%09self%20visit%3A%20index.%0D%0A%09stream%20nextPutAll%3A%20%27%5D%27."));
smalltalk.bind(smalltalk.Compiler,"visitNodeIndices:",0
,function (aNode){var self=this;aNode.indices().do_((function(each){return self.visitNode_index_(aNode, each);}));return self;}
,"visiting",unescape("visitNodeIndices%3A%20aNode%0D%0A%09%22%20Private%20-%20Generate%20code%20for%20direct%20property%20access.%20%22%0D%0A%0D%0A%09aNode%20indices%20do%3A%20%5B%3Aeach%7C%20self%20visitNode%3A%20aNode%20index%3A%20each%20%5D."));
smalltalk.bind(smalltalk.Compiler,"visitVariableNode:",0
,function (aNode){var self=this;var code=nil;code=self.currentClass().codeFor_accessing_(self, aNode);
(((nil.isNil_(code)).and_((function(){return aNode.needsVerification();}))).mustBeBoolean()==true ? (function(){return ((self.knownVariables().includes_(aNode.value())).mustBeBoolean()==true ? nil : (function(){return self.triggerEvent_with_ifNotHandled_("unknownVariable:", aNode, (function(){self.unknownVariables().add_(aNode.value());return self.$klass.unknownVariable_in_(aNode, self);}));})());})() : nil);
(((nil.isNil_(code)).or_((function(){return self.knownVariables().includes_(aNode.value());}))).mustBeBoolean()==true ? (function(){return code=aNode.localNameIn_(self);})() : nil);
self['@stream'].nextPutAll_(code);
self.visitNodeIndices_(aNode);return self;}
,"visiting",unescape("visitVariableNode%3A%20aNode%0D%0A%09%22%20Generate%20code%20to%20access%20variable%20aNode.%20%22%0D%0A%0D%0A%09%7C%20code%20%7C%0D%0A%09code%20%3A%3D%20self%20currentClass%20codeFor%3A%20self%20accessing%3A%20aNode.%0D%0A%09%28code%20isNil%20and%3A%20%5BaNode%20needsVerification%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%28self%20knownVariables%20includes%3A%20aNode%20value%29%20ifFalse%3A%20%5B%0D%0A%09%09%09self%09triggerEvent%3A%20%23unknownVariable%3A%20with%3A%20aNode%0D%0A%09%09%09%09ifNotHandled%3A%20%5B%0D%0A%09%09%09%09%09self%20unknownVariables%20add%3A%20aNode%20value.%0D%0A%09%09%09%09%09self%20class%20unknownVariable%3A%20aNode%20in%3A%20self.%0D%0A%09%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%28code%20isNil%20or%3A%20%5Bself%20knownVariables%20includes%3A%20aNode%20value%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09code%20%3A%3D%20aNode%20localNameIn%3A%20self%0D%0A%09%5D.%0D%0A%0D%0A%09stream%20nextPutAll%3A%20code.%0D%0A%09self%20visitNodeIndices%3A%20aNode."));
smalltalk.bind(smalltalk.Compiler,"unknownVariables",0
,function (){var self=this;return self['@unknownVariables'];;return self;}
,"accessing",unescape("unknownVariables%0D%0A%09%5EunknownVariables"));
smalltalk.bind(smalltalk.Compiler,"pseudoVariables",0
,function (){var self=this;return ["self", "super", "true", "false", "nil", "thisContext"];;return self;}
,"accessing",unescape("pseudoVariables%0D%0A%09%5E%23%28%27self%27%20%27super%27%20%27true%27%20%27false%27%20%27nil%27%20%27thisContext%27%29"));
smalltalk.bind(smalltalk.Compiler,"tempVariables",0
,function (){var self=this;return self['@tempVariables'];;return self;}
,"accessing",unescape("tempVariables%0D%0A%09%5EtempVariables%20%22copy%22"));
smalltalk.bind(smalltalk.Compiler,"knownVariables",0
,function (){var self=this;return self.pseudoVariables()._comma(self.tempVariables());;return self;}
,"accessing",unescape("knownVariables%0D%0A%09%5Eself%20pseudoVariables%20%2C%20self%20tempVariables"));
smalltalk.bind(smalltalk.Compiler,"evaluate:",0
,function (smalltalkExpression){var self=this;return self.evaluate_in_to_(smalltalkExpression, nil.$klass, nil);;return self;}
,"doIt",unescape("evaluate%3A%20smalltalkExpression%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20smalltalk%20expression%20in%20global%20context.%20%22%0D%0A%0D%0A%09%5Eself%20evaluate%3A%20smalltalkExpression%20in%3A%20nil%20class%20to%3A%20nil"));
smalltalk.bind(smalltalk.Compiler,"evaluate:in:to:",0
,function (smalltalkExpression,aClass,aReceiver){var self=this;var result=nil;var doIt=nil;var node=nil;var jsCode=nil;doIt=smalltalk.String.doItSelector();
self.currentClass_(aClass);
node=self.parseCode_(doIt._comma(unescape("%20%5E%5B"))._comma(smalltalkExpression)._comma(unescape("%5D%20value")));
jsCode=self.compileNode_(node);
aClass.addCompiledMethod_(self.eval_(jsCode));
(function(){return result=aReceiver.perform_(doIt);}).ensure_((function(){return aClass.removeSelector_(doIt);}));
return result;;return self;}
,"evaluation",unescape("evaluate%3A%20smalltalkExpression%20in%3A%20aClass%20to%3A%20aReceiver%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20the%20smalltalk%20expression%20with%20aReceiver.%20%22%0D%0A%0D%0A%09%7C%20result%20doIt%20node%20jsCode%20%7C%0D%0A%09doIt%20%3A%3D%20String%20doItSelector.%0D%0A%09self%20currentClass%3A%20aClass.%0D%0A%09node%20%3A%3D%20self%20parseCode%3A%20doIt%2C%27%20%5E%5B%27%2C%20smalltalkExpression%2C%20%27%5D%20value%27.%0D%0A%09jsCode%20%3A%3D%20self%20compileNode%3A%20node.%0D%0A%09aClass%20addCompiledMethod%3A%20%28self%20eval%3A%20jsCode%29.%0D%0A%09%5B%20result%20%3A%3D%20aReceiver%20perform%3A%20doIt.%0D%0A%09%5D%20ensure%3A%20%5B%20aClass%20removeSelector%3A%20doIt.%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.SmalltalkParser.$klass,"constructEventsTriggered",0
,function (){var self=this;return ["needsDirectiveParser:ws:"]._comma(smalltalk.superImplementor(smalltalk.SmalltalkParser.$klass,'constructEventsTriggered').apply(self, []));;return self;}
,"events",unescape("constructEventsTriggered%0D%0A%09%22%20Private%20-%20Return%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%09%23needsDirectiveParser%3Aws%3A%0D%0A%09%29%20%2C%20super%20constructEventsTriggered"));
smalltalk.bind(smalltalk.SmalltalkParser.$klass,"parse:",0
,function (aStream){var self=this;return self.$$new().parse_(aStream);;return self;}
,"instantiation",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%5Eself%20new%20parse%3A%20aStream%20"));
smalltalk.bind(smalltalk.SmalltalkParser,"missingDirective:ws:",0
,function (number,ws){var self=this;return unescape("%5E%3E").asCharacterParser().star().flatten()._comma(unescape("%3E"))._eq_eq_gt((function(node){return node.first().error_("Invalid directive.");}));;return self;}
,"directives",unescape("missingDirective%3A%20number%20ws%3A%20ws%0D%0A%09%22%20Private%20-%20Return%20the%20parser%20for%20missing%20support%20of%20directives.%20%22%0D%0A%0D%0A%09%5E%27%5E%3E%27%20asCharacterParser%20star%20flatten%2C%20%24%3E%0D%0A%09%09%3D%3D%3E%20%5B%3Anode%7C%20node%20first%20error%3A%20%27Invalid%20directive.%27%20%5D"));
smalltalk.bind(smalltalk.SmalltalkParser,"jsDirective:ws:",0
,function (number,ws){var self=this;return "js:".asParser()._slash("javascript:".asParser())._comma(smalltalk.PPInlineParser.upTo_(unescape("%3A%3E")))._eq_eq_gt((function(node){return smalltalk.JSDirectiveNode.code_protected_(node.second(), node.first()._eq("javascript"));}));;return self;}
,"directives",unescape("jsDirective%3A%20number%20ws%3A%20ws%0D%0A%09%22%20Private%20-%20Return%20the%20parser%20for%20javascript%20directives.%0D%0A%09%22%0D%0A%0D%0A%09%5E%28%27js%3A%27%20asParser%20/%20%27javascript%3A%27%20asParser%29%2C%20%28PPInlineParser%20upTo%3A%20%27%3A%3E%27%29%0D%0A%09%09%3D%3D%3E%20%5B%3Anode%7C%20JSDirectiveNode%20code%3A%20node%20second%20protected%3A%20node%20first%20%3D%20%23javascript%20%5D"));
smalltalk.bind(smalltalk.SmalltalkParser,"defaultDirective:ws:",0
,function (number,ws){var self=this;return self.jsDirective_ws_(number, ws)._slash(self.missingDirective_ws_(number, ws));;return self;}
,"directives",unescape("defaultDirective%3A%20number%20ws%3A%20ws%0D%0A%09%22%20Private%20-%20Return%20the%20parser%20for%20default%20support%20of%20directives.%0D%0A%09We%20support%20inlined%20javascript%20directives.%0D%0A%09%22%0D%0A%0D%0A%09%5E%28self%20jsDirective%3A%20number%20ws%3A%20ws%29%0D%0A%09/%28self%20missingDirective%3A%20number%20ws%3A%20ws%29"));
smalltalk.bind(smalltalk.SmalltalkParser,"directive:ws:",0
,function (number,ws){var self=this;var parser=nil;parser=self.triggerEvent_withArguments_ifNotHandled_("needsDirectiveParser:ws:", smalltalk.Array.with_with_(number, ws), (function(){return self.defaultDirective_ws_(number, ws);}));
return unescape("%3C").asParser()._comma(ws._comma(parser)._comma(ws))._eq_eq_gt((function(node){return node.second().second();}));;return self;}
,"directives",unescape("directive%3A%20number%20ws%3A%20ws%0D%0A%09%22%20Private%20-%20Return%20the%20parser%20for%20directives.%20%22%0D%0A%0D%0A%09%7C%20parser%20%7C%0D%0A%09parser%20%3A%3D%20self%0D%0A%09%09triggerEvent%3A%20%23needsDirectiveParser%3Aws%3A%0D%0A%09%09withArguments%3A%20%28Array%20with%3A%20number%20with%3A%20ws%29%0D%0A%09%09ifNotHandled%3A%20%5B%20self%20defaultDirective%3A%20number%20ws%3A%20ws%20%5D.%0D%0A%0D%0A%09%5E%24%3C%20asParser%2C%20%28ws%2C%20parser%2C%20ws%29%0D%0A%09%09%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20second%20%5D"));
smalltalk.bind(smalltalk.SmalltalkParser,"parse:",0
,function (aStream){var self=this;return self.parser().parse_(aStream);;return self;}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%5Eself%20parser%20parse%3A%20aStream"));
smalltalk.bind(smalltalk.SmalltalkParser,"symbolChars",0
,function (){var self=this;return unescape("a-zA-Z0-9_");;return self;}
,"constants",unescape("symbolChars%0D%0A%09%22%20Return%20the%20symbol%20characters%20mask.%20%22%0D%0A%0D%0A%09%5E%27a-zA-Z0-9_%27"));
smalltalk.bind(smalltalk.SmalltalkParser,"binarySelectorChars",0
,function (){var self=this;return unescape("%7C%26%5C%5C+*/%3D%3E%3C%2C@%25%7E-");;return self;}
,"constants",unescape("binarySelectorChars%0D%0A%09%22%20Return%20the%20binary%20selector%20characters%20mask.%20%22%0D%0A%0D%0A%09%5E%27%7C%26%5C%5C+*/%3D%3E%3C%2C@%25%7E-%27"));
smalltalk.bind(smalltalk.SmalltalkParser,"jsSymbolChars",0
,function (){var self=this;return self.symbolChars()._comma("$");;return self;}
,"constants",unescape("jsSymbolChars%0D%0A%09%22%20Return%20the%20javascript%20symbol%20characters%20mask.%20%22%0D%0A%0D%0A%09%5Eself%20symbolChars%20%2C%24%24"));
smalltalk.bind(smalltalk.SmalltalkParser,"extendedSymbolChars",0
,function (){var self=this;return self.symbolChars()._comma(":")._comma(self.binarySelectorChars());;return self;}
,"constants",unescape("extendedSymbolChars%0D%0A%09%22%20Return%20the%20extended%20symbol%20characters%20mask.%20%22%0D%0A%0D%0A%09%5Eself%20symbolChars%20%2C%27%3A%27%20%2C%20self%20binarySelectorChars"));
smalltalk.bind(smalltalk.SmalltalkParser,"globalNameParser",0
,function (){var self=this;return unescape("A-Z").asCharacterParser()._comma(self.symbolChars().asCharacterParser().star()).flatten();;return self;}
,"parsers",unescape("globalNameParser%0D%0A%09%22%20Return%20the%20parser%20for%20global%20names.%20%22%0D%0A%0D%0A%09%5E%28%27A-Z%27%20asCharacterParser%2C%20self%20symbolChars%20asCharacterParser%20star%29%20flatten"));
smalltalk.bind(smalltalk.SmalltalkParser,"parser",0
,function (){var self=this;var method=nil;var expression=nil;var separator=nil;var comment=nil;var ws=nil;var identifier=nil;var keyword=nil;var stSelectorPart=nil;var string=nil;var symbol=nil;var number=nil;var variable=nil;var reference=nil;var globalReference=nil;var literal=nil;var returnExpression=nil;var methodParser=nil;var expressionParser=nil;var keyword=nil;var unarySelector=nil;var binarySelector=nil;var keywordPattern=nil;var unaryPattern=nil;var binaryPattern=nil;var assignment=nil;var temps=nil;var blockParamList=nil;var block=nil;var expression=nil;var expressions=nil;var subexpression=nil;var statements=nil;var sequence=nil;var operand=nil;var unaryMessage=nil;var unarySend=nil;var unaryTail=nil;var binaryMessage=nil;var binarySend=nil;var binaryTail=nil;var keywordMessage=nil;var keywordSend=nil;var keywordPair=nil;var cascade=nil;var message=nil;var jsStatement=nil;var jsIndex=nil;var character=nil;var directive=nil;var arrayLiteral=nil;var arrayVariable=nil;var literalArray=nil;var aSymbol=nil;var stIdentifier=nil;var jsIdentifier=nil;var noReference=nil;var alienReference=nil;var alienIdentifier=nil;var emptyArray=nil;var hashedString=nil;separator=smalltalk.String.cr()._comma(smalltalk.String.space())._comma(smalltalk.String.lf())._comma(smalltalk.String.tab()).asChoiceParser();
comment=unescape("%22").asCharacterParser()._comma(unescape("%22").asParser().not()._comma(smalltalk.PPAnyParser.$$new()).star())._comma(unescape("%22").asCharacterParser()).flatten();
ws=separator._slash(comment).star();
string=unescape("%27").asParser()._comma(smalltalk.PPStStringParser.$$new())._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(node.second());}));
hashedString=unescape("%23")._comma(unescape("%27")).asParser()._comma(smalltalk.PPStStringParser.$$new())._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(node.second());}));
stIdentifier=unescape("a-z_").asCharacterParser()._comma(self.symbolChars().asCharacterParser().star()).flatten();
stSelectorPart=unescape("A-Za-z_").asCharacterParser()._comma(self.symbolChars().asCharacterParser().star()).flatten();
jsIdentifier=unescape("%23").asParser()._comma(self.jsSymbolChars().asCharacterParser().plus()).flatten();
alienIdentifier=self.jsSymbolChars().asCharacterParser().plus().flatten();
identifier=jsIdentifier._slash(stIdentifier);
keyword=stSelectorPart._slash(identifier)._comma(":").flatten();
symbol=unescape("%23").asParser()._comma(self.extendedSymbolChars().asCharacterParser().plus().flatten())._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(node.second());}));
number=unescape("-0-9").asCharacterParser().plus()._comma(".".asParser()._comma(unescape("0-9").asCharacterParser().plus()).optional())._comma("r".asParser()._comma(unescape("A-Z0-9").asCharacterParser().plus()).optional()).flatten()._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(node.asNumber());}));
character="$".asParser()._comma(smalltalk.PPAnyParser.$$new())._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(node.at_((2)));}));
directive=self.directive_ws_(number, ws);
variable=identifier._eq_eq_gt((function(token){return smalltalk.VariableNode.$$new().value_(token);}));
noReference=unescape("%23").asParser()._eq_eq_gt((function(token){return smalltalk.NoReceiverNode.$$new();}));
literal=smalltalk.PPDelegateParser.$$new();
expression=smalltalk.PPDelegateParser.$$new();
arrayVariable="true".asParser()._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(true);}))._slash("false".asParser()._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(false);})))._slash("nil".asParser()._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(nil);})));
aSymbol=self.extendedSymbolChars().asCharacterParser().plus().flatten()._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(node);}));
arrayLiteral=literal._slash(arrayVariable)._slash(aSymbol)._slash(variable);
literalArray=unescape("%23%28").asParser()._comma(ws._comma(arrayLiteral)._comma(ws).star())._comma(unescape("%29"))._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(smalltalk.Array.withAll_(node.second().collect_((function(each){return each.second().value();}))));}));
emptyArray=unescape("%23%28").asParser()._comma(ws)._comma(unescape("%29"))._eq_eq_gt((function(node){return smalltalk.ValueNode.$$new().value_(smalltalk.Array.$$new());}));
globalReference=self.globalNameParser()._eq_eq_gt((function(token){return smalltalk.GlobalReferenceNode.$$new().value_(token);}));
alienReference=unescape("%23%7B").asParser()._comma(alienIdentifier)._comma(unescape("%7D"))._eq_eq_gt((function(node){return smalltalk.AlienNode.$$new().value_(node.second());}));
jsIndex=unescape("%5B").asParser()._comma(expression)._comma(unescape("%5D"))._slash(unescape("%23").asParser()._comma(identifier));
reference=variable._slash(globalReference)._slash(alienReference)._comma(jsIndex.star())._eq_eq_gt((function(nodes){return nodes.first().indexedAs_(nodes);}));
binarySelector=unescape("%23").asParser().optional()._comma(self.binarySelectorChars().asCharacterParser().plus()).flatten();
unarySelector=stSelectorPart._slash(identifier);
keywordPattern=ws._comma(keyword)._comma(ws)._comma(identifier).plus()._eq_eq_gt((function(nodes){return smalltalk.Array.with_with_(nodes.collect_((function(each){return each.at_((2));})).join_(""), nodes.collect_((function(each){return each.at_((4));})));}));
binaryPattern=ws._comma(binarySelector)._comma(ws)._comma(identifier)._eq_eq_gt((function(node){return smalltalk.Array.with_with_(node.second(), smalltalk.Array.with_(node.fourth()));}));
unaryPattern=ws._comma(unarySelector)._eq_eq_gt((function(node){return smalltalk.Array.with_with_(node.second(), smalltalk.Array.$$new());}));
expressions=expression._comma(ws._comma(".")._comma(ws)._comma(expression)._eq_eq_gt((function(node){return node.fourth();})).star())._eq_eq_gt((function(node){return smalltalk.Array.with_(node.first())._comma(node.second());}));
assignment=reference._comma(ws)._comma(unescape("%3A%3D"))._comma(ws)._comma(expression)._eq_eq_gt((function(node){return (function($rec){$rec.left_(node.first());return $rec.right_(node.at_((5)));})(smalltalk.AssignmentNode.$$new());}));
returnExpression=unescape("%5E").asParser()._comma(ws)._comma(expression)._comma(ws)._comma(".".asParser().optional())._eq_eq_gt((function(node){return (function($rec){$rec.addNode_(node.third());return $rec.yourself();})(smalltalk.ReturnNode.$$new());}));
temps=unescape("%7C").asParser()._comma(ws._comma(identifier).star())._comma(ws)._comma(unescape("%7C"))._eq_eq_gt((function(node){return node.second().collect_((function(each){return each.second();}));}));
blockParamList=":".asParser()._comma(ws)._comma(identifier)._comma(ws).plus()._comma(unescape("%7C"))._eq_eq_gt((function(node){return node.first().collect_((function(each){return each.third();}));}));
subexpression=unescape("%28").asParser()._comma(ws)._comma(expression)._comma(ws)._comma(unescape("%29"))._eq_eq_gt((function(node){return node.third();}));
statements=returnExpression._eq_eq_gt((function(node){return smalltalk.Array.with_(node);}))._slash(expressions._comma(ws)._comma(".")._comma(ws)._comma(returnExpression)._eq_eq_gt((function(node){return (function($rec){$rec.add_(node.at_((5)));return $rec.yourself();})(node.first());})))._slash(expressions._comma(".".asParser().optional())._eq_eq_gt((function(node){return node.first();})));
sequence=temps.optional()._comma(ws)._comma(directive.optional())._comma(ws)._comma(statements.optional())._comma(ws)._eq_eq_gt((function(node){return (function($rec){$rec.directive_(node.third());$rec.temps_(node.first());$rec.nodes_(node.at_((5)));return $rec.yourself();})(smalltalk.ExtendedSequenceNode.$$new());}));
block=unescape("%5B").asParser()._comma(ws)._comma(blockParamList.optional())._comma(ws)._comma(sequence.optional())._comma(ws)._comma(unescape("%5D"))._eq_eq_gt((function(node){return (function($rec){$rec.parameters_(node.third());return $rec.addNode_(node.at_((5)).asBlockSequenceNode());})(smalltalk.BlockNode.$$new());}));
operand=block._slash(literal)._slash(reference)._slash(noReference)._slash(subexpression);
literal.parser_(symbol._slash(number)._slash(string)._slash(character)._slash(emptyArray)._slash(literalArray)._slash(hashedString));
unaryMessage=ws._comma(unarySelector)._comma(":".asParser().not())._eq_eq_gt((function(node){return smalltalk.SendNode.$$new().selector_(node.second());}));
unaryTail=smalltalk.PPDelegateParser.$$new();
unaryTail.parser_(unaryMessage._comma(unaryTail.optional())._eq_eq_gt((function(node){return (((nil.isNil_(node.second()))).mustBeBoolean()==true ? (function(){return node.first();})() : (function(){return node.second().valueForReceiver_(node.first());})());})));
unarySend=operand._comma(unaryTail.optional())._eq_eq_gt((function(node){return (((nil.isNil_(node.second()))).mustBeBoolean()==true ? (function(){return node.first();})() : (function(){return node.second().valueForReceiver_(node.first());})());}));
binaryMessage=ws._comma(binarySelector)._comma(ws)._comma(unarySend._slash(operand))._eq_eq_gt((function(node){return (function($rec){$rec.selector_(node.second());return $rec.arguments_(smalltalk.Array.with_(node.fourth()));})(smalltalk.SendNode.$$new());}));
binaryTail=smalltalk.PPDelegateParser.$$new();
binaryTail.parser_(binaryMessage._comma(binaryTail.optional())._eq_eq_gt((function(node){return (((nil.isNil_(node.second()))).mustBeBoolean()==true ? (function(){return node.first();})() : (function(){return node.second().valueForReceiver_(node.first());})());})));
binarySend=unarySend._comma(binaryTail.optional())._eq_eq_gt((function(node){return (((nil.isNil_(node.second()))).mustBeBoolean()==true ? (function(){return node.first();})() : (function(){return node.second().valueForReceiver_(node.first());})());}));
keywordPair=keyword._comma(ws)._comma(binarySend);
keywordMessage=ws._comma(keywordPair).plus()._eq_eq_gt((function(nodes){return (function($rec){$rec.selector_(nodes.collect_((function(each){return each.second().first();})).join_(""));return $rec.arguments_(nodes.collect_((function(each){return each.second().third();})));})(smalltalk.SendNode.$$new());}));
keywordSend=binarySend._comma(keywordMessage)._eq_eq_gt((function(node){return node.second().valueForReceiver_(node.first());}));
message=binaryMessage._slash(unaryMessage)._slash(keywordMessage);
cascade=keywordSend._slash(binarySend)._comma(ws._comma(unescape("%3B"))._comma(message).plus())._eq_eq_gt((function(node){return node.first().cascadeNodeWithMessages_(node.second().collect_((function(each){return each.third();})));}));
jsStatement=unescape("%7B").asParser()._comma(ws)._comma(string)._comma(ws)._comma(unescape("%7D"))._eq_eq_gt((function(node){return (function($rec){$rec.source_(node.third());return $rec.yourself();})(smalltalk.InlineNode.$$new());}));
expression.parser_(assignment._slash(cascade)._slash(keywordSend)._slash(binarySend)._slash(jsStatement));
method=ws._comma(keywordPattern._slash(binaryPattern)._slash(unaryPattern))._comma(ws)._comma(sequence.optional())._comma(ws).withSource()._eq_eq_gt((function(node){return (function($rec){$rec.selector_(node.first().second().first());$rec.arguments_(node.first().second().second());$rec.addNode_(node.first().fourth());$rec.source_(node.second());return $rec.yourself();})(smalltalk.MethodNode.$$new());}));
return method._comma(smalltalk.PPEOFParser.$$new())._eq_eq_gt((function(node){return node.first();}));;return self;}
,"parsers",unescape("parser%0D%0A%09%22%20Return%20the%20parser%20of%20the%20receiver.%20%22%0D%0A%0D%0A%20%7C%20method%20expression%20separator%20comment%20ws%20identifier%20keyword%20stSelectorPart%0D%0A%20%20string%20symbol%20number%20variable%20reference%20globalReference%0D%0A%20%20literal%20returnExpression%20methodParser%20expressionParser%20keyword%20unarySelector%0D%0A%20%20binarySelector%20keywordPattern%20unaryPattern%20binaryPattern%20assignment%0D%0A%20%20temps%20blockParamList%20block%20expression%20expressions%20subexpression%0D%0A%20%20statements%20sequence%20operand%20unaryMessage%20unarySend%20unaryTail%0D%0A%20%20binaryMessage%20binarySend%20binaryTail%20keywordMessage%20keywordSend%0D%0A%20%20keywordPair%20cascade%20message%20jsStatement%20jsIndex%20character%20directive%0D%0A%20%20arrayLiteral%20arrayVariable%20literalArray%20aSymbol%0D%0A%20%20stIdentifier%20jsIdentifier%20noReference%20alienReference%0D%0A%20%20alienIdentifier%20emptyArray%20hashedString%0D%0A%20%7C%0D%0A%0D%0A%20separator%20%3A%3D%20%28String%20cr%2C%20String%20space%2C%20String%20lf%2C%20String%20tab%29%20asChoiceParser.%0D%0A%20comment%20%3A%3D%20%28%24%22%20asCharacterParser%2C%20%28%24%22%20asParser%20not%2C%20PPAnyParser%20new%29%20star%2C%20%24%22%20asCharacterParser%29%20flatten.%0D%0A%20ws%20%3A%3D%20%28separator%20/%20comment%29%20star.%0D%0A%20%0D%0A%20string%20%3A%3D%20%24%27%20asParser%20%2C%20PPStStringParser%20new%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%7C%20ValueNode%20new%20value%3A%20node%20second%20%5D.%0D%0A%20%0D%0A%20hashedString%20%3A%3D%20%28%24%23%2C%24%27%29%20asParser%20%2C%20PPStStringParser%20new%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%7C%20ValueNode%20new%20value%3A%20node%20second%20%5D.%0D%0A%0D%0A%20stIdentifier%20%3A%3D%20%28%27a-z_%27%20asCharacterParser%2C%20self%20symbolChars%20asCharacterParser%20star%29%20flatten.%0D%0A%20stSelectorPart%20%3A%3D%20%28%27A-Za-z_%27%20asCharacterParser%2C%20self%20symbolChars%20asCharacterParser%20star%29%20flatten.%0D%0A%20jsIdentifier%20%3A%3D%20%28%24%23%20asParser%2C%20self%20jsSymbolChars%20asCharacterParser%20plus%29%20flatten.%0D%0A%20alienIdentifier%20%3A%3D%20self%20jsSymbolChars%20asCharacterParser%20plus%20flatten.%0D%0A%20identifier%20%3A%3D%20jsIdentifier%20/%20stIdentifier.%0D%0A%0D%0A%20keyword%20%3A%3D%20%28stSelectorPart%20/%20identifier%2C%20%24%3A%29%20flatten.%0D%0A%0D%0A%20symbol%20%3A%3D%20%24%23%20asParser%2C%20self%20extendedSymbolChars%20asCharacterParser%20plus%20flatten%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ValueNode%20new%20value%3A%20node%20second%20%5D.%0D%0A%0D%0A%20number%20%3A%3D%20%28%27-0-9%27%20asCharacterParser%20plus%0D%0A%20%20%2C%20%28%24.%20asParser%2C%20%270-9%27%20asCharacterParser%20plus%29%20optional%0D%0A%20%20%2C%20%28%24r%20asParser%2C%20%27A-Z0-9%27%20asCharacterParser%20plus%29%20optional%0D%0A%20%20%29%20flatten%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ValueNode%20new%20value%3A%20node%20asNumber%20%5D.%0D%0A%0D%0A%20character%20%3A%3D%20%24%24%20asParser%2C%20PPAnyParser%20new%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ValueNode%20new%20value%3A%20%28node%20at%3A%202%29%20%5D.%0D%0A%0D%0A%20directive%20%3A%3D%20self%20directive%3A%20number%20ws%3A%20ws.%0D%0A%0D%0A%20variable%20%3A%3D%20identifier%20%3D%3D%3E%20%5B%3Atoken%20%7C%20VariableNode%20new%20value%3A%20token%20%5D.%0D%0A%20noReference%20%3A%3D%20%24%23%20asParser%20%3D%3D%3E%20%5B%3Atoken%20%7C%20NoReceiverNode%20new%20%5D.%0D%0A%20literal%20%3A%3D%20PPDelegateParser%20new.%0D%0A%20expression%20%3A%3D%20PPDelegateParser%20new.%0D%0A%0D%0A%20arrayVariable%20%3A%3D%0D%0A%20%20%20%20%28%23true%20asParser%20%3D%3D%3E%20%5B%3Anode%7C%20ValueNode%20new%20value%3A%20true%20%5D%29%0D%0A%20%20/%20%28%23false%20asParser%20%3D%3D%3E%20%5B%3Anode%7C%20ValueNode%20new%20value%3A%20false%20%5D%29%0D%0A%20%20/%20%28%23nil%20asParser%20%3D%3D%3E%20%5B%3Anode%7C%20ValueNode%20new%20value%3A%20nil%20%5D%29.%0D%0A%20aSymbol%20%3A%3D%20self%20extendedSymbolChars%20asCharacterParser%20plus%20flatten%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%7C%20ValueNode%20new%20value%3A%20node%20%5D.%0D%0A%0D%0A%20arrayLiteral%20%3A%3D%20literal%20/%20arrayVariable%20/%20aSymbol%20/%20variable.%0D%0A%20literalArray%20%3A%3D%20%27%23%28%27%20asParser%2C%20%28ws%2C%20arrayLiteral%2C%20ws%29%20star%2C%20%24%29%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ValueNode%20new%20value%3A%0D%0A%20%20%20%20%28Array%20withAll%3A%20%28node%20second%0D%0A%20%20%20%20%20collect%3A%20%5B%3Aeach%20%7C%20each%20second%20value%5D%29%29%20%5D.%0D%0A%20emptyArray%20%3A%3D%20%27%23%28%27%20asParser%20%2Cws%20%2C%24%29%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ValueNode%20new%20value%3A%20Array%20new%20%5D.%0D%0A%0D%0A%20globalReference%20%3A%3D%20self%20globalNameParser%0D%0A%20%20%3D%3D%3E%20%5B%3Atoken%20%7C%20GlobalReferenceNode%20new%20value%3A%20token%20%5D.%0D%0A%20alienReference%20%3A%3D%20%27%23%7B%27%20asParser%2C%20alienIdentifier%2C%20%24%7D%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20AlienNode%20new%20value%3A%20node%20second%20%5D.%0D%0A%0D%0A%20jsIndex%20%3A%3D%20%24%5B%20asParser%2C%20expression%2C%20%24%5D%0D%0A%20%20/%20%28%24%23%20asParser%2C%20identifier%29.%0D%0A%20reference%20%3A%3D%20%28variable%20/%20globalReference%20/%20alienReference%29%20%2C%20jsIndex%20star%0D%0A%20%20%3D%3D%3E%20%5B%3Anodes%20%7C%20nodes%20first%20indexedAs%3A%20nodes%20%5D.%0D%0A%0D%0A%20binarySelector%20%3A%3D%20%28%24%23%20asParser%20optional%2C%20self%20binarySelectorChars%20asCharacterParser%20plus%29%20flatten.%0D%0A%0D%0A%20unarySelector%20%3A%3D%20stSelectorPart%20/%20identifier.%0D%0A%0D%0A%20keywordPattern%20%3A%3D%20%28ws%2C%20keyword%2C%20ws%2C%20identifier%29%20plus%0D%0A%20%20%3D%3D%3E%20%5B%3Anodes%20%7C%20Array%0D%0A%20%20%20with%3A%20%28%28nodes%20collect%3A%20%5B%3Aeach%20%7C%20each%20at%3A%202%5D%29%20join%3A%20%27%27%29%0D%0A%20%20%20with%3A%20%28nodes%20collect%3A%20%5B%3Aeach%20%7C%20each%20at%3A%204%5D%29%20%5D.%0D%0A%0D%0A%20binaryPattern%20%3A%3D%20ws%2C%20binarySelector%2C%20ws%2C%20identifier%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20Array%20with%3A%20node%20second%20with%3A%20%28Array%20with%3A%20node%20fourth%29%5D.%0D%0A%0D%0A%20unaryPattern%20%3A%3D%20ws%2C%20unarySelector%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20Array%20with%3A%20node%20second%20with%3A%20Array%20new%5D.%0D%0A%20%0D%0A%20expressions%20%3A%3D%20expression%2C%20%28%28ws%2C%20%24.%2C%20ws%2C%20expression%29%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20fourth%5D%29%20star%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20%28Array%20with%3A%20node%20first%29%20%2Cnode%20second%20%5D.%0D%0A%0D%0A%20assignment%20%3A%3D%20reference%2C%20ws%2C%20%27%3A%3D%27%2C%20ws%2C%20expression%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20AssignmentNode%20new%20left%3A%20node%20first%3B%20right%3A%20%28node%20at%3A%205%29%5D.%0D%0A%0D%0A%20returnExpression%20%3A%3D%20%24%5E%20asParser%2C%20ws%2C%20expression%2C%20ws%2C%20%24.%20asParser%20optional%0D%0A%20%20%20%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ReturnNode%20new%20addNode%3A%20node%20third%3B%20yourself%20%5D.%0D%0A%0D%0A%20temps%20%3A%3D%20%24%7C%20asParser%2C%20%28ws%2C%20identifier%29%20star%2C%20ws%2C%20%24%7C%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20collect%3A%20%5B%3Aeach%20%7C%20each%20second%20%5D%20%5D.%0D%0A%0D%0A%20blockParamList%20%3A%3D%20%28%24%3A%20asParser%2C%20ws%2C%20identifier%2C%20ws%29%20plus%2C%20%24%7C%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20first%20collect%3A%20%5B%3Aeach%20%7C%20each%20third%20%5D%20%5D.%0D%0A%0D%0A%20subexpression%20%3A%3D%20%24%28%20asParser%2C%20ws%2C%20expression%2C%20ws%2C%20%24%29%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20third%20%5D.%0D%0A%0D%0A%20statements%20%3A%3D%20%28returnExpression%20%3D%3D%3E%20%5B%3Anode%20%7C%20Array%20with%3A%20node%5D%29%0D%0A%20%20/%20%28expressions%2C%20ws%2C%20%24.%2C%20ws%2C%20returnExpression%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20first%20add%3A%20%28node%20at%3A%205%29%3B%20yourself%20%5D%29%0D%0A%20%20/%20%28expressions%20%2C%20%24.%20asParser%20optional%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20first%20%5D%29.%0D%0A%0D%0A%20sequence%20%3A%3D%20temps%20optional%2C%20ws%2C%20directive%20optional%2C%20ws%2C%20statements%20optional%2C%20ws%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20ExtendedSequenceNode%20new%0D%0A%20%20%20directive%3A%20node%20third%3B%0D%0A%20%20%20temps%3A%20node%20first%3B%0D%0A%20%20%20nodes%3A%20%28node%20at%3A%205%29%3B%0D%0A%20%20%20yourself%20%5D.%0D%0A%0D%0A%20block%20%3A%3D%20%24%5B%20asParser%2C%20ws%2C%20blockParamList%20optional%2C%20ws%2C%20sequence%20optional%2C%20ws%2C%20%24%5D%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%0D%0A%20%20%20%20%20%20BlockNode%20new%0D%0A%20%20%20parameters%3A%20node%20third%3B%0D%0A%20%20%20addNode%3A%20%28node%20at%3A%205%29%20asBlockSequenceNode%20%5D.%0D%0A%0D%0A%20operand%20%3A%3D%20block%20/%20literal%20/%20reference%20/%20noReference%20/%20subexpression.%0D%0A%0D%0A%20literal%20parser%3A%20symbol%20/%20number%20/%20string%20/%20character%0D%0A%20%20/%20emptyArray%20/%20literalArray%20/%20hashedString.%0D%0A%0D%0A%20unaryMessage%20%3A%3D%20ws%2C%20unarySelector%2C%20%24%3A%20asParser%20not%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20SendNode%20new%20selector%3A%20node%20second%20%5D.%0D%0A%0D%0A%20unaryTail%20%3A%3D%20PPDelegateParser%20new.%0D%0A%20unaryTail%20parser%3A%20%28unaryMessage%2C%20unaryTail%20optional%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20isNil%20ifTrue%3A%20%5B%20node%20first%20%5D%0D%0A%20%20%20ifFalse%3A%20%5B%20node%20second%20valueForReceiver%3A%20node%20first%20%5D%20%5D%29.%0D%0A%0D%0A%20unarySend%20%3A%3D%20operand%2C%20unaryTail%20optional%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20isNil%20ifTrue%3A%20%5B%20node%20first%20%5D%0D%0A%20%20%20ifFalse%3A%20%5B%20node%20second%20valueForReceiver%3A%20node%20first%20%5D%20%5D.%0D%0A%0D%0A%20binaryMessage%20%3A%3D%20ws%2C%20binarySelector%2C%20ws%2C%20%28unarySend%20/%20operand%29%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20SendNode%20new%0D%0A%20%20%20selector%3A%20node%20second%3B%0D%0A%20%20%20arguments%3A%20%28Array%20with%3A%20node%20fourth%29%20%5D.%0D%0A%0D%0A%20binaryTail%20%3A%3D%20PPDelegateParser%20new.%0D%0A%20binaryTail%20parser%3A%20%28binaryMessage%2C%20binaryTail%20optional%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20isNil%20ifTrue%3A%20%5B%20node%20first%20%5D%0D%0A%20%20%20ifFalse%3A%20%5B%20node%20second%20valueForReceiver%3A%20node%20first%20%5D%20%5D%29.%0D%0A%0D%0A%20binarySend%20%3A%3D%20unarySend%2C%20binaryTail%20optional%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20isNil%20ifTrue%3A%20%5B%20node%20first%20%5D%0D%0A%20%20%20ifFalse%3A%20%5B%20node%20second%20valueForReceiver%3A%20node%20first%20%5D%20%5D.%0D%0A%0D%0A%20keywordPair%20%3A%3D%20keyword%2C%20ws%2C%20binarySend.%0D%0A%0D%0A%20keywordMessage%20%3A%3D%20%28ws%2C%20keywordPair%29%20plus%0D%0A%20%20%3D%3D%3E%20%5B%3Anodes%20%7C%20SendNode%20new%0D%0A%20%20%20selector%3A%20%28%28nodes%20collect%3A%20%5B%3Aeach%20%7C%20each%20second%20first%5D%29%20join%3A%20%27%27%29%3B%0D%0A%20%20%20arguments%3A%20%28nodes%20collect%3A%20%5B%3Aeach%20%7C%20each%20second%20third%5D%29%5D.%0D%0A%0D%0A%20keywordSend%20%3A%3D%20binarySend%2C%20keywordMessage%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20second%20valueForReceiver%3A%20node%20first%5D.%0D%0A%0D%0A%20message%20%3A%3D%20binaryMessage%20/%20unaryMessage%20/%20keywordMessage.%0D%0A%0D%0A%20cascade%20%3A%3D%20%28keywordSend%20/%20binarySend%29%2C%20%28ws%2C%20%24%3B%2C%20message%29%20plus%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20first%20cascadeNodeWithMessages%3A%20%0D%0A%20%20%20%28node%20second%20collect%3A%20%5B%3Aeach%20%7C%20each%20third%20%5D%29%5D.%0D%0A%0D%0A%20jsStatement%20%3A%3D%20%24%7B%20asParser%2C%20ws%2C%20string%2C%20ws%2C%20%24%7D%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20InlineNode%20new%20source%3A%20node%20third%3B%20yourself%20%5D.%0D%0A%0D%0A%20expression%20parser%3A%20assignment%20/%20cascade%20/%20keywordSend%20/%20binarySend%20/%20jsStatement.%0D%0A%0D%0A%20method%20%3A%3D%20%28ws%2C%20%28keywordPattern%20/%20binaryPattern%20/%20unaryPattern%29%2C%20ws%2C%20sequence%20optional%2C%20ws%29%20withSource%0D%0A%20%20%3D%3D%3E%20%5B%3Anode%20%7C%20MethodNode%20new%0D%0A%20%20%20selector%3A%20node%20first%20second%20first%3B%0D%0A%20%20%20arguments%3A%20node%20first%20second%20second%3B%0D%0A%20%20%20addNode%3A%20node%20first%20fourth%3B%0D%0A%20%20%20source%3A%20node%20second%3B%0D%0A%20%20%20yourself%20%5D.%0D%0A%20%0D%0A%20%5Emethod%2C%20PPEOFParser%20new%20%3D%3D%3E%20%5B%3Anode%20%7C%20node%20first%20%5D"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"constructEventsTriggered",0
,function (){var self=this;return ["found:", "found:pattern:in:", "needsMethods", "searchStarted", "searchFinished"]._comma(smalltalk.superImplementor(smalltalk.MethodReferences.$klass,'constructEventsTriggered').apply(self, []));;return self;}
,"events",unescape("constructEventsTriggered%0D%0A%09%22%20Private%20-%20Return%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%09%23found%3A%20%23found%3Apattern%3Ain%3A%0D%0A%09%09%23needsMethods%0D%0A%09%09%23searchStarted%20%23searchFinished%0D%0A%09%29%20%2C%20super%20constructEventsTriggered"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"of:",0
,function (selector){var self=this;return self.$$new().referencesOf_(selector);;return self;}
,"testing",unescape("of%3A%20selector%0D%0A%09%22%20Return%20the%20references%20to%20selector.%20%22%0D%0A%0D%0A%09%5Eself%20new%20referencesOf%3A%20selector"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"ofGlobal:",0
,function (globalName){var self=this;return self.$$new().referencesOfGlobal_(globalName);;return self;}
,"testing",unescape("ofGlobal%3A%20globalName%0D%0A%09%22%20Return%20the%20references%20to%20global%20globalName.%20%22%0D%0A%0D%0A%09%5Eself%20new%20referencesOfGlobal%3A%20globalName"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"findClasses:",0
,function (what){var self=this;return self.$$new().findClasses_(what);;return self;}
,"testing",unescape("findClasses%3A%20what%0D%0A%09%22%20Find%20classes%20in%20the%20system%20matching%20what.%20%22%0D%0A%0D%0A%09%5Eself%20new%20findClasses%3A%20what"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"globals",0
,function (){var self=this;var tool=nil;var result=nil;tool=self.$$new();
result=smalltalk.PoolDictionary.$$new();
tool.when_do_("found:pattern:in:", (function(mth,mask,stream){var global=nil;global=smalltalk.SmalltalkParser.$$new().globalNameParser().parse_(stream);return ((global.isParseFailure()).mustBeBoolean()==true ? nil : (function(){return result.at_ifAbsentPut_(global, (function(){return smalltalk.Array.$$new();})).add_(mth);})());}));
tool.searchGlobalReferences();
return result;;return self;}
,"testing",unescape("globals%0D%0A%09%22%20Return%20the%20references%20to%20all%20global%20names.%20%22%0D%0A%0D%0A%09%7C%20tool%20result%20%7C%0D%0A%09tool%20%3A%3D%20self%20new.%0D%0A%09result%20%3A%3D%20PoolDictionary%20new.%0D%0A%09tool%20when%3A%20%23found%3Apattern%3Ain%3A%20do%3A%20%5B%3Amth%20%3Amask%20%3Astream%7C%20%7C%20global%20%7C%0D%0A%09%09global%20%3A%3D%20SmalltalkParser%20new%20globalNameParser%20parse%3A%20stream.%0D%0A%09%09global%20isParseFailure%20ifFalse%3A%20%5B%0D%0A%09%09%09%28result%20at%3A%20global%20ifAbsentPut%3A%20%5BArray%20new%5D%29%20add%3A%20mth%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09tool%20searchGlobalReferences.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"methodOverwrites",0
,function (){var self=this;return self.$$new().methodOverwrites();;return self;}
,"testing",unescape("methodOverwrites%0D%0A%09%22%20Find%20the%20methods%20that%20are%20implemented/overwritten%20by%20subclasses.%20%22%0D%0A%0D%0A%09%5Eself%20new%20methodOverwrites"));
smalltalk.bind(smalltalk.MethodReferences.$klass,"variableOverwrites",0
,function (){var self=this;return self.$$new().variableOverwrites();;return self;}
,"testing",unescape("variableOverwrites%0D%0A%09%22%20Find%20the%20methods%20that%20has%20potential%20overwrite%20of%20variable%20names.%20%22%0D%0A%0D%0A%09%5Eself%20new%20variableOverwrites"));
smalltalk.bind(smalltalk.MethodReferences,"initializeResults",0
,function (){var self=this;self['@results']=smalltalk.Array.$$new();return self;}
,"initialize",unescape("initializeResults%0D%0A%09%22%20Private%20-%20Initialize%20the%20results%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09results%20%3A%3D%20Array%20new"));
smalltalk.bind(smalltalk.MethodReferences,"reset",0
,function (){var self=this;self.results_(nil);return self;}
,"initialize",unescape("reset%0D%0A%09%22%20Reset%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20results%3A%20nil"));
smalltalk.bind(smalltalk.MethodReferences,"rootClasses:",0
,function (array){var self=this;self['@rootClasses']=array;return self;}
,"accessing",unescape("rootClasses%3A%20array%0D%0A%09%22%20Set%20the%20rootClasses%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09rootClasses%20%3A%3D%20array"));
smalltalk.bind(smalltalk.MethodReferences,"results",0
,function (){var self=this;(((nil.isNil_(self['@results']))).mustBeBoolean()==true ? (function(){return self.initializeResults();})() : nil);
return self['@results'];;return self;}
,"accessing",unescape("results%0D%0A%09%22%20Return%20the%20results%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09results%20isNil%20ifTrue%3A%20%5B%20self%20initializeResults%20%5D.%0D%0A%09%5Eresults"));
smalltalk.bind(smalltalk.MethodReferences,"results:",0
,function (array){var self=this;self['@results']=array;return self;}
,"accessing",unescape("results%3A%20array%0D%0A%09%22%20Set%20the%20results%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09results%20%3A%3D%20array"));
smalltalk.bind(smalltalk.MethodReferences,"rootClasses",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@rootClasses']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Smalltalk.rootClasses();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@rootClasses'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("rootClasses%0D%0A%09%22%20Return%20the%20rootClasses%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09rootClasses%20isNil%20ifTrue%3A%20%5B%20%5ESmalltalk%20rootClasses%20%5D.%0D%0A%09%5ErootClasses"));
smalltalk.bind(smalltalk.MethodReferences,"allMethodsIn:",0
,function (aCollection){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.rootClasses().do_((function(root){return root.instanceClass().withAllSubclasses().do_((function(cls){cls.methodsDo_((function(each){return result.add_(each);}));return cls.$klass.methodsDo_((function(each){return result.add_(each);}));}));}));
return result;;return self;}
,"accessing",unescape("allMethodsIn%3A%20aCollection%0D%0A%09%22%20Return%20the%20methods%20defined%20by%20aCollection%20of%20classes.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20rootClasses%20do%3A%20%5B%3Aroot%7C%0D%0A%09%09root%20instanceClass%20withAllSubclasses%20do%3A%20%5B%3Acls%7C%0D%0A%09%09%09cls%20methodsDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%09%09cls%20class%20methodsDo%3A%20%5B%3Aeach%7C%20result%20add%3A%20each%20%5D.%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.MethodReferences,"allMethods",0
,function (){var self=this;return self.triggerEvent_ifNotHandled_("needsMethods", (function(){return self.allMethodsIn_(self.rootClasses());}));;return self;}
,"accessing",unescape("allMethods%0D%0A%09%22%20Return%20the%20methods%20to%20search%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%09triggerEvent%3A%20%23needsMethods%0D%0A%09%09ifNotHandled%3A%20%5B%20self%20allMethodsIn%3A%20self%20rootClasses%20%5D"));
smalltalk.bind(smalltalk.MethodReferences,"search:with:",0
,function (what,targetBlock){var self=this;var atoms=nil;atoms=self.allMethods();
self.triggerEvent_("searchStarted");
atoms=atoms.select_((function(aMethod){var source=nil;source=targetBlock.value_(aMethod);return (((nil.isNil_(source)===false).and_((function(){return source.toString().includes_(what);}))).mustBeBoolean()==true ? (function(){self.results().add_(aMethod);self.triggerEvent_with_("found:", aMethod);((self.hasActionForEvent_("found:pattern:in:")).mustBeBoolean()==true ? (function(){var stream=nil;var args=nil;stream=source.toString().stream();args=smalltalk.Array.with_with_with_(aMethod, what, stream);return (function(){while(!(function(){return (function($rec){$rec.upTo_(what);return $rec.atEnd();})(stream);})()){(function(){return self.triggerEvent_withArguments_("found:pattern:in:", args);})()};return nil})();})() : nil);return true;})() : (function(){return false;})());}));
self.triggerEvent_("searchFinished");
return atoms;;return self;}
,"searching",unescape("search%3A%20what%20with%3A%20targetBlock%0D%0A%09%22%20Find%20what%20on%20target%20of%20selected%20methods.%20%22%0D%0A%0D%0A%09%7C%20atoms%20%7C%0D%0A%09atoms%20%3A%3D%20self%20allMethods.%0D%0A%09self%20triggerEvent%3A%20%23searchStarted.%0D%0A%09atoms%20%3A%3D%20atoms%20select%3A%20%5B%3AaMethod%7C%20%7C%20source%20%7C%0D%0A%09%09source%20%3A%3D%20targetBlock%20value%3A%20aMethod.%0D%0A%09%09%28source%20notNil%20and%3A%20%5Bsource%20toString%20includes%3A%20what%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20results%20add%3A%20aMethod.%0D%0A%09%09%09self%20triggerEvent%3A%20%23found%3A%20with%3A%20aMethod.%0D%0A%09%09%09%28self%20hasActionForEvent%3A%20%23found%3Apattern%3Ain%3A%29%20ifTrue%3A%20%5B%20%7C%20stream%20args%20%7C%0D%0A%09%09%09%09stream%20%3A%3D%20source%20toString%20stream.%0D%0A%09%09%09%09args%20%3A%3D%20Array%20with%3A%20aMethod%20with%3A%20what%20with%3A%20stream.%0D%0A%09%09%09%09%5B%20stream%20upTo%3A%20what%3B%20atEnd%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09%09%09%09self%20triggerEvent%3A%20%23found%3Apattern%3Ain%3A%20withArguments%3A%20args%0D%0A%09%09%09%09%5D%0D%0A%09%09%09%5D.%0D%0A%09%09%09true%0D%0A%09%09%5D%20ifFalse%3A%20%5B%20false%20%5D%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23searchFinished.%0D%0A%09%5Eatoms"));
smalltalk.bind(smalltalk.MethodReferences,"search:",0
,function (what){var self=this;return self.search_with_(what, (function(aMethod){return aMethod.fn();}));;return self;}
,"searching",unescape("search%3A%20what%0D%0A%09%22%20Find%20references%20to%20what%20in%20selected%20methods.%0D%0A%09Note%3A%20search%20is%20realized%20on%20javascript%20source%20of%20native%20code%20of%20methods.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20search%3A%20what%20with%3A%20%5B%3AaMethod%7C%20aMethod%20fn%20%5D"));
smalltalk.bind(smalltalk.MethodReferences,"searchSource:",0
,function (what){var self=this;return self.search_with_(what, (function(aMethod){return aMethod.source();}));;return self;}
,"searching",unescape("searchSource%3A%20what%0D%0A%09%22%20Find%20what%20in%20source%20of%20selected%20methods.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20what%20with%3A%20%5B%3AaMethod%7C%20aMethod%20source%20%5D"));
smalltalk.bind(smalltalk.MethodReferences,"inlines",0
,function (){var self=this;return self.searchSource_(unescape("%7B%27"));;return self;}
,"searching",unescape("inlines%0D%0A%09%22%20Find%20javascript%20inlines%20in%20selected%20methods.%20%22%0D%0A%0D%0A%09%5Eself%20searchSource%3A%20%27%7B%27%27%27"));
smalltalk.bind(smalltalk.MethodReferences,"searchCategory:",0
,function (aName){var self=this;var found=nil;self.triggerEvent_("searchStarted");
found=smalltalk.Exporter.$$new().matchCategory_from_(aName, self.rootClasses());
found=found.first()._comma(found.last());
found.do_((function(each){self.results().add_(each);return self.triggerEvent_with_("found:", each);}));
self.triggerEvent_("searchFinished");
return found;;return self;}
,"searching",unescape("searchCategory%3A%20aName%0D%0A%09%22%20Find%20%28source%29%20references%20to%20category%20starting%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%7C%20found%20%7C%0D%0A%09self%20triggerEvent%3A%20%23searchStarted.%0D%0A%09found%20%3A%3D%20Exporter%20new%20matchCategory%3A%20aName%20from%3A%20self%20rootClasses.%0D%0A%09found%20%3A%3D%20found%20first%20%2C%20found%20last.%0D%0A%09found%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%09self%20results%20add%3A%20each.%0D%0A%09%09%09self%20triggerEvent%3A%20%23found%3A%20with%3A%20each.%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23searchFinished.%0D%0A%09%5Efound"));
smalltalk.bind(smalltalk.MethodReferences,"sendPatternsOf:",0
,function (aSelector){var self=this;return smalltalk.Array.with_with_(self.normalSendPatternOf_(aSelector), self.superSendPatternOf_(aSelector));;return self;}
,"patterns",unescape("sendPatternsOf%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20the%20search%20patterns%20for%20references%20of%20aSelector.%20%22%0D%0A%0D%0A%09%5EArray%0D%0A%09%09with%3A%20%28self%20normalSendPatternOf%3A%20aSelector%29%0D%0A%09%09with%3A%20%28self%20superSendPatternOf%3A%20aSelector%29"));
smalltalk.bind(smalltalk.MethodReferences,"normalSendPatternOf:",0
,function (aSelector){var self=this;return "."._comma(aSelector.asSelector())._comma(unescape("%28"));;return self;}
,"patterns",unescape("normalSendPatternOf%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20the%20search%20pattern%20for%20normal%20senders%20of%20aSelector.%20%22%0D%0A%0D%0A%09%5E%27.%27%20%2CaSelector%20asSelector%20%2C%27%28%27"));
smalltalk.bind(smalltalk.MethodReferences,"superSendPatternOf:",0
,function (aSelector){var self=this;return unescape(".%24superclass.%24fn.prototype%5B%27")._comma(aSelector.asSelector())._comma(unescape("%27%5D.apply%28"));;return self;}
,"patterns",unescape("superSendPatternOf%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20the%20search%20pattern%20for%20senders%20%28to%20super%29%20of%20aSelector.%20%22%0D%0A%0D%0A%09%5E%27.%24superclass.%24fn.prototype%5B%27%27%27%20%2CaSelector%20asSelector%20%2C%27%27%27%5D.apply%28%27"));
smalltalk.bind(smalltalk.MethodReferences,"instVarPatternOf:",0
,function (instVarName){var self=this;return unescape("self%5B%27@")._comma(instVarName.asJavascriptName())._comma(unescape("%27%5D"));;return self;}
,"patterns",unescape("instVarPatternOf%3A%20instVarName%0D%0A%09%22%20Private%20-%20Return%20the%20search%20pattern%20for%20instance%20variable%20access.%20%22%0D%0A%0D%0A%09%5E%27self%5B%27%27@%27%20%2CinstVarName%20asJavascriptName%20%2C%27%27%27%5D%27"));
smalltalk.bind(smalltalk.MethodReferences,"globalPatternOf:",0
,function (globalName){var self=this;return "smalltalk."._comma(globalName);;return self;}
,"patterns",unescape("globalPatternOf%3A%20globalName%0D%0A%09%22%20Private%20-%20Return%20the%20search%20pattern%20for%20global%20variable%20access.%20%22%0D%0A%0D%0A%09%5E%27smalltalk.%27%20%2CglobalName"));
smalltalk.bind(smalltalk.MethodReferences,"types",0
,function (){var self=this;return ["referencesOf:", "referencesOfGlobal:", "referencesOfClassVariable:", "referencesOfInstanceVariable:", "findClasses:", "searchCategory:", "search:", "searchSource:", "globalReferences", "missingGlobals", "inlines", "methodOverwrites", "variableOverwrites"];;return self;}
,"types",unescape("types%0D%0A%09%22%20Private%20-%20Return%20the%20types%20of%20search%20implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%09%23referencesOf%3A%20%23referencesOfGlobal%3A%0D%0A%09%09%23referencesOfClassVariable%3A%20%0D%0A%09%09%23referencesOfInstanceVariable%3A%0D%0A%09%09%23findClasses%3A%0D%0A%09%09%23searchCategory%3A%0D%0A%09%09%23search%3A%20%23searchSource%3A%0D%0A%09%09%23globalReferences%20%23missingGlobals%20%23inlines%0D%0A%09%09%23methodOverwrites%20%23variableOverwrites%0D%0A%09%29"));
smalltalk.bind(smalltalk.MethodReferences,"search:type:",0
,function (aName,typeSelector){var self=this;var selector=nil;selector=((typeSelector.includes_(":")).mustBeBoolean()==true ? (function(){return typeSelector.upTo_(":")._comma(":");})() : (function(){return typeSelector.upTo_(" ");})());
return ((smalltalk.responds_to_(self,(selector))).mustBeBoolean()==true ? (function(){return self.perform_with_(selector, aName.trimBlanks());})() : nil);;return self;}
,"searching",unescape("search%3A%20aName%20type%3A%20typeSelector%0D%0A%09%22%20Return%20the%20result%20of%20searching%20for%20aName%20as%20a%20search%20of%20specified%20type%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20selector%20%7C%0D%0A%09selector%20%3A%3D%20%28typeSelector%20includes%3A%20%24%3A%29%0D%0A%09ifTrue%3A%20%5B%20%28typeSelector%20upTo%3A%20%24%3A%29%20%2C%24%3A%20%5D%0D%0A%09ifFalse%3A%20%5B%20typeSelector%20upTo%3A%20%24%20%20%5D.%0D%0A%09%5E%28self%20respondsTo%3A%20selector%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20perform%3A%20selector%20with%3A%20aName%20trimBlanks%0D%0A%09%5D"));
smalltalk.bind(smalltalk.MethodReferences,"sendersOf:",0
,function (aSelector){var self=this;return self.sendPatternsOf_(aSelector).inject_into_(smalltalk.Array.$$new(), (function(total,each){return total._comma(self.search_(each));}));;return self;}
,"searching",unescape("sendersOf%3A%20aSelector%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5E%28self%20sendPatternsOf%3A%20aSelector%29%20inject%3A%20Array%20new%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09total%20%2C%20%28self%20search%3A%20each%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.MethodReferences,"referencesOf:",0
,function (aSelector){var self=this;(function($rec){$rec.add_(unescape("---%20Implementors%20of%20%23")._comma(aSelector)._comma(unescape("%20---")));$rec.addAll_(self.implementorsOf_(aSelector));return $rec.add_(unescape("---%20Senders%20of%20%23")._comma(aSelector)._comma(unescape("%20---")));})(self.results());
self.sendersOf_(aSelector);
return self['@results'];;return self;}
,"searching",unescape("referencesOf%3A%20aSelector%0D%0A%09%22%20Find%20the%20references%20to%20message%20%28aSelector%29.%20%22%0D%0A%0D%0A%09self%20results%0D%0A%09%09add%3A%20%27---%20Implementors%20of%20%23%27%20%2CaSelector%20%2C%27%20---%27%3B%0D%0A%09%09addAll%3A%20%28self%20implementorsOf%3A%20aSelector%29%3B%0D%0A%09%09add%3A%20%27---%20Senders%20of%20%23%27%20%2CaSelector%20%2C%27%20---%27.%0D%0A%09self%20sendersOf%3A%20aSelector.%0D%0A%09%5Eresults"));
smalltalk.bind(smalltalk.MethodReferences,"referencesOfInstanceVariable:",0
,function (instVarName){var self=this;return self.search_(self.instVarPatternOf_(instVarName));;return self;}
,"searching",unescape("referencesOfInstanceVariable%3A%20instVarName%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%28self%20instVarPatternOf%3A%20instVarName%29"));
smalltalk.bind(smalltalk.MethodReferences,"settersOfInstanceVariable:",0
,function (instVarName){var self=this;return self.search_(self.instVarPatternOf_(instVarName)._comma(unescape("%3D")));;return self;}
,"searching",unescape("settersOfInstanceVariable%3A%20instVarName%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%28self%20instVarPatternOf%3A%20instVarName%29%20%2C%27%3D%27"));
smalltalk.bind(smalltalk.MethodReferences,"referencesOfGlobal:",0
,function (globalName){var self=this;return self.search_(self.globalPatternOf_(globalName));;return self;}
,"searching",unescape("referencesOfGlobal%3A%20globalName%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%28self%20globalPatternOf%3A%20globalName%29"));
smalltalk.bind(smalltalk.MethodReferences,"searchGlobalReferences",0
,function (){var self=this;return self.search_(self.globalPatternOf_(""));;return self;}
,"searching",unescape("searchGlobalReferences%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%28self%20globalPatternOf%3A%20%27%27%29"));
smalltalk.bind(smalltalk.MethodReferences,"settersOfGlobalVariable:",0
,function (globalName){var self=this;return self.search_(self.globalPatternOf_(globalName)._comma(unescape("%3D")));;return self;}
,"searching",unescape("settersOfGlobalVariable%3A%20globalName%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%28self%20globalPatternOf%3A%20globalName%29%20%2C%27%3D%27"));
smalltalk.bind(smalltalk.MethodReferences,"referencesOfClassVariable:",0
,function (classVarName){var self=this;return self.search_(unescape(".classVariableAt_%28%22")._comma(classVarName)._comma(unescape("%22%29")));;return self;}
,"searching",unescape("referencesOfClassVariable%3A%20classVarName%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%27.classVariableAt_%28%22%27%2CclassVarName%2C%27%22%29%27"));
smalltalk.bind(smalltalk.MethodReferences,"settersOfClassVariable:",0
,function (classVarName){var self=this;return self.search_(unescape(".classVariableAt_put_%28%22")._comma(classVarName)._comma(unescape("%22%2C")));;return self;}
,"searching",unescape("settersOfClassVariable%3A%20classVarName%0D%0A%09%22%20Find%20the%20requested%20elements%20from%20root%20classes.%20%22%0D%0A%0D%0A%09%5Eself%20search%3A%20%27.classVariableAt_put_%28%22%27%2CclassVarName%2C%27%22%2C%27"));
smalltalk.bind(smalltalk.MethodReferences,"globalReferences",0
,function (){var self=this;var pool=nil;pool=self.$klass.globals();
pool.keys().sorted().do_((function(aName){return (function($rec){$rec.add_(unescape("---%20References%20to%3A%20")._comma(aName)._comma(unescape("%20---")));return $rec.addAll_(pool.at_(aName));})(self.results());}));
return self['@results'];;return self;}
,"searching",unescape("globalReferences%0D%0A%09%22%20Find%20the%20references%20to%20globals.%20%22%0D%0A%0D%0A%09%7C%20pool%20%7C%0D%0A%09pool%20%3A%3D%20self%20class%20globals.%0D%0A%09pool%20keys%20sorted%20do%3A%20%5B%3AaName%7C%0D%0A%09%09self%20results%0D%0A%09%09%09add%3A%20%27---%20References%20to%3A%20%27%2CaName%2C%27%20---%27%3B%0D%0A%09%09%09addAll%3A%20%28pool%20at%3A%20aName%29%0D%0A%09%5D.%0D%0A%09%5Eresults"));
smalltalk.bind(smalltalk.MethodReferences,"missingGlobals",0
,function (){var self=this;var pool=nil;pool=self.$klass.globals();
pool.keys().sorted().reject_((function(key){return smalltalk.Smalltalk.includesKey_(key);})).do_((function(aName){return (function($rec){$rec.add_(unescape("---%20Missing%20global%3A%20")._comma(aName)._comma(unescape("%20---")));return $rec.addAll_(pool.at_(aName));})(self.results());}));
((self.results().isEmpty()).mustBeBoolean()==true ? (function(){return self.results().add_(unescape("---%20All%20global%20references%20are%20bound%20to%20Smalltalk%20---"));})() : nil);
return self['@results'];;return self;}
,"searching",unescape("missingGlobals%0D%0A%09%22%20Find%20the%20references%20to%20missing%20globals.%20%22%0D%0A%0D%0A%09%7C%20pool%20%7C%0D%0A%09pool%20%3A%3D%20self%20class%20globals.%0D%0A%09%28pool%20keys%20sorted%0D%0A%09%09reject%3A%20%5B%3Akey%7C%20%28Smalltalk%20includesKey%3A%20key%29%20%5D%29%0D%0A%09%09do%3A%20%5B%3AaName%7C%0D%0A%09%09%09self%20results%0D%0A%09%09%09%09add%3A%20%27---%20Missing%20global%3A%20%27%2CaName%2C%27%20---%27%3B%0D%0A%09%09%09%09addAll%3A%20%28pool%20at%3A%20aName%29%0D%0A%09%09%5D.%0D%0A%09self%20results%20isEmpty%20ifTrue%3A%20%5B%0D%0A%09%09self%20results%20add%3A%20%27---%20All%20global%20references%20are%20bound%20to%20Smalltalk%20---%27%0D%0A%09%5D.%0D%0A%09%5Eresults"));
smalltalk.bind(smalltalk.MethodReferences,"implementorsOf:",0
,function (aSelector){var self=this;return smalltalk.Smalltalk.current().implementorsOf_(aSelector);;return self;}
,"private",unescape("implementorsOf%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20the%20implementors%20of%20aSelector.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20current%20implementorsOf%3A%20aSelector"));
smalltalk.bind(smalltalk.MethodReferences,"messagesOf:",0
,function (aCompiledMethod){var self=this;var stream=nil;var selectors=nil;var string=nil;stream=aCompiledMethod.fn().toString().stream();
stream.upTo_(unescape("%7B"));
selectors=smalltalk.Set.$$new();
(function(){while(!(function(){return stream.atEnd();})()){(function(){return selectors.add_((function($rec){$rec.upTo_(".");return $rec.upTo_(unescape("%28"));})(stream).asArrayOfSubstringsSeparatedBy_(".").last().asStSelector());})()};return nil})();
selectors.remove_ifAbsent_("", (function(){return nil;}));
return selectors.asArray().select_((function(each){return each.isLiteral();})).sorted();;return self;}
,"accessing",unescape("messagesOf%3A%20aCompiledMethod%0D%0A%09%22%20Return%20all%20the%20messages%20that%20can%20be%20sent%20during%20execution%20of%20aCompiledMethod.%20%22%0D%0A%0D%0A%09%7C%20stream%20selectors%20string%20%7C%0D%0A%09stream%20%3A%3D%20aCompiledMethod%20fn%20toString%20stream.%0D%0A%09stream%20upTo%3A%20%24%7B.%0D%0A%09selectors%20%3A%3D%20Set%20new.%0D%0A%09%5Bstream%20atEnd%5D%20whileFalse%3A%20%5B%0D%0A%09%09selectors%20add%3A%20%28%28%0D%0A%09%09%09stream%20upTo%3A%20%24.%3BupTo%3A%20%24%28%0D%0A%09%09%09%29%20asArrayOfSubstringsSeparatedBy%3A%20%24.%29%0D%0A%09%09%09last%20asStSelector%0D%0A%09%5D.%0D%0A%09selectors%20remove%3A%20%27%27%20ifAbsent%3A%20%5B%5D.%0D%0A%09%5E%28selectors%20asArray%20select%3A%20%5B%3Aeach%7C%20each%20isLiteral%20%5D%29%20sorted"));
smalltalk.bind(smalltalk.MethodReferences,"globalReferencesOf:",0
,function (aCompiledMethod){var self=this;var result=nil;result=smalltalk.Set.$$new();
(function($rec){$rec.when_do_("needsMethods", (function(){return smalltalk.Array.with_(aCompiledMethod);}));$rec.when_do_("found:pattern:in:", (function(mth,mask,stream){var global=nil;global=smalltalk.SmalltalkParser.$$new().globalNameParser().parse_(stream);return ((global.isParseFailure()).mustBeBoolean()==true ? nil : (function(){return result.add_(global);})());}));return $rec.yourself();})(self);
self.searchGlobalReferences();
return result.asArray().sorted();;return self;}
,"accessing",unescape("globalReferencesOf%3A%20aCompiledMethod%0D%0A%09%22%20Return%20all%20the%20global%20reference%20names%20in%20aCompiledMethod.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Set%20new.%0D%0A%09self%0D%0A%09%09when%3A%20%23needsMethods%20do%3A%20%5B%20Array%20with%3A%20aCompiledMethod%20%5D%3B%0D%0A%09%09when%3A%20%23found%3Apattern%3Ain%3A%20do%3A%20%5B%3Amth%20%3Amask%20%3Astream%7C%20%7C%20global%20%7C%0D%0A%09%09%09global%20%3A%3D%20SmalltalkParser%20new%20globalNameParser%20parse%3A%20stream.%0D%0A%09%09%09global%20isParseFailure%20ifFalse%3A%20%5B%20result%20add%3A%20global%20%5D.%0D%0A%09%09%5D%3B%0D%0A%09%09yourself.%0D%0A%09self%20searchGlobalReferences.%0D%0A%09%5Eresult%20asArray%20sorted"));
smalltalk.bind(smalltalk.MethodReferences,"findClasses:",0
,function (what){var $s8Ret$={name:"stReturn"};try{var self=this;var keys=nil;var system=nil;((what.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.findClasses_(what.trimBlanks().asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
self.triggerEvent_("searchStarted");
keys=what.collect_((function(each){return each.asString().asLowercase();}));
system=smalltalk.Smalltalk.current();
((keys.notEmpty()).mustBeBoolean()==true ? (function(){return system.classes().do_((function(aClass){var key=nil;key=aClass.name().asLowercase();return (((nil.isNil_(keys.detect_ifNone_((function(one){return key.includes_(one);}), (function(){return nil;})))===false)).mustBeBoolean()==true ? (function(){self.results().add_(aClass);return self.triggerEvent_with_("found:", aClass);})() : nil);}));})() : nil);
self.triggerEvent_("searchFinished");
(function(){$s8Ret$.result=(function(){return self.results();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"searching",unescape("findClasses%3A%20what%0D%0A%09%22%20Find%20classes%20matching%20what.%20%22%0D%0A%0D%0A%09%7C%20keys%20system%20%7C%0D%0A%09what%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20findClasses%3A%20what%20trimBlanks%20asArrayOfSubstrings%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23searchStarted.%0D%0A%09keys%20%3A%3D%20what%20collect%3A%20%5B%3Aeach%7C%20each%20asString%20asLowercase%20%5D.%0D%0A%09system%20%3A%3D%20Smalltalk%20current.%0D%0A%09keys%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09system%20classes%20do%3A%20%5B%3AaClass%7C%20%7C%20key%20%7C%0D%0A%09%09%09key%20%3A%3D%20aClass%20name%20asLowercase.%0D%0A%09%09%09%28keys%20detect%3A%20%5B%3Aone%7C%20key%20includes%3A%20one%20%5D%20ifNone%3A%20%5B%5D%29%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09%09self%20results%20add%3A%20aClass.%0D%0A%09%09%09%09self%20triggerEvent%3A%20%23found%3A%20with%3A%20aClass.%0D%0A%09%09%09%5D%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23searchFinished.%0D%0A%09%5Eself%20results"));
smalltalk.bind(smalltalk.MethodReferences,"methodOverwritesOf:",0
,function (aClass){var $s8Ret$={name:"stReturn"};try{var self=this;var map=nil;var subclasses=nil;subclasses=aClass.allSubclasses();
map=smalltalk.PoolDictionary.$$new();
((subclasses.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return map;})();throw($s8Ret$)})();})() : nil);
aClass.methodsDo_((function(mth){var selector=nil;selector=mth.selector();map.at_put_(selector, smalltalk.Array.with_(mth));return subclasses.do_((function(each){return ((each.selectors().includes_(selector)).mustBeBoolean()==true ? (function(){return map.at_(selector).add_(each._gt_gt(selector));})() : nil);}));}));
subclasses.do_((function(each){return self.methodOverwritesOf_(each).keysAndValuesDo_((function(key,value){return map.at_ifAbsentPut_(key, (function(){return smalltalk.Array.$$new();})).addAll_(value);}));}));
map.keys().asArray().select_((function(key){return map.at_(key).size()._lt_eq((1));})).do_((function(key){return map.removeKey_(key);}));
(function(){$s8Ret$.result=(function(){return map;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("methodOverwritesOf%3A%20aClass%0D%0A%09%22%20Private%20-%20Find%20the%20methods%20subimplemented%20by%20subclasses%20of%20aClass.%20%22%0D%0A%0D%0A%09%7C%20map%20subclasses%20%7C%0D%0A%09subclasses%20%3A%3D%20aClass%20allSubclasses.%0D%0A%09map%20%3A%3D%20PoolDictionary%20new.%0D%0A%09subclasses%20isEmpty%20ifTrue%3A%20%5B%20%5Emap%20%5D.%0D%0A%09aClass%20methodsDo%3A%20%5B%3Amth%7C%20%7C%20selector%20%7C%0D%0A%09%09selector%20%3A%3D%20mth%20selector.%0D%0A%09%09map%20at%3A%20selector%20put%3A%20%28Array%20with%3A%20mth%29.%0D%0A%09%09subclasses%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%09%28each%20selectors%20includes%3A%20selector%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%28map%20at%3A%20selector%29%20add%3A%20each%20%3E%3E%20selector%0D%0A%09%09%09%5D.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09subclasses%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28self%20methodOverwritesOf%3A%20each%29%20keysAndValuesDo%3A%20%5B%3Akey%20%3Avalue%7C%0D%0A%09%09%09%28map%20at%3A%20key%20ifAbsentPut%3A%20%5BArray%20new%5D%29%20addAll%3A%20value%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%28map%20keys%20asArray%0D%0A%09%09select%3A%20%5B%3Akey%7C%20%28map%20at%3A%20key%29%20size%20%3C%3D%201%20%5D%0D%0A%09%09%29%20do%3A%20%5B%3Akey%7C%20map%20removeKey%3A%20key%20%5D.%0D%0A%09%5Emap"));
smalltalk.bind(smalltalk.MethodReferences,"addMethodOverwrites:",0
,function (map){var self=this;map.associationsDo_((function(assoc){return assoc.value().do_((function(each){self.triggerEvent_with_("found:", each);return self.results().add_(each);}));}));return self;}
,"private",unescape("addMethodOverwrites%3A%20map%0D%0A%09%22%20Private%20-%20Register%20the%20methods%20overwrites%20in%20map.%20%22%0D%0A%0D%0A%09map%20associationsDo%3A%20%5B%3Aassoc%7C%0D%0A%09%09assoc%20value%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%09self%20triggerEvent%3A%20%23found%3A%20with%3A%20each.%0D%0A%09%09%09self%20results%20add%3A%20each.%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.MethodReferences,"methodOverwrites",0
,function (){var self=this;self.triggerEvent_("searchStarted");
smalltalk.Smalltalk.rootClasses().do_((function(aClass){self.addMethodOverwrites_(self.methodOverwritesOf_(aClass));return self.addMethodOverwrites_(self.methodOverwritesOf_(aClass.$klass));}));
self.triggerEvent_("searchFinished");
return self.results();;return self;}
,"searching",unescape("methodOverwrites%0D%0A%09%22%20Find%20the%20methods%20that%20are%20implemented/overwritten%20by%20subclasses.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23searchStarted.%0D%0A%09Smalltalk%20rootClasses%20do%3A%20%5B%3AaClass%7C%0D%0A%09%09self%20addMethodOverwrites%3A%20%28self%20methodOverwritesOf%3A%20aClass%29.%0D%0A%09%09self%20addMethodOverwrites%3A%20%28self%20methodOverwritesOf%3A%20aClass%20class%29.%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23searchFinished.%0D%0A%09%5Eself%20results"));
smalltalk.bind(smalltalk.MethodReferences,"hasArgumentOverwrites:in:",0
,function (names,stream){var $s8Ret$={name:"stReturn"};try{var self=this;var args=nil;args=(function($rec){$rec.upTo_(unescape("%28"));return $rec.upTo_(unescape("%29"));})(stream).asArrayOfSubstringsSeparatedBy_(unescape("%2C"));
args.do_((function(each){return ((names.includes_(each)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("hasArgumentOverwrites%3A%20names%20in%3A%20stream%0D%0A%09%22%20Private%20-%20Returns%20true%20if%20stream%20of%20code%20has%20argument%20name%20conflicts.%20%22%0D%0A%0D%0A%09%7C%20args%20%7C%0D%0A%09args%20%3A%3D%20%28stream%20upTo%3A%20%24%28%3B%20upTo%3A%20%24%29%29%20asArrayOfSubstringsSeparatedBy%3A%20%24%2C.%0D%0A%09args%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28names%20includes%3A%20each%29%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.MethodReferences,"hasLocalOverwrites:in:",0
,function (names,stream){var $s8Ret$={name:"stReturn"};try{var self=this;var candidate=nil;(function(){while(!(function(){return stream.atEnd();})()){(function(){candidate=(function($rec){$rec.upTo_("var ");return $rec.upTo_(unescape("%3D"));})(stream).trimBlanks();return ((names.includes_(candidate)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);})()};return nil})();
(function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("hasLocalOverwrites%3A%20names%20in%3A%20stream%0D%0A%09%22%20Private%20-%20Returns%20true%20if%20stream%20of%20code%20has%20local%20name%20conflicts.%20%22%0D%0A%0D%0A%09%7C%20candidate%20%7C%0D%0A%09%5Bstream%20atEnd%5D%20whileFalse%3A%20%5B%0D%0A%09%09candidate%20%3A%3D%20%28stream%20upTo%3A%20%27var%20%27%3B%20upTo%3A%20%24%3D%29%20trimBlanks.%0D%0A%09%09%28names%20includes%3A%20candidate%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%5Etrue%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.MethodReferences,"addVariableOverwrites:in:",0
,function (names,mth){var self=this;var stream=nil;stream=mth.fn().toString().stream();
((self.hasArgumentOverwrites_in_(names, stream).or_((function(){return self.hasLocalOverwrites_in_(names, stream);}))).mustBeBoolean()==true ? (function(){self.triggerEvent_with_("found:", mth);return self.results().add_(mth);})() : nil);return self;}
,"private",unescape("addVariableOverwrites%3A%20names%20in%3A%20mth%0D%0A%09%22%20Private%20-%20Register%20the%20methods%20that%20has%20name%20overwrites.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20mth%20fn%20toString%20stream.%0D%0A%09%28%28self%20hasArgumentOverwrites%3A%20names%20in%3A%20stream%29%0D%0A%09or%3A%20%5B%20self%20hasLocalOverwrites%3A%20names%20in%3A%20stream%20%5D%29%0D%0A%09ifTrue%3A%20%5B%0D%0A%09%09self%20triggerEvent%3A%20%23found%3A%20with%3A%20mth.%0D%0A%09%09self%20results%20add%3A%20mth.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.MethodReferences,"variableOverwrites",0
,function (){var self=this;self.triggerEvent_("searchStarted");
smalltalk.Smalltalk.current().classes().do_((function(aClass){var names=nil;names=aClass.allInstVarNames();aClass.methodsDo_((function(mth){return self.addVariableOverwrites_in_(names, mth);}));names=aClass.$klass.allInstVarNames();return aClass.$klass.methodsDo_((function(mth){return self.addVariableOverwrites_in_(names, mth);}));}));
self.triggerEvent_("searchFinished");
return self.results();;return self;}
,"searching",unescape("variableOverwrites%0D%0A%09%22%20Find%20the%20methods%20that%20has%20potential%20overwrite%20of%20variable%20names.%20%22%0D%0A%0D%0A%09self%20triggerEvent%3A%20%23searchStarted.%0D%0A%09Smalltalk%20current%20classes%20do%3A%20%5B%3AaClass%7C%20%7C%20names%20%7C%0D%0A%09%09names%20%3A%3D%20aClass%20allInstVarNames.%0D%0A%09%09aClass%20methodsDo%3A%20%5B%3Amth%7C%0D%0A%09%09%09self%20addVariableOverwrites%3A%20names%20in%3A%20mth.%0D%0A%09%09%5D.%0D%0A%09%09names%20%3A%3D%20aClass%20class%20allInstVarNames.%0D%0A%09%09aClass%20class%20methodsDo%3A%20%5B%3Amth%7C%0D%0A%09%09%09self%20addVariableOverwrites%3A%20names%20in%3A%20mth.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09self%20triggerEvent%3A%20%23searchFinished.%0D%0A%09%5Eself%20results"));
smalltalk.bind(smalltalk.SystemManager.$klass,"constructEventsTriggered",0
,function (){var self=this;return smalltalk.superImplementor(smalltalk.SystemManager.$klass,'constructEventsTriggered').apply(self, [])._comma(["aboutToBind:to:", "methodBound:to:", "aboutToRemove:from:", "methodRemoved:from:", "aboutToChange:to:", "aboutToCreateClass:with:", "classChanged:", "classShapeChanged:", "object:at:notFoundIn:", "log:", "memoryWarning:"]);;return self;}
,"events",unescape("constructEventsTriggered%0D%0A%09%22%20Private%20-%20Return%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Esuper%20constructEventsTriggered%20%2C%23%28%0D%0A%09%09%23aboutToBind%3Ato%3A%0D%0A%09%09%23methodBound%3Ato%3A%0D%0A%09%09%23aboutToRemove%3Afrom%3A%0D%0A%09%09%23methodRemoved%3Afrom%3A%0D%0A%09%09%23aboutToChange%3Ato%3A%0D%0A%09%09%23aboutToCreateClass%3Awith%3A%0D%0A%09%09%23classChanged%3A%0D%0A%09%09%23classShapeChanged%3A%0D%0A%09%09%23object%3Aat%3AnotFoundIn%3A%0D%0A%09%09%23log%3A%0D%0A%09%09%23memoryWarning%3A%0D%0A%09%29"));
smalltalk.bind(smalltalk.SystemManager.$klass,"currentOrNil",0
,function (){var self=this;return self.classVariableAt_ifAbsent_("Current", (function(){return nil;}));;return self;}
,"singleton",unescape("currentOrNil%0D%0A%09%22%20Return%20the%20current%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20classVariableAt%3A%20%23Current%20ifAbsent%3A%20%5B%20nil%20%5D"));
smalltalk.bind(smalltalk.SystemManager.$klass,"current",0
,function (){var self=this;(((nil.isNil_(smalltalk.SystemManager.classVariableAt_("Current")))).mustBeBoolean()==true ? (function(){return self.current_(self.$$new());})() : nil);
return smalltalk.SystemManager.classVariableAt_("Current");;return self;}
,"singleton",unescape("current%0D%0A%09%22%20Return%20the%20current%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09Current%20isNil%20ifTrue%3A%20%5B%20self%20current%3A%20self%20new%20%5D.%0D%0A%09%5ECurrent"));
smalltalk.bind(smalltalk.SystemManager.$klass,"current:",0
,function (aSystemManager){var self=this;smalltalk.SystemManager.classVariableAt_put_("Current",aSystemManager);
aSystemManager.install();return self;}
,"singleton",unescape("current%3A%20aSystemManager%0D%0A%09%22%20Set%20the%20current%20source%20manager%20of%20the%20system.%20%22%0D%0A%0D%0A%09Current%20%3A%3D%20aSystemManager.%0D%0A%09aSystemManager%20install."));
smalltalk.bind(smalltalk.SystemManager.$klass,"log:",0
,function (aString){var self=this;(((nil.isNil_(smalltalk.SystemManager.classVariableAt_("Current"))===false)).mustBeBoolean()==true ? (function(){return smalltalk.SystemManager.classVariableAt_("Current").log_(aString);})() : nil);return self;}
,"log",unescape("log%3A%20aString%0D%0A%09%22%20Log%20aString%20onto%20loggin%20stream.%20%22%0D%0A%0D%0A%09Current%20notNil%20ifTrue%3A%20%5B%20Current%20log%3A%20aString%20%5D"));
smalltalk.bind(smalltalk.SystemManager.$klass,"memoryWarning:",0
,function (anArgument){var self=this;(((nil.isNil_(smalltalk.SystemManager.classVariableAt_("Current"))===false)).mustBeBoolean()==true ? (function(){return smalltalk.SystemManager.classVariableAt_("Current").memoryWarning_(anArgument);})() : nil);return self;}
,"memory",unescape("memoryWarning%3A%20anArgument%0D%0A%09%22%20Trigger%20a%20memory%20warning%20event.%20%22%0D%0A%0D%0A%09Current%20notNil%20ifTrue%3A%20%5B%20Current%20memoryWarning%3A%20anArgument%20%5D"));
smalltalk.bind(smalltalk.SystemManager,"install",0
,function (){var self=this;return self;}
,"install",unescape("install%0D%0A%09%22%20Private%20-%20Install%20the%20receiver%20as%20the%20source%20manager%20of%20the%20system.%0D%0A%09The%20default%20action%20is%20to%20do%20nothing.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses.%0D%0A%09%22"));
smalltalk.bind(smalltalk.SystemManager,"aboutToBind:to:",0
,function (aMethod,aClass){var self=this;return self.triggerEvent_with_with_("aboutToBind:to:", aMethod, aClass);;return self;}
,"tracking-methods",unescape("aboutToBind%3A%20aMethod%20to%3A%20aClass%0D%0A%09%22%20Private%20-%20The%20method%20will%20be%20bound%20to%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23aboutToBind%3Ato%3A%20with%3A%20aMethod%20with%3A%20aClass%20"));
smalltalk.bind(smalltalk.SystemManager,"methodBound:to:",0
,function (aMethod,aClass){var self=this;return self.triggerEvent_with_with_("methodBound:to:", aMethod, aClass);;return self;}
,"tracking-methods",unescape("methodBound%3A%20aMethod%20to%3A%20aClass%0D%0A%09%22%20Private%20-%20The%20method%20has%20been%20bound%20to%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23methodBound%3Ato%3A%20with%3A%20aMethod%20with%3A%20aClass%20"));
smalltalk.bind(smalltalk.SystemManager,"aboutToRemove:from:",0
,function (aMethod,aClass){var self=this;return self.triggerEvent_with_with_("aboutToRemove:from:", aMethod, aClass);;return self;}
,"tracking-methods",unescape("aboutToRemove%3A%20aMethod%20from%3A%20aClass%0D%0A%09%22%20Private%20-%20The%20method%20will%20be%20removed%20from%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23aboutToRemove%3Afrom%3A%20with%3A%20aMethod%20with%3A%20aClass%20"));
smalltalk.bind(smalltalk.SystemManager,"methodRemoved:from:",0
,function (aMethod,aClass){var self=this;return self.triggerEvent_with_with_("methodRemoved:from:", aMethod, aClass);;return self;}
,"tracking-methods",unescape("methodRemoved%3A%20aMethod%20from%3A%20aClass%0D%0A%09%22%20Private%20-%20The%20method%20has%20been%20removed%20from%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23methodRemoved%3Afrom%3A%20with%3A%20aMethod%20with%3A%20aClass%20"));
smalltalk.bind(smalltalk.SystemManager,"aboutToChange:superclass:iVarNames:category:",0
,function (aClass,superclass,iVarNames,category){var self=this;return self.triggerEvent_with_with_("aboutToChange:to:", aClass, smalltalk.Array.with_with_with_(superclass, iVarNames, category));;return self;}
,"tracking-classes",unescape("aboutToChange%3A%20aClass%20superclass%3A%20superclass%20iVarNames%3A%20iVarNames%20category%3A%20category%0D%0A%09%22%20Private%20-%20aClass%20is%20about%20to%20be%20changed.%20%22%0D%0A%0D%0A%09%5Eself%09triggerEvent%3A%20%23aboutToChange%3Ato%3A%0D%0A%09%09with%3A%20aClass%0D%0A%09%09with%3A%20%28Array%20with%3A%20superclass%20with%3A%20iVarNames%20with%3A%20category%29"));
smalltalk.bind(smalltalk.SystemManager,"aboutToCreateClass:superclass:iVarNames:category:",0
,function (globalName,superclass,iVarNames,category){var self=this;return self.triggerEvent_with_with_("aboutToCreateClass:with:", globalName, smalltalk.Array.with_with_with_(superclass, iVarNames, category));;return self;}
,"tracking-classes",unescape("aboutToCreateClass%3A%20globalName%20superclass%3A%20superclass%20iVarNames%3A%20iVarNames%20category%3A%20category%0D%0A%09%22%20Private%20-%20Attemp%20to%20create%20Class%20with%20name%20globalName.%20%22%0D%0A%0D%0A%09%5Eself%09triggerEvent%3A%20%23aboutToCreateClass%3Awith%3A%0D%0A%09%09with%3A%20globalName%0D%0A%09%09with%3A%20%28Array%20with%3A%20superclass%20with%3A%20iVarNames%20with%3A%20category%29"));
smalltalk.bind(smalltalk.SystemManager,"classChanged:",0
,function (aBehavior){var self=this;return self.triggerEvent_with_("classChanged:", aBehavior);;return self;}
,"tracking-classes",unescape("classChanged%3A%20aBehavior%0D%0A%09%22%20Private%20-%20aBehavior%20has%20been%20changed.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23classChanged%3A%20with%3A%20aBehavior%20"));
smalltalk.bind(smalltalk.SystemManager,"classShapeChanged:",0
,function (aBehavior){var self=this;return self.triggerEvent_with_ifNotHandled_("classShapeChanged:", aBehavior, (function(){return aBehavior.recompileAll();}));;return self;}
,"tracking-classes",unescape("classShapeChanged%3A%20aBehavior%0D%0A%09%22%20Private%20-%20aBehavior%20has%20changed%20shape.%20%22%0D%0A%0D%0A%09%5Eself%09triggerEvent%3A%20%23classShapeChanged%3A%0D%0A%09%09with%3A%20aBehavior%0D%0A%09%09ifNotHandled%3A%20%5B%20aBehavior%20recompileAll%20%5D"));
smalltalk.bind(smalltalk.SystemManager,"log:",0
,function (aString){var self=this;return self.triggerEvent_with_("log:", aString);;return self;}
,"log",unescape("log%3A%20aString%0D%0A%09%22%20Private%20-%20Log%20aString%20onto%20loggin%20device.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23log%3A%20with%3A%20aString"));
smalltalk.bind(smalltalk.SystemManager,"memoryWarning:",0
,function (anArgument){var self=this;return self.triggerEvent_with_("memoryWarning:", anArgument);;return self;}
,"memory",unescape("memoryWarning%3A%20anArgument%0D%0A%09%22%20Trigger%20a%20memory%20warning%20event.%0D%0A%09The%20execution%20environment%20can%20signal%20memory%20warning/low%20conditions%2C%20we%20trigger%20an%20event%20to%20be%20handled%20at%20application%20level.%0D%0A%09Note%3A%20It%20is%20frequent%20procedure%20to%20clean%20cached%20resources%20that%20can%20be%20reconstructed%20later%2C%20if%20required.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23memoryWarning%3A%20with%3A%20anArgument"));
smalltalk.bind(smalltalk.SystemManager,"object:at:notFoundIn:",0
,function (anObject,indexOrKey,aCollection){var self=this;return self.triggerEvent_withArguments_ifNotHandled_("object:at:notFoundIn:", smalltalk.Array.with_with_with_(anObject, indexOrKey, aCollection), (function(){return self.print_(unescape("Object/key%28")._comma((((nil.isNil_(indexOrKey))).mustBeBoolean()==true ? (function(){return anObject;})() : (function(){return indexOrKey;})()).toString())._comma(unescape("%29%20not%20found%20in%20"))._comma(aCollection.printString()));}));;return self;}
,"failures",unescape("object%3A%20anObject%20at%3A%20indexOrKey%20notFoundIn%3A%20aCollection%0D%0A%09%22%20Trigger%20a%20missing%20object%20event.%20%22%0D%0A%0D%0A%09%5Eself%20triggerEvent%3A%20%23object%3Aat%3AnotFoundIn%3A%0D%0A%09%09withArguments%3A%20%28Array%20with%3A%20anObject%20with%3A%20indexOrKey%20with%3A%20aCollection%29%0D%0A%09%09ifNotHandled%3A%20%5B%0D%0A%09%09%09self%20print%3A%20%27Object/key%28%27%0D%0A%09%09%09%09%2C%28indexOrKey%20isNil%20ifTrue%3A%20%5BanObject%5D%20ifFalse%3A%20%5BindexOrKey%5D%29%20toString%0D%0A%09%09%09%09%2C%27%29%20not%20found%20in%20%27%2CaCollection%20printString%0D%0A%09%09%5D"));
smalltalk.bind(smalltalk.CompilerNode,"nodes",0
,function (){var self=this;(((nil.isNil_(self['@nodes']))).mustBeBoolean()==true ? (function(){return self['@nodes']=smalltalk.Array.$$new();})() : nil);
return self['@nodes'];;return self;}
,"accessing",unescape("nodes%0D%0A%09nodes%20isNil%20ifTrue%3A%20%5B%20nodes%20%3A%3D%20Array%20new%20%5D.%0D%0A%09%5Enodes"));
smalltalk.bind(smalltalk.CompilerNode,"nodes:",0
,function (aCollection){var self=this;self['@nodes']=aCollection;return self;}
,"accessing",unescape("nodes%3A%20aCollection%0D%0A%09nodes%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.CompilerNode,"addNode:",0
,function (aNode){var self=this;self.nodes().add_(aNode);return self;}
,"accessing",unescape("addNode%3A%20aNode%0D%0A%09self%20nodes%20add%3A%20aNode"));
smalltalk.bind(smalltalk.CompilerNode,"start",0
,function (){var self=this;return self['@start'];;return self;}
,"accessing",unescape("start%0D%0A%09%5Estart"));
smalltalk.bind(smalltalk.CompilerNode,"end",0
,function (){var self=this;return self['@end'];;return self;}
,"accessing",unescape("end%0D%0A%09%5Eend"));
smalltalk.bind(smalltalk.CompilerNode,"start:end:",0
,function (startOffset,endOffset){var self=this;self['@start']=startOffset;
self['@end']=endOffset;return self;}
,"accessing",unescape("start%3A%20startOffset%20end%3A%20endOffset%0D%0A%09%22%20Set%20the%20offsets%20of%20the%20receiver%20in%20source%20code.%20%22%0D%0A%0D%0A%09start%20%3A%3D%20startOffset.%0D%0A%09end%20%3A%3D%20endOffset."));
smalltalk.bind(smalltalk.CompilerNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitNode%3A%20self"));
smalltalk.bind(smalltalk.CompilerNode,"acceptMacroAssignment:with:",0
,function (anExpressionNode,aVisitor){var self=this;return aVisitor.visitMacroAssignment_to_(self, anExpressionNode);;return self;}
,"visiting",unescape("acceptMacroAssignment%3A%20anExpressionNode%20with%3A%20aVisitor%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20can%20resolve%20assignment%20on%20aVisitor.%20%22%0D%0A%0D%0A%09%5EaVisitor%20visitMacroAssignment%3A%20self%20to%3A%20anExpressionNode"));
smalltalk.bind(smalltalk.CompilerNode,"isSuper",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isSuper%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20super.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"hasNumber",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("hasNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20has%20a%20numeric%20literal%20value.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"hasString",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("hasString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20has%20a%20string%20literal%20value.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isAssignment",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isAssignment%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isBlock",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isBlock%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isCascade",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isCascade%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isInline",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isInline%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isReturn",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isReturn%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isSend",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isSend%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isSequence",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isSequence%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"isValue",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("isValue%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.CompilerNode,"bindings",0
,function (){var self=this;return [];;return self;}
,"bindings",unescape("bindings%0D%0A%09%22%20Return%20the%20bindings%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.CompilerNode,"messageSendConnector",0
,function (){var self=this;return ".";;return self;}
,"accessing",unescape("messageSendConnector%0D%0A%09%22%20Return%20the%20binder%20used%20to%20send%20message%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27.%27"));
smalltalk.bind(smalltalk.MethodNode,"selector",0
,function (){var self=this;return self['@selector'];;return self;}
,"accessing",unescape("selector%0D%0A%09%5Eselector"));
smalltalk.bind(smalltalk.MethodNode,"selector:",0
,function (aString){var self=this;self['@selector']=aString;return self;}
,"accessing",unescape("selector%3A%20aString%0D%0A%09selector%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.MethodNode,"arguments",0
,function (){var self=this;return (((nil.isNil_(self['@arguments']))).mustBeBoolean()==true ? (function(){return [];})() : (function(){return self['@arguments'];})());;return self;}
,"accessing",unescape("arguments%0D%0A%09%5Earguments%20isNil%20ifTrue%3A%20%5B%20%23%28%29%20%5D%20ifFalse%3A%20%5B%20arguments%20%5D"));
smalltalk.bind(smalltalk.MethodNode,"arguments:",0
,function (aCollection){var self=this;self['@arguments']=aCollection;return self;}
,"accessing",unescape("arguments%3A%20aCollection%0D%0A%09arguments%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.MethodNode,"source",0
,function (){var self=this;return self['@source'];;return self;}
,"accessing",unescape("source%0D%0A%09%5Esource"));
smalltalk.bind(smalltalk.MethodNode,"source:",0
,function (aString){var self=this;self['@source']=aString;return self;}
,"accessing",unescape("source%3A%20aString%0D%0A%09source%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.MethodNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitMethodNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitMethodNode%3A%20self"));
smalltalk.bind(smalltalk.SendNode,"selector",0
,function (){var self=this;return self['@selector'];;return self;}
,"accessing",unescape("selector%0D%0A%09%5Eselector"));
smalltalk.bind(smalltalk.SendNode,"selector:",0
,function (aString){var self=this;self['@selector']=aString;return self;}
,"accessing",unescape("selector%3A%20aString%0D%0A%09selector%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.SendNode,"arguments",0
,function (){var self=this;return (((nil.isNil_(self['@arguments']))).mustBeBoolean()==true ? (function(){return [];})() : (function(){return self['@arguments'];})());;return self;}
,"accessing",unescape("arguments%0D%0A%09%5Earguments%20isNil%20ifTrue%3A%20%5B%20%23%28%29%20%5D%20ifFalse%3A%20%5B%20arguments%20%5D"));
smalltalk.bind(smalltalk.SendNode,"arguments:",0
,function (aCollection){var self=this;self['@arguments']=aCollection;return self;}
,"accessing",unescape("arguments%3A%20aCollection%0D%0A%09arguments%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.SendNode,"receiver",0
,function (){var self=this;return self['@receiver'];;return self;}
,"accessing",unescape("receiver%0D%0A%09%5Ereceiver"));
smalltalk.bind(smalltalk.SendNode,"receiver:",0
,function (aNode){var self=this;self['@receiver']=aNode;return self;}
,"accessing",unescape("receiver%3A%20aNode%0D%0A%09receiver%20%3A%3D%20aNode"));
smalltalk.bind(smalltalk.SendNode,"valueForReceiver:",0
,function (anObject){var self=this;return (function($rec){$rec.receiver_((((nil.isNil_(self.receiver()))).mustBeBoolean()==true ? (function(){return anObject;})() : (function(){return self.receiver().valueForReceiver_(anObject);})()));$rec.selector_(self.selector());$rec.arguments_(self.arguments());$rec.start_end_(self.start(), self.end());return $rec.yourself();})(smalltalk.SendNode.$$new());;return self;}
,"accessing",unescape("valueForReceiver%3A%20anObject%0D%0A%09%5ESendNode%20new%0D%0A%09%20%20%20%20receiver%3A%20%28self%20receiver%20isNil%20ifTrue%3A%20%5BanObject%5D%0D%0A%09%09ifFalse%3A%20%5Bself%20receiver%20valueForReceiver%3A%20anObject%5D%29%3B%0D%0A%09%20%20%20%20selector%3A%20self%20selector%3B%0D%0A%09%20%20%20%20arguments%3A%20self%20arguments%3B%0D%0A%09%20%20%20%20start%3A%20self%20start%20end%3A%20self%20end%3B%0D%0A%09%20%20%20%20yourself"));
smalltalk.bind(smalltalk.SendNode,"cascadeNodeWithMessages:",0
,function (aCollection){var self=this;var first=nil;var sends=nil;first=(function($rec){$rec.selector_(self.selector());$rec.arguments_(self.arguments());$rec.start_end_(self.start(), self.end());return $rec.yourself();})(smalltalk.SendNode.$$new());
sends=smalltalk.Array.with_(first)._comma(aCollection);
return (function($rec){$rec.receiver_(self.receiver());$rec.nodes_(sends);$rec.start_end_(sends.first().start(), sends.last().end());return $rec.yourself();})(smalltalk.CascadeNode.$$new());;return self;}
,"accessing",unescape("cascadeNodeWithMessages%3A%20aCollection%0D%0A%09%7C%20first%20sends%20%7C%0D%0A%09first%20%3A%3D%20SendNode%20new%0D%0A%09%20%20%20%20selector%3A%20self%20selector%3B%0D%0A%09%20%20%20%20arguments%3A%20self%20arguments%3B%0D%0A%09%20%20%20%20start%3A%20self%20start%20end%3A%20self%20end%3B%0D%0A%09%20%20%20%20yourself.%0D%0A%09sends%20%3A%3D%20%28Array%20with%3A%20first%29%2C%20aCollection.%0D%0A%09%5ECascadeNode%20new%0D%0A%09%20%20%20%20receiver%3A%20self%20receiver%3B%0D%0A%09%20%20%20%20nodes%3A%20sends%3B%0D%0A%09%20%20%20%20start%3A%20sends%20first%20start%20end%3A%20sends%20last%20end%3B%0D%0A%09%20%20%20%20yourself"));
smalltalk.bind(smalltalk.SendNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitSendNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitSendNode%3A%20self"));
smalltalk.bind(smalltalk.SendNode,"isSend",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isSend%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.CascadeNode,"receiver",0
,function (){var self=this;return self['@receiver'];;return self;}
,"accessing",unescape("receiver%0D%0A%09%5Ereceiver"));
smalltalk.bind(smalltalk.CascadeNode,"receiver:",0
,function (aNode){var self=this;self['@receiver']=aNode;return self;}
,"accessing",unescape("receiver%3A%20aNode%0D%0A%09receiver%20%3A%3D%20aNode"));
smalltalk.bind(smalltalk.CascadeNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitCascadeNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitCascadeNode%3A%20self"));
smalltalk.bind(smalltalk.CascadeNode,"isCascade",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isCascade%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.AssignmentNode,"left",0
,function (){var self=this;return self['@left'];;return self;}
,"accessing",unescape("left%0D%0A%09%5Eleft"));
smalltalk.bind(smalltalk.AssignmentNode,"left:",0
,function (aNode){var self=this;self['@left']=aNode;return self;}
,"accessing",unescape("left%3A%20aNode%0D%0A%09left%20%3A%3D%20aNode"));
smalltalk.bind(smalltalk.AssignmentNode,"right",0
,function (){var self=this;return self['@right'];;return self;}
,"accessing",unescape("right%0D%0A%09%5Eright"));
smalltalk.bind(smalltalk.AssignmentNode,"right:",0
,function (aNode){var self=this;self['@right']=aNode;return self;}
,"accessing",unescape("right%3A%20aNode%0D%0A%09right%20%3A%3D%20aNode"));
smalltalk.bind(smalltalk.AssignmentNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitAssignmentNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitAssignmentNode%3A%20self"));
smalltalk.bind(smalltalk.AssignmentNode,"isAssignment",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isAssignment%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20an%20assignment%20node.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.BlockNode,"parameters",0
,function (){var self=this;(((nil.isNil_(self['@parameters']))).mustBeBoolean()==true ? (function(){return self['@parameters']=smalltalk.Array.$$new();})() : nil);
return self['@parameters'];;return self;}
,"accessing",unescape("parameters%0D%0A%09parameters%20isNil%20ifTrue%3A%20%5B%20parameters%20%3A%3D%20Array%20new%20%5D.%0D%0A%09%5Eparameters"));
smalltalk.bind(smalltalk.BlockNode,"parameters:",0
,function (aCollection){var self=this;self['@parameters']=aCollection;return self;}
,"accessing",unescape("parameters%3A%20aCollection%0D%0A%09parameters%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.BlockNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitBlockNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitBlockNode%3A%20self"));
smalltalk.bind(smalltalk.BlockNode,"bindings",0
,function (){var self=this;return self.parameters();;return self;}
,"bindings",unescape("bindings%0D%0A%09%22%20Return%20the%20bindings%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20parameters"));
smalltalk.bind(smalltalk.BlockNode,"isBlock",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isBlock%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.SequenceNode,"temps",0
,function (){var self=this;return (((nil.isNil_(self['@temps']))).mustBeBoolean()==true ? (function(){return [];})() : (function(){return self['@temps'];})());;return self;}
,"accessing",unescape("temps%0D%0A%09%5Etemps%20isNil%20ifTrue%3A%20%5B%20%23%28%29%20%5D%20ifFalse%3A%20%5B%20temps%20%5D"));
smalltalk.bind(smalltalk.SequenceNode,"temps:",0
,function (aCollection){var self=this;self['@temps']=aCollection;return self;}
,"accessing",unescape("temps%3A%20aCollection%0D%0A%09temps%20%3A%3D%20aCollection"));
smalltalk.bind(smalltalk.SequenceNode,"asBlockSequenceNode",0
,function (){var self=this;return (function($rec){$rec.nodes_(self.nodes());$rec.temps_(self.temps());$rec.start_end_(self.start(), self.end());return $rec.yourself();})(smalltalk.BlockSequenceNode.$$new());;return self;}
,"converting",unescape("asBlockSequenceNode%0D%0A%09%5EBlockSequenceNode%20new%0D%0A%09%20%20%20%20nodes%3A%20self%20nodes%3B%0D%0A%09%20%20%20%20temps%3A%20self%20temps%3B%0D%0A%09%20%20%20%20start%3A%20self%20start%20end%3A%20self%20end%3B%0D%0A%09%20%20%20%20yourself"));
smalltalk.bind(smalltalk.SequenceNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitSequenceNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitSequenceNode%3A%20self"));
smalltalk.bind(smalltalk.SequenceNode,"bindings",0
,function (){var self=this;return self.temps();;return self;}
,"bindings",unescape("bindings%0D%0A%09%22%20Return%20the%20bindings%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20temps"));
smalltalk.bind(smalltalk.SequenceNode,"isSequence",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isSequence%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.BlockSequenceNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitBlockSequenceNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitBlockSequenceNode%3A%20self"));
smalltalk.bind(smalltalk.ExtendedSequenceNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitExtendedSequenceNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09%22%20Accept%20aVisitor.%20%22%0D%0A%0D%0A%09aVisitor%20visitExtendedSequenceNode%3A%20self"));
smalltalk.bind(smalltalk.ExtendedSequenceNode,"directive",0
,function (){var self=this;return self['@directive'];;return self;}
,"accessing",unescape("directive%0D%0A%09%22%20Return%20the%20directive%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Edirective"));
smalltalk.bind(smalltalk.ExtendedSequenceNode,"directive:",0
,function (aDirective){var self=this;self['@directive']=aDirective;return self;}
,"accessing",unescape("directive%3A%20aDirective%0D%0A%09%22%20Set%20the%20directive%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09directive%20%3A%3D%20aDirective"));
smalltalk.bind(smalltalk.ReturnNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitReturnNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitReturnNode%3A%20self"));
smalltalk.bind(smalltalk.ReturnNode,"isReturn",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isReturn%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.ValueNode,"value",0
,function (){var self=this;return self['@value'];;return self;}
,"accessing",unescape("value%0D%0A%09%5Evalue"));
smalltalk.bind(smalltalk.ValueNode,"value:",0
,function (anObject){var self=this;self['@value']=anObject;return self;}
,"accessing",unescape("value%3A%20anObject%0D%0A%09value%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.ValueNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitValueNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitValueNode%3A%20self"));
smalltalk.bind(smalltalk.ValueNode,"hasNumber",0
,function (){var self=this;return self['@value'].isNumber();;return self;}
,"testing",unescape("hasNumber%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20has%20a%20numeric%20literal%20value.%20%22%0D%0A%0D%0A%09%5Evalue%20isNumber"));
smalltalk.bind(smalltalk.ValueNode,"hasString",0
,function (){var self=this;return self['@value'].isString();;return self;}
,"testing",unescape("hasString%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20has%20a%20string%20literal%20value.%20%22%0D%0A%0D%0A%09%5Evalue%20isString"));
smalltalk.bind(smalltalk.ValueNode,"isValue",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isValue%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.VariableNode,"localNameIn:",0
,function (aCompiler){var self=this;return aCompiler.localName_(self.value());;return self;}
,"accessing",unescape("localNameIn%3A%20aCompiler%0D%0A%09%22%20Return%20the%20name%20of%20the%20receiver%20to%20be%20used%20by%20aCompiler%20locally.%20%22%0D%0A%0D%0A%09%5EaCompiler%20localName%3A%20self%20value%20"));
smalltalk.bind(smalltalk.VariableNode,"needsVerification",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("needsVerification%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20need%20verification.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.VariableNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitVariableNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitVariableNode%3A%20self"));
smalltalk.bind(smalltalk.VariableNode,"isSuper",0
,function (){var self=this;return self['@value']._eq("super");;return self;}
,"testing",unescape("isSuper%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20super.%20%22%0D%0A%0D%0A%09%5Evalue%20%3D%20%27super%27"));
smalltalk.bind(smalltalk.VariableNode,"indices",0
,function (){var self=this;return (((nil.isNil_(self['@indices']))).mustBeBoolean()==true ? (function(){return smalltalk.Array.$$new();})() : (function(){return self['@indices'];})());;return self;}
,"accessing",unescape("indices%0D%0A%09%22%20Return%20the%20indexing%20references%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eindices%20isNil%20ifTrue%3A%20%5B%20Array%20new%20%5D%20ifFalse%3A%20%5B%20indices%20%5D"));
smalltalk.bind(smalltalk.VariableNode,"indexedAs:",0
,function (chain){var self=this;self['@indices']=((chain.size()._gt((1)).and_((function(){return chain.second().notEmpty();}))).mustBeBoolean()==true ? (function(){return chain.second().collect_((function(tuple){return ((tuple.second().isString()).mustBeBoolean()==true ? (function(){return smalltalk.ValueNode.$$new().value_(tuple.second());})() : (function(){return tuple.second();})());}));})() : nil);
return self;;return self;}
,"visiting",unescape("indexedAs%3A%20chain%0D%0A%09%22%20The%20receiver%20has%20indexing%20references%20defined%20by%20chain.%20%22%0D%0A%0D%0A%09indices%20%3A%3D%20%28chain%20size%20%3E%201%20and%3A%20%5B%20chain%20second%20notEmpty%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09chain%20second%20collect%3A%20%5B%3Atuple%7C%0D%0A%09%09%09tuple%20second%20isString%0D%0A%09%09%09ifTrue%3A%20%5B%20ValueNode%20new%20value%3A%20tuple%20second%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20tuple%20second%20%5D%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.GlobalReferenceNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitGlobalReferenceNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitGlobalReferenceNode%3A%20self"));
smalltalk.bind(smalltalk.NoReceiverNode,"accept:",0
,function (aVisitor){var self=this;return self;}
,"visiting",unescape("accept%3A%20aVisitor"));
smalltalk.bind(smalltalk.NoReceiverNode,"messageSendConnector",0
,function (){var self=this;return smalltalk.String.$$new();;return self;}
,"accessing",unescape("messageSendConnector%0D%0A%09%22%20Return%20the%20binder%20used%20to%20send%20message%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EString%20new"));
smalltalk.bind(smalltalk.AlienNode,"localNameIn:",0
,function (aCompiler){var self=this;return self.value();;return self;}
,"accessing",unescape("localNameIn%3A%20aCompiler%0D%0A%09%22%20Return%20the%20name%20of%20the%20receiver%20to%20be%20used%20by%20aCompiler%20locally.%20%22%0D%0A%0D%0A%09%5Eself%20value%20"));
smalltalk.bind(smalltalk.AlienNode,"needsVerification",0
,function (){var self=this;return false;;return self;}
,"testing",unescape("needsVerification%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20need%20verification.%20%22%0D%0A%0D%0A%09%5Efalse"));
smalltalk.bind(smalltalk.InlineNode,"source",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@source']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "";})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@source'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("source%0D%0A%09source%20isNil%20ifTrue%3A%20%5B%20%5E%27%27%20%5D.%0D%0A%09%5Esource"));
smalltalk.bind(smalltalk.InlineNode,"source:",0
,function (aString){var self=this;self['@source']=aString;return self;}
,"accessing",unescape("source%3A%20aString%0D%0A%09source%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.InlineNode,"accept:",0
,function (aVisitor){var self=this;aVisitor.visitInlineNode_(self);return self;}
,"visiting",unescape("accept%3A%20aVisitor%0D%0A%09aVisitor%20visitInlineNode%3A%20self"));
smalltalk.bind(smalltalk.InlineNode,"isInline",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isInline%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20of%20this%20type.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.DirectiveNode,"description",0
,function (){var self=this;return self.$klass.name();;return self;}
,"visiting",unescape("description%0D%0A%09%22%20Return%20a%20literal%20description%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20name"));
smalltalk.bind(smalltalk.DirectiveNode,"selector",0
,function (){var self=this;return "directive:arguments:".asSelector();;return self;}
,"visiting",unescape("selector%0D%0A%09%22%20Private%20-%20Return%20the%20internal%20selector%20used%20to%20execute%20directive.%20%22%0D%0A%0D%0A%09%5E%23directive%3Aarguments%3A%20asSelector"));
smalltalk.bind(smalltalk.DirectiveNode,"literal",0
,function (){var self=this;return self.implementedBySubclass();;return self;}
,"visiting",unescape("literal%0D%0A%09%22%20Private%20-%20Return%20the%20literal%20to%20embedd%20in%20directive%20call.%20%22%0D%0A%0D%0A%09%5Eself%20implementedBySubclass"));
smalltalk.bind(smalltalk.DirectiveNode,"asJavascript:for:on:",0
,function (selector,aCompiler,aStream){var self=this;return self.tryExpressionDoing_(self.asJavascript_(selector));;return self;}
,unescape("code%20generation"),unescape("asJavascript%3A%20selector%20for%3A%20aCompiler%20on%3A%20aStream%0D%0A%09%22%20Return%20the%20javascript%20code%20to%20emmit%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20tryExpressionDoing%3A%20%28self%20asJavascript%3A%20selector%29"));
smalltalk.bind(smalltalk.DirectiveNode,"tryExpressionDoing:",0
,function (sourceCode){var self=this;return unescape("try%7B")._comma(sourceCode)._comma(unescape("%7D%20catch%28%24%24e%29%20%7B%0D%0A%09if%20%28%24%24e.directiveError%29%09%7B%20return%28this.error_%28%24%24e.directiveError%29%29%3B%20%7D%0D%0A%09if%20%28%21%24%24e.directiveFailed%29%20%7B%20throw%28%24%24e%29%3B%20%7D%20%7D"));;return self;}
,unescape("code%20generation"),unescape("tryExpressionDoing%3A%20sourceCode%0D%0A%09%22%20Private%20-%20Return%20the%20try/catch%20code%20wrapping%20sourceCode.%20%22%0D%0A%0D%0A%09%5E%27try%7B%27%20%2CsourceCode%20%2C%27%7D%20catch%28%24%24e%29%20%7B%0D%0A%09if%20%28%24%24e.directiveError%29%09%7B%20return%28this.error_%28%24%24e.directiveError%29%29%3B%20%7D%0D%0A%09if%20%28%21%24%24e.directiveFailed%29%20%7B%20throw%28%24%24e%29%3B%20%7D%20%7D%27"));
smalltalk.bind(smalltalk.DirectiveNode,"asJavascript:",0
,function (selector){var self=this;return "return this."._comma(self.selector())._comma(unescape("%28"))._comma(self.literal())._comma(unescape("%2C"))._comma("arguments")._comma(unescape("%29%3B"));;return self;}
,unescape("code%20generation"),unescape("asJavascript%3A%20selector%0D%0A%09%22%20Private%20-%20Return%20the%20javascript%20code%20to%20emmit%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%27return%20this.%27%2Cself%20selector%2C%27%28%27%2Cself%20literal%2C%27%2C%27%2C%27arguments%27%2C%27%29%3B%27"));
smalltalk.bind(smalltalk.JSDirectiveNode.$klass,"code:protected:",0
,function (aCode,useTry){var self=this;return (function($rec){$rec.code_(aCode);$rec.protected_(useTry);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("code%3A%20aCode%20protected%3A%20useTry%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09code%3A%20aCode%3B%0D%0A%09%09protected%3A%20useTry%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.JSDirectiveNode,"code:",0
,function (aCode){var self=this;self['@code']=aCode;return self;}
,"accessing",unescape("code%3A%20aCode%0D%0A%09%22%20Set%20the%20code%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09code%20%3A%3D%20aCode"));
smalltalk.bind(smalltalk.JSDirectiveNode,"jsCodeFor:",0
,function (aCompiler){var self=this;return ((self['@code'].isString()).mustBeBoolean()==true ? (function(){return self['@code'];})() : (function(){return self['@code'].evaluateWith_(aCompiler);})());;return self;}
,"accessing",unescape("jsCodeFor%3A%20aCompiler%0D%0A%09%22%20Private%20-%20Return%20the%20javascript%20code%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ecode%20isString%0D%0A%09%09ifTrue%3A%20%5B%20code%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20code%20evaluateWith%3A%20aCompiler%20%5D"));
smalltalk.bind(smalltalk.JSDirectiveNode,"protected:",0
,function (aBoolean){var self=this;self['@protected']=aBoolean;return self;}
,"accessing",unescape("protected%3A%20aBoolean%0D%0A%09%22%20Set%20the%20receiver%20to%20use%20try/catch%20to%20handle%20failure.%20%22%0D%0A%0D%0A%09protected%20%3A%3D%20aBoolean"));
smalltalk.bind(smalltalk.JSDirectiveNode,"asJavascript:for:on:",0
,function (selector,aCompiler,aStream){var self=this;var jsCode=nil;jsCode=self.jsCodeFor_(aCompiler);
return (((self['@protected'] === true)).mustBeBoolean()==true ? (function(){return self.tryExpressionDoing_(jsCode);})() : (function(){return jsCode;})());;return self;}
,unescape("code%20generation"),unescape("asJavascript%3A%20selector%20for%3A%20aCompiler%20on%3A%20aStream%0D%0A%09%22%20Return%20the%20javascript%20code%20to%20emmit%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20jsCode%20%7C%0D%0A%09jsCode%20%3A%3D%20self%20jsCodeFor%3A%20aCompiler.%0D%0A%09%5Eprotected%20%3D%3D%20true%0D%0A%09%09ifTrue%3A%20%5B%20self%20tryExpressionDoing%3A%20jsCode%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20jsCode%20%5D"));
smalltalk.bind(smalltalk.PPFailure.$klass,"reason:at:",0
,function (aString,anInteger){var self=this;return self.$$new().reason_at_(aString, anInteger);;return self;}
,"instantiation",unescape("reason%3A%20aString%20at%3A%20anInteger%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20reason%3A%20aString%20at%3A%20anInteger"));
smalltalk.bind(smalltalk.PPFailure,"position",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@position']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (0);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@position'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("position%0D%0A%09%22%20Return%20the%20position%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09position%20isNil%20ifTrue%3A%20%5B%20%5E0%20%5D.%0D%0A%09%5Eposition"));
smalltalk.bind(smalltalk.PPFailure,"position:",0
,function (aNumber){var self=this;self['@position']=aNumber;return self;}
,"accessing",unescape("position%3A%20aNumber%0D%0A%09%22%20Set%20the%20position%20of%20the%20rceiver.%20%22%0D%0A%0D%0A%09position%20%3A%3D%20aNumber"));
smalltalk.bind(smalltalk.PPFailure,"reason",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@reason']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.String.$$new();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@reason'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("reason%0D%0A%09%22%20Return%20the%20reason%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09reason%20isNil%20ifTrue%3A%20%5B%20%5EString%20new%20%5D.%0D%0A%09%5Ereason"));
smalltalk.bind(smalltalk.PPFailure,"reason:",0
,function (aString){var self=this;self['@reason']=aString;return self;}
,"accessing",unescape("reason%3A%20aString%0D%0A%09%22%20Set%20the%20reason%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09reason%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.PPFailure,"reason:at:",0
,function (aString,anInteger){var self=this;(function($rec){$rec.reason_(aString);return $rec.position_(anInteger);})(self);return self;}
,"accessing",unescape("reason%3A%20aString%20at%3A%20anInteger%0D%0A%09%22%20Set%20the%20reason%20and%20position%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09reason%3A%20aString%3B%20%0D%0A%09%09position%3A%20anInteger"));
smalltalk.bind(smalltalk.PPFailure,"isParseFailure",0
,function (){var self=this;return true;;return self;}
,"testing",unescape("isParseFailure%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20a%20parse%20failure.%20%22%0D%0A%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.PPFailure,"accept:",0
,function (aCompiler){var self=this;var description=nil;description="PPFailure: "._comma(self.reason())._comma(" at: ")._comma(self.position().asString())._comma(" source: ")._comma(aCompiler.stream().contents());
self.print_(description);
self.error_(unescape("%23accept%3A%20out%20of%20control%20-%20")._comma(description));return self;}
,"bug",unescape("accept%3A%20aCompiler%0D%0A%09%22%20Report%20buggy%20send%20in%20compiler.%20%22%0D%0A%0D%0A%09%7C%20description%20%7C%0D%0A%09description%20%3A%3D%20%27PPFailure%3A%20%27%2C%20self%20reason%0D%0A%09%09%2C%27%20at%3A%20%27%20%2Cself%20position%20asString%0D%0A%09%09%2C%27%20source%3A%20%27%20%2CaCompiler%20stream%20contents.%0D%0A%09self%20print%3A%20description.%0D%0A%09self%20error%3A%20%27%23accept%3A%20out%20of%20control%20-%20%27%20%2Cdescription"));
smalltalk.bind(smalltalk.PPParser.$klass,",","_comma"
,function (anObject){var self=this;return anObject.asParser();;return self;}
,"instantiation",unescape("%2C%20anObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EanObject%20asParser"));
smalltalk.bind(smalltalk.PPParser,"memo",0
,function (){var self=this;(((nil.isNil_(self['@memo']))).mustBeBoolean()==true ? (function(){return self['@memo']=[];})() : nil);
return self['@memo'];;return self;}
,"accessing",unescape("memo%0D%0A%09%22%20Return%20the%20memoized%20information.%20%22%0D%0A%0D%0A%09memo%20isNil%20ifTrue%3A%20%5B%20memo%20%3A%3D%20%23%28%29%20%5D.%0D%0A%09%5Ememo"));
smalltalk.bind(smalltalk.PPParser,"set:start:end:",0
,function (anElement,start,end){var self=this;((smalltalk.responds_to_(anElement,("start:end:"))).mustBeBoolean()==true ? (function(){return anElement.start_end_(start, end);})() : nil);return self;}
,"private",unescape("set%3A%20anElement%20start%3A%20start%20end%3A%20end%0D%0A%09%22%20Private%20-%20Set%20start%26end%20source%20offest%20of%20anElement.%20%22%0D%0A%0D%0A%09%28anElement%20respondsTo%3A%20%23start%3Aend%3A%29%20ifTrue%3A%20%5B%0D%0A%09%09anElement%20start%3A%20start%20end%3A%20end%0D%0A%09%5D"));
smalltalk.bind(smalltalk.PPParser,"flatten",0
,function (){var self=this;return smalltalk.PPFlattenParser.on_(self);;return self;}
,"operations",unescape("flatten%0D%0A%09%22%20Return%20a%20flattened%20version%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPFlattenParser%20on%3A%20self"));
smalltalk.bind(smalltalk.PPParser,"withSource",0
,function (){var self=this;return smalltalk.PPSourceParser.on_(self);;return self;}
,"operations",unescape("withSource%0D%0A%09%22%20Return%20a%20source%20parser%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPSourceParser%20on%3A%20self"));
smalltalk.bind(smalltalk.PPParser,"==>","_eq_eq_gt"
,function (aBlock){var self=this;return smalltalk.PPActionParser.on_block_(self, aBlock);;return self;}
,"operations",unescape("%3D%3D%3E%20aBlock%0D%0A%09%22%20Return%20an%20action%20parser%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPActionParser%20on%3A%20self%20block%3A%20aBlock"));
smalltalk.bind(smalltalk.PPParser,",","_comma"
,function (aParser){var self=this;return smalltalk.PPSequenceParser.with_with_(self, aParser);;return self;}
,"operations",unescape("%2C%20aParser%0D%0A%09%22%20Return%20a%20composed%20version%20of%20the%20receiver%20and%20aParser.%20%22%0D%0A%0D%0A%09%5EPPSequenceParser%20with%3A%20self%20with%3A%20aParser"));
smalltalk.bind(smalltalk.PPParser,"/","_slash"
,function (aParser){var self=this;return smalltalk.PPChoiceParser.with_with_(self, aParser);;return self;}
,"operations",unescape("/%20aParser%0D%0A%09%22%20Return%20a%20choice%20composite%20version%20of%20the%20receiver%20and%20aParser.%20%22%0D%0A%0D%0A%09%5EPPChoiceParser%20with%3A%20self%20with%3A%20aParser"));
smalltalk.bind(smalltalk.PPParser,"@","_at"
,function (tag){var self=this;return self._eq_eq_gt((function(node){self.print_(tag._comma(unescape("%3D%3D%3E"))._comma(node.printString()));return node;}));;return self;}
,"debug",unescape("@%20tag%0D%0A%09%22%20DEBUG%20-%20Return%20a%20notification%20wrapper%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20%3D%3D%3E%20%5B%3Anode%7C%20self%20print%3A%20tag%20%2C%27%3D%3D%3E%27%2Cnode%20printString.%20node%20%5D"));
smalltalk.bind(smalltalk.PPParser,"plus",0
,function (){var self=this;return smalltalk.PPRepeatingParser.on_min_(self, (1));;return self;}
,"operations",unescape("plus%0D%0A%09%22%20Return%20an%20iterative%20version%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPRepeatingParser%20on%3A%20self%20min%3A%201"));
smalltalk.bind(smalltalk.PPParser,"star",0
,function (){var self=this;return smalltalk.PPRepeatingParser.on_min_(self, (0));;return self;}
,"operations",unescape("star%0D%0A%09%22%20Return%20an%20iterative%20version%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPRepeatingParser%20on%3A%20self%20min%3A%200"));
smalltalk.bind(smalltalk.PPParser,"not",0
,function (){var self=this;return smalltalk.PPNotParser.on_(self);;return self;}
,"operations",unescape("not%0D%0A%09%22%20Return%20the%20negation%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EPPNotParser%20on%3A%20self"));
smalltalk.bind(smalltalk.PPParser,"optional",0
,function (){var self=this;return self._slash(smalltalk.PPEpsilonParser.$$new());;return self;}
,"operations",unescape("optional%0D%0A%09%22%20Return%20an%20optional%20version%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20/%20PPEpsilonParser%20new"));
smalltalk.bind(smalltalk.PPParser,"memoizedParse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var value=nil;start=aStream.position();
value=self.memo().at_ifAbsent_(start, (function(){var end=nil;var node=nil;node=self.parse_(aStream);end=aStream.position();self.set_start_end_(node, start, end);self.memo().at_put_(start, smalltalk.Array.with_with_(node, end));return (function(){$s8Ret$.result=(function(){return node;})();throw($s8Ret$)})();}));
aStream.position_(value.second());
(function(){$s8Ret$.result=(function(){return value.first();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"operations",unescape("memoizedParse%3A%20aStream%0D%0A%09%22%20Private%20-%20Evaluate%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20start%20value%20%7C%0D%0A%09start%20%3A%3D%20aStream%20position.%0D%0A%09value%20%3A%3D%20self%20memo%20at%3A%20start%20ifAbsent%3A%20%5B%20%7C%20end%20node%20%7C%0D%0A%09%09node%20%3A%3D%20self%20parse%3A%20aStream.%0D%0A%09%09end%20%3A%3D%20aStream%20position.%0D%0A%09%09self%20set%3A%20node%20start%3A%20start%20end%3A%20end.%0D%0A%09%09self%20memo%20at%3A%20start%20put%3A%20%28Array%20with%3A%20node%20with%3A%20end%29.%0D%0A%09%09%5Enode%0D%0A%09%5D.%0D%0A%09aStream%20position%3A%20value%20second.%0D%0A%09%5Evalue%20first"));
smalltalk.bind(smalltalk.PPParser,"parse:",0
,function (aStream){var self=this;self.subclassResponsibility_("parse:");return self;}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09self%20subclassResponsibility%3A%20%23parse%3A"));
smalltalk.bind(smalltalk.PPParser,"parseAll:",0
,function (aStream){var self=this;var result=nil;result=smalltalk.PPSequenceParser.with_with_(self, smalltalk.PPEOFParser.$$new()).memoizedParse_(aStream);
return ((result.isParseFailure()).mustBeBoolean()==true ? (function(){return self.error_(result.messageFor_(aStream.contents()));})() : (function(){return result.first();})());;return self;}
,"parsing",unescape("parseAll%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20%28PPSequenceParser%0D%0A%09%09with%3A%20self%20with%3A%20PPEOFParser%20new%29%0D%0A%09%09memoizedParse%3A%20aStream.%0D%0A%09%5Eresult%20isParseFailure%20%0D%0A%09%20%20%20%20ifTrue%3A%20%5B%20self%20error%3A%20%28result%20messageFor%3A%20aStream%20contents%29%20%5D%0D%0A%09%20%20%20%20ifFalse%3A%20%5B%20result%20first%20%5D"));
smalltalk.bind(smalltalk.PPParser,"asParser",0
,function (){var self=this;return self;;return self;}
,"converting",unescape("asParser%0D%0A%09%22%20Return%20a%20parser%20on%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.PPEOFParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;((aStream.atEnd()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_("EOF expected", aStream.position());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09aStream%20atEnd%20ifTrue%3A%20%5B%20%5Enil%20%5D%20.%0D%0A%09%5EPPFailure%20reason%3A%20%27EOF%20expected%27%20at%3A%20aStream%20position"));
smalltalk.bind(smalltalk.PPAnyParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;((aStream.atEnd()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return aStream.next();})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_("End of stream", aStream.position());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09aStream%20atEnd%20ifFalse%3A%20%5B%20%5EaStream%20next%20%5D.%0D%0A%09%5EPPFailure%20reason%3A%20%27End%20of%20stream%27%20at%3A%20aStream%20position"));
smalltalk.bind(smalltalk.PPEpsilonParser,"parse:",0
,function (aStream){var self=this;return nil;;return self;}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%5Enil"));
smalltalk.bind(smalltalk.PPStringParser,"string",0
,function (){var self=this;return self['@string'];;return self;}
,"accessing",unescape("string%0D%0A%09%22%20Return%20the%20string%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Estring"));
smalltalk.bind(smalltalk.PPStringParser,"string:",0
,function (aString){var self=this;self['@string']=aString;return self;}
,"accessing",unescape("string%3A%20aString%0D%0A%09%22%20Set%20the%20string%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09string%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.PPStringParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var back=nil;var reason=nil;((self['@string'].isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@string'];})();throw($s8Ret$)})();})() : nil);
((aStream.peekForAll_(self['@string'])).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@string'];})();throw($s8Ret$)})();})() : nil);
back=aStream.position();
reason="Expecting "._comma(self['@string'].toString().printString())._comma(" at ")._comma(back.printString())._comma(" read ")._comma(aStream.next_(self['@string'].size()).printString());
aStream.position_(back);
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_(reason, back);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20back%20reason%20%7C%0D%0A%09string%20isEmpty%20ifTrue%3A%20%5B%20%5Estring%20%5D.%0D%0A%09%28aStream%20peekForAll%3A%20string%29%20ifTrue%3A%20%5B%20%5Estring%20%5D.%0D%0A%09back%20%3A%3D%20aStream%20position.%0D%0A%09reason%20%3A%3D%20%27Expecting%20%27%2C%20string%20toString%20printString%0D%0A%09%09%2C%27%20at%20%27%2Cback%20printString%0D%0A%09%09%2C%27%20read%20%27%2C%28aStream%20next%3A%20string%20size%29%20printString.%0D%0A%09aStream%20position%3A%20back.%0D%0A%09%5EPPFailure%20reason%3A%20reason%20at%3A%20back"));
smalltalk.bind(smalltalk.PPStringParser,"parseOBSOLETE:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var back=nil;((self['@string'].isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self['@string'];})();throw($s8Ret$)})();})() : nil);
((self['@string'].size()._eq((1)).and_((function(){return self['@string']._eq(aStream.peek());}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aStream.next();})();throw($s8Ret$)})();})() : nil);
back=aStream.position();
self['@string'].do_((function(c){((c._eq(aStream.peek())).mustBeBoolean()==true ? nil : (function(){var reason=nil;aStream.position_(back);reason="Expecting "._comma(self.string().printString())._comma(" at ")._comma(back.printString())._comma(" read ")._comma(aStream.next_(self['@string'].size()).printString());aStream.position_(back);return (function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_(reason, back);})();throw($s8Ret$)})();})());return aStream.next();}));
(function(){$s8Ret$.result=(function(){return self['@string'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parseOBSOLETE%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20back%20%7C%0D%0A%09string%20isEmpty%20ifTrue%3A%20%5B%20%5Estring%20%5D.%0D%0A%09%28string%20size%20%3D%201%20and%3A%20%5B%20string%20%3D%20aStream%20peek%20%5D%29%20ifTrue%3A%20%5B%20%5EaStream%20next%20%5D.%0D%0A%09back%20%3A%3D%20aStream%20position.%0D%0A%09string%20do%3A%20%5B%3Ac%7C%0D%0A%09%09c%20%3D%20aStream%20peek%20ifFalse%3A%20%5B%20%7C%20reason%20%7C%0D%0A%09%09%09aStream%20position%3A%20back.%0D%0A%09%09%09reason%20%3A%3D%20%27Expecting%20%27%2C%20self%20string%20printString%0D%0A%09%09%09%09%2C%27%20at%20%27%2Cback%20printString%0D%0A%09%09%09%09%2C%27%20read%20%27%2C%28aStream%20next%3A%20string%20size%29%20printString.%0D%0A%09%09%09aStream%20position%3A%20back.%0D%0A%09%09%09%5EPPFailure%20reason%3A%20reason%20at%3A%20back%0D%0A%09%09%5D.%0D%0A%09%09aStream%20next%0D%0A%09%5D.%0D%0A%09%5Estring"));
smalltalk.bind(smalltalk.PPStStringParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var position=nil;var result=nil;position=aStream.position();
result="";
(function(){while(!(function(){result=result._comma(aStream.upTo_(unescape("%27")));return aStream.atEnd();})()){(function(){((aStream.peek()._eq(unescape("%27"))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})());return result=result._comma(aStream.next());})()};return nil})();
((aStream.position()._gt(position)).mustBeBoolean()==true ? (function(){aStream.position_(aStream.position()._minus((1)));return ((aStream.next()._eq(unescape("%27"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);})() : nil);
aStream.position_(position);
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_("Unfinished String", position);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20position%20result%20%7C%0D%0A%09position%20%3A%3D%20aStream%20position.%0D%0A%09result%20%3A%3D%20%27%27.%0D%0A%09%5B%20result%20%3A%3D%20result%20%2C%20%28aStream%20upTo%3A%20%24%27%29.%0D%0A%09%20%20aStream%20atEnd%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09aStream%20peek%20%3D%20%24%27%20ifFalse%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%09result%20%3A%3D%20result%20%2CaStream%20next.%0D%0A%09%5D.%0D%0A%09aStream%20position%20%3E%20position%20ifTrue%3A%20%5B%0D%0A%09%09aStream%20position%3A%20aStream%20position%20-%201.%0D%0A%09%09aStream%20next%20%3D%20%24%27%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%5D.%0D%0A%09aStream%20position%3A%20position.%0D%0A%09%5EPPFailure%20reason%3A%20%27Unfinished%20String%27%20at%3A%20position"));
smalltalk.bind(smalltalk.PPCharacterParser,"string:",0
,function (aString){var self=this;self['@regexp']=smalltalk.RegularExpression.fromString_(unescape("%5B")._comma(aString)._comma(unescape("%5D")));return self;}
,"accessing",unescape("string%3A%20aString%0D%0A%09%22%20Set%20the%20string%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09regexp%20%3A%3D%20RegularExpression%20fromString%3A%20%27%5B%27%2C%20aString%2C%20%27%5D%27"));
smalltalk.bind(smalltalk.PPCharacterParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(aStream.peek())===false).and_((function(){return self.match_(aStream.peek());}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aStream.next();})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_("Could not match", aStream.position());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%28aStream%20peek%20notNil%0D%0A%09and%3A%20%5B%20self%20match%3A%20aStream%20peek%20%5D%29%0D%0A%09ifTrue%3A%20%5B%20%5EaStream%20next%20%5D.%0D%0A%0D%0A%09%5EPPFailure%20reason%3A%20%27Could%20not%20match%27%20at%3A%20aStream%20position"));
smalltalk.bind(smalltalk.PPCharacterParser,"match:",0
,function (aString){var self=this;return aString.match_(self['@regexp']);;return self;}
,"private",unescape("match%3A%20aString%0D%0A%09%22%20Match%20the%20receiver%20to%20string.%20%22%0D%0A%0D%0A%09%5EaString%20match%3A%20regexp"));
smalltalk.bind(smalltalk.PPListParser.$klass,"withAll:",0
,function (aCollection){var self=this;return (function($rec){$rec.parsers_(aCollection);return $rec.yourself();})(self.basicNew());;return self;}
,"instantiation",unescape("withAll%3A%20aCollection%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%20%20%20%20%5Eself%20basicNew%0D%0A%09%09parsers%3A%20aCollection%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.PPListParser.$klass,"with:with:",0
,function (aParser,anotherParser){var self=this;return self.withAll_(smalltalk.Array.with_with_(aParser, anotherParser));;return self;}
,"instantiation",unescape("with%3A%20aParser%20with%3A%20anotherParser%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20withAll%3A%20%28Array%20with%3A%20aParser%20with%3A%20anotherParser%29"));
smalltalk.bind(smalltalk.PPListParser,"parsers",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@parsers']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self['@parsers'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("parsers%0D%0A%09%22%20Return%20the%20parsers%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09parsers%20isNil%20ifTrue%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09%5Eparsers"));
smalltalk.bind(smalltalk.PPListParser,"parsers:",0
,function (aCollection){var self=this;self['@parsers']=aCollection.collect_((function(each){return each.asParser();}));return self;}
,"accessing",unescape("parsers%3A%20aCollection%0D%0A%09%22%20Set%20the%20parsers%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09parsers%20%3A%3D%20aCollection%20collect%3A%20%5B%3Aeach%7C%20each%20asParser%20%5D"));
smalltalk.bind(smalltalk.PPListParser,"copyWith:",0
,function (aParser){var self=this;return self.$klass.withAll_(self.parsers().copyWith_(aParser));;return self;}
,"copying",unescape("copyWith%3A%20aParser%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20aParser.%20%22%0D%0A%0D%0A%09%5Eself%20class%20withAll%3A%20%28self%20parsers%20copyWith%3A%20aParser%29"));
smalltalk.bind(smalltalk.PPSequenceParser,",","_comma"
,function (aRule){var self=this;return self.copyWith_(aRule);;return self;}
,"copying",unescape("%2C%20aRule%0D%0A%09%22%20Return%20a%20copy%20of%20the%20receiver%20with%20aRule.%20%22%0D%0A%0D%0A%09%5Eself%20copyWith%3A%20aRule"));
smalltalk.bind(smalltalk.PPSequenceParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var result=nil;var element=nil;result=[];
start=aStream.position();
self.parsers().do_((function(each){element=each.memoizedParse_(aStream);result.add_(element);return ((element.isParseFailure()).mustBeBoolean()==true ? (function(){aStream.position_(start);return (function(){$s8Ret$.result=(function(){return element;})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20start%20result%20element%20%7C%0D%0A%09result%20%3A%3D%20%23%28%29.%0D%0A%09start%20%3A%3D%20aStream%20position.%0D%0A%09self%20parsers%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09element%20%3A%3D%20each%20memoizedParse%3A%20aStream.%0D%0A%09%09result%20add%3A%20element.%0D%0A%09%09element%20isParseFailure%20ifTrue%3A%20%5B%0D%0A%09%09%09aStream%20position%3A%20start.%0D%0A%09%09%09%5Eelement%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.PPChoiceParser,"/","_slash"
,function (aRule){var self=this;return self.copyWith_(aRule);;return self;}
,"copying",unescape("/%20aRule%0D%0A%09%22%20Return%20the%20receiver%20composed%20with%20aRule.%20%22%0D%0A%0D%0A%09%5Eself%20copyWith%3A%20aRule"));
smalltalk.bind(smalltalk.PPChoiceParser,"parse:",0
,function (aStream){var self=this;var result=nil;self.parsers().detect_ifNone_((function(each){result=each.memoizedParse_(aStream);return result.isParseFailure().not();}), (function(){return nil;}));
return result;;return self;}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20parsers%20detect%3A%20%5B%3Aeach%20%7C%0D%0A%09%09result%20%3A%3D%20each%20memoizedParse%3A%20aStream.%0D%0A%09%09result%20isParseFailure%20not%0D%0A%09%5D%20ifNone%3A%20%5B%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.PPDelegateParser.$klass,"on:",0
,function (aParser){var self=this;return (function($rec){$rec.parser_(aParser);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("on%3A%20aParser%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%20%20%20%20%5Eself%20new%0D%0A%09%09parser%3A%20aParser%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.PPDelegateParser,"parser",0
,function (){var self=this;return self['@parser'];;return self;}
,"accessing",unescape("parser%0D%0A%09%22%20Return%20the%20parser%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eparser"));
smalltalk.bind(smalltalk.PPDelegateParser,"parser:",0
,function (aParser){var self=this;self['@parser']=aParser;return self;}
,"accessing",unescape("parser%3A%20aParser%0D%0A%09%22%20Set%20the%20parser%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09parser%20%3A%3D%20aParser"));
smalltalk.bind(smalltalk.PPDelegateParser,"parse:",0
,function (aStream){var self=this;return self.parser().memoizedParse_(aStream);;return self;}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%5Eself%20parser%20memoizedParse%3A%20aStream"));
smalltalk.bind(smalltalk.PPAndParser,"parse:",0
,function (aStream){var self=this;return self.basicParse_(aStream);;return self;}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%5Eself%20basicParse%3A%20aStream"));
smalltalk.bind(smalltalk.PPAndParser,"basicParse:",0
,function (aStream){var self=this;var element=nil;var position=nil;position=aStream.position();
element=self.parser().memoizedParse_(aStream);
aStream.position_(position);
return element;;return self;}
,"parsing",unescape("basicParse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20element%20position%20%7C%0D%0A%09position%20%3A%3D%20aStream%20position.%0D%0A%09element%20%3A%3D%20self%20parser%20memoizedParse%3A%20aStream.%0D%0A%09aStream%20position%3A%20position.%0D%0A%09%5Eelement"));
smalltalk.bind(smalltalk.PPNotParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var element=nil;element=self.basicParse_(aStream);
((element.isParseFailure()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_(element, aStream.position());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20element%20%7C%0D%0A%09element%20%3A%3D%20self%20basicParse%3A%20aStream.%0D%0A%09element%20isParseFailure%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5EPPFailure%20reason%3A%20element%20at%3A%20aStream%20position"));
smalltalk.bind(smalltalk.PPActionParser.$klass,"on:block:",0
,function (aParser,aBlock){var self=this;return (function($rec){$rec.parser_(aParser);$rec.block_(aBlock);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("on%3A%20aParser%20block%3A%20aBlock%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09parser%3A%20aParser%3B%0D%0A%09%09block%3A%20aBlock%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.PPActionParser,"block",0
,function (){var self=this;return self['@block'];;return self;}
,"accessing",unescape("block%0D%0A%09%22%20Return%20the%20block%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eblock"));
smalltalk.bind(smalltalk.PPActionParser,"block:",0
,function (aBlock){var self=this;self['@block']=aBlock;return self;}
,"accessing",unescape("block%3A%20aBlock%0D%0A%09%22%20Set%20the%20block%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09block%20%3A%3D%20aBlock"));
smalltalk.bind(smalltalk.PPActionParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var element=nil;element=self.parser().memoizedParse_(aStream);
((element.isParseFailure()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return element;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.block().value_(element);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20element%20%7C%0D%0A%09element%20%3A%3D%20self%20parser%20memoizedParse%3A%20aStream.%0D%0A%09element%20isParseFailure%20ifTrue%3A%20%5B%20%5Eelement%20%5D.%0D%0A%09%5Eself%20block%20value%3A%20element"));
smalltalk.bind(smalltalk.PPFlattenParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var element=nil;start=aStream.position();
element=self.parser().memoizedParse_(aStream);
((element.isParseFailure()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return element;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return aStream.collection().copyFrom_to_(start._plus((1)), aStream.position());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20start%20element%20%7C%0D%0A%09start%20%3A%3D%20aStream%20position.%0D%0A%09element%20%3A%3D%20self%20parser%20memoizedParse%3A%20aStream.%0D%0A%09element%20isParseFailure%20ifTrue%3A%20%5B%20%5Eelement%20%5D.%0D%0A%09%5EaStream%20collection%20%0D%0A%09%09copyFrom%3A%20start%20+%201%20%0D%0A%09%09to%3A%20aStream%20position"));
smalltalk.bind(smalltalk.PPSourceParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var element=nil;var result=nil;start=aStream.position();
element=self.parser().memoizedParse_(aStream);
((element.isParseFailure()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return element;})();throw($s8Ret$)})();})() : nil);
result=aStream.collection().copyFrom_to_(start._plus((1)), aStream.position());
(function(){$s8Ret$.result=(function(){return smalltalk.Array.with_with_(element, result);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20start%20element%20result%20%7C%0D%0A%09start%20%3A%3D%20aStream%20position.%0D%0A%09element%20%3A%3D%20self%20parser%20memoizedParse%3A%20aStream.%0D%0A%09element%20isParseFailure%20ifTrue%3A%20%5B%20%5Eelement%20%5D.%0D%0A%09result%20%3A%3D%20aStream%20collection%0D%0A%09%09copyFrom%3A%20start%20+%201%0D%0A%09%09to%3A%20aStream%20position.%0D%0A%09%5EArray%20with%3A%20element%20with%3A%20result"));
smalltalk.bind(smalltalk.PPRepeatingParser.$klass,"on:min:",0
,function (aParser,aNumber){var self=this;return (function($rec){$rec.parser_(aParser);$rec.min_(aNumber);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("on%3A%20aParser%20min%3A%20aNumber%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09parser%3A%20aParser%3B%0D%0A%09%09min%3A%20aNumber%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.PPRepeatingParser,"min",0
,function (){var self=this;return self['@min'];;return self;}
,"accessing",unescape("min%0D%0A%09%22%20Return%20the%20min%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Emin"));
smalltalk.bind(smalltalk.PPRepeatingParser,"min:",0
,function (aNumber){var self=this;self['@min']=aNumber;return self;}
,"accessing",unescape("min%3A%20aNumber%0D%0A%09%22%20Set%20the%20min%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09min%20%3A%3D%20aNumber"));
smalltalk.bind(smalltalk.PPRepeatingParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var start=nil;var element=nil;var result=nil;var failure=nil;start=aStream.position();
result=smalltalk.Array.$$new();
(function(){while((function(){return result.size()._lt(self.min()).and_((function(){return (nil.isNil_(failure));}));})()){(function(){element=self.parser().memoizedParse_(aStream);return ((element.isParseFailure()).mustBeBoolean()==true ? (function(){aStream.position_(start);return failure=element;})() : (function(){return result.addLast_(element);})());})()};return nil})();
(((nil.isNil_(failure)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return failure;})();throw($s8Ret$)})();})() : nil);
(function(){while((function(){return (nil.isNil_(failure));})()){(function(){element=self.parser().memoizedParse_(aStream);return ((element.isParseFailure()).mustBeBoolean()==true ? (function(){return failure=element;})() : (function(){return result.addLast_(element);})());})()};return nil})();
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20start%20element%20result%20failure%20%7C%0D%0A%09start%20%3A%3D%20aStream%20position.%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09%5B%20%28result%20size%20%3C%20self%20min%29%20and%3A%20%5B%20failure%20isNil%20%5D%0D%0A%09%5D%20whileTrue%3A%20%5B%0D%0A%09%20%20%20%20element%20%3A%3D%20self%20parser%20memoizedParse%3A%20aStream.%0D%0A%09%20%20%20%20element%20isParseFailure%0D%0A%09%09ifFalse%3A%20%5B%20result%20addLast%3A%20element%20%5D%0D%0A%09%09ifTrue%3A%20%5B%20aStream%20position%3A%20start.%0D%0A%09%09%09%20%20failure%20%3A%3D%20element%20%5D%0D%0A%09%5D.%0D%0A%09failure%20notNil%20ifTrue%3A%20%5B%20%5Efailure%20%5D.%0D%0A%09%5Bfailure%20isNil%5D%20whileTrue%3A%20%5B%0D%0A%09%09element%20%3A%3D%20self%20parser%20memoizedParse%3A%20aStream.%0D%0A%09%20%09element%20isParseFailure%0D%0A%09%09%09ifTrue%3A%20%5B%20failure%20%3A%3D%20element%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20result%20addLast%3A%20element%20%5D%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.PPInlineParser.$klass,"upTo:",0
,function (aString){var self=this;return (function($rec){$rec.terminator_(aString);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("upTo%3A%20aString%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20terminator%3A%20aString%3B%20yourself"));
smalltalk.bind(smalltalk.PPInlineParser,"terminator:",0
,function (aString){var self=this;self['@terminator']=aString;return self;}
,"accessing",unescape("terminator%3A%20aString%0D%0A%09%22%20Set%20terminator%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09terminator%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.PPInlineParser,"parse:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=aStream.upTo_(self['@terminator']);
((aStream.atEnd()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return smalltalk.PPFailure.reason_at_(unescape("Missing%20inline%20terminator%20%28")._comma(self['@terminator'])._comma(unescape("%29")), aStream.position());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"parsing",unescape("parse%3A%20aStream%0D%0A%09%22%20Parse%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20aStream%20upTo%3A%20terminator.%0D%0A%09aStream%20atEnd%20ifFalse%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%5EPPFailure%0D%0A%09%09reason%3A%20%27Missing%20inline%20terminator%20%28%27%2Cterminator%2C%27%29%27%0D%0A%09%09at%3A%20aStream%20position"));
smalltalk.bind(smalltalk.FileInReader,"scanFrom:",0
,function (aStream){var self=this;return self.subclassResponsibility_("scanFrom:");;return self;}
,"fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20FileIn%20-%20Return%20the%20result%20of%20evaluating%20the%20next%20chunk%20of%20data%20from%20aStream.%0D%0A%09The%20method%20must%20be%20implemented%20by%20chunk%20readers%20to%20support%20custom%20fileIn%20features.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23scanFrom%3A"));
smalltalk.bind(smalltalk.ChunkReader.$klass,"doing:until:",0
,function (aBlock,terminationBlock){var self=this;return (function($rec){$rec.actionBlock_(aBlock);$rec.terminationBlock_(terminationBlock);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("doing%3A%20aBlock%20until%3A%20terminationBlock%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09actionBlock%3A%20aBlock%3B%0D%0A%09%09terminationBlock%3A%20terminationBlock%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.ChunkReader.$klass,"doing:",0
,function (aBlock){var self=this;return self.doing_until_(aBlock, (function(){return true;}));;return self;}
,"instantiation",unescape("doing%3A%20aBlock%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20doing%3A%20aBlock%20until%3A%20%5B%20true%20%5D"));
smalltalk.bind(smalltalk.ChunkReader.$klass,"until:",0
,function (terminationBlock){var self=this;return self.doing_until_(nil, terminationBlock);;return self;}
,"instantiation",unescape("until%3A%20terminationBlock%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20doing%3A%20nil%20until%3A%20terminationBlock"));
smalltalk.bind(smalltalk.ChunkReader.$klass,"ignore",0
,function (){var self=this;return self.$$new();;return self;}
,"instantiation",unescape("ignore%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%0D%0A%09The%20returned%20reader%20will%20ignore/absorb%20next%20chunk.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20new"));
smalltalk.bind(smalltalk.ChunkReader.$klass,"javascriptChunk",0
,function (){var self=this;return self.doing_((function(aStream){return smalltalk.Smalltalk.current().eval_(aStream.nextChunk());}));;return self;}
,"instantiation",unescape("javascriptChunk%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%0D%0A%09The%20returned%20reader%20will%20evaluate%20next%20chunk%20as%20javascript%20code%20%28in%20global%20context%29.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20doing%3A%20%5B%3AaStream%7C%20Smalltalk%20current%20eval%3A%20aStream%20nextChunk%20%5D"));
smalltalk.bind(smalltalk.ChunkReader.$klass,"javascript",0
,function (){var self=this;return self.doing_((function(aStream){return smalltalk.Smalltalk.current().eval_(aStream.upToEnd());}));;return self;}
,"instantiation",unescape("javascript%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%0D%0A%09The%20returned%20reader%20will%20evaluate%20following%20contents%20as%20javascript%20code%20%28in%20global%20context%29.%0D%0A%09The%20stream%20will%20be%20consumed%20up%20to%20end.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20doing%3A%20%5B%3AaStream%7C%20Smalltalk%20current%20eval%3A%20aStream%20upToEnd%20%5D"));
smalltalk.bind(smalltalk.ChunkReader,"actionBlock",0
,function (){var self=this;return self['@actionBlock'];;return self;}
,"accessing",unescape("actionBlock%0D%0A%09%22%20Return%20the%20actionBlock%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EactionBlock"));
smalltalk.bind(smalltalk.ChunkReader,"actionBlock:",0
,function (aBlock){var self=this;self['@actionBlock']=aBlock;return self;}
,"accessing",unescape("actionBlock%3A%20aBlock%0D%0A%09%22%20Set%20the%20actionBlock%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09actionBlock%20%3A%3D%20aBlock"));
smalltalk.bind(smalltalk.ChunkReader,"terminationBlock",0
,function (){var self=this;return self['@terminationBlock'];;return self;}
,"accessing",unescape("terminationBlock%0D%0A%09%22%20Return%20the%20terminationBlock%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EterminationBlock"));
smalltalk.bind(smalltalk.ChunkReader,"terminationBlock:",0
,function (aBlock){var self=this;self['@terminationBlock']=aBlock;return self;}
,"accessing",unescape("terminationBlock%3A%20aBlock%0D%0A%09%22%20Set%20the%20terminationBlock%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09terminationBlock%20%3A%3D%20aBlock"));
smalltalk.bind(smalltalk.ChunkReader,"scanFrom:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var chunk=nil;(((nil.isNil_(self.actionBlock()))).mustBeBoolean()==true ? (function(){chunk=aStream.nextChunk();return ((chunk.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);})() : (function(){return self.actionBlock().value_(aStream);})());
(((nil.isNil_(self.terminationBlock())).or_((function(){return (true === self.terminationBlock().value());}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20Scan%20the%20next%20chunk%20of%20data%20from%20aStream.%20%22%0D%0A%0D%0A%09%7C%20chunk%20%7C%0D%0A%09self%20actionBlock%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09chunk%20%3A%3D%20aStream%20nextChunk.%0D%0A%09%09chunk%20isEmpty%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5D%20ifFalse%3A%20%5B%20self%20actionBlock%20value%3A%20aStream%20%5D.%0D%0A%09%28self%20terminationBlock%20isNil%0D%0A%09%09or%3A%20%5B%20true%20%3D%3D%20self%20terminationBlock%20value%20%5D%29%0D%0A%09%09ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.ClassCategoryReader,"class:category:",0
,function (aClass,aString){var self=this;self['@class']=aClass;
self['@category']=aString;return self;}
,"accessing",unescape("class%3A%20aClass%20category%3A%20aString%0D%0A%09%22%20Private%20-%20Set%20the%20class%20and%20category%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09class%20%3A%3D%20aClass.%0D%0A%09category%20%3A%3D%20aString"));
smalltalk.bind(smalltalk.ClassCategoryReader,"scanFrom:",0
,function (aStream){var self=this;var chunk=nil;chunk=aStream.nextChunk();
return (function(){return ((chunk.isEmpty()).mustBeBoolean()==true ? nil : (function(){return self.compileMethod_(chunk);})());}).logEvaluate_(chunk);;return self;}
,"fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20Scan%20the%20next%20chunk%20of%20data%20from%20aStream.%20%22%0D%0A%0D%0A%09%7C%20chunk%20%7C%0D%0A%09chunk%20%3A%3D%20aStream%20nextChunk.%0D%0A%09%5E%5B%20chunk%20isEmpty%20ifFalse%3A%20%5B%20self%20compileMethod%3A%20chunk%20%5D%0D%0A%09%5D%20logEvaluate%3A%20chunk"));
smalltalk.bind(smalltalk.ClassCategoryReader,"compileMethod:",0
,function (aString){var self=this;var method=nil;method=self['@class'].compiler().load_forClass_(aString, self['@class']);
method.category_(self['@category']);
self['@class'].addCompiledMethod_(method);return self;}
,"private",unescape("compileMethod%3A%20aString%0D%0A%09%22%20Compile%20aString%20as%20a%20method%20source.%20%22%0D%0A%0D%0A%09%7C%20method%20%7C%0D%0A%09method%20%3A%3D%20class%20compiler%20load%3A%20aString%20forClass%3A%20class.%0D%0A%09method%20category%3A%20category.%0D%0A%09class%20addCompiledMethod%3A%20method"));
smalltalk.bind(smalltalk.ClassCommentReader,"class:",0
,function (aClass){var self=this;self['@class']=aClass;return self;}
,"accessing",unescape("class%3A%20aClass%0D%0A%09%22%20Set%20the%20destination%20class%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09class%20%3A%3D%20aClass"));
smalltalk.bind(smalltalk.ClassCommentReader,"scanFrom:",0
,function (aStream){var self=this;self.comment_(aStream.nextChunk());
return nil;;return self;}
,"fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20FileIn%20-%20Parse%20next%20chunk%20in%20aStream%20as%20a%20comment%20for%20target%20class.%20%22%0D%0A%0D%0A%09self%20comment%3A%20aStream%20nextChunk.%0D%0A%09%5Enil"));
smalltalk.bind(smalltalk.ClassCommentReader,"comment:",0
,function (aString){var self=this;self['@class'].comment_(((aString.isEmpty()).mustBeBoolean()==true ? nil : (function(){return aString;})()));return self;}
,"private",unescape("comment%3A%20aString%0D%0A%09%22%20Set%20the%20comment%20of%20target%20class.%20%22%0D%0A%0D%0A%09class%20comment%3A%20%28aString%20isEmpty%20ifFalse%3A%20%5B%20aString%20%5D%29"));
smalltalk.bind(smalltalk.SkipFileInReader.$klass,"upTo:",0
,function (aToken){var self=this;return self.$$new().limit_(aToken);;return self;}
,"instantiation",unescape("upTo%3A%20aToken%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20new%20limit%3A%20aToken"));
smalltalk.bind(smalltalk.SkipFileInReader,"scanFrom:",0
,function (aStream){var self=this;(((nil.isNil_(self['@limit']))).mustBeBoolean()==true ? (function(){return aStream.setToEnd();})() : (function(){return aStream.skipTo_(self['@limit']);})());
return nil;;return self;}
,"fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20Consume/Ignore%20contents%20in%20aStream.%20%22%0D%0A%0D%0A%09limit%20isNil%0D%0A%09%09ifTrue%3A%20%5B%20aStream%20setToEnd%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20aStream%20skipTo%3A%20limit%20%5D.%0D%0A%09%5Enil"));
smalltalk.bind(smalltalk.SkipFileInReader,"limit:",0
,function (aToken){var self=this;self['@limit']=aToken;return self;}
,"accessing",unescape("limit%3A%20aToken%0D%0A%09%22%20Set%20the%20token%20limit.%20%22%0D%0A%0D%0A%09limit%20%3A%3D%20aToken"));
smalltalk.bind(smalltalk.AssociationsReader,"keyFrom:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;((aStream.peek()._eq(unescape("%23"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function($rec){$rec.next();return $rec.upTo_(" ");})(aStream).asSymbol();})();throw($s8Ret$)})();})() : nil);
((aStream.peek()._eq(unescape("%27"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function($rec){$rec.next();return $rec.upTo_(unescape("%27"));})(aStream);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return aStream.upTo_(" ");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("keyFrom%3A%20aStream%0D%0A%09%22%20Private%20-%20Return%20the%20name%20of%20the%20current%20binding%20in%20aStream.%20%22%0D%0A%0D%0A%09aStream%20peek%20%3D%20%24%23%20ifTrue%3A%20%5B%20%5E%28aStream%20next%3B%20upTo%3A%20%24%20%29%20asSymbol%20%5D.%0D%0A%09aStream%20peek%20%3D%20%24%27%20ifTrue%3A%20%5B%20%5EaStream%20next%3B%20upTo%3A%20%24%27%20%5D.%0D%0A%09%5EaStream%20upTo%3A%20%24%20"));
smalltalk.bind(smalltalk.AssociationsReader,"valueFrom:",0
,function (aStream){var self=this;return self.compilerSupport().evaluate_(aStream.upToEnd());;return self;}
,"reading",unescape("valueFrom%3A%20aStream%0D%0A%09%22%20Private%20-%20Return%20the%20value%20of%20the%20current%20binding%20in%20aStream.%20%22%0D%0A%0D%0A%09%5Eself%20compilerSupport%20evaluate%3A%20aStream%20upToEnd%20"));
smalltalk.bind(smalltalk.AssociationsReader,"compilerSupport",0
,function (){var self=this;return self.smalltalk().compilerSupport();;return self;}
,"evaluating",unescape("compilerSupport%0D%0A%09%22%20Private%20-%20Return%20compiler%20in%20use%20to%20get%20values%20from%20stream.%20%22%0D%0A%0D%0A%09%5Eself%20smalltalk%20compilerSupport"));
smalltalk.bind(smalltalk.AssociationsReader,"bind:",0
,function (tuples){var self=this;return self.subclassResponsibility_("bind:");;return self;}
,"binding",unescape("bind%3A%20tuples%0D%0A%09%22%20Private%20-%20Bind%20the%20filedIn%20tuples%20to%20target.%0D%0A%09Must%20return%20the%20result%20of%20the%20fileIn/binding%20process.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23bind%3A%20"));
smalltalk.bind(smalltalk.AssociationsReader,"scanFrom:",0
,function (aStream){var self=this;var chunk=nil;var tuples=nil;tuples=smalltalk.Array.$$new();
(function(){while((function(){return aStream.atEnd().not().and_((function(){chunk=aStream.nextChunk().trimBlanks();return chunk.notEmpty();}));})()){(function(){chunk=chunk.stream();return tuples.add_(smalltalk.Array.with_with_(self.keyFrom_(chunk), self.valueFrom_(chunk)));})()};return nil})();
return self.bind_(tuples);;return self;}
,"fileIn",unescape("scanFrom%3A%20aStream%0D%0A%09%22%20Consume%20chunks%20in%20aStream%20until%20empty%20chunk.%0D%0A%09The%20chunks%20are%20considered%20associative%20bindings%20with%20the%20syntax%3A%0D%0A%09%09%3Ckey%3E%20%3Cexpression%3E%0D%0A%09Where%0D%0A%09%09key%20is%20the%20keyword%20of%20the%20binding%20%28name%2C%20string%20or%20symbol%29.%0D%0A%09%09expression%20is%20a%20valid%20smalltalk%20expression%20that%20will%20be%20evaluated%20to%20generate%20the%20value%20of%20the%20binding.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20chunk%20tuples%20%7C%0D%0A%09tuples%20%3A%3D%20Array%20new.%0D%0A%09%5B%20aStream%20atEnd%20not%20and%3A%20%5B%0D%0A%09%20%20chunk%20%3A%3D%20aStream%20nextChunk%20trimBlanks.%0D%0A%09%20%20chunk%20notEmpty%20%5D%5D%20whileTrue%3A%20%5B%0D%0A%09%20%20chunk%20%3A%3D%20chunk%20stream.%0D%0A%09%20%20tuples%20add%3A%20%28Array%0D%0A%09%09with%3A%20%28self%20keyFrom%3A%20chunk%29%0D%0A%09%09with%3A%20%28self%20valueFrom%3A%20chunk%29%29.%0D%0A%09%5D.%0D%0A%09%5Eself%20bind%3A%20tuples"));
smalltalk.bind(smalltalk.PoolDictionaryReader,"scope:",0
,function (aScope){var self=this;self['@scope']=aScope;return self;}
,"accessing",unescape("scope%3A%20aScope%0D%0A%09%22%20Set%20the%20scope%20where%20the%20read%20bindings%20will%20be%20stored.%20%22%0D%0A%0D%0A%09scope%20%3A%3D%20aScope"));
smalltalk.bind(smalltalk.PoolDictionaryReader,"bind:",0
,function (tuples){var $s8Ret$={name:"stReturn"};try{var self=this;((self['@scope'].isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Smalltalk.definePool_with_(self['@scope'], tuples);})();throw($s8Ret$)})();})() : nil);
(((nil.isNil_(self['@scope']))).mustBeBoolean()==true ? (function(){return self['@scope']=smalltalk.PoolDictionary.$$new();})() : nil);
tuples.do_((function(each){return self['@scope'].at_put_(each.first(), each.last());}));
(function(){$s8Ret$.result=(function(){return self['@scope'];})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"binding",unescape("bind%3A%20tuples%0D%0A%09%22%20Private%20-%20Bind%20the%20filedIn%20tuples%20to%20target.%0D%0A%09Must%20return%20the%20result%20of%20the%20fileIn/binding%20process.%0D%0A%09%22%0D%0A%0D%0A%09scope%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5ESmalltalk%20definePool%3A%20scope%20with%3A%20tuples%0D%0A%09%5D.%0D%0A%09scope%20isNil%20ifTrue%3A%20%5B%20scope%20%3A%3D%20PoolDictionary%20new%20%5D.%0D%0A%09tuples%20do%3A%20%5B%3Aeach%7C%20scope%20at%3A%20each%20first%20put%3A%20each%20last%20%5D.%0D%0A%09%5Escope"));
smalltalk.bind(smalltalk.PoolDictionaryReader,"valueFrom:",0
,function (aStream){var $s8Ret$={name:"stReturn"};try{var self=this;var code=nil;var result=nil;var word=nil;code=aStream.upToEnd();
word=code.trimBlanks();
((word._eq("nil").or_((function(){return word.isEmpty();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
result=word.asNumber();
((result.isNumber()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.PoolDictionaryReader,'valueFrom_').apply(self, [code.stream()]);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"reading",unescape("valueFrom%3A%20aStream%0D%0A%09%22%20Private%20-%20Return%20the%20value%20of%20the%20current%20binding%20in%20aStream.%20%22%0D%0A%0D%0A%09%7C%20code%20result%20word%20%7C%0D%0A%09code%20%3A%3D%20aStream%20upToEnd.%0D%0A%09word%20%3A%3D%20code%20trimBlanks.%0D%0A%09%28word%20%3D%20%23nil%20or%3A%20%5B%20word%20isEmpty%20%5D%29%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09result%20%3A%3D%20word%20asNumber.%0D%0A%09result%20isNumber%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%5Esuper%20valueFrom%3A%20code%20stream%20"));
smalltalk.bind(smalltalk.JSReader,"bind:",0
,function (tuples){var self=this;(((nil.isNil_(self['@object']))).mustBeBoolean()==true ? (function(){return self.initializeObject();})() : nil);
tuples.do_((function(each){return (self['@object'][each.first()]=(each.last()));}));
return self['@object'];;return self;}
,"binding",unescape("bind%3A%20tuples%0D%0A%09%22%20Private%20-%20Bind%20the%20filedIn%20tuples%20to%20target.%0D%0A%09Must%20return%20the%20result%20of%20the%20fileIn/binding%20process.%0D%0A%09%22%0D%0A%0D%0A%09object%20isNil%20ifTrue%3A%20%5B%20self%20initializeObject%20%5D.%0D%0A%09tuples%20do%3A%20%5B%3Aeach%7C%20object%20basicAt%3A%20each%20first%20put%3A%20each%20last%20%5D.%0D%0A%09%5Eobject"));
smalltalk.bind(smalltalk.JSReader,"object:",0
,function (anObject){var self=this;self['@object']=anObject;return self;}
,"accessing",unescape("object%3A%20anObject%0D%0A%09%22%20Set%20the%20object%20where%20the%20bindings%20will%20be%20stored.%20%22%0D%0A%0D%0A%09object%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.JSReader,"initializeObject",0
,function (){var self=this;self['@object']={};return self;}
,"initialize",unescape("initializeObject%0D%0A%09%22%20Private%20-%20Initialize%20the%20object%20where%20the%20bindings%20will%20be%20stored.%20%22%0D%0A%0D%0A%09object%20%3A%3D%20%7B%27%7B%7D%27%7D"));
smalltalk.bind(smalltalk.Exporter.$klass,"fileOutCategories:",0
,function (categories){var self=this;return self.$$new().fileOutCategories_(categories);;return self;}
,"fileOut",unescape("fileOutCategories%3A%20categories%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20all%20the%20classes%20in%20categories.%20%22%0D%0A%0D%0A%09%5Eself%20new%20fileOutCategories%3A%20categories"));
smalltalk.bind(smalltalk.Exporter.$klass,"fileOutCategory:",0
,function (aString){var self=this;return self.$$new().fileOutCategory_(aString);;return self;}
,"fileOut",unescape("fileOutCategory%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20all%20the%20classes%20in%20category%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20new%20fileOutCategory%3A%20aString"));
smalltalk.bind(smalltalk.Exporter.$klass,"fileOutAll:",0
,function (elements){var self=this;return self.$$new().fileOutAll_(elements);;return self;}
,"fileOut",unescape("fileOutAll%3A%20elements%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20elements%20%28classes%2C%20methods%20and/or%20categories%29.%20%22%0D%0A%0D%0A%09%5Eself%20new%20fileOutAll%3A%20elements"));
smalltalk.bind(smalltalk.Exporter.$klass,"fileOutAll",0
,function (){var self=this;return self.fileOutAll_(self.allClasses());;return self;}
,"fileOut",unescape("fileOutAll%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20of%20all%20classes%20in%20the%20system.%20%22%0D%0A%0D%0A%09%5Eself%20fileOutAll%3A%20self%20allClasses"));
smalltalk.bind(smalltalk.Exporter.$klass,"fileOut:",0
,function (spec){var $s8Ret$={name:"stReturn"};try{var self=this;var aName=nil;(((nil.isNil_(spec))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "";})();throw($s8Ret$)})();})() : nil);
((spec.isString()).mustBeBoolean()==true ? nil : (function(){((smalltalk.is_kindOf_(spec,(smalltalk.Behavior))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.$$new().fileOut_(spec);})();throw($s8Ret$)})();})() : nil);return (function(){$s8Ret$.result=(function(){return spec.asArray().fileOut();})();throw($s8Ret$)})();})());
((spec.includes_(unescape("%2C"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.fileOut_(spec.asArrayOfSubstringsSeparatedBy_(unescape("%2C")));})();throw($s8Ret$)})();})() : nil);
((spec.includes_(" ")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.fileOut_(spec.asArrayOfSubstringsSeparatedBy_(" "));})();throw($s8Ret$)})();})() : nil);
aName=spec.trimBlanks();
((smalltalk.Smalltalk.includesKey_(aName)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.fileOut_(smalltalk.Smalltalk.at_(aName));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.fileOutCategories_(aName);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOut%3A%20spec%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20of%20literals%20in%20spec.%20%22%0D%0A%0D%0A%09%7C%20aName%20%7C%0D%0A%09spec%20isNil%20ifTrue%3A%20%5B%20%5E%27%27%20%5D.%0D%0A%09spec%20isString%20ifFalse%3A%20%5B%0D%0A%09%09%28spec%20isKindOf%3A%20Behavior%29%20ifTrue%3A%20%5B%20%5Eself%20new%20fileOut%3A%20spec%20%5D.%0D%0A%09%09%5Espec%20asArray%20fileOut%0D%0A%09%5D.%0D%0A%09%28spec%20includes%3A%20%24%2C%29%20ifTrue%3A%20%5B%20%5Eself%20fileOut%3A%20%28spec%20asArrayOfSubstringsSeparatedBy%3A%20%24%2C%29%20%5D.%0D%0A%09%28spec%20includes%3A%20%24%20%29%20ifTrue%3A%20%5B%20%5Eself%20fileOut%3A%20%28spec%20asArrayOfSubstringsSeparatedBy%3A%20%24%20%29%20%5D.%0D%0A%09aName%20%3A%3D%20spec%20trimBlanks.%0D%0A%09%28Smalltalk%20includesKey%3A%20aName%29%20ifTrue%3A%20%5B%20%5Eself%20fileOut%3A%20%28Smalltalk%20at%3A%20aName%29%5D.%0D%0A%09%5Eself%20fileOutCategories%3A%20aName"));
smalltalk.bind(smalltalk.Exporter.$klass,"exportCategories:",0
,function (categories){var self=this;return self.$$new().exportCategories_(categories);;return self;}
,"export",unescape("exportCategories%3A%20categories%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20the%20classes%20in%20categories.%20%22%0D%0A%0D%0A%09%5Eself%20new%20exportCategories%3A%20categories"));
smalltalk.bind(smalltalk.Exporter.$klass,"exportCategory:",0
,function (aString){var self=this;return self.$$new().exportCategory_(aString);;return self;}
,"export",unescape("exportCategory%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20the%20classes%20in%20category%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20new%20exportCategory%3A%20aString"));
smalltalk.bind(smalltalk.Exporter.$klass,"export:",0
,function (spec){var $s8Ret$={name:"stReturn"};try{var self=this;var aName=nil;(((nil.isNil_(spec))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "";})();throw($s8Ret$)})();})() : nil);
((spec.isString()).mustBeBoolean()==true ? nil : (function(){((smalltalk.is_kindOf_(spec,(smalltalk.Behavior))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.$$new().export_(spec);})();throw($s8Ret$)})();})() : nil);return (function(){$s8Ret$.result=(function(){return spec.asArray().$$export();})();throw($s8Ret$)})();})());
((spec.includes_(unescape("%2C"))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.export_(spec.asArrayOfSubstringsSeparatedBy_(unescape("%2C")));})();throw($s8Ret$)})();})() : nil);
((spec.includes_(" ")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.export_(spec.asArrayOfSubstringsSeparatedBy_(" "));})();throw($s8Ret$)})();})() : nil);
aName=spec.trimBlanks();
((smalltalk.Smalltalk.includesKey_(aName)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.export_(smalltalk.Smalltalk.at_(aName));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.exportCategories_(aName);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"export",unescape("export%3A%20spec%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20literals%20in%20spec.%20%22%0D%0A%0D%0A%09%7C%20aName%20%7C%0D%0A%09spec%20isNil%20ifTrue%3A%20%5B%20%5E%27%27%20%5D.%0D%0A%09spec%20isString%20ifFalse%3A%20%5B%0D%0A%09%09%28spec%20isKindOf%3A%20Behavior%29%20ifTrue%3A%20%5B%20%5Eself%20new%20export%3A%20spec%20%5D.%0D%0A%09%09%5Espec%20asArray%20export%0D%0A%09%5D.%0D%0A%09%28spec%20includes%3A%20%24%2C%29%20ifTrue%3A%20%5B%20%5Eself%20export%3A%20%28spec%20asArrayOfSubstringsSeparatedBy%3A%20%24%2C%29%20%5D.%0D%0A%09%28spec%20includes%3A%20%24%20%29%20ifTrue%3A%20%5B%20%5Eself%20export%3A%20%28spec%20asArrayOfSubstringsSeparatedBy%3A%20%24%20%29%20%5D.%0D%0A%09aName%20%3A%3D%20spec%20trimBlanks.%0D%0A%09%28Smalltalk%20includesKey%3A%20aName%29%20ifTrue%3A%20%5B%20%5Eself%20export%3A%20%28Smalltalk%20at%3A%20aName%29%5D.%0D%0A%09%5Eself%20exportCategories%3A%20aName"));
smalltalk.bind(smalltalk.Exporter.$klass,"exportAll",0
,function (){var self=this;return self.$$new().exportAll();;return self;}
,"export",unescape("exportAll%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20classes%20in%20the%20system.%20%22%0D%0A%0D%0A%09%5Eself%20new%20exportAll"));
smalltalk.bind(smalltalk.Exporter.$klass,"exportAll:",0
,function (elements){var self=this;return self.$$new().exportAll_(elements);;return self;}
,"export",unescape("exportAll%3A%20elements%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20elements%20%28classes%2C%20methods%20and/or%20categories%29.%20%22%0D%0A%0D%0A%09%5Eself%20new%20exportAll%3A%20elements"));
smalltalk.bind(smalltalk.Exporter.$klass,"allClasses",0
,function (){var self=this;return smalltalk.Smalltalk.rootClasses().inject_into_(smalltalk.Array.$$new(), (function(total,each){return total._comma(each.withAllSubclasses());}));;return self;}
,"private",unescape("allClasses%0D%0A%09%22%20Private%20-%20Return%20all%20the%20classes%20in%20the%20system%20%28in%20fileIn%20order%29.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20rootClasses%0D%0A%09%09inject%3A%20Array%20new%0D%0A%09%09into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2C%20each%20withAllSubclasses%20%5D"));
smalltalk.bind(smalltalk.Exporter,"matchCategory:",0
,function (aString){var self=this;return self.matchCategory_from_(aString, smalltalk.Smalltalk.rootClasses());;return self;}
,"categories",unescape("matchCategory%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20filtering%20all%20the%20classes%20%28and%20orphan%20methods%29%20in%20category%20aString.%20%22%0D%0A%0D%0A%09%5Eself%20matchCategory%3A%20aString%20from%3A%20Smalltalk%20rootClasses"));
smalltalk.bind(smalltalk.Exporter,"matchCategory:from:",0
,function (aString,rootClasses){var self=this;var selection=nil;var selected=nil;var rejected=nil;var orphanMethods=nil;var fileOutMethods=nil;selected=smalltalk.Array.$$new();
rejected=smalltalk.Array.$$new();
orphanMethods=smalltalk.Array.$$new();
selection=((aString.includes_(unescape("-"))).mustBeBoolean()==true ? (function(){return (function(each){return each.category().asString()._eq(aString);});})() : (function(){return (function(each){return each.category().asString().upTo_(unescape("-"))._eq(aString);});})());
rootClasses.do_((function(root){return root.instanceClass().withAllSubclasses().do_((function(each){return ((selection.value_(each)).mustBeBoolean()==true ? (function(){return selected;})() : (function(){return rejected;})()).add_(each);}));}));
fileOutMethods=(function(cls){return cls.methodsDo_((function(aMethod){return ((selection.value_(aMethod)).mustBeBoolean()==true ? (function(){return orphanMethods.add_(aMethod);})() : nil);}));});
rejected.do_((function(each){return (function($rec){$rec.value_(each);return $rec.value_(each.$klass);})(fileOutMethods);}));
return smalltalk.Array.with_with_with_(selected, rejected, orphanMethods);;return self;}
,"categories",unescape("matchCategory%3A%20aString%20from%3A%20rootClasses%0D%0A%09%22%20Return%20the%20result%20of%20filtering%20all%20the%20classes%20%28and%20orphan%20methods%29%20in%20category%20aString.%20%22%0D%0A%0D%0A%09%7C%20selection%20selected%20rejected%20orphanMethods%20fileOutMethods%20%7C%0D%0A%09selected%20%3A%3D%20Array%20new.%0D%0A%09rejected%20%3A%3D%20Array%20new.%0D%0A%09orphanMethods%20%3A%3D%20Array%20new.%0D%0A%09selection%20%3A%3D%20%28aString%20includes%3A%20%24-%29%0D%0A%09%09ifTrue%3A%20%5B%20%5B%3Aeach%7C%20each%20category%20asString%20%3D%20aString%20%5D%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20%5B%3Aeach%7C%20%28each%20category%20asString%20upTo%3A%20%24-%29%20%3D%20aString%20%5D%20%5D.%0D%0A%09rootClasses%20do%3A%20%5B%3Aroot%7C%0D%0A%09%09root%20instanceClass%20withAllSubclasses%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%09%28%28selection%20value%3A%20each%29%0D%0A%09%09%09%09ifTrue%3A%20%5B%20selected%20%5D%20ifFalse%3A%20%5B%20rejected%20%5D%29%0D%0A%09%09%09%09add%3A%20each%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09fileOutMethods%20%3A%3D%20%5B%3Acls%7C%0D%0A%09%09cls%20methodsDo%3A%20%5B%3AaMethod%20%7C%0D%0A%09%09%09%28selection%20value%3A%20aMethod%29%20ifTrue%3A%20%5B%20orphanMethods%20add%3A%20aMethod%20%5D%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09rejected%20do%3A%20%5B%3Aeach%7C%20fileOutMethods%20value%3A%20each%3B%20value%3A%20each%20class%20%5D.%0D%0A%09%5EArray%20with%3A%20selected%20with%3A%20rejected%20with%3A%20orphanMethods"));
smalltalk.bind(smalltalk.Exporter,"fileOutCategories:",0
,function (categories){var $s8Ret$={name:"stReturn"};try{var self=this;((categories.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.fileOutCategories_(categories.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return categories.asArray().inject_into_("", (function(total,each){return total._comma(self.fileOutCategory_(each));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOutCategories%3A%20categories%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20all%20the%20classes%20in%20categories.%20%22%0D%0A%0D%0A%09categories%20isString%20ifTrue%3A%20%5B%20%5Eself%20fileOutCategories%3A%20categories%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Ecategories%20asArray%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09total%2C%20%28self%20fileOutCategory%3A%20each%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Exporter,"fileOutCategory:",0
,function (aString){var self=this;var stream=nil;var match=nil;stream="".writeStream();
match=self.matchCategory_(aString);
self.fileOutAll_on_(match.first(), stream);
match.last().do_((function(aMethod){return self.fileOutMethod_of_on_(aMethod, aMethod.classField(), stream);}));
return stream.contents();;return self;}
,"fileOut",unescape("fileOutCategory%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20fileOut%20all%20the%20classes%20in%20category%20aString.%20%22%0D%0A%0D%0A%09%7C%20stream%20match%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09match%20%3A%3D%20self%20matchCategory%3A%20aString.%0D%0A%09self%20fileOutAll%3A%20match%20first%20on%3A%20stream.%0D%0A%09match%20last%20do%3A%20%5B%3AaMethod%20%7C%0D%0A%09%09self%20fileOutMethod%3A%20aMethod%20of%3A%20aMethod%20classField%20on%3A%20stream%0D%0A%09%5D.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"fileOut:",0
,function (aClass){var self=this;var stream=nil;stream="".writeStream();
self.fileOut_on_(aClass, stream);
return stream.contents();;return self;}
,"fileOut",unescape("fileOut%3A%20aClass%0D%0A%09%22%20Return%20fileOut%20definition%20and%20code%20of%20a%20class.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20fileOut%3A%20aClass%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"fileOutClass:",0
,function (aClass){var self=this;return self.fileOut_(aClass);;return self;}
,"fileOut",unescape("fileOutClass%3A%20aClass%0D%0A%09%22%20Return%20fileOut%20definition%20and%20code%20of%20a%20class.%20%22%0D%0A%0D%0A%09%5Eself%20fileOut%3A%20aClass"));
smalltalk.bind(smalltalk.Exporter,"fileOutAll:",0
,function (elements){var self=this;var stream=nil;stream="".writeStream();
self.fileOutAll_on_(elements, stream);
return stream.contents();;return self;}
,"fileOut",unescape("fileOutAll%3A%20elements%0D%0A%09%22%20Return%20fileOut%20definition%20and%20code%20of%20elements%20%28classes%2C%20methods%20and/or%20categories%29.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20fileOutAll%3A%20elements%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"fileOutMethod:of:",0
,function (aMethod,aClass){var self=this;var stream=nil;stream="".writeStream();
self.fileOutMethod_of_on_(aMethod, aClass, stream);
return stream.contents();;return self;}
,"fileOut",unescape("fileOutMethod%3A%20aMethod%20of%3A%20aClass%0D%0A%09%22%20Return%20fileOut%20method%20of%20a%20class.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20fileOutMethod%3A%20aMethod%20of%3A%20aClass%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"fileOutAllMethodsOf:on:",0
,function (aClass,stream){var self=this;self.fileOutMethodsOf_on_(aClass.$klass, stream);
self.fileOutMethodsOf_on_(aClass, stream);return self;}
,"fileOut",unescape("fileOutAllMethodsOf%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20all%20methods%20of%20aClass%20%28and%20metaclass%29%20onto%20stream.%20%22%0D%0A%0D%0A%09self%20fileOutMethodsOf%3A%20aClass%20class%20on%3A%20stream.%0D%0A%09self%20fileOutMethodsOf%3A%20aClass%20on%3A%20stream."));
smalltalk.bind(smalltalk.Exporter,"fileOutDefinitionOfClass:on:",0
,function (aClass,stream){var self=this;self.fileOutDefinitionOf_on_(aClass, stream);
self.fileOutDefinitionOf_on_(aClass.$klass, stream);return self;}
,"fileOut",unescape("fileOutDefinitionOfClass%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20definition%20of%20aClass%20%28and%20metaclass%29%20onto%20stream.%20%22%0D%0A%0D%0A%09self%20fileOutDefinitionOf%3A%20aClass%20on%3A%20stream.%0D%0A%09self%20fileOutDefinitionOf%3A%20aClass%20class%20on%3A%20stream"));
smalltalk.bind(smalltalk.Exporter,"fileOutAll:on:",0
,function (elements,stream){var $s8Ret$={name:"stReturn"};try{var self=this;((elements.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.fileOutAll_on_(elements.asArrayOfSubstrings(), stream);})();throw($s8Ret$)})();})() : nil);
elements.do_((function(each){return ((smalltalk.is_kindOf_(each,(smalltalk.Behavior))).mustBeBoolean()==true ? (function(){return self.fileOutDefinitionOfClass_on_(each, stream);})() : nil);}));
stream.cr();
elements.do_((function(each){return ((smalltalk.is_kindOf_(each,(smalltalk.Behavior))).mustBeBoolean()==true ? (function(){return self.fileOutAllMethodsOf_on_(each, stream);})() : (function(){return ((each.isString()).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextPutAll_(self.fileOutCategory_(each));return $rec.cr();})(stream);})() : (function(){return self.fileOutAllMethod_on_(each, stream);})());})());}));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOutAll%3A%20elements%20on%3A%20stream%0D%0A%09%22%20FileOut%20definition%20and%20code%20of%20elements%20%28classes%2C%20methods%20and/or%20categories%29%20onto%20stream.%20%22%0D%0A%0D%0A%09elements%20isString%20ifTrue%3A%20%5B%20%5Eself%20fileOutAll%3A%20elements%20asArrayOfSubstrings%20on%3A%20stream%20%5D.%0D%0A%09elements%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28each%20isKindOf%3A%20Behavior%29%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20fileOutDefinitionOfClass%3A%20each%20on%3A%20stream%0D%0A%09%09%5D.%0D%0A%09%5D.%09stream%20cr.%0D%0A%09elements%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28each%20isKindOf%3A%20Behavior%29%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20fileOutAllMethodsOf%3A%20each%20on%3A%20stream%0D%0A%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09each%20isString%0D%0A%09%09%09ifTrue%3A%20%5B%20stream%20nextPutAll%3A%20%28self%20fileOutCategory%3A%20each%29%3Bcr%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20self%20fileOutAllMethod%3A%20each%20on%3A%20stream%20%5D%0D%0A%09%09%5D%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Exporter,"fileOutDefinitionOf:",0
,function (aClass){var self=this;var stream=nil;stream="".writeStream();
self.fileOutDefinitionOfClass_on_(aClass.instanceClass(), stream);
return stream.contents();;return self;}
,"fileOut",unescape("fileOutDefinitionOf%3A%20aClass%0D%0A%09%22%20Return%20the%20definition%20of%20a%20class.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20fileOutDefinitionOfClass%3A%20aClass%20instanceClass%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"fileOut:on:",0
,function (aClass,stream){var self=this;self.fileOutAll_on_(smalltalk.Array.with_(aClass), stream);return self;}
,"fileOut",unescape("fileOut%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20definition%20and%20code%20of%20a%20class%20onto%20stream.%20%22%0D%0A%0D%0A%09self%20fileOutAll%3A%20%28Array%20with%3A%20aClass%29%20on%3A%20stream."));
smalltalk.bind(smalltalk.Exporter,"fileOutDefinitionOf:on:",0
,function (aClass,stream){var $s8Ret$={name:"stReturn"};try{var self=this;((aClass.isMetaclass()).mustBeBoolean()==true ? (function(){((self.fileOutStrings_of_on_("instanceVariableNames", aClass, stream)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextChunkPut_("");return $rec.cr();})(stream);})() : nil);((self.fileOutArray_of_on_("propertyNames", aClass, stream)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextChunkPut_("");return $rec.cr();})(stream);})() : nil);return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
(function($rec){$rec.nextPutAll_(aClass.superclass().asString());$rec.cr();$rec.tab();return $rec.nextPutAll_(unescape("subclass%3A%20%23"));})(stream);
((self.fileOutStrings_of_on_("instanceVariableNames", aClass, stream)).mustBeBoolean()==true ? nil : (function(){return (function($rec){$rec.nextPutAll_(self.globalNameFor_(aClass));$rec.cr();$rec.tab();$rec.nextPutAll_("instanceVariableNames: ");return $rec.nextPutAll_("".printString());})(stream);})());
(((nil.isNil_(aClass.classVariables())===false)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.cr();$rec.tab();$rec.nextPutAll_("classVariableNames: ");return $rec.nextPutAll_(aClass.classVariablesString().printString());})(stream);})() : nil);
(((nil.isNil_(aClass.poolDictionaries())===false)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.cr();$rec.tab();$rec.nextPutAll_("poolDictionaries: ");return $rec.nextPutAll_(aClass.poolDictionariesString().printString());})(stream);})() : nil);
(function($rec){$rec.cr();$rec.tab();$rec.nextPutAll_("category: ");return $rec.nextPutAll_(aClass.category().asLiteral());})(stream);
(function($rec){$rec.nextChunkPut_("");return $rec.cr();})(stream);
((self.fileOutArray_of_on_("propertyNames", aClass, stream)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextChunkPut_("");return $rec.cr();})(stream);})() : nil);
(((nil.isNil_(aClass.comment())===false).and_((function(){return aClass.comment().notEmpty();}))).mustBeBoolean()==true ? (function(){stream.nextPutAll_(self.globalNameFor_(aClass)._comma(" comment: ")._comma(aClass.comment().printString()));return (function($rec){$rec.nextChunkPut_("");return $rec.cr();})(stream);})() : nil);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOutDefinitionOf%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20definition%20of%20a%20class%20onto%20stream.%20%22%0D%0A%0D%0A%09aClass%20isMetaclass%20ifTrue%3A%20%5B%0D%0A%09%09%28self%20fileOutStrings%3A%20%23instanceVariableNames%20of%3A%20aClass%20on%3A%20stream%29%20ifTrue%3A%20%5B%0D%0A%09%09%09stream%20nextChunkPut%3A%20%27%27%3Bcr.%0D%0A%09%09%5D.%0D%0A%09%09%28self%20fileOutArray%3A%20%23propertyNames%20of%3A%20aClass%20on%3A%20stream%29%20ifTrue%3A%20%5B%0D%0A%09%09%09stream%20nextChunkPut%3A%20%27%27%3Bcr.%0D%0A%09%09%5D.%0D%0A%09%09%5Eself%0D%0A%09%5D.%0D%0A%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20aClass%20superclass%20asString%3B%20cr%3Btab%3B%0D%0A%09%09nextPutAll%3A%20%27subclass%3A%20%23%27.%0D%0A%09%28self%20fileOutStrings%3A%20%23instanceVariableNames%20of%3A%20aClass%20on%3A%20stream%29%20ifFalse%3A%20%5B%0D%0A%09%09stream%0D%0A%09%09%09nextPutAll%3A%20%28self%20globalNameFor%3A%20aClass%29%3B%20cr%3Btab%3B%0D%0A%09%09%09nextPutAll%3A%20%27instanceVariableNames%3A%20%27%3B%0D%0A%09%09%09nextPutAll%3A%20%27%27%20printString%0D%0A%09%5D.%0D%0A%09aClass%20classVariables%20notNil%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20stream%09%20cr%3Btab%3B%0D%0A%09%09nextPutAll%3A%20%27classVariableNames%3A%20%27%3B%0D%0A%09%09nextPutAll%3A%20aClass%20classVariablesString%20printString%0D%0A%09%5D.%0D%0A%09aClass%20poolDictionaries%20notNil%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20stream%09%20cr%3Btab%3B%0D%0A%09%09nextPutAll%3A%20%27poolDictionaries%3A%20%27%3B%0D%0A%09%09nextPutAll%3A%20aClass%20poolDictionariesString%20printString%0D%0A%09%5D.%0D%0A%09stream%20cr%3Btab%3B%0D%0A%09%09nextPutAll%3A%20%27category%3A%20%27%3B%0D%0A%09%09nextPutAll%3A%20aClass%20category%20asLiteral.%0D%0A%09stream%20nextChunkPut%3A%20%27%27%3Bcr.%0D%0A%09%28self%20fileOutArray%3A%20%23propertyNames%20of%3A%20aClass%20on%3A%20stream%29%20ifTrue%3A%20%5B%0D%0A%09%09stream%20nextChunkPut%3A%20%27%27%3Bcr.%0D%0A%09%5D.%0D%0A%09%28aClass%20comment%20notNil%20and%3A%20%5BaClass%20comment%20notEmpty%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09stream%20nextPutAll%3A%20%28self%20globalNameFor%3A%20aClass%29%2C%27%20comment%3A%20%27%2C%20aClass%20comment%20printString.%0D%0A%09%09stream%20nextChunkPut%3A%20%27%27%3Bcr.%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Exporter,"fileOutStrings:of:on:",0
,function (selector,aClass,stream){var $s8Ret$={name:"stReturn"};try{var self=this;var strings=nil;strings=aClass.perform_(selector);
((strings.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
(function($rec){$rec.nextPutAll_(self.globalNameFor_(aClass));$rec.cr();$rec.tab();return $rec.nextPutAll_(selector._comma(unescape("%3A%20%27")));})(stream);
strings.do_((function(each){return stream.nextPutAll_(" "._comma(each));}));
stream.nextPutAll_(unescape("%20%27"));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOutStrings%3A%20selector%20of%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20Private%20-%20FileOut%20selector%20strings%20of%20a%20class%20onto%20stream.%0D%0A%09Return%20true%20if%20code%20has%20been%20filedOut.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20strings%20%7C%0D%0A%09strings%20%3A%3D%20aClass%20perform%3A%20selector.%0D%0A%09strings%20isEmpty%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20%28self%20globalNameFor%3A%20aClass%29%3B%20cr%3Btab%3B%0D%0A%09%09nextPutAll%3A%20selector%2C%27%3A%20%27%27%27.%0D%0A%09strings%20do%3A%20%5B%3Aeach%7C%20stream%20nextPutAll%3A%20%27%20%27%2Ceach%20%5D.%0D%0A%09stream%20nextPutAll%3A%20%27%20%27%27%27.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Exporter,"fileOutArray:of:on:",0
,function (selector,aClass,stream){var $s8Ret$={name:"stReturn"};try{var self=this;var strings=nil;strings=aClass.perform_(selector);
((strings.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
(function($rec){$rec.nextPutAll_(self.globalNameFor_(aClass));return $rec.nextPutAll_(" "._comma(selector)._comma(": ")._comma(strings.asLiteral()));})(stream);
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOutArray%3A%20selector%20of%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20Private%20-%20FileOut%20selector%20arrayed%20strings%20of%20a%20class%20onto%20stream.%0D%0A%09Return%20true%20if%20code%20has%20been%20filedOut.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20strings%20%7C%0D%0A%09strings%20%3A%3D%20aClass%20perform%3A%20selector.%0D%0A%09strings%20isEmpty%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09stream%0D%0A%09%09nextPutAll%3A%20%28self%20globalNameFor%3A%20aClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27%20%27%2Cselector%2C%27%3A%20%27%2C%20strings%20asLiteral.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.Exporter,"fileOutMethodsOf:on:",0
,function (aClass,stream){var $s8Ret$={name:"stReturn"};try{var self=this;var selectors=nil;selectors=aClass.selectors();
((selectors.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
stream.cr();
self.fileOutSelectors_of_on_(selectors, aClass, stream);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"fileOut",unescape("fileOutMethodsOf%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20methods%20of%20a%20class%20onto%20stream.%20%22%0D%0A%0D%0A%09%7C%20selectors%20%7C%0D%0A%09selectors%20%3A%3D%20aClass%20selectors.%0D%0A%09selectors%20isEmpty%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09stream%20cr.%0D%0A%09self%0D%0A%09%09fileOutSelectors%3A%20selectors%0D%0A%09%09of%3A%20aClass%20on%3A%20stream"));
smalltalk.bind(smalltalk.Exporter,"fileOutClusters",0
,function (){var self=this;return ["APIBuilder"].select_((function(key){return smalltalk.Smalltalk.includesKey_(key);})).collect_((function(each){return smalltalk.Smalltalk.at_(each).$$default();}));;return self;}
,"private",unescape("fileOutClusters%0D%0A%09%22%20Private%20-%20Return%20the%20fileOut%20chustering%20dumpers%20of%20the%20receiver.%0D%0A%09A%20fileOutCluster%20is%20an%20object%20that%20potentially%20dump%20clustered%20actions%20for%20selectors%20implemented%20by%20aClass.%0D%0A%09The%20fileOut%20write%20%28smalltalk%29code%20for%20multiple%20selectors%20removing%20them%20from%20selectors%20collection.%0D%0A%09Note%3A%20the%20selectors%20collection%20is%20modified%20during%20fileOut.%0D%0A%09The%20default%20answer%20is%20an%20empty%20collection%20of%20custed%20or%20a%20collection%20with%20default%20APIBuilder.%0D%0A%09This%20method%20can%20be%20refined%20by%20the%20subclasses.%0D%0A%09%22%0D%0A%0D%0A%09%5E%28%23%28%20%23APIBuilder%20%29%0D%0A%09%09select%3A%20%5B%3Akey%7C%20Smalltalk%20includesKey%3A%20key%20%5D%29%0D%0A%09%09collect%3A%20%5B%3Aeach%7C%20%28Smalltalk%20at%3A%20each%29%20default%20%5D"));
smalltalk.bind(smalltalk.Exporter,"fileOutSelectors:of:on:",0
,function (selectors,aClass,stream){var self=this;self.fileOutClusters().do_((function(each){return each.fileOut_selectors_of_on_(self, selectors, aClass, stream);}));
selectors.sorted().do_((function(each){return self.fileOutMethod_of_on_(aClass.compiledMethodAt_(each), aClass, stream);}));return self;}
,"fileOut",unescape("fileOutSelectors%3A%20selectors%20of%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20methods%20implementing%20selectors%20of%20a%20class%20onto%20stream.%20%22%0D%0A%0D%0A%09self%20fileOutClusters%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%0D%0A%09%09%09fileOut%3A%20self%20selectors%3A%20selectors%0D%0A%09%09%09of%3A%20aClass%20on%3A%20stream%0D%0A%09%5D.%0D%0A%09selectors%20sorted%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09self%0D%0A%09%09%09fileOutMethod%3A%20%28aClass%20compiledMethodAt%3A%20each%29%0D%0A%09%09%09of%3A%20aClass%20on%3A%20stream%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Exporter,"isASymbol:",0
,function (aString){var self=this;return (nil.isNil_(smalltalk.RegularExpression.fromString_(unescape("%5B%5Ea-zA-Z0-9_%3A%5D")).exec_(aString)));;return self;}
,"private",unescape("isASymbol%3A%20aString%0D%0A%09%22%20Private%20-%20Return%20true%20if%20aString%20can%20be%20output%20with%20symbol%20notation.%20%22%0D%0A%0D%0A%09%5E%28%28RegularExpression%20fromString%3A%20%27%5B%5Ea-zA-Z0-9_%3A%5D%27%29%20exec%3A%20aString%29%20isNil"));
smalltalk.bind(smalltalk.Exporter,"fileOutMethod:",0
,function (aMethod){var self=this;var stream=nil;stream="".writeStream();
self.fileOutMethod_of_on_(aMethod, aMethod.classField(), stream);
return stream.contents();;return self;}
,"fileOut",unescape("fileOutMethod%3A%20aMethod%0D%0A%09%22%20Return%20the%20fileOut%20of%20aMethod.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20fileOutMethod%3A%20aMethod%20of%3A%20aMethod%20classField%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"fileOutMethod:on:",0
,function (aMethod,aStream){var self=this;return self.fileOutMethod_of_on_(aMethod, aMethod.classField(), aStream);;return self;}
,"fileOut",unescape("fileOutMethod%3A%20aMethod%20on%3A%20aStream%0D%0A%09%22%20Return%20the%20fileOut%20of%20aMethod.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09fileOutMethod%3A%20aMethod%0D%0A%09%09of%3A%20aMethod%20classField%0D%0A%09%09on%3A%20aStream"));
smalltalk.bind(smalltalk.Exporter,"fileOutMethod:of:on:",0
,function (aMethod,aClass,stream){var self=this;(function($rec){$rec.cr();$rec.nextChunkPut_("");$rec.nextChunkPut_(" "._comma(self.globalNameFor_(aClass))._comma(" methodsFor: ")._comma(aMethod.category().asLiteral())._comma(" "));$rec.cr();$rec.nextChunkPut_(aMethod.source());$rec.nextChunkPut_(" ");return $rec.cr();})(stream);return self;}
,"fileOut",unescape("fileOutMethod%3A%20aMethod%20of%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20FileOut%20method%20of%20a%20class%20onto%20stream.%20%22%0D%0A%0D%0A%09stream%0D%0A%09%09cr%3BnextChunkPut%3A%20%27%27%3B%0D%0A%09%09nextChunkPut%3A%20%27%20%27%2C%20%28self%20globalNameFor%3A%20aClass%29%2C%20%27%20methodsFor%3A%20%27%2C%20aMethod%20category%20asLiteral%20%2C%27%20%27%3B%20cr%3B%0D%0A%09%09nextChunkPut%3A%20aMethod%20source%3B%0D%0A%09%09nextChunkPut%3A%20%27%20%27%3Bcr"));
smalltalk.bind(smalltalk.Exporter,"exportCategory:",0
,function (aString){var self=this;var stream=nil;var match=nil;stream="".writeStream();
match=self.matchCategory_(aString);
match.first().do_((function(each){return stream.nextPutAll_(self.export_(each));}));
match.last().do_((function(aMethod){return self.export_method_on_(aMethod.classField(), aMethod, stream);}));
return stream.contents();;return self;}
,"export",unescape("exportCategory%3A%20aString%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20the%20classes%20in%20category%20aString.%20%22%0D%0A%0D%0A%09%7C%20stream%20match%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09match%20%3A%3D%20self%20matchCategory%3A%20aString.%0D%0A%09match%20first%20do%3A%20%5B%3Aeach%7C%20stream%20nextPutAll%3A%20%28self%20export%3A%20each%29%20%5D.%0D%0A%09match%20last%20do%3A%20%5B%3AaMethod%20%7C%0D%0A%09%09self%20export%3A%20aMethod%20classField%20method%3A%20aMethod%20on%3A%20stream%0D%0A%09%5D.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportCategories:",0
,function (categories){var $s8Ret$={name:"stReturn"};try{var self=this;((categories.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.exportCategories_(categories.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return categories.asArray().inject_into_("", (function(total,each){return total._comma(self.exportCategory_(each));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"export",unescape("exportCategories%3A%20categories%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20the%20classes%20in%20categories.%20%22%0D%0A%0D%0A%09categories%20isString%20ifTrue%3A%20%5B%20%5Eself%20exportCategories%3A%20categories%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Ecategories%20asArray%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09total%2C%20%28self%20exportCategory%3A%20each%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Exporter,"exportAllMethodsOf:on:",0
,function (aClass,stream){var self=this;self.exportMethodsOf_on_(aClass.$klass, stream);
self.exportMethodsOf_on_(aClass, stream);return self;}
,"export",unescape("exportAllMethodsOf%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20Export%20all%20methods%20of%20a%20class%20%28and%20metaclass%29%20onto%20stream.%20%22%0D%0A%0D%0A%09self%20exportMethodsOf%3A%20aClass%20class%20on%3A%20stream.%0D%0A%09self%20exportMethodsOf%3A%20aClass%20on%3A%20stream."));
smalltalk.bind(smalltalk.Exporter,"exportDefinitionOfClass:on:",0
,function (aClass,stream){var self=this;self.exportDefinitionOf_on_(aClass, stream);
self.exportMetaDefinitionOf_on_(aClass, stream);return self;}
,"export",unescape("exportDefinitionOfClass%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20Export%20definition%20of%20aClass%20%28and%20metaclass%29%20onto%20stream.%20%22%0D%0A%0D%0A%09self%20exportDefinitionOf%3A%20aClass%20on%3A%20stream.%0D%0A%09self%20exportMetaDefinitionOf%3A%20aClass%20on%3A%20stream."));
smalltalk.bind(smalltalk.Exporter,"export:",0
,function (aClass){var self=this;var stream=nil;stream="".writeStream();
self.exportDefinitionOfClass_on_(aClass, stream);
self.exportAllMethodsOf_on_(aClass, stream);
return stream.contents();;return self;}
,"export",unescape("export%3A%20aClass%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20definition%20and%20source%20code%20of%20a%20class.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20%27%27%20writeStream.%0D%0A%09self%20exportDefinitionOfClass%3A%20aClass%20on%3A%20stream.%0D%0A%09self%20exportAllMethodsOf%3A%20aClass%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportNew:",0
,function (aClass){var self=this;return self.exportDefinitionOf_(aClass);;return self;}
,"export",unescape("exportNew%3A%20aClass%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20definition%20of%20aClass.%20%22%0D%0A%0D%0A%09%5Eself%20exportDefinitionOf%3A%20aClass"));
smalltalk.bind(smalltalk.Exporter,"defaultRequirementsFor:",0
,function (aClass){var $s8Ret$={name:"stReturn"};try{var self=this;var constructorName=nil;var code=nil;constructorName=aClass.constructorName();
(((nil.isNil_(constructorName))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Array.with_(unescape("if%28")._comma(constructorName)._comma(unescape("%20%26%26%20%21"))._comma(self.smalltalkNameFor_(aClass))._comma(unescape("%29%20smalltalk.mapClassName%28%22"))._comma(self.globalNameFor_(aClass))._comma(unescape("%22%2C%22"))._comma(aClass.category())._comma(unescape("%22%2C"))._comma(constructorName)._comma(unescape("%2C"))._comma(self.smalltalkNameFor_(aClass.superclass()))._comma(unescape("%29%3B")));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"requirements",unescape("defaultRequirementsFor%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20the%20default%20requirements%20to%20load%20aClass.%0D%0A%09Detect%20native%20bindings%20and%20generate%20code%20to%20rebind%20before%20class%20definition.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20constructorName%20code%20%7C%0D%0A%09constructorName%20%3A%3D%20aClass%20constructorName.%0D%0A%09constructorName%20isNil%20ifTrue%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09%5EArray%20with%3A%0D%0A%09%09%27if%28%27%2CconstructorName%2C%27%20%26%26%20%21%27%0D%0A%09%09%2C%20%28self%20smalltalkNameFor%3A%20aClass%29%0D%0A%09%09%2C%27%29%20smalltalk.mapClassName%28%22%27%0D%0A%09%09%2C%28self%20globalNameFor%3A%20aClass%29%20%2C%27%22%2C%22%27%0D%0A%09%09%2CaClass%20category%2C%20%27%22%2C%27%0D%0A%09%09%2CconstructorName%2C%20%27%2C%27%0D%0A%09%09%2C%28self%20smalltalkNameFor%3A%20aClass%20superclass%29%0D%0A%09%09%2C%27%29%3B%27"));
smalltalk.bind(smalltalk.Exporter,"loadRequirementsOf:",0
,function (aClass){var self=this;var requirements=nil;requirements=self.defaultRequirementsFor_(aClass);
aClass.loadRequirementsInto_(requirements);
return requirements;;return self;}
,"requirements",unescape("loadRequirementsOf%3A%20aClass%0D%0A%09%22%20Return%20the%20requirements%20to%20load%20aClass.%0D%0A%09It%20must%20be%20a%20collection%20of%20requirements.%0D%0A%09aRequirement%20must%20implement%20%23fileOutOn%3A%20or%20must%20be%20a%20string%20with%20javascript%20code%20to%20execute%20just%20before%20defining%20aClass.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20requirements%20%7C%0D%0A%09requirements%20%3A%3D%20self%20defaultRequirementsFor%3A%20aClass.%0D%0A%09aClass%20loadRequirementsInto%3A%20requirements.%0D%0A%09%5Erequirements"));
smalltalk.bind(smalltalk.Exporter,"exportDefinitionOf:on:",0
,function (aClass,aStream){var self=this;self.loadRequirementsOf_(aClass).do_((function(each){return ((each.isString()).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextPutAll_(each);return $rec.cr();})(aStream);})() : (function(){return aStream.fileOutOn_(aStream);})());}));
(function($rec){$rec.nextPutAll_(unescape("smalltalk.addClass%28%22")._comma(self.globalNameFor_(aClass))._comma(unescape("%22%2C")));$rec.nextPutAll_(self.smalltalkNameFor_(aClass.superclass()));return $rec.nextPutAll_(unescape("%2C%20%5B"));})(aStream);
aClass.instanceVariableNames().do_separatedBy_((function(each){return aStream.nextPutAll_(unescape("%27")._comma(each)._comma(unescape("%27")));}), (function(){return aStream.nextPutAll_(unescape("%2C%20"));}));
(function($rec){$rec.nextPutAll_(unescape("%5D%2C%20%27"));$rec.nextPutAll_(aClass.category()._comma(unescape("%27")));$rec.nextPutAll_(unescape("%29%3B"));return $rec.cr();})(aStream);
(((nil.isNil_(aClass.comment())===false).and_((function(){return aClass.comment().notEmpty();}))).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass));$rec.nextPutAll_(unescape(".%24comment%3D")._comma(aClass.comment().escapedCode()));$rec.nextPutAll_(unescape("%3B"));return $rec.cr();})(aStream);})() : nil);
(((nil.isNil_(aClass.classVariables())===false)).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass));$rec.nextPutAll_(unescape(".%24classVariableNames%3D")._comma(aClass.classVariablesString().escapedCode()));$rec.nextPutAll_(unescape("%3B"));return $rec.cr();})(aStream);})() : nil);
(((nil.isNil_(aClass.poolDictionaries())===false)).mustBeBoolean()==true ? (function(){(function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass));return $rec.nextPutAll_(unescape(".%24poolDictionaries%3D%5B"));})(aStream);aClass.poolDictionaries().do_separatedBy_((function(each){return aStream.nextPutAll_(unescape("%27")._comma(each)._comma(unescape("%27")));}), (function(){return aStream.nextPutAll_(unescape("%2C%20"));}));return (function($rec){$rec.nextPutAll_(unescape("%5D%3B"));return $rec.cr();})(aStream);})() : nil);
((aClass.propertyNames().notEmpty()).mustBeBoolean()==true ? (function(){(function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass));return $rec.nextPutAll_(unescape(".%24propertyNames%3D%5B"));})(aStream);aClass.propertyNames().do_separatedBy_((function(each){return aStream.nextPutAll_(unescape("%27")._comma(each)._comma(unescape("%27")));}), (function(){return aStream.nextPutAll_(unescape("%2C%20"));}));return (function($rec){$rec.nextPutAll_(unescape("%5D%3B"));return $rec.cr();})(aStream);})() : nil);return self;}
,"private",unescape("exportDefinitionOf%3A%20aClass%20on%3A%20aStream%0D%0A%09%22%20Export%20definition%20of%20aClass%20onto%20aStream.%20%22%0D%0A%0D%0A%09%28self%20loadRequirementsOf%3A%20aClass%29%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20isString%0D%0A%09%09ifTrue%3A%20%5B%20aStream%20nextPutAll%3A%20each%3Bcr%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20aStream%20fileOutOn%3A%20aStream%20%5D.%0D%0A%09%5D.%0D%0A%09aStream%20%0D%0A%09%20%20%20%20nextPutAll%3A%20%27smalltalk.addClass%28%22%27%2C%20%28self%20globalNameFor%3A%20aClass%29%2C%20%27%22%2C%27%3B%0D%0A%09%20%20%20%20nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%20superclass%29%3B%0D%0A%09%20%20%20%20nextPutAll%3A%20%27%2C%20%5B%27.%0D%0A%09aClass%20instanceVariableNames%20%0D%0A%09%20%20%20%20do%3A%20%5B%3Aeach%20%7C%20aStream%20nextPutAll%3A%20%27%27%27%27%2C%20each%2C%20%27%27%27%27%20%5D%0D%0A%09%20%20%20%20separatedBy%3A%20%5B%20aStream%20nextPutAll%3A%20%27%2C%20%27%20%5D.%0D%0A%09aStream%09%0D%0A%09%20%20%20%20nextPutAll%3A%20%27%5D%2C%20%27%27%27%3B%0D%0A%09%20%20%20%20nextPutAll%3A%20aClass%20category%2C%20%27%27%27%27%3B%0D%0A%09%20%20%20%20nextPutAll%3A%20%27%29%3B%27%3B%20cr.%0D%0A%09%28aClass%20comment%20notNil%20and%3A%20%5BaClass%20comment%20notEmpty%5D%29%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20aStream%0D%0A%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27.%24comment%3D%27%20%2CaClass%20comment%20escapedCode%3B%0D%0A%09%09nextPutAll%3A%20%27%3B%27%3B%20cr%0D%0A%09%5D.%0D%0A%09aClass%20classVariables%20notNil%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20aStream%0D%0A%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27.%24classVariableNames%3D%27%20%2CaClass%20classVariablesString%20escapedCode%3B%0D%0A%09%09nextPutAll%3A%20%27%3B%27%3B%20cr%0D%0A%09%5D.%0D%0A%09aClass%20poolDictionaries%20notNil%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20aStream%0D%0A%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27.%24poolDictionaries%3D%5B%27.%0D%0A%09%20%20%20%20aClass%20poolDictionaries%0D%0A%09%20%20%20%20%09do%3A%20%5B%3Aeach%20%7C%20aStream%20nextPutAll%3A%20%27%27%27%27%2C%20each%2C%20%27%27%27%27%20%5D%0D%0A%09%20%20%20%20%09separatedBy%3A%20%5B%20aStream%20nextPutAll%3A%20%27%2C%20%27%20%5D.%0D%0A%09%20%20%20%20aStream%20%20nextPutAll%3A%20%27%5D%3B%27%3B%20cr%0D%0A%09%5D.%0D%0A%09aClass%20propertyNames%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20aStream%0D%0A%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%29%3B%0D%0A%09%09nextPutAll%3A%20%27.%24propertyNames%3D%5B%27.%0D%0A%09%20%20%20%20aClass%20propertyNames%0D%0A%09%20%20%20%20%09do%3A%20%5B%3Aeach%20%7C%20aStream%20nextPutAll%3A%20%27%27%27%27%2C%20each%2C%20%27%27%27%27%20%5D%0D%0A%09%20%20%20%20%09separatedBy%3A%20%5B%20aStream%20nextPutAll%3A%20%27%2C%20%27%20%5D.%0D%0A%09%20%20%20%20aStream%20%20nextPutAll%3A%20%27%5D%3B%27%3B%20cr%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Exporter,"exportMetaDefinitionOf:on:",0
,function (aClass,aStream){var self=this;((aClass.$klass.instanceVariableNames().notEmpty()).mustBeBoolean()==true ? (function(){(function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass.$klass));return $rec.nextPutAll_(unescape(".%24iVarNames%20%3D%20%5B"));})(aStream);aClass.$klass.instanceVariableNames().do_separatedBy_((function(each){return aStream.nextPutAll_(unescape("%27")._comma(each)._comma(unescape("%27")));}), (function(){return aStream.nextPutAll_(unescape("%2C"));}));return (function($rec){$rec.nextPutAll_(unescape("%5D%3B"));return $rec.cr();})(aStream);})() : nil);
((aClass.$klass.propertyNames().notEmpty()).mustBeBoolean()==true ? (function(){(function($rec){$rec.nextPutAll_(self.smalltalkNameFor_(aClass.$klass));return $rec.nextPutAll_(unescape(".%24propertyNames%20%3D%20%5B"));})(aStream);aClass.$klass.propertyNames().do_separatedBy_((function(each){return aStream.nextPutAll_(unescape("%27")._comma(each)._comma(unescape("%27")));}), (function(){return aStream.nextPutAll_(unescape("%2C"));}));return (function($rec){$rec.nextPutAll_(unescape("%5D%3B"));return $rec.cr();})(aStream);})() : nil);return self;}
,"private",unescape("exportMetaDefinitionOf%3A%20aClass%20on%3A%20aStream%0D%0A%09%22%20Export%20class%20side%20definition%20of%20aClass%20onto%20aStream.%20%22%0D%0A%0D%0A%09aClass%20class%20instanceVariableNames%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09aStream%20%0D%0A%09%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%20class%29%3B%0D%0A%09%09%09nextPutAll%3A%20%27.%24iVarNames%20%3D%20%5B%27.%0D%0A%09%09aClass%20class%20instanceVariableNames%0D%0A%09%09%09do%3A%20%5B%3Aeach%20%7C%20aStream%20nextPutAll%3A%20%27%27%27%27%2C%20each%2C%20%27%27%27%27%20%5D%0D%0A%09%09%09separatedBy%3A%20%5B%20aStream%20nextPutAll%3A%20%27%2C%27%20%5D.%0D%0A%09%09aStream%20nextPutAll%3A%20%27%5D%3B%27%3B%20cr.%0D%0A%09%5D.%0D%0A%0D%0A%09aClass%20class%20propertyNames%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09aStream%20%0D%0A%09%09%09nextPutAll%3A%20%28self%20smalltalkNameFor%3A%20aClass%20class%29%3B%0D%0A%09%09%09nextPutAll%3A%20%27.%24propertyNames%20%3D%20%5B%27.%0D%0A%09%09aClass%20class%20propertyNames%0D%0A%09%09%09do%3A%20%5B%3Aeach%20%7C%20aStream%20nextPutAll%3A%20%27%27%27%27%2C%20each%2C%20%27%27%27%27%20%5D%0D%0A%09%09%09separatedBy%3A%20%5B%20aStream%20nextPutAll%3A%20%27%2C%27%20%5D.%0D%0A%09%09aStream%20nextPutAll%3A%20%27%5D%3B%27%3B%20cr.%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Exporter,"smalltalkNameFor:",0
,function (aClass){var self=this;return aClass.compiler().smalltalkNameFor_(aClass);;return self;}
,"private",unescape("smalltalkNameFor%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20the%20javascript%20reference%20expression%20of%20aClass%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5EaClass%20compiler%20smalltalkNameFor%3A%20aClass"));
smalltalk.bind(smalltalk.Exporter,"globalNameFor:",0
,function (aClass){var self=this;return (((nil.isNil_(aClass))).mustBeBoolean()==true ? (function(){return "nil";})() : (function(){return aClass.name();})());;return self;}
,"private",unescape("globalNameFor%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20the%20smalltalk%20name%20of%20aClass%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5EaClass%20isNil%20ifTrue%3A%20%5B%20%23nil%20%5D%20ifFalse%3A%20%5B%20aClass%20name%20%5D"));
smalltalk.bind(smalltalk.Exporter,"exportAll",0
,function (){var self=this;return self.exportClasses_(self.$klass.allClasses());;return self;}
,"export",unescape("exportAll%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20classes%20in%20the%20system.%20%22%0D%0A%0D%0A%09%5Eself%20exportClasses%3A%20self%20class%20allClasses"));
smalltalk.bind(smalltalk.Exporter,"exportAllCategories",0
,function (){var self=this;var categories=nil;categories=smalltalk.Array.$$new();
self.$klass.allClasses().do_((function(each){return ((categories.includes_(each.category())).mustBeBoolean()==true ? nil : (function(){return categories.add_(each.category());})());}));
return categories.inject_into_("", (function(total,each){return total._comma(self.exportCategory_(each));}));;return self;}
,"export",unescape("exportAllCategories%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20all%20categories%20in%20the%20system.%20%22%0D%0A%0D%0A%09%7C%20categories%20%7C%0D%0A%09categories%20%3A%3D%20Array%20new.%0D%0A%09self%20class%20allClasses%20do%3A%20%5B%3Aeach%20%7C%0D%0A%09%09%28categories%20includes%3A%20each%20category%29%20ifFalse%3A%20%5B%0D%0A%09%09%09categories%20add%3A%20each%20category%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Ecategories%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%20%7C%20total%20%2C%28self%20exportCategory%3A%20each%29%20%5D"));
smalltalk.bind(smalltalk.Exporter,"exportDefinitionOf:",0
,function (aClass){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.exportDefinitionOf_on_(aClass, stream);
return stream.contents();;return self;}
,"export",unescape("exportDefinitionOf%3A%20aClass%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20definition%20of%20aClass.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20exportDefinitionOf%3A%20aClass%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportMetaDefinitionOf:",0
,function (aClass){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.exportMetaDefinitionOf_on_(aClass, stream);
return stream.contents();;return self;}
,"export",unescape("exportMetaDefinitionOf%3A%20aClass%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20class%20side%20definition%20of%20aClass.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20exportMetaDefinitionOf%3A%20aClass%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportClasses:on:",0
,function (classes,stream){var self=this;return self.exportAll_on_(classes, stream);;return self;}
,"export",unescape("exportClasses%3A%20classes%20on%3A%20stream%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20class%20definitions%20onto%20stream.%20%22%0D%0A%0D%0A%09%5Eself%20exportAll%3A%20classes%20on%3A%20stream"));
smalltalk.bind(smalltalk.Exporter,"exportAll:on:",0
,function (elements,stream){var $s8Ret$={name:"stReturn"};try{var self=this;((elements.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.exportAll_on_(elements.asArrayOfSubstrings(), stream);})();throw($s8Ret$)})();})() : nil);
elements.do_((function(each){return ((smalltalk.is_kindOf_(each,(smalltalk.Behavior))).mustBeBoolean()==true ? (function(){return self.exportDefinitionOfClass_on_(each, stream);})() : nil);}));
stream.cr();
elements.do_((function(each){return ((smalltalk.is_kindOf_(each,(smalltalk.Behavior))).mustBeBoolean()==true ? (function(){return self.exportAllMethodsOf_on_(each, stream);})() : (function(){return ((each.isString()).mustBeBoolean()==true ? (function(){return (function($rec){$rec.nextPutAll_(self.exportCategory_(each));return $rec.cr();})(stream);})() : (function(){return self.exportMethod_on_(each, stream);})());})());}));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"export",unescape("exportAll%3A%20elements%20on%3A%20stream%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20elements%20%28classes%2C%20methods%20and/or%20categories%29%20onto%20stream.%20%22%0D%0A%0D%0A%09elements%20isString%20ifTrue%3A%20%5B%20%5Eself%20exportAll%3A%20elements%20asArrayOfSubstrings%20on%3A%20stream%20%5D.%0D%0A%09elements%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28each%20isKindOf%3A%20Behavior%29%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20exportDefinitionOfClass%3A%20each%20on%3A%20stream%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09stream%20cr.%0D%0A%09elements%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28each%20isKindOf%3A%20Behavior%29%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20exportAllMethodsOf%3A%20each%20on%3A%20stream%0D%0A%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09each%20isString%0D%0A%09%09%09ifTrue%3A%20%5B%20stream%20nextPutAll%3A%20%28self%20exportCategory%3A%20each%29%3Bcr%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20self%20exportMethod%3A%20each%20on%3A%20stream%20%5D%0D%0A%09%09%5D%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Exporter,"exportAll:",0
,function (elements){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.exportAll_on_(elements, stream);
return stream.contents();;return self;}
,"export",unescape("exportAll%3A%20elements%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20elements%20%28classes%2C%20methods%20and/or%20categories%29.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20exportAll%3A%20elements%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportClasses:",0
,function (classes){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.exportClasses_on_(classes, stream);
return stream.contents();;return self;}
,"export",unescape("exportClasses%3A%20classes%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20classes.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20exportClasses%3A%20classes%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportObject:on:",0
,function (anObject,stream){var self=this;stream.nextPutAll_(anObject.asJavascript());return self;}
,"export",unescape("exportObject%3A%20anObject%20on%3A%20stream%0D%0A%09%22%20Export%20a%20%28javascript%29literal%20representation%20of%20anObject%20onto%20stream.%20%22%0D%0A%0D%0A%09stream%20nextPutAll%3A%20anObject%20asJavascript."));
smalltalk.bind(smalltalk.Exporter,"exportObject:",0
,function (anObject){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.exportObject_on_(anObject, stream);
return stream.contents();;return self;}
,"export",unescape("exportObject%3A%20anObject%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20a%20literal%20representation%20of%20anObject.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20exportObject%3A%20anObject%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"export:method:",0
,function (aClass,aMethod){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.export_method_on_(aClass, aMethod, stream);
return stream.contents();;return self;}
,"export",unescape("export%3A%20aClass%20method%3A%20aMethod%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20aClass%20method.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20export%3A%20aClass%20method%3A%20aMethod%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportMethod:",0
,function (aMethod){var self=this;return self.export_method_(aMethod.classField(), aMethod);;return self;}
,"export",unescape("exportMethod%3A%20aMethod%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20aMethod.%20%22%0D%0A%0D%0A%09%5Eself%20export%3A%20aMethod%20classField%20method%3A%20aMethod"));
smalltalk.bind(smalltalk.Exporter,"exportMethod:on:",0
,function (aMethod,aStream){var self=this;return self.export_method_on_(aMethod.classField(), aMethod, aStream);;return self;}
,"export",unescape("exportMethod%3A%20aMethod%20on%3A%20aStream%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20aMethod%20on%20stream.%20%22%0D%0A%0D%0A%09%5Eself%20export%3A%20aMethod%20classField%20method%3A%20aMethod%20on%3A%20aStream"));
smalltalk.bind(smalltalk.Exporter,"exportMethods:on:",0
,function (aCollection,aStream){var self=this;aCollection.do_((function(each){return self.exportMethod_on_(each, aStream);}));return self;}
,"export",unescape("exportMethods%3A%20aCollection%20on%3A%20aStream%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20aCollection%20of%20methods%20on%20stream.%20%22%0D%0A%0D%0A%09aCollection%20do%3A%20%5B%3Aeach%7C%20self%20exportMethod%3A%20each%20on%3A%20aStream%20%5D"));
smalltalk.bind(smalltalk.Exporter,"exportMethods:",0
,function (aCollection){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.exportMethods_on_(aCollection, stream);
return stream.contents();;return self;}
,"export",unescape("exportMethods%3A%20aCollection%0D%0A%09%22%20Return%20the%20result%20of%20exporting%20aCollection%20of%20methods.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20exportMethods%3A%20aCollection%20on%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Exporter,"exportMethodsOf:on:",0
,function (aClass,aStream){var self=this;aClass.methodsDo_((function(each){return self.export_method_on_(aClass, each, aStream);}));return self;}
,"private",unescape("exportMethodsOf%3A%20aClass%20on%3A%20aStream%0D%0A%09%22%20Export%20methods%20of%20aClass%20onto%20aStream.%20%22%0D%0A%0D%0A%09aClass%20methodsDo%3A%20%5B%3Aeach%7C%0D%0A%09%09self%20export%3A%20aClass%20method%3A%20each%20on%3A%20aStream%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Exporter,"javascriptSourceFor:",0
,function (aMethod){var self=this;return aMethod.fn().compiledSource();;return self;}
,"private",unescape("javascriptSourceFor%3A%20aMethod%0D%0A%09%22%20Private%20-%20Return%20the%20code%20of%20javascript%20function%20implementing%20aMethod.%20%22%0D%0A%0D%0A%09%5EaMethod%20fn%20compiledSource"));
smalltalk.bind(smalltalk.Exporter,"export:method:on:",0
,function (aClass,aMethod,aStream){var self=this;var functionName=nil;var selectorName=nil;var bar=nil;bar=unescape("%22").asString();
functionName=aMethod.selector();
((functionName.first().isBackSlash()).mustBeBoolean()==true ? (function(){selectorName=aMethod.selector().escapedCode();return functionName=functionName.asSelector().escapedCode();})() : (function(){selectorName=bar._comma(aMethod.selector())._comma(bar);return ((functionName.asSelector()._eq(aMethod.selector().replace_with_(unescape("%5C%3A"), "_"))).mustBeBoolean()==true ? (function(){return functionName="0";})() : (function(){return functionName=bar._comma(functionName.asSelector())._comma(bar);})());})());
aStream.nextPutAll_(unescape("smalltalk.bind%28")._comma(self.smalltalkNameFor_(aClass))._comma(unescape("%2C"))._comma(selectorName)._comma(unescape("%2C"))._comma(functionName)._comma(unescape("%0D%0A%2C"))._comma(self.javascriptSourceFor_(aMethod)));
(((nil.isNil_(aMethod.source())===false).and_((function(){return aMethod.source().notEmpty();}))).mustBeBoolean()==true ? (function(){return (function($rec){$rec.cr();return $rec.nextPutAll_(unescape("%2C")._comma(aMethod.category().escapedCode())._comma(unescape("%2C"))._comma(aMethod.source().escapedCode()));})(aStream);})() : nil);
aStream.nextPutAll_(unescape("%29%3B%0D%0A"));return self;}
,"export",unescape("export%3A%20aClass%20method%3A%20aMethod%20on%3A%20aStream%0D%0A%09%22%20Export%20a%20method%20definition%20of%20aClass%20onto%20aStream.%20%22%0D%0A%0D%0A%09%7C%20functionName%20selectorName%20bar%20%7C%0D%0A%09bar%20%3A%3D%20%24%22%20asString.%0D%0A%09functionName%20%3A%3D%20aMethod%20selector.%0D%0A%09functionName%20first%20isBackSlash%20ifTrue%3A%20%5B%0D%0A%09%09selectorName%20%3A%3D%20aMethod%20selector%20escapedCode.%0D%0A%09%09functionName%20%3A%3D%20functionName%20asSelector%20escapedCode.%0D%0A%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09selectorName%20%3A%3D%20bar%20%2CaMethod%20selector%2C%20bar.%0D%0A%09%09functionName%20asSelector%20%3D%20%28aMethod%20selector%20replace%3A%20%27%5C%3A%27%20with%3A%20%24_%29%20ifTrue%3A%20%5B%0D%0A%09%09%09functionName%20%3A%3D%20%270%27%20%22we%20exploit%20the%20fact%20that%200%20isNil%20to%20signal%20a%20compact%20selector%22%0D%0A%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09functionName%20%3A%3D%20bar%20%2CfunctionName%20asSelector%2C%20bar%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09aStream%0D%0A%09%09nextPutAll%3A%20%27smalltalk.bind%28%27%2C%20%28self%20smalltalkNameFor%3A%20aClass%29%0D%0A%09%09%09%2C%27%2C%27%2C%20selectorName%2C%20%27%2C%27%2C%20functionName%20%2C%27%0D%0A%2C%27%09%09%09%2C%20%28self%20javascriptSourceFor%3A%20aMethod%29.%0D%0A%09%28aMethod%20source%20notNil%20and%3A%20%5B%20aMethod%20source%20notEmpty%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20aStream%20cr%3B%20%22warning%3A%20this%20cr%20is%20important%20for%20debugger%22%0D%0A%09%09nextPutAll%3A%20%27%2C%27%2C%20aMethod%20category%20escapedCode%0D%0A%09%09%09%2C%27%2C%27%2C%20aMethod%20source%20escapedCode.%0D%0A%09%5D.%0D%0A%09aStream%20nextPutAll%3A%20%27%29%3B%0D%0A%27"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"default","$$default"
,function (){var self=this;(((nil.isNil_(self['@default']))).mustBeBoolean()==true ? (function(){return self['@default']=self.$$new();})() : nil);
return self['@default'];;return self;}
,"accessing",unescape("default%0D%0A%09%22%20Return%20the%20default%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09default%20isNil%20ifTrue%3A%20%5B%20default%20%3A%3D%20self%20new%20%5D.%0D%0A%09%5Edefault"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"build:doing:",0
,function (token,aBlock){var self=this;var builder=nil;var result=nil;var success=nil;builder=self.$$default();
builder.open_(token);
success=false;
(function(){result=aBlock.value();return success=true;}).ensure_((function(){return builder.close_success_(token, success);}));
return result;;return self;}
,"building",unescape("build%3A%20token%20doing%3A%20aBlock%0D%0A%09%22%20Process%20a%20%28build...%3A%20spec%29%20definition%20marking%20methods%20generated%20while%20evaluating%20aBlock.%0D%0A%09Return%20the%20result%20of%20evaluating%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20builder%20result%20success%20%7C%0D%0A%09builder%20%3A%3D%20self%20default.%0D%0A%09builder%20open%3A%20token.%0D%0A%09success%20%3A%3D%20false.%0D%0A%09%5B%09result%20%3A%3D%20aBlock%20value.%0D%0A%09%09success%20%3A%3D%20true.%0D%0A%09%5D%20ensure%3A%20%5B%20builder%20close%3A%20token%20success%3A%20success%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"register:",0
,function (aMethod){var self=this;return (nil.isNil_(self['@default'])===false).and_((function(){return self['@default'].register_(aMethod);}));;return self;}
,"building",unescape("register%3A%20aMethod%0D%0A%09%22%20Register%20aMethod%20as%20related%20to%20current%20builder.%20%22%0D%0A%0D%0A%09%5Edefault%20notNil%20and%3A%20%5B%20default%20register%3A%20aMethod%20%5D"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"imageSaved:on:",0
,function (snapshot,stream){var self=this;return smalltalk.superImplementor(smalltalk.APIBuilder.$klass,'imageSaved_on_').apply(self, [snapshot, stream]);;return self;}
,"snapshot",unescape("imageSaved%3A%20snapshot%20on%3A%20stream%0D%0A%09%22%20Private%20-%20A%20system%20snapshot%20has%20been%20taken%2C%20the%20receiver%20can%20restore%20state.%20%22%0D%0A%0D%0A%22%20Unused%2CToDo%20-%20uncomment%20this%20code%20to%20save%20builders%20in%20snapshot.%0D%0A%09%7C%20builders%20%7C%0D%0A%09builders%20%3A%3D%20self%20builders.%0D%0A%09builders%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09stream%20cr%3BnextPutAll%3A%0D%0A%09%09%09%27smalltalk.%27%2C%20self%20name%20%2C%27.builders_%28%27%0D%0A%09%09%09%2C%28Exporter%20new%20exportObject%3A%20builders%29%0D%0A%09%09%09%2C%27%29%3B%27%0D%0A%09%5D.%0D%0A%22%09%5Esuper%20imageSaved%3A%20snapshot%20on%3A%20stream"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"builders",0
,function (){var self=this;return smalltalk.Smalltalk.classes().collect_((function(cls){return smalltalk.Array.with_with_with_(cls.name(), self.buildersIn_(cls.$klass), self.buildersIn_(cls));})).reject_((function(tuple){return tuple.second().isEmpty().and_((function(){return tuple.third().isEmpty();}));}));;return self;}
,"private",unescape("builders%0D%0A%09%22%20Private%20-%20Return%20the%20builders%20on%20this%20system.%0D%0A%09%23%28%20className%20%23%28--classbuilders--%29%20%23%28--instanceBuilders---%29%29%0D%0A%09%22%0D%0A%0D%0A%09%5E%28Smalltalk%20classes%0D%0A%09%09collect%3A%20%5B%3Acls%7C%20Array%20with%3A%20cls%20name%20with%3A%20%28self%20buildersIn%3A%20cls%20class%29%20with%3A%20%28self%20buildersIn%3A%20cls%29%5D%29%0D%0A%09%09reject%3A%20%5B%3Atuple%7C%20tuple%20second%20isEmpty%20and%3A%20%5Btuple%20third%20isEmpty%5D%5D"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"buildersIn:",0
,function (aClass){var self=this;var map=nil;map=smalltalk.Array.$$new();
aClass.methodsDo_((function(mth){var assoc=nil;assoc=mth.builder();return (((nil.isNil_(assoc)===false)).mustBeBoolean()==true ? (function(){return map.detect_ifNone_((function(tuple){return tuple.first()._eq(assoc);}), (function(){return map.add_(smalltalk.Array.with_with_(assoc, smalltalk.Array.$$new()));})).add_(mth.selector());})() : nil);}));
return map.collect_((function(tuple){return smalltalk.Array.with_with_with_(tuple.first().key(), tuple.first().value(), tuple.last());}));;return self;}
,"private",unescape("buildersIn%3A%20aClass%0D%0A%09%22%20Private%20-%20Return%20the%20builders%20used%20in%20aClass.%0D%0A%09%23%28%20builderType%20builderSpec%20%23%28%20selectors%20%29%20%29%0D%0A%09%22%0D%0A%0D%0A%09%7C%20map%20%7C%0D%0A%09map%20%3A%3D%20Array%20new.%0D%0A%09aClass%20methodsDo%3A%20%5B%3Amth%7C%20%7C%20assoc%20%7C%0D%0A%09%09assoc%20%3A%3D%20mth%20builder.%0D%0A%09%09assoc%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09%28map%09detect%3A%20%5B%3Atuple%7C%20tuple%20first%20%3D%20assoc%20%5D%0D%0A%09%09%09%09ifNone%3A%20%5B%20map%20add%3A%20%28Array%20with%3A%20assoc%20with%3A%20Array%20new%29%20%5D%29%0D%0A%09%09%09%09add%3A%20mth%20selector%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Emap%20collect%3A%20%5B%3Atuple%7C%20Array%0D%0A%09%09with%3A%20tuple%20first%20key%0D%0A%09%09with%3A%20tuple%20first%20value%0D%0A%09%09with%3A%20tuple%20last%0D%0A%09%5D"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"builders:",0
,function (spec){var self=this;spec.do_((function(builder){var cls=nil;cls=smalltalk.Smalltalk.at_ifAbsent_(builder.first(), (function(){return nil;}));return (((nil.isNil_(cls)===false)).mustBeBoolean()==true ? (function(){self.setBuilders_in_(builder.second(), cls.cls());return self.setBuilders_in_(builder.third(), cls);})() : nil);}));return self;}
,"private",unescape("builders%3A%20spec%0D%0A%09%22%20Private%20-%20Set%20the%20builders%20on%20this%20system.%20%22%0D%0A%0D%0A%09spec%20do%3A%20%5B%3Abuilder%7C%20%7C%20cls%20%7C%0D%0A%09%09cls%20%3A%3D%20Smalltalk%20at%3A%20builder%20first%20ifAbsent%3A%20%5B%5D.%0D%0A%09%09cls%20notNil%20ifTrue%3A%20%5B%20%22ignore%20broken%20spec%2C%20see%20%23builders%20implementation.%22%0D%0A%09%09%09self%20setBuilders%3A%20builder%20second%20in%3A%20cls%20cls.%0D%0A%09%09%09self%20setBuilders%3A%20builder%20third%20in%3A%20cls.%0D%0A%09%09%5D.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.APIBuilder.$klass,"setBuilders:in:",0
,function (map,aClass){var self=this;var builder=nil;builder=smalltalk.Association.key_value_(map.first(), map.second());
map.last().do_((function(selector){var mth=nil;mth=aClass.compiledMethodAt_(selector);return (((nil.isNil_(mth)===false)).mustBeBoolean()==true ? (function(){return mth.builder_(builder);})() : nil);}));return self;}
,"private",unescape("setBuilders%3A%20map%20in%3A%20aClass%0D%0A%09%22%20Private%20-%20Set%20the%20builders%20on%20aClass.%20%22%0D%0A%0D%0A%09%7C%20builder%20%7C%0D%0A%09builder%20%3A%3D%20Association%20key%3A%20map%20first%20value%3A%20map%20second.%0D%0A%09map%20last%20do%3A%20%5B%3Aselector%7C%20%7C%20mth%20%7C%0D%0A%09%09mth%20%3A%3D%20aClass%20compiledMethodAt%3A%20selector.%0D%0A%09%09mth%20notNil%20ifTrue%3A%20%5B%20mth%20builder%3A%20builder%20%5D.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.APIBuilder,"register:",0
,function (aMethod){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@token']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})() : nil);
(((nil.isNil_(self['@bound']))).mustBeBoolean()==true ? (function(){return self['@bound']=smalltalk.Array.$$new();})() : nil);
self['@bound'].add_(aMethod);
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("register%3A%20aMethod%0D%0A%09%22%20Private%20-%20Register%20aMethod%20as%20related%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09token%20isNil%20ifTrue%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09bound%20isNil%20ifTrue%3A%20%5B%20bound%20%3A%3D%20Array%20new%20%5D.%0D%0A%09bound%20add%3A%20aMethod.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.APIBuilder,"open:",0
,function (spec){var self=this;(((nil.isNil_(self['@parents']))).mustBeBoolean()==true ? (function(){return self['@parents']=smalltalk.Array.$$new();})() : nil);
(((nil.isNil_(self['@token'])===false)).mustBeBoolean()==true ? (function(){return self['@parents'].addLast_(self['@token']);})() : nil);
self['@token']=spec;return self;}
,"private",unescape("open%3A%20spec%0D%0A%09%22%20Private%20-%20The%20spec%20will%20be%20generated.%0D%0A%09Prepare%20the%20receiver%20to%20track%20generated%20methods%20while%20building%20spec.%0D%0A%09%22%0D%0A%0D%0A%09parents%20isNil%20ifTrue%3A%20%5B%20parents%20%3A%3D%20Array%20new%20%5D.%0D%0A%09token%20notNil%20ifTrue%3A%20%5B%20parents%20addLast%3A%20token%20%5D.%0D%0A%09token%20%3A%3D%20spec."));
smalltalk.bind(smalltalk.APIBuilder,"close:success:",0
,function (spec,success){var $s8Ret$={name:"stReturn"};try{var self=this;((self['@token']._eq(spec)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Builders out of sync.");})();throw($s8Ret$)})();})());
(((nil.isNil_(self['@parents'])===false).and_((function(){return self['@parents'].notEmpty();}))).mustBeBoolean()==true ? (function(){self['@token']=self['@parents'].removeLast();return (function(){$s8Ret$.result=(function(){return success;})();throw($s8Ret$)})();})() : nil);
(((nil.isNil_(self['@bound'])===false)).mustBeBoolean()==true ? (function(){self['@bound'].do_((function(each){return self.mark_(each);}));return self['@token']=self['@parents']=self['@bound']=nil;})() : nil);
(function(){$s8Ret$.result=(function(){return success;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("close%3A%20spec%20success%3A%20success%0D%0A%09%22%20Private%20-%20The%20spec%20has%20been%20implemented%2C%20backtrack%20to%20parent%20or%20mark%20collected%20methods.%20%22%0D%0A%0D%0A%09token%20%3D%20spec%20ifFalse%3A%20%5B%20%5Eself%20error%3A%20%27Builders%20out%20of%20sync.%27%20%5D.%0D%0A%09%28parents%20notNil%20and%3A%20%5B%20parents%20notEmpty%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09token%20%3A%3D%20parents%20removeLast.%0D%0A%09%09%5Esuccess%0D%0A%09%5D.%0D%0A%09bound%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09bound%20do%3A%20%5B%3Aeach%7C%20self%20mark%3A%20each%20%5D.%0D%0A%09%09token%20%3A%3D%20parents%20%3A%3D%20bound%20%3A%3D%20nil.%0D%0A%09%5D.%0D%0A%09%5Esuccess"));
smalltalk.bind(smalltalk.APIBuilder,"mark:",0
,function (aMethod){var self=this;aMethod.builder_(self['@token']);return self;}
,"private",unescape("mark%3A%20aMethod%0D%0A%09%22%20Private%20-%20Mark%20aMethod%20as%20dependent%20of%20current%20token.%20%22%0D%0A%0D%0A%09aMethod%20builder%3A%20token"));
smalltalk.bind(smalltalk.APIBuilder,"fileOut:selectors:of:on:",0
,function (exporter,selectors,aClass,stream){var self=this;var specs=nil;specs=smalltalk.Set.$$new();
selectors.copy().do_((function(selector){var assoc=nil;assoc=aClass.compiledMethodAt_(selector).builder();return (((nil.isNil_(assoc)===false)).mustBeBoolean()==true ? (function(){specs.add_(assoc);return selectors.remove_(selector);})() : nil);}));
specs.asArray().sorted_((function(a,b){return a.key()._lt_eq(b.key());})).do_((function(assoc){stream.nextPutAll_(aClass.name()._comma(" build")._comma(assoc.key()));((assoc.value().notEmpty()).mustBeBoolean()==true ? (function(){stream.nextPut_(":");return self.fileOutSpec_on_(assoc.value(), stream);})() : nil);return (function($rec){$rec.nextChunkPut_(" ");return $rec.cr();})(stream);}));return self;}
,"fileOut",unescape("fileOut%3A%20exporter%20selectors%3A%20selectors%20of%3A%20aClass%20on%3A%20stream%0D%0A%09%22%20Fileout%20clustered%20sources%20for%20selectors%20onto%20stream.%0D%0A%09Note%3A%20Remove%20the%20clustered%20message%20selectors%20from%20selectors%20collection%20while%20fileOut.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20specs%20%7C%0D%0A%09specs%20%3A%3D%20Set%20new.%0D%0A%09selectors%20copy%20do%3A%20%5B%3Aselector%7C%20%7C%20assoc%20%7C%0D%0A%09%09assoc%20%3A%3D%20%28aClass%20compiledMethodAt%3A%20selector%29%20builder.%0D%0A%09%09assoc%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09specs%20add%3A%20assoc.%0D%0A%09%09%09selectors%20remove%3A%20selector.%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%28specs%20asArray%20sorted%3A%20%5B%3Aa%20%3Ab%7C%20a%20key%20%3C%3D%20b%20key%20%5D%29%20do%3A%20%5B%3Aassoc%7C%0D%0A%09%09stream%20nextPutAll%3A%20aClass%20name%20%2C%27%20build%27%20%2Cassoc%20key.%0D%0A%09%09assoc%20value%20notEmpty%20ifTrue%3A%20%5B%0D%0A%09%09%09stream%20nextPut%3A%20%24%3A.%0D%0A%09%09%09self%20fileOutSpec%3A%20assoc%20value%20on%3A%20stream%0D%0A%09%09%5D.%0D%0A%09%09stream%20nextChunkPut%3A%20%24%20%3Bcr%0D%0A%09%5D."));
smalltalk.bind(smalltalk.APIBuilder,"fileOutSpec:on:",0
,function (array,stream){var self=this;(function($rec){$rec.nextPutAll_(unescape("%20%23%28"));return $rec.cr();})(stream);
array.do_((function(each){return (function($rec){$rec.tab();$rec.nextPutAll_(each.asLiteral());return $rec.cr();})(stream);}));
stream.nextPut_(unescape("%29"));return self;}
,"fileOut",unescape("fileOutSpec%3A%20array%20on%3A%20stream%0D%0A%09%22%20Private%20-%20Fileout%20API%20spec%20in%20array%20onto%20stream.%20%22%0D%0A%0D%0A%09stream%20nextPutAll%3A%20%27%20%23%28%27%3Bcr.%0D%0A%09array%20do%3A%20%5B%3Aeach%7C%20stream%20tab%3B%20nextPutAll%3A%20each%20asLiteral%3Bcr%20%5D.%0D%0A%09stream%20%22tab%3B%22nextPut%3A%20%24%29."));
smalltalk.bind(smalltalk.Snapshot.$klass,"contents",0
,function (){var self=this;return self.$$new().contents();;return self;}
,"accessing",unescape("contents%0D%0A%09%22%20Return%20a%20snapshot%20of%20current%20system%20contents.%20%22%0D%0A%0D%0A%09%5Eself%20new%20contents"));
smalltalk.bind(smalltalk.Snapshot.$klass,"outputToFile:",0
,function (fileName){var self=this;self.contents().outputToFile_(fileName);return self;}
,"saveImage",unescape("outputToFile%3A%20fileName%0D%0A%09%22%20Save%20a%20complete%20system%20snapshot%20in%20a%20file%20at%20fileName.%20%22%0D%0A%0D%0A%09self%20contents%20outputToFile%3A%20fileName"));
smalltalk.bind(smalltalk.Snapshot,"contents",0
,function (){var self=this;var stream=nil;stream=smalltalk.String.$$new().writeStream();
self.saveImageOn_(stream);
return stream.contents();;return self;}
,"accessing",unescape("contents%0D%0A%09%22%20Return%20a%20snapshot%20of%20current%20system%20contents.%20%22%0D%0A%0D%0A%09%7C%20stream%20%7C%0D%0A%09stream%20%3A%3D%20String%20new%20writeStream.%0D%0A%09self%20saveImageOn%3A%20stream.%0D%0A%09%5Estream%20contents"));
smalltalk.bind(smalltalk.Snapshot,"saveImageOn:",0
,function (stream){var self=this;return self.saveImage_on_(self.smalltalk(), stream);;return self;}
,"saveImage",unescape("saveImageOn%3A%20stream%0D%0A%09%22%20Save%20the%20current%20system%20contents%20onto%20stream.%20%22%0D%0A%0D%0A%09%5Eself%20saveImage%3A%20self%20smalltalk%20on%3A%20stream"));
smalltalk.bind(smalltalk.Snapshot,"saveImage:on:",0
,function (aSmalltalk,stream){var self=this;(function($rec){$rec.writeLicense_on_(aSmalltalk, stream);$rec.writeBootOn_(stream);$rec.writePrologueOn_(stream);$rec.writeImageContents_on_(aSmalltalk, stream);$rec.writeEpilogueOn_(stream);return $rec.yourself();})(self);return self;}
,"saveImage",unescape("saveImage%3A%20aSmalltalk%20on%3A%20stream%0D%0A%09%22%20Save%20aSmalltalk%20system%20contents%20onto%20stream.%20%22%0D%0A%0D%0A%09self%0D%0A%09%09writeLicense%3A%20aSmalltalk%20on%3A%20stream%3B%0D%0A%09%09writeBootOn%3A%20stream%3B%0D%0A%09%09writePrologueOn%3A%20stream%3B%0D%0A%09%09writeImageContents%3A%20aSmalltalk%20on%3A%20stream%3B%0D%0A%09%09writeEpilogueOn%3A%20stream%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Snapshot,"writeLicense:on:",0
,function (aSmalltalk,aStream){var self=this;(function($rec){$rec.nextPutAll_(unescape("/*"));$rec.cr();$rec.nextPutAll_(aSmalltalk.licenseTerms());$rec.cr();$rec.nextPutAll_(unescape("*/"));$rec.cr();return $rec.cr();})(aStream);return self;}
,"writing",unescape("writeLicense%3A%20aSmalltalk%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20license%20terms%20onto%20aStream.%20%22%0D%0A%0D%0A%09aStream%0D%0A%09%09nextPutAll%3A%20%27/*%27%3Bcr%3B%0D%0A%09%09nextPutAll%3A%20aSmalltalk%20licenseTerms%3Bcr%3B%0D%0A%09%09nextPutAll%3A%20%27*/%27%3Bcr%3B%0D%0A%09%09cr"));
smalltalk.bind(smalltalk.Snapshot,"writeBootOn:",0
,function (aStream){var self=this;self.writeJSGlobals_on_(["StObject", "StBehavior", "StClass", "StMetaclass", "StMethod", "StUndefinedObject"], aStream);
self.writeNilDefinitionOn_(aStream);
self.writeJSGlobals_on_(["StSystemDictionary"], aStream);
self.writeSystemDefinitionOn_(aStream);
self.write_mappingsOn_("Kernel", aStream);return self;}
,"writing",unescape("writeBootOn%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20boot%20section%20of%20the%20image%20onto%20aStream.%20%22%0D%0A%0D%0A%09self%20writeJSGlobals%3A%20%23%28%0D%0A%09%09%23StObject%20%23StBehavior%20%23StClass%20%23StMetaclass%0D%0A%09%09%23StMethod%0D%0A%09%09%23StUndefinedObject%0D%0A%09%09%29%20on%3A%20aStream.%0D%0A%09self%20writeNilDefinitionOn%3A%20aStream.%0D%0A%09self%20writeJSGlobals%3A%20%23%28%20%23StSystemDictionary%20%29%20on%3A%20aStream.%0D%0A%09self%20writeSystemDefinitionOn%3A%20aStream.%0D%0A%09self%20write%3A%20%23Kernel%20mappingsOn%3A%20aStream."));
smalltalk.bind(smalltalk.Snapshot,"writePrologueOn:",0
,function (aStream){var self=this;self.write_on_(unescape("smalltalk.%24state%20%3D%20%22initialize%22%3B"), aStream);
self.writeJSGlobals_on_(["smalltalk.st", "smalltalk.doIt", "fileIn", "fileInJS", "doit", "exportCategory", "saveImage", "saveImageAs"], aStream);
self.write_on_(unescape("smalltalk.%24imageFileName%20%3D%20smalltalk.%24imageFileName%20%20%7C%7C%20%22s8.image.js%22%3B"), aStream);
self.write_on_(unescape("smalltalk.%24state%20%3D%20%22startup%22%3B"), aStream);return self;}
,"writing",unescape("writePrologueOn%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20prologue%20section%20of%20the%20image%20onto%20aStream.%20%22%0D%0A%0D%0A%09self%20write%3A%20%27smalltalk.%24state%20%3D%20%22initialize%22%3B%27%20on%3A%20aStream.%0D%0A%09self%20writeJSGlobals%3A%20%23%28%0D%0A%09%09%27smalltalk.st%27%20%27smalltalk.doIt%27%0D%0A%09%09%23fileIn%20%23fileInJS%0D%0A%09%09%23doit%20%23exportCategory%0D%0A%09%09%23saveImage%20%23saveImageAs%0D%0A%09%09%29%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27smalltalk.%24imageFileName%20%3D%20smalltalk.%24imageFileName%20%20%7C%7C%20%22s8.image.js%22%3B%27%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27smalltalk.%24state%20%3D%20%22startup%22%3B%27%20on%3A%20aStream."));
smalltalk.bind(smalltalk.Snapshot,"writeEpilogueOn:",0
,function (aStream){var self=this;self.write_on_(unescape("smalltalk.launchImage%28%29%3B"), aStream);return self;}
,"writing",unescape("writeEpilogueOn%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20epilogue%20section%20of%20the%20image%20onto%20aStream.%20%22%0D%0A%0D%0A%09self%20write%3A%20%27smalltalk.launchImage%28%29%3B%27%20on%3A%20aStream."));
smalltalk.bind(smalltalk.Snapshot,"write:on:",0
,function (aString,aStream){var self=this;(function($rec){$rec.cr();return $rec.nextPutAll_(aString);})(aStream);return self;}
,"writing",unescape("write%3A%20aString%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20aString%20onto%20aStream.%20%22%0D%0A%0D%0A%09aStream%20cr%3B%20nextPutAll%3A%20aString"));
smalltalk.bind(smalltalk.Snapshot,"globalNotFound:",0
,function (aJSGlobal){var self=this;return self.error_("Global not found: "._comma(aJSGlobal));;return self;}
,"error",unescape("globalNotFound%3A%20aJSGlobal%0D%0A%09%22%20Private%20-%20A%20global%20at%20javascript%20level%20has%20not%20been%20found.%20%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Global%20not%20found%3A%20%27%2CaJSGlobal"));
smalltalk.bind(smalltalk.Snapshot,"writeJSGlobals:on:",0
,function (globals,aStream){var self=this;var jsObject=nil;var varName=nil;globals.do_((function(each){jsObject=smalltalk.Smalltalk.current().eval_(each);(((nil.isNil_(jsObject))).mustBeBoolean()==true ? (function(){return jsObject=self.globalNotFound_(each);})() : nil);varName=((each.includes_(".")).mustBeBoolean()==true ? (function(){return each;})() : (function(){return "var "._comma(each);})());return self.write_on_(varName._comma(unescape("%20%3D%20"))._comma(jsObject.toString())._comma(unescape("%3B")), aStream);}));return self;}
,"writing",unescape("writeJSGlobals%3A%20globals%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20prologue%20section%20of%20the%20image%20onto%20aStream.%20%22%0D%0A%0D%0A%09%7C%20jsObject%20varName%20%7C%0D%0A%09globals%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09jsObject%20%3A%3D%20Smalltalk%20current%20eval%3A%20each.%0D%0A%09%09jsObject%20isNil%20ifTrue%3A%20%5B%20jsObject%20%3A%3D%20self%20globalNotFound%3A%20each%20%5D.%0D%0A%09%09varName%20%3A%3D%20%28each%20includes%3A%20%24.%29%20ifTrue%3A%20%5B%20each%20%5D%20ifFalse%3A%20%5B%20%27var%20%27%2Ceach%20%5D.%0D%0A%09%09self%20write%3A%20varName%2C%27%20%3D%20%27%2C%20jsObject%20toString%20%2C%24%3B%20on%3A%20aStream.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Snapshot,"writeNilDefinitionOn:",0
,function (aStream){var self=this;self.write_on_(unescape("var%20nil%20%3D%20new%20StUndefinedObject%28%29%3B"), aStream);
self.write_on_(unescape("nil.toString%20%3D%20")._comma(nil.toString.toString()), aStream);
self.write_on_(unescape("nil.isNil_%20%3D%20")._comma(nil["isNil_"].toString()), aStream);return self;}
,"writing",unescape("writeNilDefinitionOn%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20definition%20of%20nil%20object%20onto%20aStream.%20%22%0D%0A%0D%0A%09self%20write%3A%20%27var%20nil%20%3D%20new%20StUndefinedObject%28%29%3B%27%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27nil.toString%20%3D%20%27%2C%20nil%23toString%20toString%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27nil.isNil_%20%3D%20%27%2C%20nil%23isNil_%20toString%20on%3A%20aStream."));
smalltalk.bind(smalltalk.Snapshot,"writeSystemDefinitionOn:",0
,function (aStream){var self=this;self.write_on_(unescape("var%20smalltalk%20%3D%20new%20StSystemDictionary%28%29%3B"), aStream);
self.write_on_(unescape("smalltalk.toString%20%3D%20function%28%29%20%7B%20return%20%22smalltalk%22%3B%20%7D"), aStream);
self.write_on_(unescape("smalltalk.%24state%20%3D%20%22booting%22%3B"), aStream);
self.write_on_(unescape("smalltalk.OverwriteMethods%20%3D%20smalltalk.OverwriteMethods%20%7C%7C%20nil%3B"), aStream);
self.write_on_(unescape("smalltalk.DumpOverwritenMethods%20%3D%20smalltalk.DumpOverwritenMethods%20%7C%7C%20nil%3B"), aStream);return self;}
,"writing",unescape("writeSystemDefinitionOn%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20definition%20of%20smalltalk%20object%20onto%20aStream.%20%22%0D%0A%0D%0A%09self%20write%3A%20%27var%20smalltalk%20%3D%20new%20StSystemDictionary%28%29%3B%27%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27smalltalk.toString%20%3D%20function%28%29%20%7B%20return%20%22smalltalk%22%3B%20%7D%27%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27smalltalk.%24state%20%3D%20%22booting%22%3B%27%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27smalltalk.OverwriteMethods%20%3D%20smalltalk.OverwriteMethods%20%7C%7C%20nil%3B%27%20on%3A%20aStream.%0D%0A%09self%20write%3A%20%27smalltalk.DumpOverwritenMethods%20%3D%20smalltalk.DumpOverwritenMethods%20%7C%7C%20nil%3B%27%20on%3A%20aStream."));
smalltalk.bind(smalltalk.Snapshot,"write:mappingsOn:",0
,function (aCategory,aStream){var self=this;var mapped=nil;var mappings=nil;var done=nil;var register=nil;var row=nil;mapped=smalltalk.Smalltalk.current().classes().select_((function(each){return each.category()._eq(aCategory).and_((function(){return (nil.isNil_(each.constructorName())===false);}));}));
mappings=smalltalk.Array.$$new();
done=smalltalk.Array.$$new();
register=(function(aClass){return (((nil.isNil_(aClass)).or_((function(){return done.includes_(aClass);}))).mustBeBoolean()==true ? nil : (function(){register.value_(aClass.superclass());row=smalltalk.Array.with_(aClass.name());row.add_((((nil.isNil_(aClass.constructorName()))).mustBeBoolean()==true ? (function(){return "undefined";})() : (function(){return aClass.constructorName();})()));(((nil.isNil_(aClass.superclass())===false)).mustBeBoolean()==true ? (function(){return row.add_(aClass.superclass().name());})() : nil);mappings.add_(row);return done.add_(aClass);})());});
mapped.do_(register);
return self.write_mappings_on_(aCategory, mappings, aStream);;return self;}
,"writing",unescape("write%3A%20aCategory%20mappingsOn%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20mappings%20for%20system%20classes%20in%20aCategory%20onto%20aStream.%20%22%0D%0A%0D%0A%09%7C%20mapped%20mappings%20done%20register%20row%20%7C%0D%0A%09mapped%20%3A%3D%20Smalltalk%20current%20classes%20select%3A%20%5B%3Aeach%7C%0D%0A%09%09each%20category%20%3D%20aCategory%0D%0A%09%09and%3A%20%5B%20each%20constructorName%20notNil%20%5D%0D%0A%09%09%5D.%0D%0A%09mappings%20%3A%3D%20Array%20new.%0D%0A%09done%20%3A%3D%20Array%20new.%0D%0A%09register%20%3A%3D%20%5B%3AaClass%7C%0D%0A%09%09%28aClass%20isNil%20or%3A%20%5B%20done%20includes%3A%20aClass%20%5D%29%20ifFalse%3A%20%5B%0D%0A%09%09%09register%20value%3A%20aClass%20superclass.%0D%0A%09%09%09row%20%3A%3D%20Array%20with%3A%20aClass%20name.%0D%0A%09%09%09row%20add%3A%20%28aClass%20constructorName%20isNil%0D%0A%09%09%09%09ifTrue%3A%20%5B%20%23undefined%20%5D%0D%0A%09%09%09%09ifFalse%3A%20%5B%20aClass%20constructorName%20%5D%29.%0D%0A%09%09%09aClass%20superclass%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09%09row%20add%3A%20aClass%20superclass%20name.%0D%0A%09%09%09%5D.%0D%0A%09%09%09mappings%20add%3A%20row.%0D%0A%09%09%09done%20add%3A%20aClass.%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09mapped%20do%3A%20register.%0D%0A%09%5Eself%20write%3A%20aCategory%20mappings%3A%20mappings%20on%3A%20aStream"));
smalltalk.bind(smalltalk.Snapshot,"write:mappings:on:",0
,function (category,mappings,aStream){var self=this;var className=nil;var fn=nil;var superclass=nil;mappings.do_((function(tuple){className=tuple.first();fn=tuple.at_((2));superclass=((tuple.size()._eq((2))).mustBeBoolean()==true ? (function(){return "";})() : (function(){return unescape("%2Csmalltalk.")._comma(tuple.last());})());return self.write_on_(unescape("smalltalk.mapClassName%28")._comma(className.printString())._comma(unescape("%2C"))._comma(category.printString())._comma(unescape("%2C"))._comma(fn.asString())._comma(superclass)._comma(unescape("%29%3B")), aStream);}));return self;}
,"writing",unescape("write%3A%20category%20mappings%3A%20mappings%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20mappings%20onto%20aStream.%20%22%0D%0A%0D%0A%09%7C%20className%20fn%20superclass%20%7C%0D%0A%09mappings%20do%3A%20%5B%3Atuple%7C%0D%0A%09%09className%20%3A%3D%20tuple%20first.%0D%0A%09%09fn%20%3A%3D%20tuple%20at%3A%202.%0D%0A%09%09superclass%20%3A%3D%20tuple%20size%20%3D%202%20ifTrue%3A%20%5B%20%27%27%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20%27%2Csmalltalk.%27%2Ctuple%20last%20%5D.%20%0D%0A%09%09self%20write%3A%20%27smalltalk.mapClassName%28%27%0D%0A%09%09%09%09%2CclassName%20printString%2C%20%27%2C%27%0D%0A%09%09%09%09%2Ccategory%20printString%2C%20%27%2C%27%0D%0A%09%09%09%09%2Cfn%20asString%0D%0A%09%09%09%09%2Csuperclass%0D%0A%09%09%09%2C%27%29%3B%27%20on%3A%20aStream.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Snapshot,"writeImageContents:on:",0
,function (aSmalltalk,aStream){var self=this;var exporter=nil;var globals=nil;var classes=nil;exporter=self.exporterFor_(aSmalltalk);
globals=self.globalsIn_(aSmalltalk);
classes=self.classesToExportFrom_with_(aSmalltalk, exporter).collect_((function(each){return each.aboutToSaveImage_on_(self, aStream);})).select_((function(each){return (nil.isNil_(each)===false);}));
exporter.exportClasses_on_(classes, aStream);
self.exportGlobals_with_on_(globals, exporter, aStream);
classes.do_((function(each){return each.imageSaved_on_(self, aStream);}));return self;}
,"writing",unescape("writeImageContents%3A%20aSmalltalk%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Write%20the%20image%20section%20of%20aSmalltalk%20system%20onto%20aStream.%20%22%0D%0A%0D%0A%09%7C%20exporter%20globals%20classes%20%7C%0D%0A%09exporter%20%3A%3D%20self%20exporterFor%3A%20aSmalltalk.%0D%0A%09globals%20%3A%3D%20self%20globalsIn%3A%20aSmalltalk.%0D%0A%09classes%20%3A%3D%20%28%28self%20classesToExportFrom%3A%20aSmalltalk%20with%3A%20exporter%29%0D%0A%09%09collect%3A%20%5B%3Aeach%7C%20each%20aboutToSaveImage%3A%20self%20on%3A%20aStream%20%5D%29%0D%0A%09%09select%3A%20%5B%3Aeach%7C%20each%20notNil%20%5D.%0D%0A%22%09self%20exportGlobalNames%3A%20globals%20keys%20sorted%20in%3A%20aSmalltalk%20on%3A%20aStream.%0D%0A%22%09exporter%20exportClasses%3A%20classes%20on%3A%20aStream.%0D%0A%09self%20exportGlobals%3A%20globals%20with%3A%20exporter%20on%3A%20aStream.%0D%0A%09classes%20do%3A%20%5B%3Aeach%7C%20each%20imageSaved%3A%20self%20on%3A%20aStream%20%5D."));
smalltalk.bind(smalltalk.Snapshot,"exporterFor:",0
,function (aSmalltalk){var self=this;return smalltalk.Exporter.$$new();;return self;}
,"exporting",unescape("exporterFor%3A%20aSmalltalk%0D%0A%09%22%20Private%20-%20Return%20the%20exporter%20to%20use%20to%20write%20contents%20of%20aSmalltalk%20system.%20%22%0D%0A%0D%0A%09%5EExporter%20new"));
smalltalk.bind(smalltalk.Snapshot,"globalsIn:",0
,function (aSmalltalk){var self=this;var result=nil;result=smalltalk.PoolDictionary.$$new();
aSmalltalk.globalsDo_((function(key){return result.at_put_(key, ((function(){var $1$=aSmalltalk[key];if(nil.isNil_($1$))return nil;return $1$;})()));}));
return result;;return self;}
,"exporting",unescape("globalsIn%3A%20aSmalltalk%0D%0A%09%22%20Private%20-%20Return%20the%20globals%20defined%20in%20aSmalltalk%20system.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20PoolDictionary%20new.%0D%0A%09aSmalltalk%20globalsDo%3A%20%5B%3Akey%7C%20result%20at%3A%20key%20put%3A%20%28aSmalltalk%20basicAt%3A%20key%29%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Snapshot,"classesToExportFrom:with:",0
,function (aSmalltalk,exporter){var self=this;return aSmalltalk.classes().select_((function(each){return (nil.isNil_(each.superclass()));})).inject_into_(smalltalk.Array.$$new(), (function(total,each){return total._comma(each.withAllSubclasses());}));;return self;}
,"exporting",unescape("classesToExportFrom%3A%20aSmalltalk%20with%3A%20exporter%0D%0A%09%22%20Private%20-%20Return%20the%20classes%20to%20export%20from%20aSmalltalk%20system.%20%22%0D%0A%0D%0A%09%5E%28aSmalltalk%20classes%0D%0A%09%09select%3A%20%5B%3Aeach%7C%20each%20superclass%20isNil%20%5D%29%0D%0A%09%09inject%3A%20Array%20new%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%20%2C%20each%20withAllSubclasses%20%5D"));
smalltalk.bind(smalltalk.Snapshot,"exportGlobalNames:in:on:",0
,function (names,aSmalltalk,aStream){var self=this;names.do_separatedBy_((function(key){return aStream.nextPutAll_("smalltalk."._comma(key));}), (function(){return aStream.nextPutAll_(unescape("%20%2C%20"));}));
(function($rec){$rec.nextPutAll_(unescape("%3Dnil%3B"));return $rec.cr();})(aStream);return self;}
,"exporting",unescape("exportGlobalNames%3A%20names%20in%3A%20aSmalltalk%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Export%20global%20names%20in%20aSmalltalk%20system.%20%22%0D%0A%0D%0A%09names%0D%0A%09%09do%3A%20%5B%3Akey%7C%20aStream%20nextPutAll%3A%20%27smalltalk.%27%2Ckey%20%5D%0D%0A%09%09separatedBy%3A%20%5B%20aStream%20nextPutAll%3A%20%27%20%2C%20%27%20%5D.%0D%0A%09aStream%20nextPutAll%3A%20%27%3Dnil%3B%27%3B%20cr."));
smalltalk.bind(smalltalk.Snapshot,"exportGlobals:with:on:",0
,function (globals,exporter,aStream){var self=this;globals.associationsDo_((function(binding){return self.write_on_("smalltalk."._comma(binding.key())._comma(unescape("%3D"))._comma(exporter.exportObject_(binding.value()))._comma(unescape("%3B")), aStream);}));return self;}
,"exporting",unescape("exportGlobals%3A%20globals%20with%3A%20exporter%20on%3A%20aStream%0D%0A%09%22%20Private%20-%20Export%20global%20objects%20onto%20aStream.%20%22%0D%0A%0D%0A%22OBSOLETE%20-%09self%20write%3A%20%27smalltalk.initRoots%28%29%3B%27%20on%3A%20aStream.%22%0D%0A%09globals%20associationsDo%3A%20%5B%3Abinding%7C%0D%0A%09%09self%20write%3A%20%27smalltalk.%27%2Cbinding%20key%2C%27%3D%27%0D%0A%09%09%09%2C%28exporter%20exportObject%3A%20binding%20value%29%0D%0A%09%09%09%2C%27%3B%27%20on%3A%20aStream%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Transcript.$klass,"current",0
,function (){var self=this;(((nil.isNil_(smalltalk.Transcript.classVariableAt_("Current")))).mustBeBoolean()==true ? (function(){return self.current_(self.$$new());})() : nil);
return smalltalk.Transcript.classVariableAt_("Current");;return self;}
,"singleton",unescape("current%0D%0A%09Current%20isNil%20ifTrue%3A%20%5B%20self%20current%3A%20self%20new%20%5D.%0D%0A%09%5ECurrent"));
smalltalk.bind(smalltalk.Transcript.$klass,"current:",0
,function (aTranscript){var self=this;smalltalk.Transcript.classVariableAt_put_("Current",aTranscript);return self;}
,"singleton",unescape("current%3A%20aTranscript%0D%0A%09Current%20%3A%3D%20aTranscript"));
smalltalk.bind(smalltalk.Transcript.$klass,"cr",0
,function (){var self=this;return self.current().cr();;return self;}
,"io",unescape("cr%0D%0A%09%5Eself%20current%20cr"));
smalltalk.bind(smalltalk.Transcript.$klass,"nextPutAll:",0
,function (aString){var self=this;return self.current().nextPutAll_(aString);;return self;}
,"io",unescape("nextPutAll%3A%20aString%0D%0A%09%5Eself%20current%20nextPutAll%3A%20aString"));
smalltalk.bind(smalltalk.Transcript.$klass,"show:",0
,function (aString){var self=this;return self.current().show_(aString);;return self;}
,"io",unescape("show%3A%20aString%0D%0A%09%5Eself%20current%20show%3A%20aString"));
smalltalk.bind(smalltalk.Transcript,"cr",0
,function (){var self=this;self.stream().cr();return self;}
,"io",unescape("cr%0D%0A%09%22%20Put%20a%20line%20break%20sequence%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20stream%20cr"));
smalltalk.bind(smalltalk.Transcript,"nextPutAll:",0
,function (aCollection){var self=this;return self.stream().nextPutAll_(aCollection.asString());;return self;}
,"io",unescape("nextPutAll%3A%20aCollection%0D%0A%09%22%20Put%20aCollection%20onto%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20stream%20nextPutAll%3A%20aCollection%20asString"));
smalltalk.bind(smalltalk.Transcript,"show:",0
,function (aString){var self=this;self.stream().nextPutAll_(aString.asString());return self;}
,"io",unescape("show%3A%20aString%0D%0A%09self%20stream%20nextPutAll%3A%20aString%20asString."));
smalltalk.bind(smalltalk.Transcript,"flush",0
,function (){var self=this;self['@stream']=nil;return self;}
,"io",unescape("flush%0D%0A%09%22%20OBSOLETE%20-%20Flush%20the%20receiver.%20%22%0D%0A%0D%0A%09stream%20%3A%3D%20nil"));
smalltalk.bind(smalltalk.Transcript,"inUse",0
,function (){var self=this;return (nil.isNil_(self['@stream'])===false);;return self;}
,"query",unescape("inUse%0D%0A%09%5Estream%20notNil"));
smalltalk.bind(smalltalk.Transcript,"stream",0
,function (){var self=this;(((nil.isNil_(self['@stream']))).mustBeBoolean()==true ? (function(){return self['@stream']=smalltalk.String.$$new().stream();})() : nil);
return self['@stream'];;return self;}
,"accessing",unescape("stream%0D%0A%09stream%20isNil%20ifTrue%3A%20%5B%20stream%20%3A%3D%20String%20new%20stream%20%5D.%0D%0A%09%5Estream"));
smalltalk.bind(smalltalk.Transcript,"stream:",0
,function (aStream){var self=this;self['@stream']=aStream;return self;}
,"accessing",unescape("stream%3A%20aStream%0D%0A%09stream%20%3A%3D%20aStream"));
smalltalk.bind(smalltalk.NativeObject.$klass,"stMessageHeader:",0
,function (msgHeader){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=smalltalk.superImplementor(smalltalk.NativeObject.$klass,'stMessageHeader_').apply(self, [msgHeader]);
((result.first().isUppercase()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result.first().asLowercase()._comma(result.copyFrom_to_((2), result.size()));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("stMessageHeader%3A%20msgHeader%0D%0A%09%22%20Private%20-%20Return%20a%20message%20header%20string%20with%20nice%20smalltalk%20looking.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20super%20stMessageHeader%3A%20msgHeader.%0D%0A%09result%20first%20isUppercase%20ifTrue%3A%20%5B%0D%0A%09%09%5Eresult%20first%20asLowercase%0D%0A%09%09%09%2C%28result%20copyFrom%3A%202%20to%3A%20result%20size%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeObject.$klass,"jsNameFromSelector:",0
,function (aSymbol){var self=this;return aSymbol;;return self;}
,"builders",unescape("jsNameFromSelector%3A%20aSymbol%0D%0A%09%22%20Private%20-%20Return%20the%20property%20name%20for%20selector%20aSymbol.%20%22%0D%0A%0D%0A%09%5EaSymbol"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildGetterCode:",0
,function (aSelector){var $s8Ret$={name:"stReturn"};try{var self=this;((self.instanceVariableNames().includes_(aSelector)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.NativeObject.$klass,'buildGetterCode_').apply(self, [aSelector]);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return unescape("%5Eself%20handle%20basicAt%3A%20")._comma(self.jsNameFromSelector_(aSelector).asLiteral());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders-private",unescape("buildGetterCode%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20source%20code%20to%20get%20aSelector.%20%22%0D%0A%0D%0A%09%28self%20instanceVariableNames%20includes%3A%20aSelector%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Esuper%20buildGetterCode%3A%20aSelector%0D%0A%09%5D.%0D%0A%09%5E%27%5Eself%20handle%20basicAt%3A%20%27%20%2C%28self%20jsNameFromSelector%3A%20aSelector%29%20asLiteral"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildGetter:",0
,function (aSelector){var $s8Ret$={name:"stReturn"};try{var self=this;((aSelector.isString()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.buildTypedGetter_(aSelector);})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.NativeObject.$klass,'buildGetter_').apply(self, [aSelector]);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildGetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09aSelector%20isString%20ifFalse%3A%20%5B%20%5Eself%20buildTypedGetter%3A%20aSelector%20%5D.%0D%0A%09%5Esuper%20buildGetter%3A%20aSelector"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildSetterCode:",0
,function (aSelector){var $s8Ret$={name:"stReturn"};try{var self=this;((self.instanceVariableNames().includes_(aSelector)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.NativeObject.$klass,'buildSetterCode_').apply(self, [aSelector]);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return "self handle basicAt: "._comma(self.jsNameFromSelector_(aSelector).asLiteral())._comma(" put: anObject");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders-private",unescape("buildSetterCode%3A%20aSelector%0D%0A%09%22%20Private%20-%20Return%20source%20code%20to%20set%20aSelector.%20%22%0D%0A%0D%0A%09%28self%20instanceVariableNames%20includes%3A%20aSelector%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Esuper%20buildSetterCode%3A%20aSelector%0D%0A%09%5D.%0D%0A%09%5E%27self%20handle%20basicAt%3A%20%27%0D%0A%09%09%2C%28self%20jsNameFromSelector%3A%20aSelector%29%20asLiteral%0D%0A%09%09%2C%20%27%20put%3A%20anObject%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildSetter:",0
,function (aSelector){var $s8Ret$={name:"stReturn"};try{var self=this;((aSelector.isString()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.buildTypedSetter_(aSelector);})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.NativeObject.$klass,'buildSetter_').apply(self, [aSelector]);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildSetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20set%20native%20property.%20%22%0D%0A%0D%0A%09aSelector%20isString%20ifFalse%3A%20%5B%20%5Eself%20buildTypedSetter%3A%20aSelector%20%5D.%0D%0A%09%5Esuper%20buildSetter%3A%20aSelector"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildTypedGetter:",0
,function (tuple){var $s8Ret$={name:"stReturn"};try{var self=this;((tuple.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildGetter_(tuple);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("TypedGetter"._minus_gt(tuple), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(tuple.first()), "Return the "._comma(tuple.first())._comma(" of the receiver."), unescape("%5E")._comma(tuple.last())._comma(unescape("%20@%20%28self%20handle%20basicAt%3A%20"))._comma(self.jsNameFromSelector_(tuple.first()).asLiteral())._comma(unescape("%29")), "accessing");}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildTypedGetter%3A%20tuple%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20get%20property%20from%20spec%20array.%20%22%0D%0A%0D%0A%09tuple%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildGetter%3A%20tuple%20%5D.%0D%0A%09%5Eself%20build%3A%20%23TypedGetter%20-%3E%20tuple%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20tuple%20first%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2Ctuple%20first%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5E%27%09%2Ctuple%20last%0D%0A%09%09%09%09%2C%27%20@%20%28self%20handle%20basicAt%3A%20%27%0D%0A%09%09%09%09%2C%28self%20jsNameFromSelector%3A%20tuple%20first%29%20asLiteral%0D%0A%09%09%09%09%2C%27%29%27%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildTypedSetter:",0
,function (tuple){var $s8Ret$={name:"stReturn"};try{var self=this;((tuple.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildSetter_(tuple);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("TypedSetter"._minus_gt(tuple), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(tuple.first()._comma(": anObject")), "Set the "._comma(tuple.first())._comma(" of the receiver."), "self handle basicAt: "._comma(self.jsNameFromSelector_(tuple.first()).asLiteral())._comma(" put: anObject handle"), "accessing");}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildTypedSetter%3A%20tuple%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20set%20property%20to%20spec%20array.%20%22%0D%0A%0D%0A%09tuple%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildSetter%3A%20tuple%20%5D.%0D%0A%09%5Eself%20build%3A%20%23TypedSetter%20-%3E%20tuple%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20tuple%20first%20%2C%20%27%3A%20anObject%27%29%0D%0A%09%09%09comment%3A%20%27Set%20the%20%27%20%2Ctuple%20first%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27self%20handle%20basicAt%3A%20%27%0D%0A%09%09%09%09%2C%28self%20jsNameFromSelector%3A%20tuple%20first%29%20asLiteral%0D%0A%09%09%09%09%2C%27%20put%3A%20anObject%20handle%27%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildTypedGetters:",0
,function (specs){var self=this;return self.build_doing_("TypedGetters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildTypedGetter_(each));}));}));;return self;}
,"builders",unescape("buildTypedGetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20get%20properties.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23TypedGetters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildTypedGetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildTypedAccessors:",0
,function (tuples){var self=this;return self.build_doing_("TypedAccessors"._minus_gt(tuples), (function(){return tuples.inject_into_(" ", (function(total,each){return total._comma(self.buildTypedGetter_(each))._comma(self.buildTypedSetter_(each));}));}));;return self;}
,"builders",unescape("buildTypedAccessors%3A%20tuples%0D%0A%09%22%20Build%20%28instance%29%20methods%20to%20get/set%20property%20from/to%20tuples.%20%22%0D%0A%09%0D%0A%09%5Eself%20build%3A%20%23TypedAccessors%20-%3E%20tuples%20doing%3A%20%5B%0D%0A%09%09tuples%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09%09total%09%2C%28self%20buildTypedGetter%3A%20each%29%0D%0A%09%09%09%09%2C%28self%20buildTypedSetter%3A%20each%29%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFastGetter:",0
,function (aSelector){var self=this;var type=nil;var jsName=nil;((aSelector.isString()).mustBeBoolean()==true ? (function(){type="";return jsName=self.jsNameFromSelector_(aSelector);})() : (function(){type=aSelector.last();return jsName=self.jsNameFromSelector_(aSelector.first());})());
return self.build_doing_("FastGetter"._minus_gt(aSelector), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), unescape("%5E")._comma(type)._comma(unescape("handle%23"))._comma(jsName), "accessing");}));;return self;}
,"builders",unescape("buildFastGetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09%7C%20type%20jsName%20%7C%0D%0A%09aSelector%20isString%0D%0A%09%09ifTrue%3A%20%5B%20type%20%3A%3D%20%27%27.%20jsName%20%3A%3D%20self%20jsNameFromSelector%3A%20aSelector%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20type%20%3A%3D%20aSelector%20last.%20jsName%20%3A%3D%20self%20jsNameFromSelector%3A%20aSelector%20first%20%5D.%0D%0A%09%5Eself%20build%3A%20%23FastGetter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5E%27%20%2Ctype%20%2C%27handle%23%27%20%2CjsName%20category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFastSetter:",0
,function (aSelector){var self=this;var jsName=nil;((aSelector.isString()).mustBeBoolean()==true ? (function(){return jsName=self.jsNameFromSelector_(aSelector);})() : (function(){return jsName=self.jsNameFromSelector_(aSelector.first());})());
return self.build_doing_("FastSetter"._minus_gt(aSelector), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector)._comma(": anObject"), "Set the "._comma(aSelector)._comma(" of the receiver."), unescape("handle%23")._comma(jsName)._comma(unescape("%20%3A%3D%20anObject")), "accessing");}));;return self;}
,"builders",unescape("buildFastSetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20set%20native%20property.%20%22%0D%0A%0D%0A%09%7C%20jsName%20%7C%0D%0A%09aSelector%20isString%0D%0A%09%09ifTrue%3A%20%5B%20jsName%20%3A%3D%20self%20jsNameFromSelector%3A%20aSelector%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20jsName%20%3A%3D%20self%20jsNameFromSelector%3A%20aSelector%20first%20%5D.%0D%0A%09%5Eself%20build%3A%20%23FastSetter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%20%2C%27%3A%20anObject%27%0D%0A%09%09%09comment%3A%20%27Set%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27handle%23%27%20%2CjsName%20%2C%27%20%3A%3D%20anObject%27%20category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFastAccessor:",0
,function (accessor){var $s8Ret$={name:"stReturn"};try{var self=this;((accessor.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.build_doing_("FastAccessor"._minus_gt(accessor), (function(){return self.buildFastGetter_(accessor)._comma(self.buildFastSetter_(accessor));}));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20%28Fast%29accessors."));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildFastAccessor%3A%20accessor%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20access%20native%20property.%20%22%0D%0A%0D%0A%09accessor%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20build%3A%20%23FastAccessor%20-%3E%20accessor%20doing%3A%20%5B%0D%0A%09%09%09%28self%20buildFastGetter%3A%20accessor%29%0D%0A%09%09%09%2C%28self%20buildFastSetter%3A%20accessor%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20%28Fast%29accessors.%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFastGetters:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildFastGetters_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("FastGetters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildFastGetter_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildFastGetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20get%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildFastGetters%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23FastGetters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildFastGetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFastAccessors:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildFastAccessors_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("FastAccessors"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildFastAccessor_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildFastAccessors%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20access%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildFastAccessors%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23FastAccessors%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildFastAccessor%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildNumberGetter:",0
,function (aSelector){var self=this;return self.build_doing_("NumberGetter"._minus_gt(aSelector), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), unescape("%5Ehandle%23")._comma(self.jsNameFromSelector_(aSelector))._comma(unescape("%20%7C%7C%200")), "accessing");}));;return self;}
,"builders",unescape("buildNumberGetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23NumberGetter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5Ehandle%23%27%20%2C%28self%20jsNameFromSelector%3A%20aSelector%29%20%2C%27%20%7C%7C%200%27%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildNumberAccessor:",0
,function (accessor){var $s8Ret$={name:"stReturn"};try{var self=this;((accessor.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.build_doing_("NumberAccessor"._minus_gt(accessor), (function(){return self.buildNumberGetter_(accessor)._comma(self.buildSetter_(accessor));}));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20%28Number%29accessors."));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildNumberAccessor%3A%20accessor%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20access%20native%20property.%20%22%0D%0A%0D%0A%09accessor%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20build%3A%20%23NumberAccessor%20-%3E%20accessor%20doing%3A%20%5B%0D%0A%09%09%09%28self%20buildNumberGetter%3A%20accessor%29%0D%0A%09%09%09%2C%28self%20buildSetter%3A%20accessor%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20%28Number%29accessors.%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildNumberGetters:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildNumberGetters_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("NumberGetters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildNumberGetter_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildNumberGetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20get%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildNumberGetters%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23NumberGetters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildNumberGetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildNumberAccessors:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildNumberAccessors_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("NumberAccessors"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildNumberAccessor_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildNumberAccessors%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20access%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildNumberAccessors%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23NumberAccessors%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildNumberAccessor%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildBooleanGetter:",0
,function (aSelector){var self=this;return self.build_doing_("BooleanGetter"._minus_gt(aSelector), (function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), unescape("%5Etrue%20%3D%3D%20handle%23")._comma(self.jsNameFromSelector_(aSelector)), "accessing");}));;return self;}
,"builders",unescape("buildBooleanGetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23BooleanGetter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5Etrue%20%3D%3D%20handle%23%27%20%2C%28self%20jsNameFromSelector%3A%20aSelector%29%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildBooleanAccessor:",0
,function (accessor){var $s8Ret$={name:"stReturn"};try{var self=this;((accessor.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.build_doing_("BooleanAccessor"._minus_gt(accessor), (function(){return self.buildBooleanGetter_(accessor)._comma(self.buildSetter_(accessor));}));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20%28Boolean%29accessors."));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildBooleanAccessor%3A%20accessor%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20access%20native%20property.%20%22%0D%0A%0D%0A%09accessor%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20build%3A%20%23BooleanAccessor%20-%3E%20accessor%20doing%3A%20%5B%0D%0A%09%09%09%28self%20buildBooleanGetter%3A%20accessor%29%0D%0A%09%09%09%2C%28self%20buildSetter%3A%20accessor%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20%28Boolean%29accessors.%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildBooleanGetters:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildBooleanGetters_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("BooleanGetters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildBooleanGetter_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildBooleanGetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20get%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildBooleanGetters%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23BooleanGetters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildBooleanGetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildBooleanAccessors:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildBooleanAccessors_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("BooleanAccessors"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildBooleanAccessor_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildBooleanAccessors%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20access%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildBooleanAccessors%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23BooleanAccessors%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildBooleanAccessor%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildIsBooleanGetter:",0
,function (aSelector){var self=this;return self.build_doing_("IsBooleanGetter"._minus_gt(aSelector), (function(){var isSelector=nil;isSelector="is"._comma(aSelector.asGlobalName());return self.implement_comment_as_category_(self.stMessageHeader_(isSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), unescape("%5Etrue%20%3D%3D%20handle%23")._comma(self.jsNameFromSelector_(isSelector)), "accessing");}));;return self;}
,"builders",unescape("buildIsBooleanGetter%3A%20aSelector%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23IsBooleanGetter%20-%3E%20aSelector%20doing%3A%20%5B%20%7C%20isSelector%20%7C%0D%0A%09%09isSelector%20%3A%3D%20%20%23is%20%2CaSelector%20asGlobalName.%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20isSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5Etrue%20%3D%3D%20handle%23%27%20%2C%28self%20jsNameFromSelector%3A%20isSelector%29%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildIsBooleanAccessor:",0
,function (accessor){var $s8Ret$={name:"stReturn"};try{var self=this;((accessor.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.build_doing_("IsBooleanAccessor"._minus_gt(accessor), (function(){return self.buildIsBooleanGetter_(accessor)._comma(self.buildSetter_(accessor));}));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20%28IsBoolean%29accessors."));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildIsBooleanAccessor%3A%20accessor%0D%0A%09%22%20Build%20%28instance%29%20method%20to%20access%20native%20property.%20%22%0D%0A%0D%0A%09accessor%20isString%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20build%3A%20%23IsBooleanAccessor%20-%3E%20accessor%20doing%3A%20%5B%0D%0A%09%09%09%28self%20buildIsBooleanGetter%3A%20accessor%29%0D%0A%09%09%09%2C%28self%20buildSetter%3A%20accessor%29%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20%28IsBoolean%29accessors.%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildIsBooleanGetters:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildIsBooleanGetters_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("IsBooleanGetters"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildIsBooleanGetter_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildIsBooleanGetters%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20get%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildIsBooleanGetters%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23IsBooleanGetters%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildIsBooleanGetter%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildIsBooleanAccessors:",0
,function (specs){var $s8Ret$={name:"stReturn"};try{var self=this;((specs.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildIsBooleanAccessors_(specs.asArrayOfSubstrings());})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.build_doing_("IsBooleanAccessors"._minus_gt(specs), (function(){return specs.inject_into_(" ", (function(total,each){return total._comma(self.buildIsBooleanAccessor_(each));}));}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildIsBooleanAccessors%3A%20specs%0D%0A%09%22%20Build%20methods%20to%20access%20properties.%20%22%0D%0A%0D%0A%09specs%20isString%20ifTrue%3A%20%5B%20%5Eself%20buildIsBooleanAccessors%3A%20specs%20asArrayOfSubstrings%20%5D.%0D%0A%09%5Eself%20build%3A%20%23IsBooleanAccessors%20-%3E%20specs%20doing%3A%20%5B%0D%0A%09%09specs%20inject%3A%20%27%20%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%20%28self%20buildIsBooleanAccessor%3A%20each%29%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildSubclasses:",0
,function (aCollection){var self=this;var result=nil;aCollection.do_((function(tuple){return result=((tuple.isString()).mustBeBoolean()==true ? (function(){return self.buildSubclass_arguments_typed_(tuple, [], []);})() : (function(){return ((tuple.size()._eq((2))).mustBeBoolean()==true ? (function(){return self.buildSubclass_arguments_typed_(tuple.first(), tuple.second(), []);})() : (function(){return self.buildSubclass_arguments_typed_(tuple.first(), tuple.second(), tuple.last());})());})());}));
return result;;return self;}
,"builder",unescape("buildSubclasses%3A%20aCollection%0D%0A%09%22%20Private%20-%20Build%20aCollection%20of%20subclasses%20of%20the%20receiver%20as%20wrappers%20to%20the%20library.%0D%0A%09Return%20the%20last%20class%20created%20%28or%20nil%29.%0D%0A%09%22%0D%0A%20%0D%0A%09%7C%20result%20%7C%0D%0A%09aCollection%20do%3A%20%5B%3Atuple%7C%0D%0A%09%09result%20%3A%3D%20tuple%20isString%0D%0A%09%09ifTrue%3A%20%5B%20self%20buildSubclass%3A%20tuple%20arguments%3A%20%23%28%29%20typed%3A%20%23%28%29%20%5D%0D%0A%09%09ifFalse%3A%20%5B%0D%0A%09%09%09tuple%20size%20%3D%202%0D%0A%09%09%09ifTrue%3A%20%5B%20self%20buildSubclass%3A%20tuple%20first%20arguments%3A%20tuple%20second%20typed%3A%20%23%28%29%20%5D%0D%0A%09%09%09ifFalse%3A%20%5B%20self%20buildSubclass%3A%20tuple%20first%20arguments%3A%20tuple%20second%20typed%3A%20tuple%20last%20%5D%0D%0A%09%09%20%5D%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildHierarchy:",0
,function (aCollection){var self=this;var stream=nil;var aClass=nil;stream=aCollection.stream();
(function(){while(!(function(){return stream.atEnd();})()){(function(){aClass=self.buildSubclasses_(smalltalk.Array.with_(stream.next()));return ((stream.peek().isArray()).mustBeBoolean()==true ? (function(){return aClass.buildHierarchy_(stream.next());})() : nil);})()};return nil})();return self;}
,"builder",unescape("buildHierarchy%3A%20aCollection%0D%0A%09%22%20Private%20-%20Build%20aCollection%20of%20subclasses%20of%20the%20receiver%20as%20wrappers%20to%20the%20library.%20%22%0D%0A%20%0D%0A%09%7C%20stream%20aClass%20%7C%0D%0A%09stream%20%3A%3D%20aCollection%20stream.%0D%0A%09%5B%20stream%20atEnd%20%5D%20whileFalse%3A%20%5B%0D%0A%09%09aClass%20%3A%3D%20self%20buildSubclasses%3A%20%28Array%20with%3A%20stream%20next%29.%0D%0A%09%09stream%20peek%20isArray%20ifTrue%3A%20%5B%0D%0A%09%09%09aClass%20buildHierarchy%3A%20stream%20next%0D%0A%09%09%5D.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildSubclass:arguments:typed:",0
,function (globalClassName,argList,typedArguments){var self=this;var cls=nil;var clsName=nil;clsName=globalClassName.first().asUppercase()._comma(globalClassName.copyFrom_to_((2), globalClassName.size()));
clsName=self.classToken()._comma(clsName);
self.subclass_instanceVariableNames_category_(clsName, "", self.category());
return smalltalk.Smalltalk.at_(clsName);;return self;}
,"builder",unescape("buildSubclass%3A%20globalClassName%20arguments%3A%20argList%20typed%3A%20typedArguments%0D%0A%09%22%20Private%20-%20Build%20a%20subclass%20of%20the%20receiver%20implementing%20a%20wrapper%20to%20the%20library.%0D%0A%09Note%3A%20argList%20and%20typed%20arguments%20are%20ignored%3B%20see%20subclasses%20to%20find%20concrete%20implementors.%0D%0A%09Return%20the%20created%20class.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20cls%20clsName%20%7C%0D%0A%09clsName%20%3A%3D%20globalClassName%20first%20asUppercase%0D%0A%09%09%09%2C%28globalClassName%20copyFrom%3A%202%20to%3A%20globalClassName%20size%29.%0D%0A%09clsName%20%3A%3D%20self%20classToken%20%2CclsName.%0D%0A%09self%0D%0A%09%09subclass%3A%20clsName%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09category%3A%20self%20category.%0D%0A%09%5ESmalltalk%20at%3A%20clsName"));
smalltalk.bind(smalltalk.NativeObject.$klass,"classToken",0
,function (){var self=this;return "";;return self;}
,"builder",unescape("classToken%0D%0A%09%22%20Private%20-%20Return%20the%20classToken%20to%20prepend/tag%20the%20receiver.%0D%0A%09The%20default%20answer%20is%20empty.%0D%0A%09The%20subclasses%20can%20subclass%20to%20build%20tagged%20subclasses.%0D%0A%09%22%0D%0A%0D%0A%09%5E%27%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"classToken:",0
,function (aToken){var self=this;return self.buildClassToken_(aToken);;return self;}
,"builder",unescape("classToken%3A%20aToken%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20return%20the%20classToken%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20buildClassToken%3A%20aToken"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildClassToken:",0
,function (aToken){var self=this;self.build_doing_("ClassToken"._minus_gt(aToken), (function(){return self.implement_comment_as_category_("classToken", unescape("Private%20-%20Return%20the%20classToken%20to%20prepend/tag%20the%20receiver."), unescape("%5E")._comma(aToken.asLiteral()), "builder");}));return self;}
,"builder",unescape("buildClassToken%3A%20aToken%0D%0A%09%22%20Generate%20code%20to%20return%20the%20classToken%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20build%3A%20%23ClassToken%20-%3E%20aToken%20doing%3A%20%5B%0D%0A%09%09self%0D%0A%09%09%09implement%3A%20%23classToken%0D%0A%09%09%09comment%3A%20%27Private%20-%20Return%20the%20classToken%20to%20prepend/tag%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%24%5E%20%2CaToken%20asLiteral%0D%0A%09%09%09category%3A%20%23builder%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFunctions:",0
,function (selectors){var self=this;self.build_doing_("Functions"._minus_gt(selectors), (function(){return selectors.do_((function(each){return self.buildFunction_(each);}));}));return self;}
,"builders",unescape("buildFunctions%3A%20selectors%0D%0A%09%22%20Generate%20code%20to%20delegate%20selectors%20as%20functions%20implemented%20by%20instance%20handle.%20%22%0D%0A%0D%0A%09self%20build%3A%20%23Functions%20-%3E%20selectors%20doing%3A%20%5B%0D%0A%09%09selectors%20do%3A%20%5B%3Aeach%7C%20self%20buildFunction%3A%20each%20%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFunction:",0
,function (selector){var $s8Ret$={name:"stReturn"};try{var self=this;((selector.isArray()).mustBeBoolean()==true ? (function(){((selector.size()._eq((3)).and_((function(){return selector.last().isString();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildFunction_(smalltalk.Array.with_with_(smalltalk.Array.with_with_(selector.first(), selector.second()), selector.last()));})();throw($s8Ret$)})();})() : nil);return ((selector.size()._eq((2)).and_((function(){return selector.last().isString();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildFunction_prologue_epilogue_(selector.first(), selector.second()._comma(unescape("%20@%20%28")), unescape("%29"));})();throw($s8Ret$)})();})() : nil);})() : nil);
(function(){$s8Ret$.result=(function(){return self.buildFunction_prologue_epilogue_(selector, "", "");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildFunction%3A%20selector%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20delegate%20message%20implemented%20as%20functions%20on%20instance%20handle.%0D%0A%09selector%20can%20be%3A%0D%0A%09%09aSymbol%20%28e.g.%20any%20smalltalk%20message%20selector%29%0D%0A%09%09%23%28%20selector%20%23ReturnClassName%20%29%0D%0A%09%09%23%28%20selector%20%23%28%20argumentNames%20%29%20%23ReturnClassName%20%29%0D%0A%09%09%23%28%20%23%28%20selector%20%23%28%20argumentNames%20%29%20%29%20%23ReturnClassName%20%29%0D%0A%09%09%23%28%20selector%20%23%28%20argumentNames%20%29%20%29%0D%0A%09argumentNames%20must%20match%20selector%20pattern%0D%0A%09if%20argumentNames%20is%20not%20given%2C%20it%20will%20be%20computed%20from%20selector%20pattern%0D%0A%09The%20function%20will%20return%20the%20result%20of%20calling%20the%20handle%2C%20wrapped%20to%20an%20instance%20of%20ReturnClassName%0D%0A%09%20%28expected%20to%20be%20subclass%20of%20NativeObject%20or%20something%20global%20implementing%20%23@%29.%0D%0A%09%22%0D%0A%0D%0A%09selector%20isArray%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20%28selector%20size%20%3D%203%20and%3A%20%5Bselector%20last%20isString%5D%29%20ifTrue%3A%20%5B%20%22%23%28%20selector%20%23%28%20argumentNames%20%29%20%23RETURNClass%20%29%22%0D%0A%09%09%5Eself%20buildFunction%3A%20%28Array%0D%0A%09%09%09with%3A%20%28Array%20with%3A%20selector%20first%20with%3A%20selector%20second%29%0D%0A%09%09%09with%3A%20selector%20last%29%0D%0A%09%20%20%20%20%5D.%20%0D%0A%09%20%20%20%20%28selector%20size%20%3D%202%20and%3A%20%5Bselector%20last%20isString%5D%29%20ifTrue%3A%20%5B%20%22%23%28%20selector%20%23RETURNClass%20%29%22%0D%0A%09%09%5Eself%0D%0A%09%09%09buildFunction%3A%20selector%20first%0D%0A%09%09%09prologue%3A%20selector%20second%20%2C%27%20@%20%28%27%0D%0A%09%09%09epilogue%3A%20%27%29%27%0D%0A%09%20%20%20%20%5D.%20%0D%0A%09%5D.%0D%0A%09%5Eself%20buildFunction%3A%20selector%20prologue%3A%20%27%27%20epilogue%3A%20%27%27"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFunction:prologue:epilogue:",0
,function (selector,prologue,epilogue){var $s8Ret$={name:"stReturn"};try{var self=this;var args=nil;((selector.isArray()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildFunction_arguments_prologue_epilogue_(selector.first(), selector.last(), prologue, epilogue);})();throw($s8Ret$)})();})() : nil);
args=(1).to_(selector.occurrencesOf_(":")).collect_((function(i){return "arg"._comma(i.asString());}));
((args.size()._eq((1))).mustBeBoolean()==true ? (function(){return args=["anObject"];})() : nil);
(function(){$s8Ret$.result=(function(){return self.buildFunction_arguments_prologue_epilogue_(selector, args, prologue, epilogue);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builders",unescape("buildFunction%3A%20selector%20prologue%3A%20prologue%20epilogue%3A%20epilogue%20%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20delegate%20message%20on%20instance%20handle.%20%22%0D%0A%0D%0A%09%7C%20args%20%7C%0D%0A%09selector%20isArray%20ifTrue%3A%20%5B%20%22%23%28%20selector%20%23%28argumentNames%29%20%29%22%0D%0A%09%09%5Eself%09buildFunction%3A%20selector%20first%0D%0A%09%09%09arguments%3A%20selector%20last%0D%0A%09%09%09prologue%3A%20prologue%20epilogue%3A%20epilogue%0D%0A%09%5D.%0D%0A%09args%20%3A%3D%20%20%281%20to%3A%20%28selector%20occurrencesOf%3A%20%24%3A%29%29%20collect%3A%20%5B%3Ai%7C%20%23arg%20%2C%20i%20asString%20%5D.%0D%0A%09args%20size%20%3D%201%20ifTrue%3A%20%5B%20args%20%3A%3D%20%23%28%20%23anObject%20%29%20%5D.%0D%0A%09%5Eself%0D%0A%09%09buildFunction%3A%20selector%20arguments%3A%20args%0D%0A%09%09prologue%3A%20prologue%20epilogue%3A%20epilogue%20"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildFunction:arguments:prologue:epilogue:",0
,function (selector,args,prologue,epilogue){var self=this;var header=nil;var code=nil;var input=nil;var argStream=nil;var msg=nil;input=selector.stream();
argStream=args.stream();
header="".stream();
code="".stream();
code.nextPut_(input.peek());
header.nextPut_(input.next().asLowercase());
(function(){while(!(function(){return argStream.atEnd();})()){(function(){var param=nil;var expr=nil;((argStream.peek().isString()).mustBeBoolean()==true ? (function(){param=argStream.next();return expr=param;})() : (function(){param=argStream.peek().first();return expr=param._comma(" ")._comma(argStream.next().last());})());msg=input.upTo_(":")._comma(": ");code.nextPutAll_(msg._comma(expr)._comma(" "));return header.nextPutAll_(msg._comma(param)._comma(" "));})()};return nil})();
msg=input.upToEnd();
code.nextPutAll_(msg);
header.nextPutAll_(msg);
self.implement_comment_as_category_(self.stMessageHeader_(header.contents()), unescape("Delegate%20%23")._comma(selector)._comma(" to handle."), unescape("%5E")._comma(prologue)._comma(unescape("self%20handle%20%23"))._comma(code.contents())._comma(epilogue), "wrappers");return self;}
,"builders",unescape("buildFunction%3A%20selector%20arguments%3A%20args%20prologue%3A%20prologue%20epilogue%3A%20epilogue%20%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20delegate%20message%20on%20instance%20handle.%20%22%0D%0A%0D%0A%09%7C%20header%20code%20input%20argStream%20msg%20%7C%0D%0A%09input%20%3A%3D%20selector%20stream.%0D%0A%09argStream%20%3A%3D%20args%20stream.%0D%0A%09header%20%3A%3D%20%27%27%20stream.%20code%20%3A%3D%20%27%27%20stream.%0D%0A%09code%20%20%20nextPut%3A%20input%20peek.%0D%0A%09header%20nextPut%3A%20input%20next%20asLowercase.%0D%0A%09%5B%20argStream%20atEnd%20%5D%20whileFalse%3A%20%5B%20%7C%20param%20expr%20%7C%0D%0A%09%09argStream%20peek%20isString%0D%0A%09%09ifTrue%3A%20%5B%20param%20%3A%3D%20argStream%20next.%20expr%20%3A%3D%20param%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20param%20%3A%3D%20argStream%20peek%20first.%20expr%20%3A%3D%20param%20%2C%27%20%27%20%2CargStream%20next%20last.%20%5D.%0D%0A%09%09msg%20%3A%3D%20%28input%20upTo%3A%20%24%3A%29%20%2C%27%3A%20%27.%0D%0A%09%09code%20%20%20nextPutAll%3A%20msg%2C%20expr%20%2C%27%20%27.%0D%0A%09%09header%20nextPutAll%3A%20msg%2C%20param%20%2C%27%20%27.%0D%0A%09%5D.%0D%0A%09msg%20%3A%3D%20input%20upToEnd.%0D%0A%09code%20%20%20nextPutAll%3A%20msg.%0D%0A%09header%20nextPutAll%3A%20msg.%0D%0A%0D%0A%09self%0D%0A%09%09implement%3A%20%28self%20stMessageHeader%3A%20header%20contents%29%0D%0A%09%09%20%20comment%3A%20%27Delegate%20%23%27%2Cselector%2C%27%20to%20handle.%27%0D%0A%09%09%20%20as%3A%20%27%5E%27%0D%0A%09%09%09%2C%20prologue%0D%0A%09%09%09%2C%27self%20handle%20%23%27%2Ccode%20contents%0D%0A%09%09%09%2C%20epilogue%0D%0A%09%09%20%20category%3A%20%23wrappers"));
smalltalk.bind(smalltalk.NativeObject.$klass,"@","_at"
,function (handle){var self=this;return self.basicNew().handle_(handle);;return self;}
,"instantiation",unescape("@%20handle%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20handle%3A%20handle"));
smalltalk.bind(smalltalk.NativeObject.$klass,"empty",0
,function (){var self=this;return self._at(smalltalk.Object.$$new().json());;return self;}
,"instantiation",unescape("empty%0D%0A%09%22%20Return%20an%20empty%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20@%20Object%20new%20json"));
smalltalk.bind(smalltalk.NativeObject.$klass,"for:",0
,function (handle){var self=this;return self.basicNew().handle_(handle);;return self;}
,"instantiation",unescape("for%3A%20handle%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicNew%20handle%3A%20handle"));
smalltalk.bind(smalltalk.NativeObject.$klass,"html5Events",0
,function (){var self=this;return [];;return self;}
,"events",unescape("html5Events%0D%0A%09%22%20Private%20-%20Return%20the%20html5%20events+notifications%20managed%20by%20instances%20of%20the%20receiver.%0D%0A%09Default%20answer%20is%20empty%2C%20this%20method%20can%20be%20refined%20by%20subclasses%20to%20handle%20html5%20events.%0D%0A%09%22%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.NativeObject.$klass,"localEvents",0
,function (){var self=this;return [];;return self;}
,"events",unescape("localEvents%0D%0A%09%22%20Private%20-%20Return%20the%20smalltalk%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.NativeObject.$klass,"constructEventsTriggered",0
,function (){var self=this;return self.html5Events()._comma(self.localEvents())._comma(smalltalk.superImplementor(smalltalk.NativeObject.$klass,'constructEventsTriggered').apply(self, []));;return self;}
,"events",unescape("constructEventsTriggered%0D%0A%09%22%20Private%20-%20Return%20the%20events%20managed%20by%20instances%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20html5Events%0D%0A%09%2Cself%20localEvents%0D%0A%09%2Csuper%20constructEventsTriggered"));
smalltalk.bind(smalltalk.NativeObject.$klass,"buildHTML5Events:",0
,function (selectors){var self=this;self.build_doing_("HTML5Events"._minus_gt(selectors), (function(){self.$klass.implement_comment_as_category_("html5Events", unescape("Private%20-%20Return%20the%20html5%20events%20managed%20by%20instances%20of%20the%20receiver."), unescape("%5E%23%28%20")._comma(selectors.inject_into_("", (function(total,each){return total._comma(unescape("%23"))._comma(each)._comma(" ");})))._comma(unescape("%29%20%2C%20super%20html5Events")), "events");return self.buildGetters_(selectors.collect_((function(each){return self.selectorForHTML5Event_(each);})));}));return self;}
,"builder",unescape("buildHTML5Events%3A%20selectors%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20route%20events%20to%20handle.%20%22%0D%0A%0D%0A%09self%20build%3A%20%23HTML5Events%20-%3E%20selectors%20doing%3A%20%5B%0D%0A%09%09self%20class%0D%0A%09%09%09implement%3A%20%23html5Events%0D%0A%09%09%09comment%3A%20%27Private%20-%20Return%20the%20html5%20events%20managed%20by%20instances%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5E%23%28%20%27%20%2C%28selectors%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09%09%09total%20%2C%27%23%27%2Ceach%20%2C%27%20%27%0D%0A%09%09%09%09%5D%29%2C%27%29%20%2C%20super%20html5Events%27%0D%0A%09%09%09category%3A%20%23events.%0D%0A%09%09self%20buildGetters%3A%20%28selectors%20collect%3A%20%5B%3Aeach%7C%0D%0A%09%09%09self%20selectorForHTML5Event%3A%20each%0D%0A%09%09%5D%29.%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"selectorForEvent:",0
,function (anEvent){var $s8Ret$={name:"stReturn"};try{var self=this;((self.localEvents().includes_(anEvent)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return ((self.html5Events().includes_(anEvent)).mustBeBoolean()==true ? (function(){return self.selectorForHTML5Event_(anEvent);})() : nil);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("selectorForEvent%3A%20anEvent%0D%0A%09%22%20Private%20-%20Return%20the%20on...%20selector%20to%20use%20to%20register%20binding%20to%20anEvent.%20%22%0D%0A%0D%0A%09%28self%20localEvents%20includes%3A%20anEvent%29%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%5E%28self%20html5Events%20includes%3A%20anEvent%29%20ifTrue%3A%20%5B%0D%0A%09%09self%20selectorForHTML5Event%3A%20anEvent%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject.$klass,"selectorForHTML5Event:",0
,function (anEvent){var self=this;return "on"._comma(anEvent.upTo_(":").asSmalltalkName_(true));;return self;}
,"events",unescape("selectorForHTML5Event%3A%20anEvent%0D%0A%09%22%20Private%20-%20Return%20the%20on...%20selector%20to%20use%20to%20register%20binding%20to%20anEvent.%20%22%0D%0A%0D%0A%09%5E%23on%20%2C%20%28%28anEvent%20upTo%3A%20%24%3A%29%20asSmalltalkName%3A%20true%29"));
smalltalk.bind(smalltalk.NativeObject,"as:",0
,function (aNativeObjectClass){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;((smalltalk.is_kindOf_(self,(aNativeObjectClass))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
result=aNativeObjectClass._at(self.handle());
(((result === self)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
result.copyPropertiesFrom_(self);
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("as%3A%20aNativeObjectClass%0D%0A%09%22%20Return%20the%20receiver%20casted%20to%20aNativeObjectClass.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09%28self%20isKindOf%3A%20aNativeObjectClass%29%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09result%20%3A%3D%20aNativeObjectClass%20@%20self%20handle.%0D%0A%09result%20%3D%3D%20self%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09result%20copyPropertiesFrom%3A%20self.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeObject,"handle",0
,function (){var self=this;(((nil.isNil_(self['@handle']))).mustBeBoolean()==true ? (function(){return self.initializeHandle();})() : nil);
return self['@handle'];;return self;}
,"accessing",unescape("handle%0D%0A%09%22%20Return%20the%20native%20handle.%20%22%0D%0A%0D%0A%09handle%20isNil%20ifTrue%3A%20%5B%20self%20initializeHandle%20%5D.%0D%0A%09%5Ehandle"));
smalltalk.bind(smalltalk.NativeObject,"handleOrNil",0
,function (){var self=this;return self['@handle'];;return self;}
,"private",unescape("handleOrNil%0D%0A%09%22%20Return%20the%20native%20handle%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%5Ehandle"));
smalltalk.bind(smalltalk.NativeObject,"=","_eq"
,function (anObject){var $s8Ret$={name:"stReturn"};try{var self=this;(((self === anObject)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
((self.isObject_(anObject)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return smalltalk.responds_to_(anObject,("handleOrNil")).and_((function(){return (self['@handle'] === anObject.handleOrNil());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("%3D%20anObject%0D%0A%0D%0A%09self%20%3D%3D%20anObject%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%0D%0A%09%28self%20isObject%3A%20anObject%29%20ifFalse%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5E%28anObject%20respondsTo%3A%20%23handleOrNil%29%20and%3A%20%5B%0D%0A%09%09handle%20%3D%3D%20anObject%20handleOrNil%0D%0A%09%5D%20"));
smalltalk.bind(smalltalk.NativeObject,"handle:",0
,function (anAlien){var $s8Ret$={name:"stReturn"};try{var self=this;self['@handle']=anAlien;
(((nil.isNil_(self['@handle']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("handle%3A%20anAlien%0D%0A%09%22%20Set%20the%20native%20handle%20to%20a%20potentialy%20non-StObject.%0D%0A%09Return%20the%20receiver%2C%20or%20nil%20if%20the%20receiver%20is%20void.%0D%0A%09%22%0D%0A%0D%0A%09handle%20%3A%3D%20anAlien.%0D%0A%09handle%20isNil%20ifTrue%3A%20%5B%20%5Enil%20%5D."));
smalltalk.bind(smalltalk.NativeObject,"jsonHiddenNames",0
,function (){var self=this;return ["handle"];;return self;}
,"converting",unescape("jsonHiddenNames%0D%0A%09%22%20Private%20-%20Return%20the%20names%20of%20the%20instance%20variables%20to%20skip%20when%20mapping%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5E%23%28%20%23handle%20%29"));
smalltalk.bind(smalltalk.NativeObject,"basicJson",0
,function (){var self=this;return smalltalk.superImplementor(smalltalk.NativeObject,'json').apply(self, []);;return self;}
,"converting",unescape("basicJson%0D%0A%09%22%20Convert%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Esuper%20json"));
smalltalk.bind(smalltalk.NativeObject,"json",0
,function (){var self=this;return self.handle();;return self;}
,"converting",unescape("json%0D%0A%09%22%20Convert%20the%20receiver%20to%20JSON%20structure.%20%22%0D%0A%0D%0A%09%5Eself%20handle"));
smalltalk.bind(smalltalk.NativeObject,"jsObject",0
,function (){var self=this;	return Object; ;return self;}
,"private",unescape("jsObject%0D%0A%09%22%20Private%20-%20Return%20the%20%28javascript%29Object.%20%22%0D%0A%0D%0A%7B%27%09return%20Object%3B%20%27%7D"));
smalltalk.bind(smalltalk.NativeObject,"ownPropertyNames",0
,function (){var self=this;return self.jsObject().getOwnPropertyNames(self['@handle']);;return self;}
,"accessing",unescape("ownPropertyNames%0D%0A%09%22%20Return%20the%20owned%20property%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20jsObject%20%23getOwnPropertyNames%3A%20handle"));
smalltalk.bind(smalltalk.NativeObject,"@","_at"
,function (propertyName){var self=this;return self['@handle'][propertyName];;return self;}
,"accessing",unescape("@%20propertyName%0D%0A%09%22%20Return%20the%20property%20at%20propertyName%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ehandle%5BpropertyName%5D"));
smalltalk.bind(smalltalk.NativeObject,"handleAt:",0
,function (propertyName){var self=this;return self['@handle'][propertyName];;return self;}
,"accessing",unescape("handleAt%3A%20propertyName%0D%0A%09%22%20Return%20the%20property%20at%20propertyName%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ehandle%5BpropertyName%5D"));
smalltalk.bind(smalltalk.NativeObject,"handleAt:put:",0
,function (propertyName,anObject){var self=this;return self['@handle'][propertyName]=anObject;;return self;}
,"accessing",unescape("handleAt%3A%20propertyName%20put%3A%20anObject%0D%0A%09%22%20Set%20the%20property%20at%20propertyName%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Ehandle%5BpropertyName%5D%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.NativeObject,"initializeHandle",0
,function (){var self=this;return self.error_("Missing "._comma(self.$klass.name())._comma(unescape("%3E%3E%23initializeHandle")));;return self;}
,"initialize",unescape("initializeHandle%0D%0A%09%22%20Private%20-%20Initialize%20the%20native%20handle.%0D%0A%09This%20method%20must%20be%20implemented%20by%20subclasses.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Missing%20%27%0D%0A%09%09%2Cself%20class%20name%0D%0A%09%09%2C%27%3E%3E%23initializeHandle%27"));
smalltalk.bind(smalltalk.NativeObject,"releaseHandle",0
,function (){var self=this;self['@handle']=nil;return self;}
,"release",unescape("releaseHandle%0D%0A%09%22%20Private%20-%20Release%20the%20native%20handle.%0D%0A%09The%20default%20implementation%20clear%20handle.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20free%20external%20resources.%0D%0A%09%22%0D%0A%0D%0A%09handle%20%3A%3D%20nil"));
smalltalk.bind(smalltalk.NativeObject,"release",0
,function (){var self=this;self.releaseHandle();
return smalltalk.superImplementor(smalltalk.NativeObject,'release').apply(self, []);;return self;}
,"release",unescape("release%0D%0A%09%22%20Private%20-%20Release%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20releaseHandle.%0D%0A%09%5Esuper%20release"));
smalltalk.bind(smalltalk.NativeObject,"copyPropertiesFrom:",0
,function (aNativeObject){var self=this;aNativeObject.ownPropertyNames().do_((function(key){return (self[key]=(((function(){var $1$=aNativeObject[key];if(nil.isNil_($1$))return nil;return $1$;})())));}));return self;}
,"copying",unescape("copyPropertiesFrom%3A%20aNativeObject%0D%0A%09%22%20Private%20-%20Copy%20receiver%27s%20properties%20from%20aNativeObject.%20%22%0D%0A%0D%0A%09aNativeObject%20ownPropertyNames%20do%3A%20%5B%3Akey%7C%0D%0A%09%09self%20basicAt%3A%20key%20put%3A%20%28aNativeObject%20basicAt%3A%20key%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject,"shallowCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("shallowCopy%0D%0A%09%22%20Return%20a%20shallow%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.NativeObject,"deepCopy",0
,function (){var self=this;return self;;return self;}
,"copying",unescape("deepCopy%0D%0A%09%22%20Return%20a%20deep%20copy%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.NativeObject,"closureForEvent:",0
,function (selector){var $s8Ret$={name:"stReturn"};try{var self=this;var argumentCount=nil;argumentCount=selector.argumentCount();
((argumentCount._eq((0))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function(){return self.triggerEvent_(selector);});})();throw($s8Ret$)})();})() : nil);
((argumentCount._eq((1))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function(arg1){return self.triggerEvent_with_(selector, arg1);});})();throw($s8Ret$)})();})() : nil);
((argumentCount._eq((2))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function(arg1,arg2){return self.triggerEvent_with_with_(selector, arg1, arg2);});})();throw($s8Ret$)})();})() : nil);
((argumentCount._eq((3))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function(arg1,arg2,arg3){return self.triggerEvent_withArguments_(selector, smalltalk.Array.with_with_with_(arg1, arg2, arg3));});})();throw($s8Ret$)})();})() : nil);
((argumentCount._eq((4))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (function(arg1,arg2,arg3,arg4){return self.triggerEvent_withArguments_(selector, smalltalk.Array.with_with_with_with_(arg1, arg2, arg3, arg4));});})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_("Invalid argument count");})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("closureForEvent%3A%20selector%0D%0A%09%22%20Private%20-%20Return%20the%20closure%20to%20handle%20event%20selector.%20%22%0D%0A%0D%0A%09%7C%20argumentCount%20%7C%0D%0A%09argumentCount%20%3A%3D%20selector%20argumentCount.%0D%0A%09argumentCount%20%3D%200%20ifTrue%3A%20%5B%20%5E%5B%20self%20triggerEvent%3A%20selector%20%5D%20%5D.%0D%0A%09argumentCount%20%3D%201%20ifTrue%3A%20%5B%20%5E%5B%3Aarg1%7C%20self%20triggerEvent%3A%20selector%20with%3A%20arg1%20%5D%20%5D.%0D%0A%09argumentCount%20%3D%202%20ifTrue%3A%20%5B%20%5E%5B%3Aarg1%20%3Aarg2%7C%20self%20triggerEvent%3A%20selector%20with%3A%20arg1%20with%3A%20arg2%20%5D%20%5D.%0D%0A%09argumentCount%20%3D%203%20ifTrue%3A%20%5B%20%5E%5B%3Aarg1%20%3Aarg2%20%3Aarg3%7C%20self%20triggerEvent%3A%20selector%20withArguments%3A%20%28Array%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%29%20%5D%20%5D.%0D%0A%09argumentCount%20%3D%204%20ifTrue%3A%20%5B%20%5E%5B%3Aarg1%20%3Aarg2%20%3Aarg3%20%3Aarg4%7C%20self%20triggerEvent%3A%20selector%20withArguments%3A%20%28Array%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%20with%3A%20arg4%29%20%5D%20%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20argument%20count%27"));
smalltalk.bind(smalltalk.NativeObject,"when:evaluate:",0
,function (anEvent,anAction){var self=this;var result=nil;var needsRegistration=nil;needsRegistration=(nil.isNil_(self.eventTable().at_ifAbsent_(anEvent, (function(){return nil;}))));
result=smalltalk.superImplementor(smalltalk.NativeObject,'when_evaluate_').apply(self, [anEvent, anAction]);
((needsRegistration).mustBeBoolean()==true ? (function(){return self.registerEvent_doing_(anEvent, self.closureForEvent_(anEvent));})() : nil);
return result;;return self;}
,"events",unescape("when%3A%20anEvent%20evaluate%3A%20anAction%0D%0A%09%22%20Register%20anAction%20to%20the%20be%20evaluated%20when%20the%20receiver%20triggers%20the%20event.%20%22%0D%0A%0D%0A%09%7C%20result%20needsRegistration%20%7C%0D%0A%09needsRegistration%20%3A%3D%20%28self%20eventTable%20at%3A%20anEvent%20ifAbsent%3A%20%5Bnil%5D%29%20isNil.%0D%0A%09result%20%3A%3D%20super%20when%3A%20anEvent%20evaluate%3A%20anAction.%0D%0A%09needsRegistration%20ifTrue%3A%20%5B%0D%0A%09%09self%09registerEvent%3A%20anEvent%0D%0A%09%09%09doing%3A%20%28self%20closureForEvent%3A%20anEvent%29.%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeObject,"registerEvent:doing:",0
,function (anEvent,closure){var $s8Ret$={name:"stReturn"};try{var self=this;var onSelector=nil;onSelector=self.$klass.selectorForEvent_(anEvent);
(((nil.isNil_(onSelector))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.bindEvent_doing_(onSelector, closure);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"events",unescape("registerEvent%3A%20anEvent%20doing%3A%20closure%0D%0A%09%22%20Private%20-%20Register%20basic%20event%20handler.%20%22%0D%0A%0D%0A%09%7C%20onSelector%20%7C%0D%0A%09onSelector%20%3A%3D%20self%20class%20selectorForEvent%3A%20anEvent.%0D%0A%09onSelector%20isNil%20ifTrue%3A%20%5B%20%5Eself%20%5D.%20%22local/smalltalk%20event%22%0D%0A%09%5Eself%20bindEvent%3A%20onSelector%20doing%3A%20closure"));
smalltalk.bind(smalltalk.NativeObject,"bindEvent:doing:",0
,function (onSelector,closure){var self=this;var $$native=nil;$$native=self.handle();
(((nil.isNil_($$native[onSelector]))).mustBeBoolean()==true ? (function(){return $$native[onSelector]=closure;})() : (function(){return $$native[onSelector].addListener(closure.json());})());return self;}
,"events",unescape("bindEvent%3A%20onSelector%20doing%3A%20closure%0D%0A%09%22%20Private%20-%20Bind%20the%20event%20handler.%20%22%0D%0A%0D%0A%09%7C%20native%20%7C%0D%0A%09native%20%3A%3D%20self%20handle.%0D%0A%09native%5BonSelector%5D%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09native%5BonSelector%5D%20%3A%3D%20closure%0D%0A%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09native%5BonSelector%5D%20%23addListener%3A%20closure%20json%0D%0A%09%5D"));
smalltalk.bind(smalltalk.NativeObject,"description",0
,function (){var self=this;return smalltalk.JS._at(self.handle()).description();;return self;}
,"debugging",unescape("description%0D%0A%09%22%20Return%20a%20string%20description%20from%20receiver%27s%20properties.%20%22%0D%0A%0D%0A%09%5E%28JS%20@%20self%20handle%29%20description"));
smalltalk.bind(smalltalk.NativeObject,"asDictionary",0
,function (){var self=this;var result=nil;result=smalltalk.PoolDictionary.$$new();
self.ownPropertyNames().do_((function(key){return result.at_put_(key, self['@handle'][key]);}));
return result;;return self;}
,"converting",unescape("asDictionary%0D%0A%09%22%20Convert%20the%20receiver%20to%20a%28Pool%29Dictionary.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20PoolDictionary%20new.%0D%0A%09self%20ownPropertyNames%20do%3A%20%5B%3Akey%7C%20result%20at%3A%20key%20put%3A%20handle%5Bkey%5D%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeObject,"asJS",0
,function (){var self=this;return smalltalk.JS._at(self.handle());;return self;}
,"converting",unescape("asJS%0D%0A%09%22%20Convert%20the%20receiver%20to%20JS%20instance%20%28for%20reflection%29.%20%22%0D%0A%0D%0A%09%5EJS%20@%20self%20handle"));
smalltalk.bind(smalltalk.JS.$klass,"@>","_at_gt"
,function (jsObject){var self=this;var js=nil;js=self._at(jsObject);
return (((nil.isNil_(js)===false)).mustBeBoolean()==true ? (function(){return js.description();})() : (function(){return js.toString();})());;return self;}
,"converting",unescape("@%3E%20jsObject%0D%0A%09%22%20Return%20the%20description%20of%20jsObject.%20%22%0D%0A%0D%0A%09%7C%20js%20%7C%0D%0A%09js%20%3A%3D%20self%20@%20jsObject.%0D%0A%09%5Ejs%20notNil%0D%0A%09%09ifTrue%3A%20%5B%20js%20description%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20js%20toString%20%5D"));
smalltalk.bind(smalltalk.JS.$klass,"@","_at"
,function (jsObject){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isObject_(jsObject).and_((function(){return jsObject.isString();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.JS.$klass,'_at').apply(self, [smalltalk.Smalltalk.jsObjectAt_ifAbsent_(jsObject, (function(){return nil;}))]);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.JS.$klass,'_at').apply(self, [jsObject]);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"instantiation",unescape("@%20jsObject%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%28%28self%20isObject%3A%20jsObject%29%20and%3A%20%5B%20jsObject%20isString%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Esuper%20@%20%28Smalltalk%20jsObjectAt%3A%20jsObject%20ifAbsent%3A%20%5B%5D%29%0D%0A%09%5D.%0D%0A%09%5Esuper%20@%20jsObject"));
smalltalk.bind(smalltalk.JS.$klass,"chunks",0
,function (){var self=this;return smalltalk.JSReader.$$new();;return self;}
,"utilities",unescape("chunks%0D%0A%09%22%20Return%20a%20JSReader%20to%20fileIn%20properties%20in%20new%20native%20object.%20%22%0D%0A%0D%0A%09%5EJSReader%20new"));
smalltalk.bind(smalltalk.JS,"prototype",0
,function (){var self=this;return self.$klass._at(self.jsObject().getPrototypeOf(self['@handle']));;return self;}
,"accessing",unescape("prototype%0D%0A%09%22%20Return%20the%20prototype%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20@%20%28self%20jsObject%20%23getPrototypeOf%3A%20handle%29"));
smalltalk.bind(smalltalk.JS,"propertyNames",0
,function (){var self=this;return self.jsObject().keys(self.handle());;return self;}
,"accessing",unescape("propertyNames%0D%0A%09%22%20Return%20the%20property%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20jsObject%20%23keys%3A%20self%20handle"));
smalltalk.bind(smalltalk.JS,"keys",0
,function (){var self=this;return self.propertyNames().sorted();;return self;}
,"accessing",unescape("keys%0D%0A%09%22%20Return%20the%20sorted%20property%20names%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20propertyNames%20sorted"));
smalltalk.bind(smalltalk.JS,"properties",0
,function (){var self=this;return self.keys().collect_((function(each){return smalltalk.Array.with_with_(each, self['@handle'][each]);}));;return self;}
,"accessing",unescape("properties%0D%0A%09%22%20Return%20an%20array%20with%20property%20name%20and%20values.%20%22%0D%0A%0D%0A%09%5Eself%20keys%20collect%3A%20%5B%3Aeach%7C%0D%0A%09%09Array%20with%3A%20each%20with%3A%20handle%5Beach%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.JS,"propertiesDo:",0
,function (aBlock){var self=this;self.propertyNames().do_((function(each){return aBlock.value_value_(each, self['@handle'][each]);}));return self;}
,"iterating",unescape("propertiesDo%3A%20aBlock%0D%0A%09%22%20Evaluate%20aTwoArgumentBlock%20with%20each%20property%20%28name%20%26%20value%29%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20propertyNames%20do%3A%20%5B%3Aeach%7C%20aBlock%20value%3A%20each%20value%3A%20handle%5Beach%5D%20%5D"));
smalltalk.bind(smalltalk.JS,"description",0
,function (){var self=this;var text=nil;text=(function(js){return (((nil.isNil_(js))).mustBeBoolean()==true ? (function(){return js;})() : (function(){return ((self.isObject_(js)).mustBeBoolean()==true ? (function(){return (((self.typeOf_(js) === "function")).mustBeBoolean()==true ? (function(){return js.toString().upTo_(unescape("%7B"))._comma(unescape("%7B...%7D"));})() : (function(){return js.asString();})());})() : (function(){return js.toString();})());})());});
return self.properties().inject_into_(unescape("%7B"), (function(total,each){return total._comma(unescape("%0D%0A%20"))._comma(each.first())._comma(": ")._comma(text.value_(each.last()))._comma(unescape("%3B"));}))._comma(unescape("%0D%0A%7D"));;return self;}
,"debugging",unescape("description%0D%0A%09%22%20Return%20a%20string%20description%20from%20receiver%27s%20properties.%20%22%0D%0A%0D%0A%09%7C%20text%20%7C%0D%0A%09text%20%3A%3D%20%5B%3Ajs%7C%0D%0A%09%09js%20isNil%20ifTrue%3A%20%5B%20js%20%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09%28self%20isObject%3A%20js%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%28self%20typeOf%3A%20js%29%20%3D%3D%20%23function%0D%0A%09%09%09%09ifTrue%3A%20%5B%20%28js%20toString%20upTo%3A%20%24%7B%29%20%2C%27%7B...%7D%27%20%5D%0D%0A%09%09%09%09ifFalse%3A%20%5B%20js%20asString%20%5D%0D%0A%09%09%09%5D%20ifFalse%3A%20%5B%20js%20toString%20%5D%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%09%5E%28self%20properties%20inject%3A%20%27%7B%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%20total%2C%27%0D%0A%20%27%20%2Ceach%20first%20%2C%27%3A%20%27%20%2C%28text%20value%3A%20each%20last%29%20%2C%27%3B%27%20%5D%29%20%2C%27%0D%0A%7D%27"));
smalltalk.bind(smalltalk.JS,"functionNames",0
,function (){var self=this;return self.propertyNames().select_((function(each){return (self.typeOf_(self['@handle'][each]) === "function");}));;return self;}
,"accessing",unescape("functionNames%0D%0A%09%22%20Return%20the%20names%20of%20property%20of%20the%20receiver%20of%20type%20function.%20%22%0D%0A%0D%0A%09%5Eself%20propertyNames%20select%3A%20%5B%3Aeach%7C%20%28self%20typeOf%3A%20handle%5Beach%5D%29%20%3D%3D%20%23function%20%5D"));
smalltalk.bind(smalltalk.JS,"functions",0
,function (){var self=this;return self.functionNames().collect_((function(each){return smalltalk.Array.with_with_(each, self['@handle'][each]);}));;return self;}
,"accessing",unescape("functions%0D%0A%09%22%20Return%20the%20functions%20of%20the%20receiver%20as%20a%20collection%20of%20tuples%20%23%28functionName%20aClosure%29.%20%22%0D%0A%0D%0A%09%5Eself%20functionNames%20collect%3A%20%5B%3Aeach%7C%20Array%20with%3A%20each%20with%3A%20handle%5Beach%5D%20%5D"));
smalltalk.bind(smalltalk.JS,"functionNamesAndArguments",0
,function (){var self=this;var argList=nil;argList=(function(source){return (function($rec){$rec.upTo_(unescape("%28"));return $rec.upTo_(unescape("%29"));})(source).asArrayOfSubstringsSeparatedBy_(unescape("%2C")).collect_((function(arg){return arg.trimBlanks();}));});
return self.functions().collect_((function(tuple){return smalltalk.Array.with_with_(tuple.first(), argList.value_(tuple.last().toString().stream()));}));;return self;}
,"accessing",unescape("functionNamesAndArguments%0D%0A%09%22%20Return%20the%20functions%20of%20the%20receiver%20as%20a%20collection%20of%20tuples%20%23%28functionName%20argumentsArray%29.%20%22%0D%0A%0D%0A%09%7C%20argList%20%7C%0D%0A%09argList%20%3A%3D%20%5B%3Asource%7C%0D%0A%09%09%28%28source%20upTo%3A%20%24%28%3B%20upTo%3A%20%24%29%29%20asArrayOfSubstringsSeparatedBy%3A%20%24%2C%29%0D%0A%09%09%09collect%3A%20%5B%3Aarg%7C%20arg%20trimBlanks%20%5D%0D%0A%09%5D.%0D%0A%09%5Eself%20functions%20collect%3A%20%5B%3Atuple%7C%20Array%20with%3A%20tuple%20first%20with%3A%20%28argList%20value%3A%20tuple%20last%20toString%20stream%29%20%5D"));
smalltalk.bind(smalltalk.JS,"ownFunctionNames",0
,function (){var self=this;return self.ownPropertyNames().select_((function(each){return (self.typeOf_(self['@handle'][each]) === "function");}));;return self;}
,"accessing",unescape("ownFunctionNames%0D%0A%09%22%20Return%20the%20names%20of%20functions%20owned/implemented%20by%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20ownPropertyNames%20select%3A%20%5B%3Aeach%7C%20%28self%20typeOf%3A%20handle%5Beach%5D%29%20%3D%3D%20%23function%20%5D"));
smalltalk.bind(smalltalk.JS,"hasOwnProperty:",0
,function (aName){var self=this;	return Object.prototype.hasOwnProperty.call(self["@handle"],aName); ;return self;}
,"testing",unescape("hasOwnProperty%3A%20aName%0D%0A%09%22%20Return%20true%20if%20receiver%20own%20a%20property%20named%20aName.%20%22%0D%0A%0D%0A%7B%27%09return%20Object.prototype.hasOwnProperty.call%28self%5B%22@handle%22%5D%2CaName%29%3B%20%27%7D"));
smalltalk.bind(smalltalk.JS,"delete:",0
,function (aName){var self=this;	delete self["@handle"][aName];	;return self;}
,"actions",unescape("delete%3A%20aName%0D%0A%09%22%20Delete%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%7B%27%09delete%20self%5B%22@handle%22%5D%5BaName%5D%3B%09%27%7D"));
smalltalk.bind(smalltalk.JS,"defineProperty:value:writable:enumerable:configurable:",0
,function (aName,aValue,writable,enumerable,configurable){var self=this;return self.defineProperty_as_(aName, smalltalk.Array.with_with_with_with_(smalltalk.Array.with_with_("value", aValue), smalltalk.Array.with_with_("writable", writable), smalltalk.Array.with_with_("enumerable", enumerable), smalltalk.Array.with_with_("configurable", configurable)));;return self;}
,"properties",unescape("defineProperty%3A%20aName%0D%0A%09value%3A%20aValue%0D%0A%09writable%3A%20writable%0D%0A%09enumerable%3A%20enumerable%0D%0A%09configurable%3A%20configurable%0D%0A%09%22%20Define%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20defineProperty%3A%20aName%20as%3A%20%28%20Array%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23value%20with%3A%20aValue%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23writable%20with%3A%20writable%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23enumerable%20with%3A%20enumerable%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23configurable%20with%3A%20configurable%29%0D%0A%09%29"));
smalltalk.bind(smalltalk.JS,"defineAccessor:get:set:enumerable:configurable:",0
,function (aName,aBlock,oneArgumentBlock,enumerable,configurable){var self=this;return self.defineProperty_as_(aName, smalltalk.Array.with_with_with_with_(smalltalk.Array.with_with_("get", aBlock), smalltalk.Array.with_with_("set", oneArgumentBlock), smalltalk.Array.with_with_("enumerable", enumerable), smalltalk.Array.with_with_("configurable", configurable)));;return self;}
,"properties",unescape("defineAccessor%3A%20aName%0D%0A%09get%3A%20aBlock%0D%0A%09set%3A%20oneArgumentBlock%0D%0A%09enumerable%3A%20enumerable%0D%0A%09configurable%3A%20configurable%0D%0A%09%22%20Define%20the%20Accessor%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20defineProperty%3A%20aName%20as%3A%20%28%20Array%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23get%20with%3A%20aBlock%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23set%20with%3A%20oneArgumentBlock%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23enumerable%20with%3A%20enumerable%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23configurable%20with%3A%20configurable%29%0D%0A%09%29"));
smalltalk.bind(smalltalk.JS,"defineProperty:value:writable:enumerable:",0
,function (aName,aValue,writable,enumerable){var self=this;return self.defineProperty_as_(aName, smalltalk.Array.with_with_with_(smalltalk.Array.with_with_("value", aValue), smalltalk.Array.with_with_("writable", writable), smalltalk.Array.with_with_("enumerable", enumerable)));;return self;}
,"properties",unescape("defineProperty%3A%20aName%0D%0A%09value%3A%20aValue%0D%0A%09writable%3A%20writable%0D%0A%09enumerable%3A%20enumerable%0D%0A%09%22%20Define%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20defineProperty%3A%20aName%20as%3A%20%28%20Array%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23value%20with%3A%20aValue%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23writable%20with%3A%20writable%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23enumerable%20with%3A%20enumerable%29%0D%0A%09%29"));
smalltalk.bind(smalltalk.JS,"defineProperty:value:writable:",0
,function (aName,aValue,writable){var self=this;return self.defineProperty_as_(aName, smalltalk.Array.with_with_(smalltalk.Array.with_with_("value", aValue), smalltalk.Array.with_with_("writable", writable)));;return self;}
,"properties",unescape("defineProperty%3A%20aName%0D%0A%09value%3A%20aValue%0D%0A%09writable%3A%20writable%0D%0A%09%22%20Define%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20defineProperty%3A%20aName%20as%3A%20%28%20Array%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23value%20with%3A%20aValue%29%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23writable%20with%3A%20writable%29%0D%0A%09%29"));
smalltalk.bind(smalltalk.JS,"defineProperty:value:",0
,function (aName,aValue){var self=this;return self.defineProperty_as_(aName, smalltalk.Array.with_(smalltalk.Array.with_with_("value", aValue)));;return self;}
,"properties",unescape("defineProperty%3A%20aName%20value%3A%20aValue%0D%0A%09%22%20Define%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20defineProperty%3A%20aName%20as%3A%20%28%20Array%0D%0A%09%09with%3A%20%28Array%20with%3A%20%23value%20with%3A%20aValue%29%0D%0A%09%29"));
smalltalk.bind(smalltalk.JS,"defineProperty:",0
,function (aName){var self=this;return self.defineProperty_as_(aName, smalltalk.Object.$$new());;return self;}
,"properties",unescape("defineProperty%3A%20aName%0D%0A%09%22%20Define%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20defineProperty%3A%20aName%20as%3A%20Object%20new"));
smalltalk.bind(smalltalk.JS,"defineProperty:as:",0
,function (aName,descriptor){var $s8Ret$={name:"stReturn"};try{var self=this;((descriptor.isArray()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.defineProperty_as_(aName, descriptor.inject_into_(smalltalk.Object.$$new(), (function(result,tuple){(((nil.isNil_(tuple.last())===false)).mustBeBoolean()==true ? (function(){return (result[tuple.first()]=(tuple.last()));})() : nil);return result;})));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.jsObject().defineProperty(self['@handle'], aName, descriptor);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"properties",unescape("defineProperty%3A%20aName%20as%3A%20descriptor%0D%0A%09%22%20Define%20the%20property%20named%20aName%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09descriptor%20isArray%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20defineProperty%3A%20aName%20as%3A%20%28descriptor%0D%0A%09%09%09inject%3A%20Object%20new%20into%3A%20%5B%3Aresult%20%3Atuple%7C%0D%0A%09%09%09%09tuple%20last%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%09result%20basicAt%3A%20tuple%20first%20put%3A%20tuple%20last%0D%0A%09%09%09%09%5D.%0D%0A%09%09%09%09result%0D%0A%09%09%09%5D%29%0D%0A%09%5D.%0D%0A%09%0D%0A%09%5Eself%20jsObject%20%23defineProperty%3A%20handle%20named%3A%20aName%20as%3A%20descriptor"));
smalltalk.bind(smalltalk.JS,"defineProperties:",0
,function (descriptors){var self=this;self.jsObject().defineProperties(self['@handle'], descriptors);return self;}
,"properties",unescape("defineProperties%3A%20descriptors%0D%0A%09%22%20Define%20the%20properties%20in%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23defineProperties%3A%20handle%20as%3A%20descriptors"));
smalltalk.bind(smalltalk.JS,"preventExtensions",0
,function (){var self=this;self.jsObject().preventExtensions(self['@handle']);return self;}
,"actions",unescape("preventExtensions%0D%0A%09%22%20Set%20the%20receiver%20as%20non-extensible.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23preventExtensions%3A%20handle"));
smalltalk.bind(smalltalk.JS,"freeze",0
,function (){var self=this;self.jsObject().freeze(self['@handle']);return self;}
,"actions",unescape("freeze%0D%0A%09%22%20Prevents%20the%20modification%20of%20existing%20property%20attributes%20and%20values%2C%20and%20prevents%20the%20addition%20of%20new%20properties.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23freeze%3A%20handle"));
smalltalk.bind(smalltalk.JS,"seal",0
,function (){var self=this;self.jsObject().seal(self['@handle']);return self;}
,"actions",unescape("seal%0D%0A%09%22%20Prevents%20the%20modification%20of%20attributes%20of%20existing%20properties%2C%20and%20prevents%20the%20addition%20of%20new%20properties.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23seal%3A%20handle"));
smalltalk.bind(smalltalk.JS,"isExtensible",0
,function (){var self=this;self.jsObject().isExtensible(self['@handle']);return self;}
,"testing",unescape("isExtensible%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20extensible.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23isExtensible%3A%20handle"));
smalltalk.bind(smalltalk.JS,"isSealed",0
,function (){var self=this;self.jsObject().isSealed(self['@handle']);return self;}
,"testing",unescape("isSealed%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20sealed.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23isSealed%3A%20handle"));
smalltalk.bind(smalltalk.JS,"isFrozen",0
,function (){var self=this;self.jsObject().isFrozen(self['@handle']);return self;}
,"testing",unescape("isFrozen%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20frozen.%20%22%0D%0A%0D%0A%09self%20jsObject%20%23isFrozen%3A%20handle"));
smalltalk.bind(smalltalk.JS,"create:with:",0
,function (prototype,descriptors){var self=this;return self.$klass._at(self.jsObject().create(prototype, descriptors));;return self;}
,"creation",unescape("create%3A%20prototype%20with%3A%20descriptors%0D%0A%09%22%20Return%20a%20JS%20object%20that%20has%20been%20created%20with%20the%20specified%20prototype%2C%20and%20that%20optionally%20contains%20specified%20properties.%20%22%0D%0A%0D%0A%09%5Eself%20class%20@%20%28self%20jsObject%20%23create%3A%20prototype%20with%3A%20descriptors%29"));
smalltalk.bind(smalltalk.JS,"createWith:",0
,function (descriptors){var self=this;return self.create_with_(self['@handle'], descriptors);;return self;}
,"creation",unescape("createWith%3A%20descriptors%0D%0A%09%22%20Return%20a%20JS%20object%20that%20has%20been%20created%20with%20the%20handle%20prototype%2C%20and%20that%20optionally%20contains%20specified%20properties.%20%22%0D%0A%0D%0A%09%5Eself%20create%3A%20handle%20with%3A%20descriptors"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"globalName",0
,function (){var self=this;return self.subclassResponsibility_("globalName");;return self;}
,"private",unescape("globalName%0D%0A%09%22%20Private%20-%20Return%20the%20name%20of%20the%20global%20to%20detect/access%20the%20library%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23globalName"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"topGlobal",0
,function (){var self=this;return smalltalk.Smalltalk.jsObjectAt_ifAbsent_("window", (function(){return self.error_("Missing window support");}));;return self;}
,"private",unescape("topGlobal%0D%0A%09%22%20Private%20-%20Return%20the%20object%20to%20access%20the%20global%20during%20detection%20stage.%0D%0A%09The%20default%20implementation%20return%20window%20global%20%28present%20when%20running%20in%20a%20web%20browser%29.%0D%0A%09This%20method%20must%20be%20refined%20by%20the%20subclasses%20requiring%20other%20root%20dependences.%0D%0A%09Can%20return%20nil%20to%20do%20not%20check%20dependents.%0D%0A%09%22%0D%0A%0D%0A%09%5ESmalltalk%20jsObjectAt%3A%20%23window%20ifAbsent%3A%20%5B%20self%20error%3A%20%27Missing%20window%20support%27%20%5D."));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"requiredFeatures",0
,function (){var self=this;return [];;return self;}
,"private",unescape("requiredFeatures%0D%0A%09%22%20Private%20-%20Return%20the%20names%20of%20the%20required%20properties/features%20to%20execute%20the%20receiver.%0D%0A%09The%20default%20implementation%20do%20not%20check%20dependents.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20ensure%20features%20to%20run%20the%20receiver%20are%20present%20in%20this%20system.%0D%0A%09%22%0D%0A%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"classNamed:",0
,function (className){var self=this;var library=nil;library=self.library();
return library[className];;return self;}
,"private",unescape("classNamed%3A%20className%0D%0A%09%22%20Private%20-%20Return%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%0D%0A%09The%20default%20implementation%20get%20the%20class%20from%20library.%0D%0A%09Subclasses%20can%20refine%20to%20obtain%20classes%20from%20anywhere%0D%0A%09%09e.g.%20global%20scope%20with%3A%20%5Eself%20global%3A%20className.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20library%20%7C%0D%0A%09library%20%3A%3D%20self%20library.%0D%0A%09%5Elibrary%5BclassName%5D"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"sourceCode",0
,function (){var self=this;return self.subclassResponsibility_("sourceCode");;return self;}
,"private",unescape("sourceCode%0D%0A%09%22%20Private%20-%20Return%20the%20%28javascript%29%20source%20code%20of%20the%20library%20as%20a%20String.%0D%0A%09This%20method%20can%20be%20implemented%20by%20subclasses%20loading%20sources%20from%20external%20media%20or%20simply%20returning%20aString%20embedded%20in%20this%20method.%0D%0A%09A%20reference/link%20to%20source%20origin%20is%20appreciated%20by%20users.%0D%0A%09CAUTION%3A%20S8%20is%20MIT%2C%20so%20you%20MUST%20embedd%20here%20MIT%20compatible%20sources.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20subclassResponsibility%3A%20%23sourceCode"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"libraryBound:",0
,function (aClassName){var self=this;self.bindingListeners().do_((function(each){return each.libraryBound_(aClassName);}));return self;}
,"binding",unescape("libraryBound%3A%20aClassName%0D%0A%09%22%20Private%20-%20The%20library%20of%20aClassName%20has%20just%20been%20bound%20to%20this%20system.%20%22%0D%0A%0D%0A%09self%20bindingListeners%20do%3A%20%5B%3Aeach%7C%20each%20libraryBound%3A%20aClassName%20%5D"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"bindingListeners",0
,function (){var self=this;(((nil.isNil_(smalltalk.NativeLibraryObject.classVariableAt_("BindingListeners")))).mustBeBoolean()==true ? (function(){return smalltalk.NativeLibraryObject.classVariableAt_put_("BindingListeners",smalltalk.Array.$$new());})() : nil);
return smalltalk.NativeLibraryObject.classVariableAt_("BindingListeners");;return self;}
,"binding",unescape("bindingListeners%0D%0A%09%22%20Private%20-%20Return%20the%20collection%20of%20listeners%20to%20library%20binding%20notifications%20of%20this%20system.%20%22%0D%0A%0D%0A%09BindingListeners%20isNil%20ifTrue%3A%20%5B%20BindingListeners%20%3A%3D%20Array%20new%20%5D.%0D%0A%09%5EBindingListeners"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"globalName:",0
,function (aName){var self=this;return self.$klass.implement_comment_as_category_("globalName", unescape("Private%20-%20Return%20the%20name%20of%20the%20global%20to%20detect/access%20the%20library%20of%20the%20receiver."), unescape("%5E")._comma(aName.printString()), "private");;return self;}
,"builder",unescape("globalName%3A%20aName%0D%0A%09%22%20Generate%20code%20to%20return%20the%20name%20of%20the%20global%20to%20detect/access%20the%20library%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%0D%0A%09%09implement%3A%20%23globalName%0D%0A%09%09comment%3A%20%27Private%20-%20Return%20the%20name%20of%20the%20global%20to%20detect/access%20the%20library%20of%20the%20receiver.%27%0D%0A%09%09as%3A%20%27%5E%27%20%2CaName%20printString%0D%0A%09%09category%3A%20%23private"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"libraryURL:",0
,function (anURL){var self=this;return self.$klass.implement_comment_as_category_("libraryURL", unescape("Private%20-%20Return%20the%20URL%20to%20use%20when%20loading%20library%20of%20the%20receiver."), unescape("%5E")._comma(anURL.printString()), "private");;return self;}
,"builder",unescape("libraryURL%3A%20anURL%0D%0A%09%22%20Generate%20the%20method%20to%20return%20libraryURL.%20%22%0D%0A%0D%0A%09%5Eself%20class%0D%0A%09%09implement%3A%20%23libraryURL%0D%0A%09%09comment%3A%20%27Private%20-%20Return%20the%20URL%20to%20use%20when%20loading%20library%20of%20the%20receiver.%27%0D%0A%09%09as%3A%20%27%5E%27%20%2CanURL%20printString%0D%0A%09%09category%3A%20%23private"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"globalClassNameFrom:",0
,function (globalClassName){var self=this;return globalClassName;;return self;}
,"private",unescape("globalClassNameFrom%3A%20globalClassName%0D%0A%09%22%20Private%20-%20Return%20the%20global%20class%20name%20for%20global%20globalClassName.%0D%0A%09It%20must%20return%20the%20%28global%29%20name%20of%20the%20constructor%20used%20to%20instantiate%20instance%20handles.%0D%0A%09The%20default%20action%20is%20to%20return%20the%20globalClassName.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20adapt%20name%20to%20%28case%20sensitive%29%20library%20constructor%20names.%0D%0A%09%22%0D%0A%0D%0A%09%5EglobalClassName"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"selectorForConstantNamed:",0
,function (aName){var $s8Ret$={name:"stReturn"};try{var self=this;aName.detect_ifNone_((function(c){return c.isLowercase();}), (function(){return (function(){$s8Ret$.result=(function(){return aName.asLowercase().asSmalltalkName_(false);})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return aName.asSmalltalkName_(false);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builder",unescape("selectorForConstantNamed%3A%20aName%0D%0A%09%22%20Private%20-%20Return%20the%20selector%20to%20use%20for%20constant%20aName.%20%22%0D%0A%0D%0A%09aName%20detect%3A%20%5B%3Ac%7C%20c%20isLowercase%20%5D%20ifNone%3A%20%5B%0D%0A%09%09%5EaName%20asLowercase%20asSmalltalkName%3A%20false%0D%0A%09%5D.%0D%0A%09%5EaName%20asSmalltalkName%3A%20false"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"constants:",0
,function (names){var self=this;names.do_((function(each){return self.$klass.implement_comment_as_category_(self.selectorForConstantNamed_(each), "Return the value of "._comma(each), unescape("%5Eself%20library%20basicAt%3A%20%23")._comma(each), "accessing");}));return self;}
,"builder",unescape("constants%3A%20names%0D%0A%09%22%20Private%20-%20Build%20methods%20to%20access%20library%20globals.%20%22%0D%0A%0D%0A%09names%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09self%20class%0D%0A%09%09%09implement%3A%20%28self%20selectorForConstantNamed%3A%20each%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20value%20of%20%27%2Ceach%0D%0A%09%09%09as%3A%20%27%5Eself%20library%20basicAt%3A%20%23%27%2Ceach%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D."));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"buildSubclass:arguments:typed:",0
,function (globalClassName,argList,typedArguments){var $s8Ret$={name:"stReturn"};try{var self=this;var cls=nil;var clsName=nil;clsName=globalClassName.first().asUppercase()._comma(globalClassName.copyFrom_to_((2), globalClassName.size()));
clsName=self.classToken()._comma(clsName);
self.subclass_instanceVariableNames_category_(clsName, "", self.category());
(((nil.isNil_(argList)).or_((function(){return argList._eq("nil");}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
cls=smalltalk.Smalltalk.at_(clsName);
cls.$klass.implement_comment_as_category_("globalClassName", unescape("Private%20-%20Return%20the%20internal%20class%20name."), unescape("%5Eself%20globalClassNameFrom%3A%20%23")._comma(globalClassName), "private");
((argList.isEmpty()).mustBeBoolean()==true ? (function(){return cls.implement_comment_as_category_("initializeHandle", unescape("Private%20-%20Initialize%20the%20receiver%27s%20handle."), unescape("self%20handle%3A%20%28self%20newHandleOf%3A%20self%20class%20globalClassName%29"), "initialize");})() : (function(){var selector=nil;var args=nil;var current=nil;selector=argList.inject_into_("", (function(total,each){return total._comma(each)._comma(": ")._comma(each)._comma(" ");}));args=argList.inject_into_("", (function(total,each){((typedArguments._eq("all").or_((function(){return typedArguments.includes_(each);}))).mustBeBoolean()==true ? (function(){return current=" handle ";})() : (function(){return current=" ";})());return total._comma("with: ")._comma(each)._comma(current);}));cls.$klass.implement_comment_as_category_(selector, "Return an instance of the receiver.", unescape("%5Eself%20basicNew%20")._comma(selector), "instantiation");return cls.implement_comment_as_category_(selector, unescape("Private%20-%20Initialize%20the%20receiver."), unescape("self%20handle%3A%20%28self%20newHandleOf%3A%20self%20class%20globalClassName%20")._comma(args)._comma(unescape("%29")), "initialize");})());return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builder",unescape("buildSubclass%3A%20globalClassName%20arguments%3A%20argList%20typed%3A%20typedArguments%0D%0A%09%22%20Private%20-%20Build%20a%20subclass%20of%20the%20receiver%20implementing%20a%20wrapper%20to%20the%20library.%20%22%0D%0A%0D%0A%09%7C%20cls%20clsName%20%7C%0D%0A%09clsName%20%3A%3D%20globalClassName%20first%20asUppercase%0D%0A%09%09%09%2C%28globalClassName%20copyFrom%3A%202%20to%3A%20globalClassName%20size%29.%0D%0A%09clsName%20%3A%3D%20self%20classToken%20%2CclsName.%0D%0A%09self%0D%0A%09%09subclass%3A%20clsName%0D%0A%09%09instanceVariableNames%3A%20%27%27%0D%0A%09%09category%3A%20self%20category.%0D%0A%09%28argList%20isNil%20or%3A%20%5B%20argList%20%3D%20%23nil%20%5D%29%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%0D%0A%09cls%20%3A%3D%20Smalltalk%20at%3A%20clsName.%0D%0A%09cls%20class%0D%0A%09%09implement%3A%20%23globalClassName%0D%0A%09%09comment%3A%20%27Private%20-%20Return%20the%20internal%20class%20name.%27%0D%0A%09%09as%3A%20%27%5Eself%20globalClassNameFrom%3A%20%23%27%20%2CglobalClassName%0D%0A%09%09category%3A%20%23private.%0D%0A%09argList%20isEmpty%20ifTrue%3A%20%5B%0D%0A%09%09cls%0D%0A%09%09%09implement%3A%20%23initializeHandle%0D%0A%09%09%09comment%3A%20%27Private%20-%20Initialize%20the%20receiver%27%27s%20handle.%27%0D%0A%09%09%09as%3A%20%27self%20handle%3A%20%28self%20newHandleOf%3A%20self%20class%20globalClassName%29%27%0D%0A%09%09%09category%3A%20%23initialize.%0D%0A%09%5D%20ifFalse%3A%20%5B%20%7C%20selector%20args%20current%20%7C%0D%0A%09%09selector%20%3A%3D%20argList%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09%09total%20%2Ceach%2C%27%3A%20%27%2Ceach%2C%27%20%27%0D%0A%09%09%5D.%0D%0A%09%09args%20%3A%3D%20argList%20inject%3A%20%27%27%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09%09%28typedArguments%20%3D%20%23all%0D%0A%09%09%09%20%20or%3A%20%5B%20typedArguments%20includes%3A%20each%20%5D%29%0D%0A%09%09%09%20%20ifTrue%3A%20%5B%20current%20%3A%3D%20%27%20handle%20%27%20%5D%0D%0A%09%09%09%20%20ifFalse%3A%20%5B%20current%20%3A%3D%20%27%20%27%20%5D.%0D%0A%09%09%09total%20%2C%27with%3A%20%27%2Ceach%2C%20current%0D%0A%09%09%5D.%0D%0A%09%09cls%20class%0D%0A%09%09%09implement%3A%20selector%0D%0A%09%09%09comment%3A%20%27Return%20an%20instance%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5Eself%20basicNew%20%27%2Cselector%0D%0A%09%09%09category%3A%20%23instantiation.%0D%0A%09%09cls%0D%0A%09%09%09implement%3A%20selector%0D%0A%09%09%09comment%3A%20%27Private%20-%20Initialize%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27self%20handle%3A%20%28self%20newHandleOf%3A%20self%20class%20globalClassName%20%27%20%2Cargs%20%2C%27%29%27%0D%0A%09%09%09category%3A%20%23initialize.%0D%0A%09%5D."));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"global:",0
,function (globalName){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;result=smalltalk.Smalltalk.jsObjectAt_ifAbsent_(globalName, (function(){return nil;}));
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
((self.isValid()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})());
self.libraryLoaded_(self.loadLibrary());
(function(){$s8Ret$.result=(function(){return smalltalk.Smalltalk.jsObjectAt_ifAbsent_(globalName, (function(){return nil;}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"accessing",unescape("global%3A%20globalName%0D%0A%09%22%20Private%20-%20Return%20the%20native%20library%20global%20object%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Smalltalk%20jsObjectAt%3A%20globalName%20ifAbsent%3A%20%5B%20nil%20%5D.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09self%20isValid%20ifFalse%3A%20%5B%20%5Enil%20%5D.%0D%0A%09self%20libraryLoaded%3A%20self%20loadLibrary.%0D%0A%09%5ESmalltalk%20jsObjectAt%3A%20globalName%20ifAbsent%3A%20%5B%20nil%20%5D"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"library",0
,function (){var self=this;return self.global_(self.globalName());;return self;}
,"validation",unescape("library%0D%0A%09%22%20Check%20support%20to%20run%20this%20framework%20and%20try%20to%20load%20the%20library%20implementation.%0D%0A%09Return%20the%20native%20library%20object%20if%20success.%0D%0A%09%22%0D%0A%0D%0A%09%5Eself%20global%3A%20self%20globalName"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"libraryOrNil",0
,function (){var self=this;return smalltalk.Smalltalk.jsObjectAt_ifAbsent_(self.globalName(), (function(){return nil;}));;return self;}
,"validation",unescape("libraryOrNil%0D%0A%09%22%20Quick%20Check%20-%20Return%20true%20if%20the%20library%20is%20already%20bound.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20jsObjectAt%3A%20self%20globalName%20ifAbsent%3A%20%5B%20nil%20%5D"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"libraryURLs",0
,function (){var self=this;return smalltalk.Array.with_(self.libraryURL()).select_((function(each){return (nil.isNil_(each)===false);}));;return self;}
,"private",unescape("libraryURLs%0D%0A%09%22%20Private%20-%20Return%20a%20collection%20of%20URL%20to%20load%20library%20of%20the%20receiver.%0D%0A%09Return%20an%20empty%20collection%2C%20the%20subclasses%20can%20complement%20addresses%20to%20load%20library%20from%20external%20resources.%0D%0A%09%22%0D%0A%0D%0A%09%5E%28Array%20with%3A%20self%20libraryURL%29%20select%3A%20%5B%3Aeach%7C%20each%20notNil%20%5D"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"libraryURL",0
,function (){var self=this;return nil;;return self;}
,"private",unescape("libraryURL%0D%0A%09%22%20Private%20-%20Return%20the%20URL%20to%20use%20when%20loading%20library%20of%20the%20receiver.%0D%0A%09Default%20implementation%20do%20not%20provide%20support%20to%20load%20library.%0D%0A%09%22%0D%0A%0D%0A%09%5Enil"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"onLoad:",0
,function (aBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var dom=nil;var success=nil;(((nil.isNil_(self.libraryOrNil())===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return aBlock.value_(self.library());})();throw($s8Ret$)})();})() : nil);
success=(function(){smalltalk.NativeLibraryObject.libraryBound_(self.name());return aBlock.value_(self.library());});
dom=smalltalk.Smalltalk.at_ifAbsent_("DOM", (function(){self.libraryURLs().do_((function(each){return load(each);}));return (function(){$s8Ret$.result=(function(){return success.value();})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return dom.document().loadAll_onLoad_(self.libraryURLs(), (function(){return success.value();}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("onLoad%3A%20aBlock%0D%0A%09%22%20Private%20-%20Load%20the%20library%20of%20the%20receiver%20and%20evaluates%20aBlock.%20%22%0D%0A%0D%0A%09%7C%20dom%20success%20%7C%0D%0A%09self%20libraryOrNil%20notNil%20ifTrue%3A%20%5B%20%5EaBlock%20value%3A%20self%20library%20%5D.%0D%0A%09success%20%3A%3D%20%5B%0D%0A%09%09NativeLibraryObject%20libraryBound%3A%20self%20name.%0D%0A%09%09aBlock%20value%3A%20self%20library%0D%0A%09%5D.%0D%0A%09dom%20%3A%3D%20Smalltalk%20at%3A%20%23DOM%20ifAbsent%3A%20%5B%0D%0A%09%09self%20libraryURLs%20do%3A%20%5B%3Aeach%7C%20%23%20%23load%3A%20each%20%5D.%0D%0A%09%09%5Esuccess%20value%0D%0A%09%5D.%0D%0A%09%5Edom%20document%0D%0A%09%09loadAll%3A%20self%20libraryURLs%0D%0A%09%09onLoad%3A%20%5B%20success%20value%20%5D"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"loadLibrary",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self.libraryURLs().notEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.onLoad_((function(ignored){return nil;}));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.Smalltalk.current().eval_as_(self.sourceCode(), smalltalk.Array.with_with_("loadLibrary", self.name()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("loadLibrary%0D%0A%09%22%20Private%20-%20Load%20the%20library%20of%20the%20receiver.%0D%0A%09Default%20implementation%20load%20the%20library%20from%20remote%20URL%20or%20sourceCode.%0D%0A%09%22%0D%0A%0D%0A%09self%20libraryURLs%20notEmpty%20ifTrue%3A%20%5B%20%5Eself%20onLoad%3A%20%5B%3Aignored%7C%20%5D%20%5D.%0D%0A%09%5ESmalltalk%20current%0D%0A%09%09eval%3A%20self%20sourceCode%0D%0A%09%09as%3A%20%28Array%20with%3A%20%23loadLibrary%20with%3A%20self%20name%29"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"libraryLoaded:",0
,function (loadResult){var self=this;return self;}
,"private",unescape("libraryLoaded%3A%20loadResult%0D%0A%09%22%20Private%20-%20The%20library%20of%20the%20receiver%20has%20been%20loaded.%0D%0A%09Default%20implementation%20do%20nothing.%0D%0A%09This%20method%20can%20be%20refined%20by%20subclasses%20to%20perform%20postLoading%20actions.%0D%0A%09The%20loadResult%20argument%20is%20the%20result%20of%20the%20just%20evaluated%20load%20process.%0D%0A%09%22"));
smalltalk.bind(smalltalk.NativeLibraryObject.$klass,"isValid",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var global=nil;global=self.topGlobal();
(((nil.isNil_(global))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();})() : nil);
self.requiredFeatures().do_((function(each){return (((nil.isNil_(global[each]))).mustBeBoolean()==true ? (function(){return self.error_("Missing support for "._comma(each));})() : nil);}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"validation",unescape("isValid%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20valid%20in%20this%20%28browser%29%20context.%0D%0A%09Generate%20error%20if%20the%20minimum%20support%20to%20run%20the%20library%20is%20not%20available.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20global%20%7C%0D%0A%09global%20%3A%3D%20self%20topGlobal.%0D%0A%09global%20isNil%20ifTrue%3A%20%5B%20%5Etrue%20%5D.%20%22always%20valid%22%0D%0A%09self%20requiredFeatures%20do%3A%20%5B%3Aeach%7C%0D%0A%09%20%20global%5Beach%5D%20isNil%20ifTrue%3A%20%5B%0D%0A%09%20%20%20%20self%20error%3A%20%27Missing%20support%20for%20%27%2Ceach%0D%0A%09%20%20%5D.%0D%0A%09%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.NativeLibraryObject,"library",0
,function (){var self=this;return self.$klass.library();;return self;}
,"private",unescape("library%0D%0A%09%22%20Private%20-%20Return%20the%20library%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20library"));
smalltalk.bind(smalltalk.NativeLibraryObject,"classNamed:",0
,function (className){var self=this;return self.$klass.classNamed_(className);;return self;}
,"private",unescape("classNamed%3A%20className%0D%0A%09%22%20Private%20-%20Return%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%5Eself%20class%20classNamed%3A%20className"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:",0
,function (className){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor() ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:",0
,function (className,arg1){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:",0
,function (className,arg1,arg2){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:with:",0
,function (className,arg1,arg2,arg3){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2,arg3) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%2Carg3%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:with:with:",0
,function (className,arg1,arg2,arg3,arg4){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2,arg3,arg4) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%20with%3A%20arg4%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%2Carg3%2Carg4%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:with:with:with:",0
,function (className,arg1,arg2,arg3,arg4,arg5){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2,arg3,arg4,arg5) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%20with%3A%20arg4%20with%3A%20arg5%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%2Carg3%2Carg4%2Carg5%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:with:with:with:with:",0
,function (className,arg1,arg2,arg3,arg4,arg5,arg6){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2,arg3,arg4,arg5,arg6) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%20with%3A%20arg4%20with%3A%20arg5%20with%3A%20arg6%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%2Carg3%2Carg4%2Carg5%2Carg6%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:with:with:with:with:with:",0
,function (className,arg1,arg2,arg3,arg4,arg5,arg6,arg7){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2,arg3,arg4,arg5,arg6,arg7) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%20with%3A%20arg4%20with%3A%20arg5%20with%3A%20arg6%20with%3A%20arg7%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%2Carg3%2Carg4%2Carg5%2Carg6%2Carg7%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.NativeLibraryObject,"newHandleOf:with:with:with:with:with:with:with:with:",0
,function (className,arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8){var self=this;var result=nil;var aConstructor=nil;aConstructor=self.classNamed_(className);
result= new aConstructor(arg1,arg2,arg3,arg4,arg5,arg6,arg7,arg8) ;
return result;;return self;}
,"private",unescape("newHandleOf%3A%20className%20with%3A%20arg1%20with%3A%20arg2%20with%3A%20arg3%20with%3A%20arg4%20with%3A%20arg5%20with%3A%20arg6%20with%3A%20arg7%20with%3A%20arg8%0D%0A%09%22%20Private%20-%20Return%20a%20new%20instance%20of%20the%20class%20named%20className%20in%20the%20receiver%27s%20library.%20%22%0D%0A%0D%0A%09%7C%20result%20aConstructor%20%7C%0D%0A%09aConstructor%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09result%20%3A%3D%20%7B%27%20new%20aConstructor%28arg1%2Carg2%2Carg3%2Carg4%2Carg5%2Carg6%2Carg7%2Carg8%29%20%27%7D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.CocoObject.$klass,"isValid",0
,function (){var self=this;return self.$$new().isValid();;return self;}
,"testing",unescape("isValid%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20is%20valid.%20%22%0D%0A%0D%0A%09%5Eself%20new%20isValid"));
smalltalk.bind(smalltalk.CocoObject.$klass,"classNamed:",0
,function (className){var self=this;return smalltalk.Smalltalk.jsObjectAt_ifAbsent_(className, (function(){return nil;}));;return self;}
,"accessing",unescape("classNamed%3A%20className%0D%0A%09%22%20Return%20the%20ObjC%20class%20named%20className%20or%20nil.%20%22%0D%0A%0D%0A%09%5ESmalltalk%20jsObjectAt%3A%20className%20ifAbsent%3A%20%5B%5D"));
smalltalk.bind(smalltalk.CocoObject.$klass,"buildBooleanGetter:",0
,function (aSelector){var $s8Ret$={name:"stReturn"};try{var self=this;return self.build_doing_("BooleanGetter"._minus_gt(aSelector), (function(){return (function(){$s8Ret$.result=(function(){return self.implement_comment_as_category_(self.stMessageHeader_(aSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), unescape("%5EBoolean%20@%20handle%23")._comma(self.jsNameFromSelector_(aSelector)), "accessing");})();throw($s8Ret$)})();}));;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builder",unescape("buildBooleanGetter%3A%20aSelector%0D%0A%09%22%20Private%20-%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23BooleanGetter%20-%3E%20aSelector%20doing%3A%20%5B%0D%0A%09%09%5Eself%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20aSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5EBoolean%20@%20handle%23%27%20%2C%28self%20jsNameFromSelector%3A%20aSelector%29%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.CocoObject.$klass,"buildIsBooleanGetter:",0
,function (aSelector){var $s8Ret$={name:"stReturn"};try{var self=this;return self.build_doing_("IsBooleanGetter"._minus_gt(aSelector), (function(){var isSelector=nil;isSelector="is"._comma(aSelector.asGlobalName());return (function(){$s8Ret$.result=(function(){return self.implement_comment_as_category_(self.stMessageHeader_(isSelector), "Return the "._comma(aSelector)._comma(" of the receiver."), unescape("%5EBoolean%20@%20handle%23")._comma(self.jsNameFromSelector_(isSelector)), "accessing");})();throw($s8Ret$)})();}));;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builder",unescape("buildIsBooleanGetter%3A%20aSelector%0D%0A%09%22%20Private%20-%20Build%20%28instance%29%20method%20to%20get%20native%20property.%20%22%0D%0A%0D%0A%09%5Eself%20build%3A%20%23IsBooleanGetter%20-%3E%20aSelector%20doing%3A%20%5B%20%7C%20isSelector%20%7C%0D%0A%09%09isSelector%20%3A%3D%20%20%23is%20%2CaSelector%20asGlobalName.%0D%0A%09%09%5Eself%0D%0A%09%09%09implement%3A%20%28self%20stMessageHeader%3A%20isSelector%29%0D%0A%09%09%09comment%3A%20%27Return%20the%20%27%20%2CaSelector%20%2C%27%20of%20the%20receiver.%27%0D%0A%09%09%09as%3A%20%27%5EBoolean%20@%20handle%23%27%20%2C%28self%20jsNameFromSelector%3A%20isSelector%29%0D%0A%09%09%09category%3A%20%23accessing%0D%0A%09%5D"));
smalltalk.bind(smalltalk.CocoObject.$klass,"buildFunction:",0
,function (selector){var $s8Ret$={name:"stReturn"};try{var self=this;((selector.isString().and_((function(){return selector.includes_(":").not();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildGetter_(selector);})();throw($s8Ret$)})();})() : nil);
((selector.isArray().and_((function(){return selector.size()._eq((2)).and_((function(){return selector.first().isString().and_((function(){return selector.first().includes_(":").not().and_((function(){return selector.last().isString();}));}));}));}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.buildTypedGetter_(selector);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.superImplementor(smalltalk.CocoObject.$klass,'buildFunction_').apply(self, [selector]);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"builder",unescape("buildFunction%3A%20selector%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20delegate%20message%20implemented%20as%20functions%20on%20instance%20handle.%0D%0A%09Note%3A%20we%20need%20to%20route%20simple%20functions%20to%20getter%20protocoll%20%28to%20avoid%20a%20JSCocoa%20bug%20-%20function%20not%20found%29.%0D%0A%09%22%0D%0A%0D%0A%09%28selector%20isString%20and%3A%20%5B%0D%0A%09%09%28selector%20includes%3A%20%24%3A%29%20not%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20buildGetter%3A%20selector%0D%0A%09%5D.%0D%0A%09%28selector%20isArray%20and%3A%20%5B%0D%0A%09%09selector%20size%20%3D%202%20and%3A%20%5B%0D%0A%09%09selector%20first%20isString%20and%3A%20%5B%0D%0A%09%09%28selector%20first%20includes%3A%20%24%3A%29%20not%20and%3A%20%5B%0D%0A%09%09selector%20last%20isString%20%5D%5D%5D%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20buildTypedGetter%3A%20selector%0D%0A%09%5D.%0D%0A%09%5Esuper%20buildFunction%3A%20selector"));
smalltalk.bind(smalltalk.CocoObject.$klass,"buildFunction:arguments:prologue:epilogue:",0
,function (selector,args,prologue,epilogue){var self=this;var header=nil;var code=nil;var input=nil;var argStream=nil;var msg=nil;var codePart=nil;input=selector.stream();
argStream=args.stream();
header="".stream();
code="".stream();
code.nextPutAll_(selector.asSelector());
codePart=": ";
header.nextPut_(input.next().asLowercase());
(function(){while(!(function(){return argStream.atEnd();})()){(function(){var param=nil;var expr=nil;((argStream.peek().isString()).mustBeBoolean()==true ? (function(){param=argStream.next();return expr=param;})() : (function(){param=argStream.peek().first();return expr=param._comma(" ")._comma(argStream.next().last());})());msg=input.upTo_(":")._comma(": ");code.nextPutAll_(codePart._comma(expr)._comma(" "));codePart="with: ";return header.nextPutAll_(msg._comma(param)._comma(" "));})()};return nil})();
msg=input.upToEnd();
code.nextPutAll_(msg);
header.nextPutAll_(msg);
header=self.stMessageHeader_(header.contents());
code=unescape("%5E")._comma(prologue)._comma(unescape("self%20handle%20%23"))._comma(code.contents())._comma(epilogue);
self.implement_comment_as_category_(header, "Wrap method delegating "._comma(selector)._comma(" to handle."), code, "wrappers");return self;}
,"builder",unescape("buildFunction%3A%20selector%20arguments%3A%20args%20prologue%3A%20prologue%20epilogue%3A%20epilogue%20%0D%0A%09%22%20Private%20-%20Generate%20code%20to%20delegate%20message%20on%20instance%20handle.%20%22%0D%0A%0D%0A%09%7C%20header%20code%20input%20argStream%20msg%20codePart%20%7C%0D%0A%09input%20%3A%3D%20selector%20stream.%0D%0A%09argStream%20%3A%3D%20args%20stream.%0D%0A%09header%20%3A%3D%20%27%27%20stream.%20code%20%3A%3D%20%27%27%20stream.%0D%0A%09code%20%20%20nextPutAll%3A%20selector%20asSelector.%20codePart%20%3A%3D%20%27%3A%20%27.%0D%0A%09header%20nextPut%3A%20input%20next%20asLowercase.%0D%0A%09%5B%20argStream%20atEnd%20%5D%20whileFalse%3A%20%5B%20%7C%20param%20expr%20%7C%0D%0A%09%09argStream%20peek%20isString%0D%0A%09%09ifTrue%3A%20%5B%20param%20%3A%3D%20argStream%20next.%20expr%20%3A%3D%20param%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20param%20%3A%3D%20argStream%20peek%20first.%20expr%20%3A%3D%20param%20%2C%27%20%27%20%2CargStream%20next%20last.%20%5D.%0D%0A%09%09msg%20%3A%3D%20%28input%20upTo%3A%20%24%3A%29%20%2C%27%3A%20%27.%0D%0A%09%09code%20%20%20nextPutAll%3A%20codePart%2C%20expr%20%2C%27%20%27.%20codePart%20%3A%3D%20%27with%3A%20%27.%0D%0A%09%09header%20nextPutAll%3A%20msg%2C%20param%20%2C%27%20%27.%0D%0A%09%5D.%0D%0A%09msg%20%3A%3D%20input%20upToEnd.%0D%0A%09code%20%20%20nextPutAll%3A%20msg.%0D%0A%09header%20nextPutAll%3A%20msg.%0D%0A%0D%0A%09header%20%3A%3D%20self%20stMessageHeader%3A%20header%20contents.%0D%0A%09code%20%20%20%3A%3D%20%27%5E%27%09%2C%20prologue%0D%0A%09%09%09%2C%27self%20handle%20%23%27%2Ccode%20contents%0D%0A%09%09%09%2C%20epilogue.%0D%0A%0D%0A%09self%09implement%3A%20header%0D%0A%09%09comment%3A%20%27Wrap%20method%20delegating%20%27%2Cselector%2C%27%20to%20handle.%27%0D%0A%09%09as%3A%20code%20category%3A%20%23wrappers"));
smalltalk.bind(smalltalk.CocoObject.$klass,"outArgument",0
,function (){var self=this;return outArgument();;return self;}
,"natives",unescape("outArgument%0D%0A%09%22%20Return%20an%20out%20argument%20for%20collecting%20output%20after%20calling%20a%20native%20function.%20%22%0D%0A%0D%0A%09%5E%23%20%23outArgument"));
smalltalk.bind(smalltalk.CocoObject.$klass,"outArgument:offset:",0
,function (type,offset){var self=this;return outArgument(type, offset);;return self;}
,"natives",unescape("outArgument%3A%20type%20offset%3A%20offset%0D%0A%09%22%20Return%20an%20out%20argument%20for%20collecting%20output%20after%20calling%20a%20native%20function.%20%22%0D%0A%0D%0A%09%5E%23%20%23outArgument%3A%20type%20atIndex%3A%20offset"));
smalltalk.bind(smalltalk.CocoObject.$klass,"memoryBuffer:",0
,function (types){var self=this;return memoryBuffer(types);;return self;}
,"natives",unescape("memoryBuffer%3A%20types%0D%0A%09%22%20Return%20a%20memory%20buffer%20with%20space%20to%20allocate%20fields%20of%20specified%20types.%20%22%0D%0A%0D%0A%09%5E%23%20%23memoryBuffer%3A%20types"));
smalltalk.bind(smalltalk.CocoObject.$klass,"log:",0
,function (anObject){var self=this;return smalltalk.JSC.$$new().log_(anObject.toString());;return self;}
,"log",unescape("log%3A%20anObject%0D%0A%09%5EJSC%20new%20log%3A%20anObject%20toString"));
smalltalk.bind(smalltalk.CocoObject,"initializeHandle",0
,function (){var self=this;self['@handle']=smalltalk.Smalltalk.jsObjectAt_(self.jsName());return self;}
,"initialize",unescape("initializeHandle%0D%0A%20%20%20%20%22%20Private%20-%20Initialize%20the%20native%20handle.%20%22%0D%0A%0D%0A%20%20%20%20handle%20%3A%3D%20Smalltalk%20jsObjectAt%3A%20self%20jsName"));
smalltalk.bind(smalltalk.CocoObject,"isValid",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(function(){return self.handle();}).on_do_(smalltalk.Error, (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return (nil.isNil_(self['@handle'])===false);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("isValid%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20is%20valid.%20%22%0D%0A%0D%0A%09%5B%20self%20handle%20%5D%20on%3A%20Error%20do%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5Ehandle%20notNil"));
smalltalk.bind(smalltalk.CocoObject,"bindings",0
,function (){var self=this;return self.basicAt_ifAbsentPut_(unescape("%24coco8-bindings"), (function(){return smalltalk.Array.$$new();}));;return self;}
,"accessing",unescape("bindings%0D%0A%09%22%20Private%20-%20Returns%20the%20objects%20bound%20to%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20basicAt%3A%20%27%24coco8-bindings%27%20ifAbsentPut%3A%20%5B%20Array%20new%20%5D"));
smalltalk.bind(smalltalk.CocoObject,"releaseHandle",0
,function (){var self=this;(self[unescape("%24coco8-bindings")]=([]));
return smalltalk.superImplementor(smalltalk.CocoObject,'releaseHandle').apply(self, []);;return self;}
,"release",unescape("releaseHandle%0D%0A%09%22%20Private%20-%20Release%20the%20native%20handle.%20%22%0D%0A%0D%0A%09self%20basicAt%3A%20%27%24coco8-bindings%27%20put%3A%20%23%28%29.%0D%0A%09%5Esuper%20releaseHandle"));
smalltalk.bind(smalltalk.CocoObject,"classNamed:",0
,function (className){var self=this;return self.$klass.classNamed_(className);;return self;}
,"accessing",unescape("classNamed%3A%20className%0D%0A%09%22%20Return%20the%20ObjC%20class%20named%20className%20or%20nil.%20%22%0D%0A%0D%0A%09%5Eself%20class%20classNamed%3A%20className"));
smalltalk.bind(smalltalk.CocoObject,"oopOf:",0
,function (aHandle){var self=this;return smalltalk.JSCocoaController.current().oopOf_(aHandle);;return self;}
,"oop",unescape("oopOf%3A%20aHandle%0D%0A%09%22%20Private%20-%20Return%20the%20oop%20of%20the%20hand%uFFFDle%20aHandle.%0D%0A%09The%20oop%20is%20a%20String%20containing%20hexadecimal%20representation%20of%20native%20object%20address.%0D%0A%09%22%0D%0A%0D%0A%09%5EJSCocoaController%20current%20oopOf%3A%20aHandle"));
smalltalk.bind(smalltalk.CocoObject,"oop",0
,function (){var self=this;return smalltalk.JSCocoaController.current().oopOf_(self['@handle']);;return self;}
,"oop",unescape("oop%0D%0A%09%22%20Return%20the%20oop%20of%20the%20receiver.%0D%0A%09The%20oop%20is%20a%20String%20containing%20hexadecimal%20representation%20of%20native%20object%20address.%0D%0A%09%22%0D%0A%0D%0A%09%5EJSCocoaController%20current%20oopOf%3A%20handle"));
smalltalk.bind(smalltalk.CocoObject,"pointsTo:",0
,function (aHandle){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(self['@handle']))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return (nil.isNil_(aHandle));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.oop()._eq(self.oopOf_(aHandle));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"handles",unescape("pointsTo%3A%20aHandle%0D%0A%09%22%20Return%20true%20if%20the%20receiver%20is%20pointing%20to%20aHandle.%20%22%0D%0A%0D%0A%09handle%20isNil%20ifTrue%3A%20%5B%20%5EaHandle%20isNil%20%5D.%0D%0A%09%5Eself%20oop%20%3D%20%28self%20oopOf%3A%20aHandle%29"));
smalltalk.bind(smalltalk.CocoObject,"jsName",0
,function (){var self=this;return self.implementedBySubclass_("jsName");;return self;}
,"private",unescape("jsName%0D%0A%20%20%20%20%22%20Private%20-%20Return%20the%20global%20name%20of%20handle.%0D%0A%09This%20message%20is%20sent%20when%20a%20global%20handle%20of%20this%20instance%20is%20required%20to%20initialize%20internal%20handle.%0D%0A%09It%20is%20used%20to%20bind%20native%20singleton%20instance.%0D%0A%09If%20this%20message%20is%20received%20in%20case%20of%20native%20instance%2C%20that%20you%20do%20not%20want%20bound%20to%20a%20singleton%2C%20it%20is%20provably%20an%20error%20on%20your%20side.%0D%0A%09e.g.%20you%20instantiated%20this%20%28native%29%20instance%20with%20%23new%20instead%20of%20using%20%23instance%20message.%0D%0A%09%22%0D%0A%0D%0A%20%20%20%20%5Eself%20implementedBySubclass%3A%20%23jsName"));
smalltalk.bind(smalltalk.CocoObject,"log:",0
,function (anObject){var self=this;return self.$klass.log_(anObject);;return self;}
,"log",unescape("log%3A%20anObject%0D%0A%09%5Eself%20class%20log%3A%20anObject"));
smalltalk.bind(smalltalk.CocoObject,"toString:",0
,function (nsString){var self=this;return new String(nsString);;return self;}
,"converting",unescape("toString%3A%20nsString%0D%0A%09%22%20Private%20-%20Return%20aString%20from%20a%20native%20NSString%20instance.%20%22%0D%0A%0D%0A%09%5E%7B%27new%20String%28nsString%29%27%7D."));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"maxInstallOrder",0
,function (){var self=this;return (5);;return self;}
,"installation",unescape("maxInstallOrder%0D%0A%09%22%20Private%20-%20Return%20the%20maximum%20installation%20order.%20%22%0D%0A%0D%0A%09%5E5"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"isInstalled",0
,function (){var self=this;return (self['@installed'] === true);;return self;}
,"private",unescape("isInstalled%0D%0A%09%22%20Private%20-%20Returns%20true%20if%20the%20receiver%20has%20been%20installed.%20%22%0D%0A%0D%0A%09%5Einstalled%20%3D%3D%20true"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"installOrder",0
,function (){var self=this;return (1);;return self;}
,"installation",unescape("installOrder%0D%0A%09%22%20Private%20-%20Return%20the%20installation%20order.%20%22%0D%0A%0D%0A%09%5E1"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"launch",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;smalltalk.superImplementor(smalltalk.Coco8Implementation.$klass,'launch').apply(self, []);
(((self === smalltalk.Coco8Implementation)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})());
((smalltalk.JSCocoa.isValid()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})());
(function(text){return self.log_(text);}).installAs_("print");
(1).to_do_(self.maxInstallOrder(), (function(step){return self.allSubclassesDo_((function(each){return ((each.installOrder()._eq(step)).mustBeBoolean()==true ? (function(){return each.install();})() : nil);}));}));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"launch",unescape("launch%0D%0A%09%22%20Private%20-%20The%20system%20has%20been%20launched%20and%20start%20execution.%0D%0A%09The%20default%20action%20is%20to%20inject%20implementations%20to%20execution%20environment.%0D%0A%09%22%0D%0A%0D%0A%09super%20launch.%0D%0A%09self%20%3D%3D%20Coco8Implementation%20ifFalse%3A%20%5B%20%5Eself%20%5D.%0D%0A%09JSCocoa%20isValid%20ifFalse%3A%20%5B%20%5Eself%20%5D.%0D%0A%22DEBUG%22%09%5B%3Atext%7C%20self%20log%3A%20text%20%5D%20installAs%3A%20%23print.%0D%0A%091%20to%3A%20self%20maxInstallOrder%20do%3A%20%5B%3Astep%7C%0D%0A%09%09self%20allSubclassesDo%3A%20%5B%3Aeach%7C%0D%0A%09%09%09each%20installOrder%20%3D%20step%20ifTrue%3A%20%5B%0D%0A%09%09%09%09each%20install%0D%0A%09%09%09%5D%0D%0A%09%09%5D.%0D%0A%09%5D."));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"basicNew:",0
,function (aHandle){var self=this;return smalltalk.superImplementor(smalltalk.Coco8Implementation.$klass,'_at').apply(self, [aHandle]);;return self;}
,"private",unescape("basicNew%3A%20aHandle%0D%0A%09%22%20Private%20-%20Returns%20an%20object%20from%20aHandle.%20%22%0D%0A%0D%0A%09%5Esuper%20@%20aHandle"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"newInstance:",0
,function (aHandle){var self=this;return smalltalk.JSCocoaController.concreteInstanceOf_handle_(self, aHandle);;return self;}
,"private",unescape("newInstance%3A%20aHandle%0D%0A%09%22%20Private%20-%20Returns%20a%20concrete%20instance%20wrapping%20aHandle.%20%22%0D%0A%0D%0A%09%5EJSCocoaController%20concreteInstanceOf%3A%20self%20handle%3A%20aHandle"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"objectFromHandle:",0
,function (handle){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(handle))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
((self.isObject_(handle)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return handle;})();throw($s8Ret$)})();})() : nil);
((self.typeOf_(handle["respondsToSelector_"])._eq("undefined")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.PoolDictionary._at(handle);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("objectFromHandle%3A%20handle%0D%0A%09%22%20Private%20-%20Returns%20a%20local%20object%20from%20handle%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09handle%20isNil%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09%28self%20isObject%3A%20handle%29%20ifTrue%3A%20%5B%20%5Ehandle%20%5D.%0D%0A%09%28self%20typeOf%3A%20handle%23respondsToSelector_%29%20%3D%20%27undefined%27%20ifTrue%3A%20%5B%20%22hash%20object%22%0D%0A%09%09%5EPoolDictionary%20@%20handle%0D%0A%09%5D.%0D%0A%09%5Enil"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"@","_at"
,function (handle){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;(((nil.isNil_(handle))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
result=self.objectFromHandle_(handle);
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
((self.readOnly()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.newInstance_(handle);})();throw($s8Ret$)})();})() : nil);
result=((function(){var $1$=handle["cachedInstance"];if(nil.isNil_($1$))return ((function(){return (function(){$s8Ret$.result=(function(){return self.newInstance_(handle).bindToHandle_(handle);})();throw($s8Ret$)})();}).value());return $1$;})());
((smalltalk.is_kindOf_(result,(self))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.newInstance_(handle);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"instantiation",unescape("@%20handle%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09handle%20isNil%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09result%20%3A%3D%20self%20objectFromHandle%3A%20handle.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09self%20readOnly%20ifTrue%3A%20%5B%20%5Eself%20newInstance%3A%20handle%20%5D.%0D%0A%09result%20%3A%3D%20handle%20basicAt%3A%20%23cachedInstance%20ifAbsent%3A%20%5B%0D%0A%09%09%5E%28self%20newInstance%3A%20handle%29%20bindToHandle%3A%20handle%0D%0A%09%5D.%0D%0A%09%28result%20isKindOf%3A%20self%29%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%5Eself%20newInstance%3A%20handle"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"nativeClass",0
,function (){var self=this;return self.classNamed_(self.implementorName());;return self;}
,"objC",unescape("nativeClass%0D%0A%09%22%20Private%20-%20Return%20the%20native%28objC%29%20class%20implementing%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20classNamed%3A%20self%20implementorName"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"nativeClassNonNil",0
,function (){var self=this;var result=nil;result=self.nativeClass();
(((nil.isNil_(result))).mustBeBoolean()==true ? (function(){return self.error_("Native class missing "._comma(self.implementorName().printString()));})() : nil);
return result;;return self;}
,"objC",unescape("nativeClassNonNil%0D%0A%09%22%20Return%20the%20native%28objC%29%20class%20implementing%20the%20receiver%2C%20or%20generates%20an%20error%20if%20not%20present%20in%20this%20system.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20self%20nativeClass.%0D%0A%09result%20isNil%20ifTrue%3A%20%5B%20self%20error%3A%20%27Native%20class%20missing%20%27%2Cself%20implementorName%20printString%20%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"readOnly",0
,function (){var self=this;return (self['@readOnly'] === true);;return self;}
,"objC",unescape("readOnly%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20was%20a%20native%28objC%29%20class.%20%22%0D%0A%0D%0A%09%5EreadOnly%20%3D%3D%20true"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"implementation",0
,function (){var self=this;return [];;return self;}
,"objC",unescape("implementation%0D%0A%09%22%20Private%20-%20Return%20the%20implementation%20literal%20of%20the%20receiver.%0D%0A%09The%20returned%20literal%20will%20be%20used%20to%20install%20the%20receiver%20on%20ObjC%20side.%0D%0A%09The%20default%20answer%20is%20an%20empty%20literal%20spec.%20to%20set%20the%20receiver%20with%20defaults.%0D%0A%09%22%0D%0A%0D%0A%09%5E%23%28%29"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"implementorName",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var tuples=nil;(((self === smalltalk.Coco8Implementation)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "NSObject";})();throw($s8Ret$)})();})() : nil);
tuples=self.implementation();
(((nil.isNil_(tuples)===false)).mustBeBoolean()==true ? (function(){return tuples.do_((function(binding){return ((binding.key()._eq("name")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return binding.value();})();throw($s8Ret$)})();})() : nil);}));})() : nil);
(function(){$s8Ret$.result=(function(){return self.name();})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("implementorName%0D%0A%09%22%20Private%20-%20Return%20the%20name%20of%20class%20that%20implements%20the%20receiver%20on%20ObjC%20side.%20%22%0D%0A%0D%0A%09%7C%20tuples%20%7C%0D%0A%09self%20%3D%3D%20Coco8Implementation%20ifTrue%3A%20%5B%20%5E%23NSObject%20%5D.%0D%0A%09tuples%20%3A%3D%20self%20implementation.%0D%0A%09tuples%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09tuples%20do%3A%20%5B%3Abinding%7C%0D%0A%09%09%09binding%20key%20%3D%20%23name%20ifTrue%3A%20%5B%20%5Ebinding%20value%20%5D%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Eself%20name"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"implementor",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;var result=nil;(((self === smalltalk.Coco8Implementation)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.invalidMessage_("implementor");})();throw($s8Ret$)})();})() : nil);
result=self.classNamed_(self.implementorName());
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){self['@installed']=true;self['@readOnly']=true;return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.JSCocoa.current().class_subclassOf_(self.implementorName(), self.superclass().implementorName());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("implementor%0D%0A%09%22%20Private%20-%20Return%20the%20class%20that%20implements%20the%20receiver%20on%20ObjC%20side.%0D%0A%09Return%20nil%20if%20it%20does%20not%20exist%20%28e.g.%20not%20installed%29.%0D%0A%09Warning%3A%20all%20ObjC%20classes%20must%20be%20subclasses%20of%20NSObject.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09self%20%3D%3D%20Coco8Implementation%20ifTrue%3A%20%5B%20%5Eself%20invalidMessage%3A%20%23implementor%20%5D.%0D%0A%09result%20%3A%3D%20self%20classNamed%3A%20self%20implementorName.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%20%22self%20print%3A%20%27//%20Existing%20class%20%27%2Cself%20implementorName.%22%0D%0A%09%09installed%20%3A%3D%20true.%0D%0A%09%09readOnly%20%3A%3D%20true.%0D%0A%09%09%5Eresult%0D%0A%09%5D.%0D%0A%22%09self%20superclass%20implementor%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20self%20superclass%20implementorName%20%2C%27%20unresolved.%27%0D%0A%09%5D.%22%0D%0A%22self%20print%3A%20%27//%20Creating%20class%20%27%2Cself%20implementorName.%22%0D%0A%09%5EJSCocoa%20current%0D%0A%09%09class%3A%20self%20implementorName%0D%0A%09%09subclassOf%3A%20self%20superclass%20implementorName"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"install",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;((self.isInstalled()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
(((nil.isNil_(self.implementor()))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.error_(self.name()._comma(" Implementor missing."));})();throw($s8Ret$)})();})() : nil);
((self.isInstalled()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self;})();throw($s8Ret$)})();})() : nil);
smalltalk.JSCocoa.current().class_bindings_(self.implementorName(), self.installationBindings());
self['@installed']=true;return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"install",unescape("install%0D%0A%09%22%20Private%20-%20Inject%20the%20receiver%20onto%20%28ObjC%29%20execution%20environment.%20%22%0D%0A%0D%0A%09self%20isInstalled%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09self%20implementor%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20self%20name%20%2C%27%20Implementor%20missing.%27%0D%0A%09%5D.%0D%0A%09self%20isInstalled%20ifTrue%3A%20%5B%20%5Eself%20%5D.%0D%0A%09JSCocoa%20current%0D%0A%09%09class%3A%20self%20implementorName%0D%0A%09%09bindings%3A%20self%20installationBindings.%0D%0A%09installed%20%3A%3D%20true."));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"installationBindings",0
,function (){var self=this;return self.implementation().inject_into_([], (function(total,each){return total._comma(self.installationBindingsFor_(each));}));;return self;}
,"bindings",unescape("installationBindings%0D%0A%09%22%20Private%20-%20Return%20the%20bindings%20to%20implement%20ObjC%20side%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20implementation%20inject%3A%20%23%28%29%20into%3A%20%5B%3Atotal%20%3Aeach%7C%0D%0A%09%09total%20%2C%28self%20installationBindingsFor%3A%20each%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"installationBindingsFor:",0
,function (assoc){var $s8Ret$={name:"stReturn"};try{var self=this;((assoc.key()._eq("name")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();})() : nil);
((assoc.key()._eq("methods")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return assoc.value().collect_((function(spec){return self.bindingForMethod_(spec);}));})();throw($s8Ret$)})();})() : nil);
((assoc.key()._eq("actions")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return assoc.value().collect_((function(selector){return self.bindingForAction_(selector);}));})();throw($s8Ret$)})();})() : nil);
((assoc.key()._eq("outlets")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return assoc.value().collect_((function(selector){return self.bindingForOutlet_(selector);}));})();throw($s8Ret$)})();})() : nil);
((assoc.key()._eq("keys")).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return assoc.value().collect_((function(selector){return self.bindingForKey_(selector);}));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20binding%20assoc%3D")._comma(assoc.asString()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"bindings",unescape("installationBindingsFor%3A%20assoc%0D%0A%09%22%20Private%20-%20Return%20the%20binding%20for%20installation%20tuple%20%28assoc%29.%20%22%0D%0A%0D%0A%09assoc%20key%20%3D%20%23name%20ifTrue%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09assoc%20key%20%3D%20%23methods%20ifTrue%3A%20%5B%20%5Eassoc%20value%20collect%3A%20%5B%3Aspec%7C%20self%20bindingForMethod%3A%20spec%20%5D%20%5D.%0D%0A%09assoc%20key%20%3D%20%23actions%20ifTrue%3A%20%5B%20%5Eassoc%20value%20collect%3A%20%5B%3Aselector%7C%20self%20bindingForAction%3A%20selector%20%5D%20%5D.%0D%0A%09assoc%20key%20%3D%20%23outlets%20ifTrue%3A%20%5B%20%5Eassoc%20value%20collect%3A%20%5B%3Aselector%7C%20self%20bindingForOutlet%3A%20selector%20%5D%20%5D.%0D%0A%09assoc%20key%20%3D%20%23keys%20%20%20%20ifTrue%3A%20%5B%20%5Eassoc%20value%20collect%3A%20%5B%3Aselector%7C%20self%20bindingForKey%3A%20selector%20%5D%20%5D.%0D%0A%09%5Eself%20error%3A%20%27Invalid%20binding%20assoc%3D%27%2Cassoc%20asString"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"bindingForKey:",0
,function (selector){var self=this;return selector._minus_gt("Key");;return self;}
,"bindings",unescape("bindingForKey%3A%20selector%0D%0A%09%22%20Private%20-%20Return%20the%20binding%20for%20this%20kind%20of%20implementor.%20%22%0D%0A%0D%0A%09%5Eselector%20-%3E%20%23Key%20"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"bindingForOutlet:",0
,function (selector){var self=this;return selector._minus_gt("IBOutlet");;return self;}
,"bindings",unescape("bindingForOutlet%3A%20selector%0D%0A%09%22%20Private%20-%20Return%20the%20binding%20for%20this%20kind%20of%20implementor.%20%22%0D%0A%0D%0A%09%5Eselector%20-%3E%20%23IBOutlet%20"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"objCMethodImplementing:",0
,function (selector){var $s8Ret$={name:"stReturn"};try{var self=this;var mth=nil;mth=self._gt_gt(selector);
(((nil.isNil_(mth))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.error_(unescape("Missing%20method%20for%20%23")._comma(selector));})();throw($s8Ret$)})();})() : nil);
self.mustBeObjC_for_(mth.fn(), selector);
(function(){$s8Ret$.result=(function(){return mth;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"bindings",unescape("objCMethodImplementing%3A%20selector%0D%0A%09%22%20Private%20-%20Return%20the%20method%20implementation%20for%20selector.%0D%0A%09Note%3A%20MUST%20be%20implemented%20in%20the%20receiver%20and%20as%20objC%20method.%0D%0A%09%20%20%20%20%20%20In%20case%20you%20want%20to%20use%20%28s8%29superclass%20implementation%2C%0D%0A%09%09it%20is%20valid%20to%20send%20message%20to%20super%2C%0D%0A%09%09just%20after%20%3CobjC%20method%3E%20directive.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20mth%20%7C%0D%0A%09mth%20%3A%3D%20self%20%3E%3E%20selector.%0D%0A%09mth%20isNil%20ifTrue%3A%20%5B%20%5Eself%20error%3A%20%27Missing%20method%20for%20%23%27%2Cselector%20%5D.%0D%0A%09self%20mustBeObjC%3A%20mth%20fn%20for%3A%20selector.%0D%0A%09%5Emth"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"bindingForAction:",0
,function (selector){var self=this;var mth=nil;mth=self.objCMethodImplementing_(selector);
return selector._minus_gt(smalltalk.Array.with_with_("IBAction", mth.fn()));;return self;}
,"bindings",unescape("bindingForAction%3A%20selector%0D%0A%09%22%20Private%20-%20Return%20the%20binding%20for%20this%20kind%20of%20implementor.%20%22%0D%0A%0D%0A%09%7C%20mth%20%7C%0D%0A%09mth%20%3A%3D%20self%20objCMethodImplementing%3A%20selector.%0D%0A%09%5Eselector%20-%3E%20%28Array%20with%3A%20%23IBAction%20with%3A%20mth%20fn%29%20"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"bindingForMethod:",0
,function (spec){var $s8Ret$={name:"stReturn"};try{var self=this;var selector=nil;var encodings=nil;var mth=nil;var result=nil;((spec.isArray()).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.bindingForMethod_(smalltalk.Array.with_with_(spec, ""));})();throw($s8Ret$)})();})());
selector=spec.first();
encodings=spec.last().asArrayOfSubstrings();
mth=self.objCMethodImplementing_(selector);
result=selector._minus_gt(encodings._comma(smalltalk.Array.with_(mth.fn())));
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"bindings",unescape("bindingForMethod%3A%20spec%0D%0A%09%22%20Private%20-%20Return%20the%20binding%20for%20this%20kind%20of%20implementor.%0D%0A%09spec%20can%20be%20aSelector%20or%20%23%28%20aSelector%20encodings%20%29%20%22%0D%0A%0D%0A%09%7C%20selector%20encodings%20mth%20result%20%7C%0D%0A%09spec%20isArray%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20bindingForMethod%3A%20%28Array%20with%3A%20spec%20with%3A%20%27%27%29%0D%0A%09%5D.%0D%0A%09selector%20%3A%3D%20spec%20first.%0D%0A%09encodings%20%3A%3D%20spec%20last%20asArrayOfSubstrings.%0D%0A%09mth%20%3A%3D%20self%20objCMethodImplementing%3A%20selector.%0D%0A%09result%20%3A%3D%20selector%20-%3E%20%28encodings%20%2C%28Array%20with%3A%20mth%20fn%29%29.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"mustBeObjC:for:",0
,function (aFunction,selector){var $s8Ret$={name:"stReturn"};try{var self=this;((aFunction.toString().includes_(unescape("self%3Dthis%3Bif%20%28%21self.%24klass%29"))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_(unescape("Missing%20%3CobjC%3A%20method%3E%20directive%20for%20method%20at%20%23")._comma(selector));})();throw($s8Ret$)})();})());return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"bindings",unescape("mustBeObjC%3A%20aFunction%20for%3A%20selector%0D%0A%09%22%20Private%20-%20Ensure%20aFunction%20implements%20an%20objC%20directive.%20%22%0D%0A%0D%0A%09%28aFunction%20toString%20includes%3A%20%27self%3Dthis%3Bif%20%28%21self.%24klass%29%27%29%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20%27Missing%20%3CobjC%3A%20method%3E%20directive%20for%20method%20at%20%23%27%2Cselector%0D%0A%09%5D"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"compiler",0
,function (){var self=this;var compiler=nil;compiler=smalltalk.superImplementor(smalltalk.Coco8Implementation.$klass,'compiler').apply(self, []);
compiler.when_do_("needsParser", (function(){var parser=nil;parser=smalltalk.SmalltalkParser.$$new();parser.when_do_("needsDirectiveParser:ws:", (function(number,ws){return self.objCParser_ws_for_(number, ws, parser);}));return parser;}));
return compiler;;return self;}
,"compiling",unescape("compiler%0D%0A%09%22%20Return%20a%20compiler%20for%20receiver%27s%20source%20code.%0D%0A%09Note%3A%20we%20use%20a%20compiler%20extension%20to%20support%20objC%20directives.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20compiler%20%7C%0D%0A%09compiler%20%3A%3D%20super%20compiler.%0D%0A%09compiler%20when%3A%20%23needsParser%20do%3A%20%5B%20%7C%20parser%20%7C%0D%0A%09%09parser%20%3A%3D%20SmalltalkParser%20new.%0D%0A%09%09parser%09when%3A%20%23needsDirectiveParser%3Aws%3A%0D%0A%09%09%09do%3A%20%5B%3Anumber%20%3Aws%7C%20self%20objCParser%3A%20number%20ws%3A%20ws%20for%3A%20parser%20%5D.%0D%0A%09%09parser%0D%0A%09%5D.%0D%0A%09%5Ecompiler"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"objCParser:ws:for:",0
,function (number,ws,parser){var self=this;var aParser=nil;aParser="objC:".asParser()._comma(unescape("%5E%3E").asCharacterParser().star().flatten())._comma(unescape("%3E").asParser())._eq_eq_gt((function(node){return self.objCNode_(node.second());}));
return aParser._slash(parser.defaultDirective_ws_(number, ws));;return self;}
,"compiling",unescape("objCParser%3A%20number%20ws%3A%20ws%20for%3A%20parser%0D%0A%09%22%20Private%20-%20Return%20the%20directive%20parser%20for%20objective%20C%20method.%20%22%0D%0A%0D%0A%09%7C%20aParser%20%7C%0D%0A%09aParser%20%3A%3D%20%27objC%3A%27%20asParser%0D%0A%09%09%2C%27%5E%3E%27%20asCharacterParser%20star%20flatten%0D%0A%09%09%2C%27%3E%27%20asParser%0D%0A%09%09%3D%3D%3E%20%5B%3Anode%7C%20self%20objCNode%3A%20node%20second%20%5D.%0D%0A%09%5EaParser%20/%28parser%20defaultDirective%3A%20number%20ws%3A%20ws%29"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"objCNode:",0
,function (spec){var self=this;var code=nil;((["method", "implementation"].includes_(spec.trimBlanks())).mustBeBoolean()==true ? nil : (function(){return spec.error_(unescape("Invalid%20objC%20directive%20%28")._comma(spec)._comma(unescape("%29.")));})());
code=(function(){return unescape("if%20%28%21self.%24klass%29%20%7Bself%20%3D%20smalltalk.")._comma(self.name())._comma(unescape("._at%28self%29%3B%7D"));});
return smalltalk.JSDirectiveNode.code_protected_(code, false);;return self;}
,"compiling",unescape("objCNode%3A%20spec%0D%0A%09%22%20Private%20-%20Return%20the%20directive%20parser%20for%20objC.%20%22%0D%0A%0D%0A%09%7C%20code%20%7C%0D%0A%09%28%23%28%20method%20implementation%20%29%20includes%3A%20spec%20trimBlanks%29%20ifFalse%3A%20%5B%0D%0A%09%09spec%20error%3A%20%27Invalid%20objC%20directive%20%28%27%2Cspec%2C%27%29.%27%0D%0A%09%5D.%0D%0A%0D%0A%09%22objC%20implementation/method%20bind%20self%20to%20an%20instance%20of%20the%20receiver%20on%20method%20activation.%22%0D%0A%09code%20%3A%3D%20%5B%20%27if%20%28%21self.%24klass%29%20%7Bself%20%3D%20smalltalk.%27%2Cself%20name%2C%27._at%28self%29%3B%7D%27%20%5D.%0D%0A%09%5EJSDirectiveNode%20code%3A%20code%20protected%3A%20false"));
smalltalk.bind(smalltalk.Coco8Implementation.$klass,"asArray:",0
,function (aNSArray){var $s8Ret$={name:"stReturn"};try{var self=this;var size=nil;(((nil.isNil_(aNSArray))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
size=((function(){var $1$=aNSArray["length"];if(nil.isNil_($1$))return ((function(){return (function(){$s8Ret$.result=(function(){return [];})();throw($s8Ret$)})();}).value());return $1$;})());
(function(){$s8Ret$.result=(function(){return (1).to_(size).collect_((function(i){return ((function(){var $1$=aNSArray[i._minus((1))];if(nil.isNil_($1$))return nil;return $1$;})());}));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"converting",unescape("asArray%3A%20aNSArray%0D%0A%09%22%20Private%20-%20Convert%20an%20objC%20NSArray%20to%20javascript%20array.%20%22%0D%0A%0D%0A%09%7C%20size%20%7C%0D%0A%09aNSArray%20isNil%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09size%20%3A%3D%20aNSArray%20basicAt%3A%20%23length%20ifAbsent%3A%20%5B%20%5E%23%28%29%20%5D.%0D%0A%09%5E%281%20to%3A%20size%29%20collect%3A%20%5B%3Ai%7C%20aNSArray%20basicAt%3A%20i%20-%201%20%5D"));
smalltalk.bind(smalltalk.Coco8Implementation,"bindToHandle:",0
,function (aHandle){var self=this;(aHandle["cachedInstance"]=(self));
return self;;return self;}
,"binding",unescape("bindToHandle%3A%20aHandle%0D%0A%09%22%20Private%20-%20Bind%20the%20receiver%20to%20aHandle.%0D%0A%09This%20produce%20a%20two-way%20binding%20to%20native%20handle%2C%0D%0A%09%20to%20ensure%20the%20same%20s8%20instance%20will%20represent%20the%20same%20native%20handle.%0D%0A%09See%20class%20side%20implementation%20for%20%23@%20%28instance-caching%29%0D%0A%09%22%0D%0A%0D%0A%09aHandle%20basicAt%3A%20%23cachedInstance%20put%3A%20self.%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.Coco8Implementation,"handle:",0
,function (aHandle){var $s8Ret$={name:"stReturn"};try{var self=this;(((nil.isNil_(smalltalk.superImplementor(smalltalk.Coco8Implementation,'handle_').apply(self, [aHandle])))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return nil;})();throw($s8Ret$)})();})() : nil);
((self.$klass.readOnly()).mustBeBoolean()==true ? nil : (function(){return self.bindToHandle_(aHandle);})());return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"binding",unescape("handle%3A%20aHandle%0D%0A%09%22%20Private%20-%20Set%20the%20handle%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%28super%20handle%3A%20aHandle%29%20isNil%20ifTrue%3A%20%5B%20%5Enil%20%5D.%0D%0A%09self%20class%20readOnly%20ifFalse%3A%20%5B%20self%20bindToHandle%3A%20aHandle%20%5D."));
smalltalk.bind(smalltalk.Coco8Implementation,"isKindOfClass:",0
,function (aCoco8ImplementationClass){var self=this;return smalltalk.JSCocoaController.current().is_kindOfClass_(self, aCoco8ImplementationClass);;return self;}
,"iko",unescape("isKindOfClass%3A%20aCoco8ImplementationClass%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20is%20kind%20of%20aCoco8ImplementationClass%20%22%0D%0A%0D%0A%09%5EJSCocoaController%20current%20is%3A%20self%20kindOfClass%3A%20aCoco8ImplementationClass"));
smalltalk.bind(smalltalk.Coco8Implementation,"super:",0
,function (args){var self=this;return self['@handle'].Super(args);;return self;}
,"objC",unescape("super%3A%20args%0D%0A%09%22%20Private%20-%20Return%20the%20result%20of%20calling%20the%20native%28objC%29%20super%20implementation.%0D%0A%09WARNING%3A%20the%20args%20MUST%20be%20the%20callee%20arguments%20and%20the%20receiver%20be%20a%20valid%20objC%20implementor%20instance.%0D%0A%09%22%0D%0A%0D%0A%09%5Ehandle%20%23Super%3A%20args"));
smalltalk.bind(smalltalk.Coco8Implementation,"original:",0
,function (args){var self=this;return self['@handle'].Original(args);;return self;}
,"objC",unescape("original%3A%20args%0D%0A%09%22%20Private%20-%20Return%20the%20result%20of%20calling%20the%20native%28objC%29%20original%20implementation.%0D%0A%09WARNING%3A%20the%20args%20MUST%20be%20the%20callee%20arguments%20and%20the%20receiver%20be%20a%20valid%20objC%20implementor%20instance.%0D%0A%09%22%0D%0A%0D%0A%09%5Ehandle%20%23Original%3A%20args"));
smalltalk.bind(smalltalk.Coco8Implementation,"nativeClass",0
,function (){var self=this;return self.$klass.nativeClass();;return self;}
,"objC",unescape("nativeClass%0D%0A%09%22%20Private%20-%20Return%20the%20native%28objC%29%20class%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20class%20nativeClass"));
smalltalk.bind(smalltalk.Coco8Implementation,"asArray:",0
,function (aNSArray){var self=this;return self.$klass.asArray_(aNSArray);;return self;}
,"converting",unescape("asArray%3A%20aNSArray%0D%0A%09%22%20Private%20-%20Convert%20an%20objC%20NSArray%20to%20javascript%20array.%20%22%0D%0A%0D%0A%09%5Eself%20class%20asArray%3A%20aNSArray"));
smalltalk.bind(smalltalk.NSObject.$klass,"instance",0
,function (){var self=this;return self._at(((function(){var $1$=self.nativeClass()["instance"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"instantiation",unescape("instance%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20@%20%28self%20nativeClass%20basicAt%3A%20%23instance%29"));
smalltalk.bind(smalltalk.NSObject.$klass,"classHandle",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["class"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("classHandle%0D%0A%09%22%20Return%20the%20objC%20class%20handle%20%28of%20the%20native%20class%29%20of%20the%20receiver.%20%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23class"));
smalltalk.bind(smalltalk.NSObject.$klass,"description",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["description"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("description%0D%0A%09%22%20Returns%20a%20string%20that%20represents%20the%20contents%20of%20the%20receiver.%20%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23description"));
smalltalk.bind(smalltalk.NSObject,"respondsToSelector:",0
,function (objCSelector){var self=this;return (nil.isNil_(self.handle().respondsToSelector_(objCSelector))===false);;return self;}
,"query",unescape("respondsToSelector%3A%20objCSelector%0D%0A%0D%0A%09%5E%28self%20handle%20respondsToSelector%3A%20objCSelector%29%20notNil"));
smalltalk.bind(smalltalk.NSObject,"releaseHandle",0
,function (){var self=this;self.handle().release();
return smalltalk.superImplementor(smalltalk.NSObject,'releaseHandle').apply(self, []);;return self;}
,"release",unescape("releaseHandle%0D%0A%09%22%20Release%20the%20handle%20%28native%20objC%20object%29.%20%22%0D%0A%0D%0A%09self%20handle%20release.%0D%0A%09%5Esuper%20releaseHandle"));
smalltalk.bind(smalltalk.NSObject,"performSelector:withObject:afterDelay:",0
,function (selector,arg,delay){var self=this;return self.handle().performSelector_withObject_afterDelay_(selector, arg.json(), delay);;return self;}
,"wrappers",unescape("performSelector%3A%20selector%20withObject%3A%20arg%20afterDelay%3A%20delay%20%0D%0A%09%22%20Wrap%20method%20delegating%20performSelector%3AwithObject%3AafterDelay%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23performSelector_withObject_afterDelay_%3A%20selector%20with%3A%20arg%20json%20with%3A%20delay%20"));
smalltalk.bind(smalltalk.NSObject,"performSelectorOnMainThread:withObject:waitUntilDone:",0
,function (selector,arg,aBoolean){var self=this;return self.handle().performSelectorOnMainThread_withObject_waitUntilDone_(selector, arg.json(), aBoolean);;return self;}
,"wrappers",unescape("performSelectorOnMainThread%3A%20selector%20withObject%3A%20arg%20waitUntilDone%3A%20aBoolean%20%0D%0A%09%22%20Wrap%20method%20delegating%20performSelectorOnMainThread%3AwithObject%3AwaitUntilDone%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23performSelectorOnMainThread_withObject_waitUntilDone_%3A%20selector%20with%3A%20arg%20json%20with%3A%20aBoolean%20"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"implementation",0
,function (){var self=this;return "outlets"._minus_gt([])._comma("actions"._minus_gt([]))._comma("methods"._minus_gt([["fire", "void"], ["fireWithArguments:", "void id"]]));;return self;}
,"objC",unescape("implementation%0D%0A%09%22%20Private%20-%20Return%20the%20implementation%20literal%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28%23outlets%20-%3E%20%23%28%29%29%0D%0A%09%2C%28%23actions%20-%3E%20%23%28%29%29%0D%0A%09%2C%28%23methods%20-%3E%20%23%28%0D%0A%09%09%23%28%20%23fire%20%23void%20%29%0D%0A%09%09%23%28%20%23fireWithArguments%3A%20%27void%20id%27%29%0D%0A%09%09%29%29"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"block:",0
,function (action){var self=this;return (function($rec){$rec.block_(action);return $rec.yourself();})(self.$$new());;return self;}
,"instantiation",unescape("block%3A%20action%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20that%20will%20evaluate%20action%20when%20fired.%20%22%0D%0A%0D%0A%09%5Eself%20new%0D%0A%09%09block%3A%20action%3B%0D%0A%09%09yourself"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"value:withArguments:after:",0
,function (action,array,milliSeconds){var self=this;return self.value_withArguments_afterSeconds_(action, array, milliSeconds._slash((1000)));;return self;}
,"instantiation",unescape("value%3A%20action%20withArguments%3A%20array%20after%3A%20milliSeconds%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20that%20will%20evaluate%20action%20with%20arguments%20array%20after%20specified%20time.%20%22%0D%0A%0D%0A%09%5Eself%09value%3A%20action%0D%0A%09%09withArguments%3A%20array%0D%0A%09%09afterSeconds%3A%20milliSeconds%20/%201000"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"value:withArguments:afterSeconds:",0
,function (action,anArray,seconds){var self=this;return self.block_((function(){return action.evaluateWithArguments_(anArray);})).performSelector_withObject_afterDelay_("fire", nil, seconds);;return self;}
,"instantiation",unescape("value%3A%20action%20withArguments%3A%20anArray%20afterSeconds%3A%20seconds%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20that%20will%20evaluate%20action%20with%20arguments%20anArray%20after%20specified%20time.%20%22%0D%0A%0D%0A%09%5E%28self%20block%3A%20%5B%20action%20evaluateWithArguments%3A%20anArray%20%5D%29%0D%0A%09%09performSelector%3A%20%23fire%20withObject%3A%20nil%0D%0A%09%09afterDelay%3A%20seconds"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"value:after:",0
,function (action,milliSeconds){var self=this;return self.value_withArguments_after_(action, [], milliSeconds);;return self;}
,"instantiation",unescape("value%3A%20action%20after%3A%20milliSeconds%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20that%20will%20evaluate%20action%20with%20arguments%20array%20after%20specified%20time.%20%22%0D%0A%0D%0A%09%5Eself%09value%3A%20action%0D%0A%09%09withArguments%3A%20%23%28%29%0D%0A%09%09after%3A%20milliSeconds"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"value:afterSeconds:",0
,function (action,seconds){var self=this;return self.value_withArguments_afterSeconds_(action, [], seconds);;return self;}
,"instantiation",unescape("value%3A%20action%20afterSeconds%3A%20seconds%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20that%20will%20evaluate%20action%20with%20arguments%20array%20after%20specified%20time.%20%22%0D%0A%0D%0A%09%5Eself%09value%3A%20action%0D%0A%09%09withArguments%3A%20%23%28%29%0D%0A%09%09afterSeconds%3A%20seconds"));
smalltalk.bind(smalltalk.Coco8Closure.$klass,"value:withArguments:",0
,function (action,anArray){var self=this;return self.block_((function(){return action.evaluateWithArguments_(anArray);})).performSelectorOnMainThread_withObject_waitUntilDone_("fire", nil, false);;return self;}
,"instantiation",unescape("value%3A%20action%20withArguments%3A%20anArray%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver%20that%20will%20evaluate%20action%20with%20arguments%20anArray%20in%20main%20thread.%20%22%0D%0A%0D%0A%09%5E%28self%20block%3A%20%5B%20action%20evaluateWithArguments%3A%20anArray%20%5D%29%0D%0A%09%09performSelectorOnMainThread%3A%20%23fire%0D%0A%09%09withObject%3A%20nil%20waitUntilDone%3A%20false"));
smalltalk.bind(smalltalk.Coco8Closure,"block",0
,function (){var self=this;return self['@block'];;return self;}
,"accessing",unescape("block%0D%0A%09%22%20Return%20the%20block%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eblock"));
smalltalk.bind(smalltalk.Coco8Closure,"block:",0
,function (anObject){var self=this;self['@block']=anObject;return self;}
,"accessing",unescape("block%3A%20anObject%0D%0A%09%22%20Set%20the%20block%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09block%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.Coco8Closure,"fireWithArguments:",0
,function (theArguments){var self=this;if (!self.$klass) {self = smalltalk.Coco8Closure._at(self);}
self.block().evaluateWithArguments_(theArguments);return self;}
,"objC",unescape("fireWithArguments%3A%20theArguments%0D%0A%09%22%20Private%20-%20Evaluate%20the%20block%20with%20arguments.%20%22%0D%0A%0D%0A%09%3CobjC%3A%20method%3E%0D%0A%09self%20block%20evaluateWithArguments%3A%20theArguments"));
smalltalk.bind(smalltalk.Coco8Closure,"fire",0
,function (){var self=this;if (!self.$klass) {self = smalltalk.Coco8Closure._at(self);}
self.block().evaluate();return self;}
,"objC",unescape("fire%0D%0A%09%22%20Private%20-%20Evaluate%20the%20block.%20%22%0D%0A%0D%0A%09%3CobjC%3A%20method%3E%0D%0A%09self%20block%20evaluate"));
smalltalk.bind(smalltalk.Coco8Closure,"initializeHandle",0
,function (){var self=this;self['@handle']=((function(){var $1$=self.nativeClass()["instance"];if(nil.isNil_($1$))return nil;return $1$;})());
self.bindToHandle_(self['@handle']);return self;}
,"initialize",unescape("initializeHandle%0D%0A%09%22%20Private%20-%20Initialize%20the%20handle%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09handle%20%3A%3D%20self%20nativeClass%20basicAt%3A%20%23instance.%0D%0A%09self%20bindToHandle%3A%20handle."));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"runtimeReport",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["runtimeReport"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("runtimeReport%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20runtimeReport%20call.%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23runtimeReport"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"hazardReport",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["hazardReport"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("hazardReport%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20hazardReport%20call.%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23hazardReport"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"liveInstanceHash",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["liveInstanceHash"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("liveInstanceHash%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20liveInstanceHash%20call.%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23liveInstanceHash"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"runningArchitecture",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["runningArchitecture"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("runningArchitecture%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20runningArchitecture%20call.%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23runningArchitecture"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"logInstanceStats",0
,function (){var self=this;return ((function(){var $1$=self.nativeClass()["logInstanceStats"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("logInstanceStats%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20logInstanceStats%20call.%20%22%0D%0A%0D%0A%09%5Eself%20nativeClass%20basicAt%3A%20%23logInstanceStats"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"rootClasses",0
,function (){var self=this;return smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["rootClasses"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("rootClasses%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20rootClasses%20call.%20%22%0D%0A%0D%0A%09%5ENSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23rootClasses%29"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"classes",0
,function (){var self=this;return smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["classes"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("classes%0D%0A%09%22%20Return%20the%20result%20of%20evaluating%20classes%20call.%20%22%0D%0A%0D%0A%09%5ENSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23classes%29"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"protocols",0
,function (){var self=this;return smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["protocols"];if(nil.isNil_($1$))return nil;return $1$;})())).asArray().collect_((function(each){return smalltalk.Array.with_with_(each.name, smalltalk.NSArray._at(each.methods).asArray().collect_((function(mth){return (function($rec){$rec.at_put_("name", mth.name);$rec.at_put_("encoding", mth.encoding);$rec.at_put_("isRequired", smalltalk.Boolean._at(mth.isRequired));$rec.at_put_("isInstance", smalltalk.Boolean._at(mth.isInstance));return $rec.yourself();})(smalltalk.PoolDictionary.$$new());})));}));;return self;}
,"accessing",unescape("protocols%0D%0A%09%22%20Return%20the%20description%20of%20the%20installed%20protocols.%20%22%0D%0A%0D%0A%09%5E%28NSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23protocols%29%29%20asArray%20collect%3A%20%5B%3Aeach%7C%0D%0A%09%09Array%09with%3A%20each%23name%0D%0A%09%09%09with%3A%20%28%20%28NSArray%20@%20each%23methods%29%20asArray%0D%0A%09%09%09collect%3A%20%5B%3Amth%7C%20PoolDictionary%20new%0D%0A%09%09%09%09at%3A%20%23name%20put%3A%20mth%23name%3B%0D%0A%09%09%09%09at%3A%20%23encoding%20put%3A%20mth%23encoding%3B%0D%0A%09%09%09%09at%3A%20%23isRequired%20put%3A%20Boolean%20@%20mth%23isRequired%3B%0D%0A%09%09%09%09at%3A%20%23isInstance%20put%3A%20Boolean%20@%20mth%23isInstance%3B%0D%0A%09%09%09%09yourself%0D%0A%09%09%09%5D%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"nativeMethods",0
,function (){var self=this;return smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["methods"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("nativeMethods%0D%0A%09%22%20Return%20the%20installed%20native%20methods.%20%22%0D%0A%0D%0A%09%5ENSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23methods%29"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"imageNames",0
,function (){var self=this;return smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["imageNames"];if(nil.isNil_($1$))return nil;return $1$;})())).asArray().collect_((function(each){return smalltalk.Array.with_with_(each.name, smalltalk.NSArray._at(each.classNames).asArray());}));;return self;}
,"accessing",unescape("imageNames%0D%0A%09%22%20Return%20the%20installed%20imageNames.%20%22%0D%0A%0D%0A%09%5E%28NSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23imageNames%29%29%20asArray%20collect%3A%20%5B%3Aeach%7C%0D%0A%09%09Array%20with%3A%20each%23name%20with%3A%20%28NSArray%20@%20each%23classNames%29%20asArray%0D%0A%09%5D"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"protocolsDo:",0
,function (aTwoArgumentsBlock){var self=this;smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["protocols"];if(nil.isNil_($1$))return nil;return $1$;})())).asArray().do_((function(each){return smalltalk.NSArray._at(each.methods).asArray().do_((function(mth){return aTwoArgumentsBlock.value_value_(each.name, (function($rec){$rec.at_put_("name", mth.name);$rec.at_put_("encoding", mth.encoding);$rec.at_put_("isRequired", smalltalk.Boolean._at(mth.isRequired));$rec.at_put_("isInstance", smalltalk.Boolean._at(mth.isInstance));return $rec.yourself();})(smalltalk.PoolDictionary.$$new()));}));}));return self;}
,"accessing",unescape("protocolsDo%3A%20aTwoArgumentsBlock%0D%0A%09%22%20Evaluates%20aTwoArgumentsBlock%20with%20description%20of%20the%20installed%20protocols.%20%22%0D%0A%0D%0A%09%28NSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23protocols%29%29%20asArray%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09%28NSArray%20@%20each%23methods%29%20asArray%20do%3A%20%5B%3Amth%7C%0D%0A%09%09%09aTwoArgumentsBlock%0D%0A%09%09%09%09value%3A%20each%23name%0D%0A%09%09%09%09value%3A%20%28PoolDictionary%20new%0D%0A%09%09%09%09%09at%3A%20%23name%20put%3A%20mth%23name%3B%0D%0A%09%09%09%09%09at%3A%20%23encoding%20put%3A%20mth%23encoding%3B%0D%0A%09%09%09%09%09at%3A%20%23isRequired%20put%3A%20Boolean%20@%20mth%23isRequired%3B%0D%0A%09%09%09%09%09at%3A%20%23isInstance%20put%3A%20Boolean%20@%20mth%23isInstance%3B%0D%0A%09%09%09%09%09yourself%29%0D%0A%09%09%5D%0D%0A%09%5D"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"allProtocols",0
,function (){var self=this;return smalltalk.NSArray._at(((function(){var $1$=self.nativeClass()["protocols"];if(nil.isNil_($1$))return nil;return $1$;})())).asArray().collect_((function(each){return smalltalk.Array.with_with_(each.name, smalltalk.NSArray._at(each.methods).asArray().collect_((function(mth){return smalltalk.Array.with_with_with_with_(mth.name, mth.encoding, ((smalltalk.Boolean._at(mth.isRequired)).mustBeBoolean()==true ? (function(){return "required";})() : (function(){return "optional";})()), ((smalltalk.Boolean._at(mth.isInstance)).mustBeBoolean()==true ? (function(){return "instance";})() : (function(){return "class";})()));})));}));;return self;}
,"accessing",unescape("allProtocols%0D%0A%09%22%20Return%20the%20literal%20spec%20of%20the%20installed%20protocols.%20%22%0D%0A%0D%0A%09%5E%28NSArray%20@%20%28self%20nativeClass%20basicAt%3A%20%23protocols%29%29%20asArray%20collect%3A%20%5B%3Aeach%7C%0D%0A%09%09Array%09with%3A%20each%23name%0D%0A%09%09%09with%3A%20%28%20%28NSArray%20@%20each%23methods%29%20asArray%0D%0A%09%09%09collect%3A%20%5B%3Amth%7C%20Array%0D%0A%09%09%09%09with%3A%20mth%23name%20with%3A%20mth%23encoding%0D%0A%09%09%09%09with%3A%20%28Boolean%20@%20mth%23isRequired%20ifTrue%3A%20%5B%23required%5D%20ifFalse%3A%20%5B%23optional%5D%29%0D%0A%09%09%09%09with%3A%20%28Boolean%20@%20mth%23isInstance%20ifTrue%3A%20%5B%23instance%5D%20ifFalse%3A%20%5B%23class%5D%29%0D%0A%09%09%09%5D%29%0D%0A%09%5D"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"sharedController",0
,function (){var self=this;return self._at(((function(){var $1$=self.nativeClass()["sharedController"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"instantiation",unescape("sharedController%0D%0A%09%22%20Return%20the%20singleton%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20@%20%28self%20nativeClass%20basicAt%3A%20%23sharedController%29"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"current",0
,function (){var self=this;(((nil.isNil_(smalltalk.JSCocoaController.classVariableAt_("Current")))).mustBeBoolean()==true ? (function(){return smalltalk.JSCocoaController.classVariableAt_put_("Current",self.sharedController());})() : nil);
return smalltalk.JSCocoaController.classVariableAt_("Current");;return self;}
,"instantiation",unescape("current%0D%0A%09%22%20Return%20the%20singleton%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09Current%20isNil%20ifTrue%3A%20%5B%20Current%20%3A%3D%20self%20sharedController%20%5D.%0D%0A%09%5ECurrent"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"garbageCollect",0
,function (){var self=this;return self.sharedController().garbageCollect();;return self;}
,"instantiation",unescape("garbageCollect%0D%0A%09%22%20Force%20garbage%20collection.%20%22%0D%0A%0D%0A%09%5Eself%20sharedController%20garbageCollect%20%22garbageCollectNow%22"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"ping:",0
,function (aNSObject){var self=this;return self.sharedController().ping_(aNSObject);;return self;}
,"debug",unescape("ping%3A%20aNSObject%0D%0A%09%22%20DEBUG%20-%20call%20to%20ping%3A%20function.%20%22%0D%0A%0D%0A%09%5Eself%20sharedController%20ping%3A%20aNSObject"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"pong",0
,function (){var self=this;return self.sharedController().pong();;return self;}
,"debug",unescape("pong%0D%0A%09%22%20DEBUG%20-%20Return%20the%20result%20of%20the%20pong%20function.%20%22%0D%0A%0D%0A%09%5Eself%20sharedController%20pong"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"install",0
,function (){var self=this;(function(){return smalltalk.JSCocoaController.garbageCollect();}).installAs_("gc");
(function(){return smalltalk.JSCocoaController.sharedController().garbageCollectNow();}).installAs_("gcNow");
self['@readOnly']=true;
self['@installed']=true;
return self;;return self;}
,"install",unescape("install%0D%0A%09%22%20Private%20-%20Inject%20the%20receiver%20onto%20%28ObjC%29%20execution%20environment.%20%22%0D%0A%0D%0A%09%5B%20JSCocoaController%20garbageCollect%20%5D%20installAs%3A%20%23gc.%0D%0A%09%5B%20JSCocoaController%20sharedController%20garbageCollectNow%20%5D%20installAs%3A%20%23gcNow.%0D%0A%09readOnly%20%3A%3D%20true.%20installed%20%3A%3D%20true.%0D%0A%09%5Eself"));
smalltalk.bind(smalltalk.JSCocoaController.$klass,"concreteInstanceOf:handle:",0
,function (aClass,aHandle){var $s8Ret$={name:"stReturn"};try{var self=this;var found=nil;var result=nil;result=aClass.basicNew_(aHandle);
(((aClass === self).or_((function(){return aClass.subclasses().isEmpty();}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
found=aClass.name();
self.current().classNamesFor_(result).do_((function(each){((found._eq(each)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);return ((smalltalk.Smalltalk.includesKey_(each)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return smalltalk.Smalltalk.at_(each).basicNew_(aHandle);})();throw($s8Ret$)})();})() : nil);}));
(function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"private",unescape("concreteInstanceOf%3A%20aClass%20handle%3A%20aHandle%0D%0A%09%22%20Private%20-%20Return%20an%20instance%20of%20the%20most%20concrete%20class%20wrapping%20behavior%20for%20aHandle.%20%22%0D%0A%0D%0A%09%7C%20found%20result%20%7C%0D%0A%09result%20%3A%3D%20aClass%20basicNew%3A%20aHandle.%0D%0A%09%28aClass%20%3D%3D%20self%20or%3A%20%5B%20aClass%20subclasses%20isEmpty%20%5D%29%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09found%20%3A%3D%20aClass%20name.%0D%0A%09%28self%20current%20classNamesFor%3A%20result%29%20do%3A%20%5B%3Aeach%7C%0D%0A%09%09found%20%3D%20each%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%09%09%28Smalltalk%20includesKey%3A%20each%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%5E%28Smalltalk%20at%3A%20each%29%20basicNew%3A%20aHandle%0D%0A%09%09%5D.%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.JSCocoaController,"useAutoCall",0
,function (){var self=this;return smalltalk.Boolean._at(self['@handle'].useAutoCall);;return self;}
,"accessing",unescape("useAutoCall%0D%0A%09%22%20Return%20the%20useAutoCall%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EBoolean%20@%20handle%23useAutoCall"));
smalltalk.bind(smalltalk.JSCocoaController,"useAutoCall:",0
,function (anObject){var self=this;(self.handle()["useAutoCall"]=(anObject));return self;}
,"accessing",unescape("useAutoCall%3A%20anObject%0D%0A%09%22%20Set%20the%20useAutoCall%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23useAutoCall%20put%3A%20anObject"));
smalltalk.bind(smalltalk.JSCocoaController,"useJSLint",0
,function (){var self=this;return smalltalk.Boolean._at(self['@handle'].useJSLint);;return self;}
,"accessing",unescape("useJSLint%0D%0A%09%22%20Return%20the%20useJSLint%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EBoolean%20@%20handle%23useJSLint"));
smalltalk.bind(smalltalk.JSCocoaController,"useJSLint:",0
,function (anObject){var self=this;(self.handle()["useJSLint"]=(anObject));return self;}
,"accessing",unescape("useJSLint%3A%20anObject%0D%0A%09%22%20Set%20the%20useJSLint%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23useJSLint%20put%3A%20anObject"));
smalltalk.bind(smalltalk.JSCocoaController,"useSafeDealloc",0
,function (){var self=this;return smalltalk.Boolean._at(self['@handle'].useSafeDealloc);;return self;}
,"accessing",unescape("useSafeDealloc%0D%0A%09%22%20Return%20the%20useSafeDealloc%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EBoolean%20@%20handle%23useSafeDealloc"));
smalltalk.bind(smalltalk.JSCocoaController,"useSafeDealloc:",0
,function (anObject){var self=this;(self.handle()["useSafeDealloc"]=(anObject));return self;}
,"accessing",unescape("useSafeDealloc%3A%20anObject%0D%0A%09%22%20Set%20the%20useSafeDealloc%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23useSafeDealloc%20put%3A%20anObject"));
smalltalk.bind(smalltalk.JSCocoaController,"useSplitCall",0
,function (){var self=this;return smalltalk.Boolean._at(self['@handle'].useSplitCall);;return self;}
,"accessing",unescape("useSplitCall%0D%0A%09%22%20Return%20the%20useSplitCall%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EBoolean%20@%20handle%23useSplitCall"));
smalltalk.bind(smalltalk.JSCocoaController,"useSplitCall:",0
,function (anObject){var self=this;(self.handle()["useSplitCall"]=(anObject));return self;}
,"accessing",unescape("useSplitCall%3A%20anObject%0D%0A%09%22%20Set%20the%20useSplitCall%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23useSplitCall%20put%3A%20anObject"));
smalltalk.bind(smalltalk.JSCocoaController,"garbageCollect",0
,function (){var self=this;return ((function(){var $1$=self.handle()["garbageCollect"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("garbageCollect%0D%0A%09%22%20Return%20the%20garbageCollect%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23garbageCollect"));
smalltalk.bind(smalltalk.JSCocoaController,"garbageCollectNow",0
,function (){var self=this;return ((function(){var $1$=self.handle()["garbageCollectNow"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("garbageCollectNow%0D%0A%09%22%20Return%20the%20garbageCollectNow%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23garbageCollectNow"));
smalltalk.bind(smalltalk.JSCocoaController,"logBoxedObjects",0
,function (){var self=this;return ((function(){var $1$=self.handle()["logBoxedObjects"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("logBoxedObjects%0D%0A%09%22%20Return%20the%20logBoxedObjects%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23logBoxedObjects"));
smalltalk.bind(smalltalk.JSCocoaController,"ping:",0
,function (aNSObject){var self=this;return smalltalk.NSObject._at(self.handle().ping_(aNSObject.handle()));;return self;}
,"wrappers",unescape("ping%3A%20aNSObject%20%0D%0A%09%22%20Wrap%20method%20delegating%20ping%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5ENSObject%20@%20%28self%20handle%20%23ping_%3A%20aNSObject%20handle%20%29"));
smalltalk.bind(smalltalk.JSCocoaController,"oopOf:",0
,function (aHandle){var self=this;return self.handle().oopOf_(aHandle);;return self;}
,"wrappers",unescape("oopOf%3A%20aHandle%20%0D%0A%09%22%20Wrap%20method%20delegating%20oopOf%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23oopOf_%3A%20aHandle%20"));
smalltalk.bind(smalltalk.JSCocoaController,"is:kindOfClass:",0
,function (aNativeObject,aNativeClass){var self=this;return smalltalk.Boolean._at(self.handle().is_kindOfClass_(aNativeObject.handle(), aNativeClass.nativeClass()));;return self;}
,"wrappers",unescape("is%3A%20aNativeObject%20kindOfClass%3A%20aNativeClass%20%0D%0A%09%22%20Wrap%20method%20delegating%20is%3AkindOfClass%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5EBoolean%20@%20%28self%20handle%20%23is_kindOfClass_%3A%20aNativeObject%20handle%20with%3A%20aNativeClass%20nativeClass%20%29"));
smalltalk.bind(smalltalk.JSCocoaController,"dispatchGetMainQueue",0
,function (){var self=this;return ((function(){var $1$=self.handle()["dispatchGetMainQueue"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("dispatchGetMainQueue%0D%0A%09%22%20Return%20the%20dispatchGetMainQueue%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23dispatchGetMainQueue"));
smalltalk.bind(smalltalk.JSCocoaController,"stringFromNSData:",0
,function (aNSData){var self=this;return self.handle().stringFromNSData_(aNSData.handle());;return self;}
,"wrappers",unescape("stringFromNSData%3A%20aNSData%20%0D%0A%09%22%20Wrap%20method%20delegating%20stringFromNSData%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23stringFromNSData_%3A%20aNSData%20handle%20"));
smalltalk.bind(smalltalk.JSCocoaController,"dataFromNSString:",0
,function (aString){var self=this;return smalltalk.NSData._at(self.handle().dataFromNSString_(aString));;return self;}
,"wrappers",unescape("dataFromNSString%3A%20aString%20%0D%0A%09%22%20Wrap%20method%20delegating%20dataFromNSString%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5ENSData%20@%20%28self%20handle%20%23dataFromNSString_%3A%20aString%20%29"));
smalltalk.bind(smalltalk.JSCocoaController,"pong",0
,function (){var self=this;return smalltalk.NSObject._at(((function(){var $1$=self.handle()["pong"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"debug",unescape("pong%0D%0A%09%22%20DEBUG%20-%20Return%20the%20result%20of%20the%20pong%20function.%20%22%0D%0A%0D%0A%09%5ENSObject%20@%20%28self%20handle%20basicAt%3A%20%23pong%29"));
smalltalk.bind(smalltalk.JSCocoaController,"classNamesFor:",0
,function (aNSObject){var self=this;return self.handle().classNamesFor_(aNSObject.handle()).asArrayOfSubstrings();;return self;}
,"private",unescape("classNamesFor%3A%20aNSObject%0D%0A%09%22%20Private%20-%20Returns%20the%20class%20hierarchy%20of%20aNSObject.%20%22%0D%0A%0D%0A%09%5E%28self%20handle%20classNamesFor%3A%20aNSObject%20handle%29%20asArrayOfSubstrings"));
smalltalk.bind(smalltalk.S8BlockAdaptor.$klass,"doing:",0
,function (aZeroArgumentBlock){var self=this;return self.for_(aZeroArgumentBlock);;return self;}
,"instantiation",unescape("doing%3A%20aZeroArgumentBlock%0D%0A%09%22%20Return%20a%20NSBlock%20calling%20a%20block%20when%20activated.%20%22%0D%0A%0D%0A%09%5Eself%20for%3A%20aZeroArgumentBlock"));
smalltalk.bind(smalltalk.S8BlockAdaptor.$klass,"empty",0
,function (){var self=this;return self.for_((function(){return nil;}));;return self;}
,"instantiation",unescape("empty%0D%0A%09%22%20Return%20a%20NSBlock%20calling%20an%20empty%20block%20when%20activated.%20%22%0D%0A%0D%0A%09%5Eself%20for%3A%20%5B%5D"));
smalltalk.bind(smalltalk.S8BlockAdaptor.$klass,"for:",0
,function (aZeroArgumentBlock){var $s8Ret$={name:"stReturn"};try{var self=this;((aZeroArgumentBlock.numberOfArguments()._eq((0))).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Must be a zero argument block.");})();throw($s8Ret$)})();})());
(function(){$s8Ret$.result=(function(){return self.for_encoding_(aZeroArgumentBlock, unescape("v@%3Av"));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"instantiation",unescape("for%3A%20aZeroArgumentBlock%0D%0A%09%22%20Return%20a%20NSBlock%20calling%20a%20block%20when%20activated.%20%22%0D%0A%0D%0A%09aZeroArgumentBlock%20numberOfArguments%20%3D%200%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20%27Must%20be%20a%20zero%20argument%20block.%27%0D%0A%09%5D.%0D%0A%09%5Eself%09for%3A%20aZeroArgumentBlock%0D%0A%09%09encoding%3A%20%27v@%3Av%27"));
smalltalk.bind(smalltalk.S8BlockAdaptor.$klass,"for:encoding:",0
,function (aBlock,literal){var self=this;return self.instance().block_encoding_(aBlock, literal);;return self;}
,"instantiation",unescape("for%3A%20aBlock%20encoding%3A%20literal%0D%0A%09%22%20Return%20a%20NSBlock%20calling%20aBlock%20when%20activated.%20%22%0D%0A%0D%0A%09%5Eself%20instance%0D%0A%09%09block%3A%20aBlock%0D%0A%09%09encoding%3A%20literal"));
smalltalk.bind(smalltalk.S8BlockAdaptor,"block:calling:",0
,function (encoding,aBlock){var self=this;return smalltalk.NSBlock._at(self.handle().block_calling_(encoding, aBlock));;return self;}
,"wrappers",unescape("block%3A%20encoding%20calling%3A%20aBlock%20%0D%0A%09%22%20Wrap%20method%20delegating%20block%3Acalling%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5ENSBlock%20@%20%28self%20handle%20%23block_calling_%3A%20encoding%20with%3A%20aBlock%20%29"));
smalltalk.bind(smalltalk.S8BlockAdaptor,"block:encoding:",0
,function (aBlock,literal){var self=this;return self.block_calling_(self.encoding_(literal), aBlock);;return self;}
,"converting",unescape("block%3A%20aBlock%20encoding%3A%20literal%0D%0A%09%22%20Private%20-%20Return%20a%20native%20NSBlock%20for%20aBlock.%20%22%0D%0A%0D%0A%09%5Eself%0D%0A%09%09block%3A%20%28self%20encoding%3A%20literal%29%0D%0A%09%09calling%3A%20aBlock"));
smalltalk.bind(smalltalk.S8BlockAdaptor,"encoding:",0
,function (literal){var $s8Ret$={name:"stReturn"};try{var self=this;((literal.isString()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return literal;})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return smalltalk.JSCocoa.current().encoding_(literal.asArray());})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"encoding",unescape("encoding%3A%20literal%0D%0A%09%22%20Return%20the%20encoding%20string%20for%20method%20with%20literal%20spec.%20%22%0D%0A%0D%0A%09literal%20isString%20ifTrue%3A%20%5B%20%5Eliteral%20%5D.%0D%0A%09%5EJSCocoa%20current%20encoding%3A%20literal%20asArray"));
smalltalk.bind(smalltalk.NSArray,"enumerateObjectsUsingBlock:",0
,function (block){var self=this;return self.handle().enumerateObjectsUsingBlock_(block.handle());;return self;}
,"wrappers",unescape("enumerateObjectsUsingBlock%3A%20block%20%0D%0A%09%22%20Wrap%20method%20delegating%20enumerateObjectsUsingBlock%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23enumerateObjectsUsingBlock_%3A%20block%20handle%20"));
smalltalk.bind(smalltalk.NSArray,"asArray",0
,function (){var self=this;var result=nil;result=smalltalk.Array.$$new();
self.enumerateObjectsUsingBlock_(smalltalk.S8BlockAdaptor.for_encoding_((function(obj,index){result.add_(obj);return false;}), unescape("v@%3A@N*")));
return result;;return self;}
,"converting",unescape("asArray%0D%0A%09%22%20Return%20an%20Array%20with%20the%20elements%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20Array%20new.%0D%0A%09self%20enumerateObjectsUsingBlock%3A%20%28S8BlockAdaptor%0D%0A%09%09for%3A%20%5B%3Aobj%20%3Aindex%7C%20result%20add%3A%20obj.%20false%20%5D%0D%0A%09%09encoding%3A%20%27v@%3A@N*%27%29.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.UIView,"bounds",0
,function (){var self=this;return smalltalk.CGRect._at(((function(){var $1$=self.handle()["bounds"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("bounds%0D%0A%09%22%20Return%20the%20bounds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ECGRect%20@%20%28self%20handle%20basicAt%3A%20%23bounds%29"));
smalltalk.bind(smalltalk.UIView,"bounds:",0
,function (anObject){var self=this;(self.handle()["bounds"]=(anObject.handle()));return self;}
,"accessing",unescape("bounds%3A%20anObject%0D%0A%09%22%20Set%20the%20bounds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23bounds%20put%3A%20anObject%20handle"));
smalltalk.bind(smalltalk.UIView,"frame",0
,function (){var self=this;return smalltalk.CGRect._at(((function(){var $1$=self.handle()["frame"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("frame%0D%0A%09%22%20Return%20the%20frame%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ECGRect%20@%20%28self%20handle%20basicAt%3A%20%23frame%29"));
smalltalk.bind(smalltalk.UIView,"frame:",0
,function (anObject){var self=this;(self.handle()["frame"]=(anObject.handle()));return self;}
,"accessing",unescape("frame%3A%20anObject%0D%0A%09%22%20Set%20the%20frame%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23frame%20put%3A%20anObject%20handle"));
smalltalk.bind(smalltalk.UIWindow,"setRootViewController:",0
,function (aViewController){var self=this;return self.handle().setRootViewController_(aViewController.handle());;return self;}
,"wrappers",unescape("setRootViewController%3A%20aViewController%20%0D%0A%09%22%20Wrap%20method%20delegating%20setRootViewController%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23setRootViewController_%3A%20aViewController%20handle%20"));
smalltalk.bind(smalltalk.UIWindow,"makeKeyAndVisible",0
,function (){var self=this;return ((function(){var $1$=self.handle()["makeKeyAndVisible"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("makeKeyAndVisible%0D%0A%09%22%20Return%20the%20makeKeyAndVisible%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23makeKeyAndVisible"));
smalltalk.bind(smalltalk.UIViewController,"view",0
,function (){var self=this;return smalltalk.UIView._at(((function(){var $1$=self.handle()["view"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("view%0D%0A%09%22%20Return%20the%20view%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EUIView%20@%20%28self%20handle%20basicAt%3A%20%23view%29"));
smalltalk.bind(smalltalk.UIViewController,"view:",0
,function (anObject){var self=this;(self.handle()["view"]=(anObject.handle()));return self;}
,"accessing",unescape("view%3A%20anObject%0D%0A%09%22%20Set%20the%20view%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09self%20handle%20basicAt%3A%20%23view%20put%3A%20anObject%20handle"));
smalltalk.bind(smalltalk.UIScreen.$klass,"mainScreen",0
,function (){var self=this;return self._at(((function(){var $1$=self.nativeClass()["mainScreen"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"instantiation",unescape("mainScreen%0D%0A%09%22%20Return%20an%20instance%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20@%20%28self%20nativeClass%20basicAt%3A%20%23mainScreen%29"));
smalltalk.bind(smalltalk.UIScreen.$klass,"bounds",0
,function (){var self=this;return self.mainScreen().bounds();;return self;}
,"accessing",unescape("bounds%0D%0A%09%22%20Return%20the%20bounds%20of%20the%20main%20screen.%20%22%0D%0A%0D%0A%09%5Eself%20mainScreen%20bounds"));
smalltalk.bind(smalltalk.UIScreen,"bounds",0
,function (){var self=this;return smalltalk.CGRect._at(((function(){var $1$=self.handle()["bounds"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("bounds%0D%0A%09%22%20Return%20the%20bounds%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5ECGRect%20@%20%28self%20handle%20basicAt%3A%20%23bounds%29"));
smalltalk.bind(smalltalk.Mini8AppDelegate.$klass,"implementation",0
,function (){var self=this;return "outlets"._minus_gt(["window", "viewController"])._comma("methods"._minus_gt([["applicationDidFinishLaunching:", "void id"], ["applicationDidReceiveMemoryWarning:", "void id"]]));;return self;}
,"objC",unescape("implementation%0D%0A%09%22%20Private%20-%20Return%20the%20implementation%20literal%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5E%28%23outlets%20-%3E%20%23%28%20window%20viewController%20%29%29%0D%0A%09%2C%28%23methods%20-%3E%20%23%28%0D%0A%09%09%23%28%23applicationDidFinishLaunching%3A%20%27void%20id%27%29%0D%0A%09%09%23%28%23applicationDidReceiveMemoryWarning%3A%20%27void%20id%27%29%0D%0A%09%09%29%29"));
smalltalk.bind(smalltalk.Mini8AppDelegate,"window",0
,function (){var self=this;return smalltalk.UIWindow._at(((function(){var $1$=self.handle()["window"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("window%0D%0A%09%22%20Return%20the%20window%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EUIWindow%20@%20%28self%20handle%20basicAt%3A%20%23window%29"));
smalltalk.bind(smalltalk.Mini8AppDelegate,"viewController",0
,function (){var self=this;return smalltalk.UIViewController._at(((function(){var $1$=self.handle()["viewController"];if(nil.isNil_($1$))return nil;return $1$;})()));;return self;}
,"accessing",unescape("viewController%0D%0A%09%22%20Return%20the%20viewController%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EUIViewController%20@%20%28self%20handle%20basicAt%3A%20%23viewController%29"));
smalltalk.bind(smalltalk.Mini8AppDelegate,"applicationDidFinishLaunching:",0
,function (application){var self=this;if (!self.$klass) {self = smalltalk.Mini8AppDelegate._at(self);}
self.viewController().view_(smalltalk.UIView.instance());
(function($rec){$rec.frame_(smalltalk.UIScreen.bounds());$rec.setRootViewController_(self.viewController());return $rec.makeKeyAndVisible();})(self.window());return self;}
,"objC",unescape("applicationDidFinishLaunching%3A%20application%0D%0A%09%22%20Private%20-%20Implements%20objC%27s%20post%20App%20launch%20action.%20%22%0D%0A%0D%0A%09%3CobjC%3A%20method%3E%0D%0A%09self%20viewController%20view%3A%20UIView%20instance.%0D%0A%09self%20window%0D%0A%09%09frame%3A%20UIScreen%20bounds%3B%0D%0A%09%09setRootViewController%3A%20self%20viewController%3B%0D%0A%09%09makeKeyAndVisible."));
smalltalk.bind(smalltalk.Mini8AppDelegate,"applicationDidReceiveMemoryWarning:",0
,function (applicationHandle){var self=this;if (!self.$klass) {self = smalltalk.Mini8AppDelegate._at(self);}
self.print_("applicationDidReceiveMemoryWarning:");return self;}
,"objC",unescape("applicationDidReceiveMemoryWarning%3A%20applicationHandle%0D%0A%09%22%20Private%20-%20Implements%20objC%27s%20memory%20low%20alert.%20%22%0D%0A%0D%0A%09%3CobjC%3A%20method%3E%0D%0A%09self%20print%3A%20%23applicationDidReceiveMemoryWarning%3A.%0D%0A%09%22self%20halt%22"));
smalltalk.bind(smalltalk.JSC,"jsName",0
,function (){var self=this;return "__jsc__";;return self;}
,"private",unescape("jsName%0D%0A%09%22%20Private%20-%20Return%20the%20global%20name%20of%20handle.%20%22%0D%0A%0D%0A%09%5E%23__jsc__"));
smalltalk.bind(smalltalk.JSC,"useAutoCall",0
,function (){var self=this;return ((function(){var $1$=self.handle()["useAutoCall"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("useAutoCall%0D%0A%09%22%20Return%20the%20useAutoCall%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23useAutoCall"));
smalltalk.bind(smalltalk.JSC,"log:",0
,function (anObject){var self=this;return self.handle().log_(anObject);;return self;}
,"wrappers",unescape("log%3A%20anObject%20%0D%0A%09%22%20Wrap%20method%20delegating%20log%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23log_%3A%20anObject%20"));
smalltalk.bind(smalltalk.JSC,"enterDebugger",0
,function (){var self=this;return ((function(){var $1$=self.handle()["enterDebugger"];if(nil.isNil_($1$))return nil;return $1$;})());;return self;}
,"accessing",unescape("enterDebugger%0D%0A%09%22%20Return%20the%20enterDebugger%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20basicAt%3A%20%23enterDebugger"));
smalltalk.bind(smalltalk.JSC,"loadFrameworkWithName:",0
,function (name){var self=this;return self.handle().loadFrameworkWithName_(name);;return self;}
,"wrappers",unescape("loadFrameworkWithName%3A%20name%20%0D%0A%09%22%20Wrap%20method%20delegating%20loadFrameworkWithName%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23loadFrameworkWithName_%3A%20name%20"));
smalltalk.bind(smalltalk.JSC,"output:toFile:",0
,function (aString,localPathName){var self=this;return self.handle().output_toFile_(aString, localPathName);;return self;}
,"wrappers",unescape("output%3A%20aString%20toFile%3A%20localPathName%20%0D%0A%09%22%20Wrap%20method%20delegating%20output%3AtoFile%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23output_toFile_%3A%20aString%20with%3A%20localPathName%20"));
smalltalk.bind(smalltalk.JSC,"append:toFile:",0
,function (aString,localPathName){var self=this;return self.handle().append_toFile_(aString, localPathName);;return self;}
,"wrappers",unescape("append%3A%20aString%20toFile%3A%20localPathName%20%0D%0A%09%22%20Wrap%20method%20delegating%20append%3AtoFile%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23append_toFile_%3A%20aString%20with%3A%20localPathName%20"));
smalltalk.bind(smalltalk.JSC,"searchPathForDirectoriesInDomains:domainMask:expandTilde:",0
,function (directory,domainMask,aBoolean){var self=this;return self.handle().searchPathForDirectoriesInDomains_domainMask_expandTilde_(directory, domainMask, aBoolean);;return self;}
,"wrappers",unescape("searchPathForDirectoriesInDomains%3A%20directory%20domainMask%3A%20domainMask%20expandTilde%3A%20aBoolean%20%0D%0A%09%22%20Wrap%20method%20delegating%20searchPathForDirectoriesInDomains%3AdomainMask%3AexpandTilde%3A%20to%20handle.%20%22%0D%0A%0D%0A%09%5Eself%20handle%20%23searchPathForDirectoriesInDomains_domainMask_expandTilde_%3A%20directory%20with%3A%20domainMask%20with%3A%20aBoolean%20"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"initializeCurrent",0
,function (){var self=this;self['@current']=self.$$new();return self;}
,"initialize",unescape("initializeCurrent%0D%0A%09%22%20Private%20-%20Initialize%20the%20current%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09current%20%3A%3D%20self%20new"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"current",0
,function (){var self=this;(((nil.isNil_(self['@current']))).mustBeBoolean()==true ? (function(){return self.initializeCurrent();})() : nil);
return self['@current'];;return self;}
,"accessing",unescape("current%0D%0A%09%22%20Return%20the%20current%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09current%20isNil%20ifTrue%3A%20%5B%20self%20initializeCurrent%20%5D.%0D%0A%09%5Ecurrent"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"current:",0
,function (anObject){var self=this;self['@current']=anObject;return self;}
,"accessing",unescape("current%3A%20anObject%0D%0A%09%22%20Set%20the%20current%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09current%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"outArgument2",0
,function (){var self=this;return self['@outArgument2'];;return self;}
,"accessing",unescape("outArgument2%0D%0A%09%22%20Return%20the%20outArgument2%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09%5EoutArgument2"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"outArgument2:",0
,function (anObject){var self=this;self['@outArgument2']=anObject;return self;}
,"accessing",unescape("outArgument2%3A%20anObject%0D%0A%09%22%20Set%20the%20outArgument2%20of%20the%20receiver.%20%22%0D%0A%0D%0A%09outArgument2%20%3A%3D%20anObject"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"isValid",0
,function (){var $s8Ret$={name:"stReturn"};try{var self=this;(function(){return JSCocoa;}).on_do_(smalltalk.Error, (function(){return (function(){$s8Ret$.result=(function(){return false;})();throw($s8Ret$)})();}));
(function(){$s8Ret$.result=(function(){return true;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"testing",unescape("isValid%0D%0A%09%22%20Private%20-%20Return%20true%20if%20the%20receiver%20is%20valid.%20%22%0D%0A%0D%0A%09%5B%20%23%7BJSCocoa%7D%20%5D%20on%3A%20Error%20do%3A%20%5B%20%5Efalse%20%5D.%0D%0A%09%5Etrue"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"types",0
,function (){var self=this;return ["char", "int", "short", "long", "long long", "unsigned char", "unsigned int", "unsigned short", "unsigned long", "unsigned long long", "float", "double", "bool", "void", unescape("char*"), "id", "class", "Class", "selector", "BOOL", unescape("void*"), "NSInteger", "NSUInteger", "CGFloat"];;return self;}
,"constants",unescape("types%0D%0A%20%20%20%20%22%20Return%20ObjC%20type%20encodings.%20%22%0D%0A%0D%0A%20%20%20%20%5E%23%28%20char%20int%20short%20long%0D%0A%20%20%20%20%20%20%20%20%27long%20long%27%20%27unsigned%20char%27%20%27unsigned%20int%27%0D%0A%20%20%20%20%20%20%20%20%27unsigned%20short%27%20%27unsigned%20long%27%20%27unsigned%20long%20long%27%0D%0A%20%20%20%20%20%20%20%20float%20double%20bool%20void%0D%0A%20%20%20%20%20%20%20%20%27char*%27%20id%20class%20%23Class%20selector%20%23BOOL%20%27void*%27%0D%0A%20%20%20%20%20%20%20%20%23NSInteger%20%23NSUInteger%20%23CGFloat%0D%0A%20%20%20%20%29"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"encodings",0
,function (){var self=this;(((nil.isNil_(self['@encodings']))).mustBeBoolean()==true ? (function(){return self.initializeEncodings();})() : nil);
return self['@encodings'];;return self;}
,"constants",unescape("encodings%0D%0A%0D%0A%09encodings%20isNil%20ifTrue%3A%20%5B%20self%20initializeEncodings%20%5D.%0D%0A%09%5Eencodings"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"decodings",0
,function (){var self=this;(((nil.isNil_(self['@decodings']))).mustBeBoolean()==true ? (function(){return self.initializeDecodings();})() : nil);
return self['@decodings'];;return self;}
,"constants",unescape("decodings%0D%0A%0D%0A%09decodings%20isNil%20ifTrue%3A%20%5B%20self%20initializeDecodings%20%5D.%0D%0A%09%5Edecodings"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"initializeEncodings",0
,function (){var self=this;var ffi=nil;var pool=nil;var loop=nil;var code=nil;ffi=smalltalk.JSCocoaFFIArgument.$$new();
pool=smalltalk.PoolDictionary.$$new();
loop=smalltalk.PoolDictionary.$$new();
self.types().do_((function(type){code=ffi.typeEncodingForType_(type);pool.at_put_(type, code);return loop.at_put_(code, type);}));
self['@encodings']=pool;
self['@decodings']=loop;
self['@encodings'].at_put_("charpointer", self['@encodings'].at_(unescape("char*")));
self['@encodings'].at_put_("IBAction", self['@encodings'].at_("void"));
self.$$new().initalizeCallbacks();return self;}
,"initialize",unescape("initializeEncodings%0D%0A%20%20%20%20%22%20Private%20-%20Initialize%20the%20encondings%20map.%20%22%0D%0A%0D%0A%20%20%20%20%7C%20ffi%20pool%20loop%20code%20%7C%0D%0A%20%20%20%20ffi%20%3A%3D%20JSCocoaFFIArgument%20new.%0D%0A%20%20%20%20pool%20%3A%3D%20PoolDictionary%20new.%0D%0A%20%20%20%20loop%20%3A%3D%20PoolDictionary%20new.%0D%0A%20%20%20%20self%20types%20do%3A%20%5B%3Atype%7C%0D%0A%20%20%20%20%20%20%20%20code%20%3A%3D%20ffi%20typeEncodingForType%3A%20type.%0D%0A%20%20%20%20%20%20%20%20pool%20at%3A%20type%20put%3A%20code.%0D%0A%20%20%20%20%20%20%20%20loop%20at%3A%20code%20put%3A%20type.%0D%0A%20%20%20%20%5D.%0D%0A%20%20%20%20encodings%20%3A%3D%20pool.%0D%0A%20%20%20%20decodings%20%3A%3D%20loop.%0D%0A%0D%0A%20%20%20%20encodings%20at%3A%20%23charpointer%20put%3A%20%28encodings%20at%3A%20%27char*%27%29.%0D%0A%20%20%20%20encodings%20at%3A%20%23IBAction%20put%3A%20%28encodings%20at%3A%20%23void%29.%0D%0A%20%20%20%20self%20new%20initalizeCallbacks."));
smalltalk.bind(smalltalk.JSCocoa.$klass,"initializeDecodings",0
,function (){var self=this;self.initializeEncodings();return self;}
,"initialize",unescape("initializeDecodings%0D%0A%20%20%20%20%22%20Private%20-%20Initialize%20the%20decondings%20map.%20%22%0D%0A%0D%0A%20%20%20%20self%20initializeEncodings%20%22initialize%20both%20mappings%22"));
smalltalk.bind(smalltalk.JSCocoa.$klass,"capture:",0
,function (anObject){var self=this;(((nil.isNil_(self['@cache']))).mustBeBoolean()==true ? (function(){return self['@cache']=smalltalk.Array.$$new();})() : nil);
return self['@cache'].add_(anObject);;return self;}
,"cache",unescape("capture%3A%20anObject%0D%0A%09%22%20Private%20-%20Cache%20the%20object%20in%20receiver%27s%20cache.%20%22%0D%0A%0D%0A%09cache%20isNil%20ifTrue%3A%20%5B%20cache%20%3A%3D%20Array%20new%20%5D.%0D%0A%09%5Ecache%20add%3A%20anObject"));
smalltalk.bind(smalltalk.JSCocoa,"jsName",0
,function (){var self=this;return "JSCocoa";;return self;}
,"private",unescape("jsName%0D%0A%09%22%20Private%20-%20Return%20the%20global%20name%20of%20handle.%20%22%0D%0A%0D%0A%09%5E%23JSCocoa"));
smalltalk.bind(smalltalk.JSCocoa,"handle",0
,function (){var self=this;return self['@handle']=JSCocoa;;return self;}
,"accessing",unescape("handle%0D%0A%09%22%20Return%20the%20native%20handle.%20%22%0D%0A%0D%0A%09%5Ehandle%20%3A%3D%20%23%7BJSCocoa%7D"));
smalltalk.bind(smalltalk.JSCocoa,"createClass:parentClass:",0
,function (aClassName,parentClassName){var self=this;return self.handle().createClass_parentClass_(aClassName, parentClassName);;return self;}
,"creation",unescape("createClass%3A%20aClassName%20parentClass%3A%20parentClassName%0D%0A%0D%0A%22%28self%20handle%20basicAt%3A%20%27createClass_parentClass_%27%29%20isNil%20ifTrue%3A%20%5B%0D%0A%09self%20print%3A%20%27//%20bad%20handle%28%27%2Chandle%20toString%2C%27%29%20for%20%27%2CaClassName.%0D%0A%5D.%22%0D%0A%22self%20print%3A%20%27//%20create%20%28%27%20%2CparentClassName%20toString%2C%27%29%27%2CaClassName%20toString.%22%0D%0A%20%20%20%20%5Eself%20handle%20createClass%3A%20aClassName%20parentClass%3A%20parentClassName%20"));
smalltalk.bind(smalltalk.JSCocoa,"jsFunctionRegistryFor:",0
,function (objClass){var self=this;var top=nil;var key=nil;var registry=nil;var clsName=nil;var cache=nil;top=smalltalk.Smalltalk.global();
key="__globalJSFunctionRepository__";
registry=((function(){var $1$=top[key];if(nil.isNil_($1$))return ((function(){return (top[key]=(smalltalk.Object.$$new().json()));}).value());return $1$;})());
clsName=self.nameOfClass_(objClass);
return ((function(){var $1$=registry[clsName];if(nil.isNil_($1$))return ((function(){cache=smalltalk.Object.$$new().json();(registry[clsName]=(cache));return cache;}).value());return $1$;})());;return self;}
,"registration",unescape("jsFunctionRegistryFor%3A%20objClass%0D%0A%09%22%20Private%20-%20Returns%20the%20global%20function%20registry%20for%20objClass.%20%22%0D%0A%0D%0A%09%7C%20top%20key%20registry%20clsName%20cache%20%7C%0D%0A%09top%20%3A%3D%20Smalltalk%20global.%0D%0A%09key%20%3A%3D%20%23__globalJSFunctionRepository__.%0D%0A%09registry%20%3A%3D%20top%20basicAt%3A%20key%20ifAbsent%3A%20%5B%0D%0A%09%09top%20basicAt%3A%20key%20put%3A%20Object%20new%20json%0D%0A%09%5D.%0D%0A%09clsName%20%3A%3D%20self%20nameOfClass%3A%20objClass.%0D%0A%09%5Eregistry%20basicAt%3A%20clsName%20ifAbsent%3A%20%5B%0D%0A%09%09cache%20%3A%3D%20Object%20new%20json.%0D%0A%09%09%22cache%20basicAt%3A%20clsName%20put%3A%20objClass.%22%0D%0A%09%09registry%20basicAt%3A%20clsName%20put%3A%20cache.%0D%0A%09%09cache%0D%0A%09%5D"));
smalltalk.bind(smalltalk.JSCocoa,"nameOfClass:",0
,function (objClass){var self=this;return self.handle().nameOfClass_(objClass).toString();;return self;}
,"private",unescape("nameOfClass%3A%20objClass%0D%0A%09%22%20Private%20-%20Return%20the%20name%20of%20an%20objClass.%20%22%0D%0A%0D%0A%09%5E%28self%20handle%20nameOfClass%3A%20objClass%29%20toString"));
smalltalk.bind(smalltalk.JSCocoa,"classOfName:",0
,function (aName){var self=this;var objClassOrNull=nil;objClassOrNull=self.handle().classOfName_(aName);
	if ((objClassOrNull || nil) === nil) return nil;
	return objClassOrNull;
;return self;}
,"private",unescape("classOfName%3A%20aName%0D%0A%09%22%20Private%20-%20Return%20the%20objClass%20of%20name%20aName%20%28or%20nil%29.%20%22%0D%0A%0D%0A%09%7C%20objClassOrNull%20%7C%0D%0A%09objClassOrNull%20%3A%3D%20self%20handle%20classOfName%3A%20aName.%0D%0A%7B%27%09if%20%28%28objClassOrNull%20%7C%7C%20nil%29%20%3D%3D%3D%20nil%29%20return%20nil%3B%0D%0A%09return%20objClassOrNull%3B%0D%0A%27%7D"));
smalltalk.bind(smalltalk.JSCocoa,"register:class:jsFunction:",0
,function (selector,objClass,jsFunction){var self=this;(self.jsFunctionRegistryFor_(objClass)[selector.asSelector()]=(jsFunction));return self;}
,"registration",unescape("register%3A%20selector%20class%3A%20objClass%20jsFunction%3A%20jsFunction%0D%0A%09%22%20Private%20-%20Register%20the%20jsFunction%20in%20global%20pool.%20%22%0D%0A%0D%0A%22self--%28%23registerjsFunction%3A%20%2Cselector%20asSelector%29.%22%0D%0A%09%28self%20jsFunctionRegistryFor%3A%20objClass%29%0D%0A%09%09basicAt%3A%20selector%20asSelector%0D%0A%09%09put%3A%20jsFunction"));
smalltalk.bind(smalltalk.JSCocoa,"addInstanceMethod:class:jsFunction:encoding:",0
,function (selector,aClass,jsFunction,encoding){var self=this;self.register_class_jsFunction_(selector, aClass, jsFunction);
return self.handle().addInstanceMethod_class_jsFunction_encoding_(selector, aClass, jsFunction, encoding);;return self;}
,"methods",unescape("addInstanceMethod%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction%20encoding%3A%20encoding%0D%0A%0D%0A%20%20%20%20self%20register%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction.%0D%0A%20%20%20%20%5Eself%20handle%0D%0A%20%20%20%20%20%20%20%20addInstanceMethod%3A%20selector%0D%0A%20%20%20%20%20%20%20%20class%3A%20aClass%20jsFunction%3A%20jsFunction%0D%0A%20%20%20%20%20%20%20%20encoding%3A%20encoding"));
smalltalk.bind(smalltalk.JSCocoa,"addClassMethod:class:jsFunction:encoding:",0
,function (selector,aClass,jsFunction,encoding){var self=this;self.register_class_jsFunction_(selector, aClass, jsFunction);
return self.handle().addClassMethod_class_jsFunction_encoding_(selector, aClass, jsFunction, encoding);;return self;}
,"methods",unescape("addClassMethod%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction%20encoding%3A%20encoding%0D%0A%0D%0A%20%20%20%20self%20register%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction.%0D%0A%20%20%20%20%5Eself%20handle%0D%0A%20%20%20%20%20%20%20%20addClassMethod%3A%20selector%0D%0A%20%20%20%20%20%20%20%20class%3A%20aClass%20jsFunction%3A%20jsFunction%0D%0A%20%20%20%20%20%20%20%20encoding%3A%20encoding"));
smalltalk.bind(smalltalk.JSCocoa,"overloadInstanceMethod:class:jsFunction:",0
,function (selector,aClass,jsFunction){var self=this;self.register_class_jsFunction_(selector, aClass, jsFunction);
return self.handle().overloadInstanceMethod_class_jsFunction_(selector, aClass, jsFunction);;return self;}
,"methods",unescape("overloadInstanceMethod%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction%0D%0A%0D%0A%20%20%20%20self%20register%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction.%0D%0A%20%20%20%20%5Eself%20handle%0D%0A%20%20%20%20%20%20%20%20overloadInstanceMethod%3A%20selector%0D%0A%20%20%20%20%20%20%20%20class%3A%20aClass%20jsFunction%3A%20jsFunction"));
smalltalk.bind(smalltalk.JSCocoa,"overloadClassMethod:class:jsFunction:",0
,function (selector,aClass,jsFunction){var self=this;self.register_class_jsFunction_(selector, aClass, jsFunction);
return self.handle().overloadClassMethod_class_jsFunction_(selector, aClass, jsFunction);;return self;}
,"methods",unescape("overloadClassMethod%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction%0D%0A%0D%0A%20%20%20%20self%20register%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction.%0D%0A%20%20%20%20%5Eself%20handle%0D%0A%20%20%20%20%20%20%20%20overloadClassMethod%3A%20selector%0D%0A%20%20%20%20%20%20%20%20class%3A%20aClass%20jsFunction%3A%20jsFunction"));
smalltalk.bind(smalltalk.JSCocoa,"swizzleInstanceMethod:class:jsFunction:",0
,function (selector,aClass,jsFunction){var self=this;self.register_class_jsFunction_(selector, aClass, jsFunction);
return self.handle().swizzleInstanceMethod_class_jsFunction_(selector, aClass, jsFunction);;return self;}
,"methods",unescape("swizzleInstanceMethod%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction%0D%0A%0D%0A%20%20%20%20self%20register%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction.%0D%0A%20%20%20%20%5Eself%20handle%0D%0A%20%20%20%20%20%20%20%20swizzleInstanceMethod%3A%20selector%0D%0A%20%20%20%20%20%20%20%20class%3A%20aClass%20jsFunction%3A%20jsFunction"));
smalltalk.bind(smalltalk.JSCocoa,"swizzleClassMethod:class:jsFunction:",0
,function (selector,aClass,jsFunction){var self=this;self.register_class_jsFunction_(selector, aClass, jsFunction);
return self.handle().swizzleClassMethod_class_jsFunction_(selector, aClass, jsFunction);;return self;}
,"methods",unescape("swizzleClassMethod%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction%0D%0A%0D%0A%20%20%20%20self%20register%3A%20selector%20class%3A%20aClass%20jsFunction%3A%20jsFunction.%0D%0A%20%20%20%20%5Eself%20handle%0D%0A%20%20%20%20%20%20%20%20swizzleClassMethod%3A%20selector%0D%0A%20%20%20%20%20%20%20%20class%3A%20aClass%20jsFunction%3A%20jsFunction"));
smalltalk.bind(smalltalk.JSCocoa,"encodings",0
,function (){var self=this;return self.$klass.encodings();;return self;}
,"constants",unescape("encodings%0D%0A%09%22%20Private%20-%20Return%20the%20encodings%20map.%20%22%0D%0A%0D%0A%09%5Eself%20class%20encodings"));
smalltalk.bind(smalltalk.JSCocoa,"unaryEncoding:",0
,function (anEncoding){var $s8Ret$={name:"stReturn"};try{var self=this;var ffi=nil;var encoding=nil;var structureName=nil;var structureEncoding=nil;var match=nil;var result=nil;ffi=smalltalk.JSCocoaFFIArgument.$$new();
encoding=anEncoding.replace_with_(unescape("%5Cs*%3C%5Cs*%5Cw+%5Cs*%3E%5Cs*"), "").toString();
(((nil.isNil_(encoding.match(smalltalk.RegularExpression.fromString_(unescape("struct%20%5Cw+"))))===false)).mustBeBoolean()==true ? (function(){structureName=encoding.asArrayOfSubStrings().second();structureEncoding=ffi.structureFullTypeEncodingFromStructureName_(structureName);(((nil.isNil_(structureEncoding))).mustBeBoolean()==true ? (function(){return self.error_("Missing enconding for "._comma(anEncoding.asLiteral()));})() : nil);return (function(){$s8Ret$.result=(function(){return structureEncoding.replace_with_(unescape("%22%5B%5E%22%5D+%22"), "");})();throw($s8Ret$)})();})() : nil);
result=self.encodings().at_ifAbsent_(encoding, (function(){return nil;}));
(((nil.isNil_(result)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return result;})();throw($s8Ret$)})();})() : nil);
match=encoding.match(smalltalk.RegularExpression.fromString_(unescape("%5E%28%5Cw+%29%5Cs*%28%5C*+%29%24")));
(((nil.isNil_(match)===false)).mustBeBoolean()==true ? (function(){var className=nil;var starCount=nil;var cls=nil;className=match.second();starCount=match.third().toString().size();cls=self.classNamed_(className);(((nil.isNil_(cls)===false).and_((function(){return (((function(){var $1$=cls["class"];if(nil.isNil_($1$))return nil;return $1$;})()) === cls);}))).mustBeBoolean()==true ? (function(){return ((starCount._gt((1))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return unescape("%5E@");})();throw($s8Ret$)})();})() : (function(){return (function(){$s8Ret$.result=(function(){return unescape("@");})();throw($s8Ret$)})();})());})() : nil);return ((starCount._eq((1))).mustBeBoolean()==true ? (function(){var raw=nil;raw=self.encodings().at_ifAbsent_(encoding.replace_with_(unescape("%5C*"), ""), (function(){return nil;}));return (((nil.isNil_(raw)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return unescape("%5E")._comma(raw);})();throw($s8Ret$)})();})() : nil);})() : nil);})() : nil);
structureEncoding=ffi.structureFullTypeEncodingFromStructureName_(encoding);
(((nil.isNil_(structureEncoding)===false)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return structureEncoding.replace_with_(unescape("%22%5B%5E%22%5D+%22"), "");})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.error_("Invalid encoding "._comma(encoding.asLiteral()));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"encoding",unescape("unaryEncoding%3A%20anEncoding%0D%0A%0D%0A%09%7C%20ffi%20encoding%20structureName%20structureEncoding%20match%20result%20%7C%0D%0A%09ffi%20%3A%3D%20JSCocoaFFIArgument%20new.%0D%0A%09encoding%20%3A%3D%20%28anEncoding%20replace%3A%20%27%5Cs*%3C%5Cs*%5Cw+%5Cs*%3E%5Cs*%27%20with%3A%20%27%27%29%20toString.%0D%0A%09%28encoding%20%23match%3A%20%28RegularExpression%20fromString%3A%20%27struct%20%5Cw+%27%29%29%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09structureName%20%3A%3D%20encoding%20asArrayOfSubStrings%20second.%0D%0A%09%09structureEncoding%20%3A%3D%20ffi%20structureFullTypeEncodingFromStructureName%3A%20structureName.%0D%0A%09%09structureEncoding%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09%09self%20error%3A%20%27Missing%20enconding%20for%20%27%2CanEncoding%20asLiteral%0D%0A%09%09%5D.%0D%0A%09%09%5EstructureEncoding%20replace%3A%20%27%22%5B%5E%22%5D+%22%27%20with%3A%20%27%27%0D%0A%09%5D.%0D%0A%09result%20%3A%3D%20self%20encodings%20at%3A%20encoding%20ifAbsent%3A%20%5B%5D.%0D%0A%09result%20notNil%20ifTrue%3A%20%5B%20%5Eresult%20%5D.%0D%0A%0D%0A%09match%20%3A%3D%20encoding%20%23match%3A%20%28RegularExpression%20fromString%3A%20%27%5E%28%5Cw+%29%5Cs*%28%5C*+%29%24%27%29.%0D%0A%09match%20notNil%20ifTrue%3A%20%5B%20%7C%20className%20starCount%20cls%20%7C%0D%0A%09%09className%20%3A%3D%20match%20second.%0D%0A%09%09starCount%20%3A%3D%20match%20third%20toString%20size.%0D%0A%09%09cls%20%3A%3D%20self%20classNamed%3A%20className.%0D%0A%09%09%28cls%20notNil%20and%3A%20%5B%20%28cls%20basicAt%3A%20%23class%29%20%3D%3D%20cls%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09starCount%20%3E%201%20ifTrue%3A%20%5B%20%5E%27%5E@%27%20%5D%20ifFalse%3A%20%5B%20%5E%24@%20%5D%0D%0A%09%09%5D.%0D%0A%09%09starCount%20%3D%201%20ifTrue%3A%20%5B%20%7C%20raw%20%7C%0D%0A%09%09%09raw%20%3A%3D%20self%20encodings%0D%0A%09%09%09%09at%3A%20%28encoding%20replace%3A%20%27%5C*%27%20with%3A%20%27%27%29%0D%0A%09%09%09%09ifAbsent%3A%20%5B%5D.%0D%0A%09%09%09raw%20notNil%20ifTrue%3A%20%5B%20%5E%24%5E%20%2Craw%20%5D%0D%0A%09%09%5D%0D%0A%09%5D.%0D%0A%0D%0A%09structureEncoding%20%3A%3D%20ffi%20structureFullTypeEncodingFromStructureName%3A%20encoding.%0D%0A%09structureEncoding%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09%5EstructureEncoding%20replace%3A%20%27%22%5B%5E%22%5D+%22%27%20with%3A%20%27%27%0D%0A%09%5D.%0D%0A%0D%0A%09%5Eself%20error%3A%20%27Invalid%20encoding%20%27%2C%20encoding%20asLiteral"));
smalltalk.bind(smalltalk.JSCocoa,"encoding:for:",0
,function (array,targetBlock){var $s8Ret$={name:"stReturn"};try{var self=this;var encoding=nil;((array.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Empty encoding array for "._comma(targetBlock.value()));})();throw($s8Ret$)})();})() : nil);
encoding=self.unaryEncoding_(array.first())._comma(unescape("@%3A"));
(2).to_do_(array.size(), (function(i){return encoding=encoding._comma(self.unaryEncoding_(array.at_(i)));}));
(function(){$s8Ret$.result=(function(){return encoding;})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"encoding",unescape("encoding%3A%20array%20for%3A%20targetBlock%0D%0A%09%22%20Return%20the%20encoding%20string%20for%20method%20with%20array%20spec.%20%22%0D%0A%0D%0A%09%7C%20encoding%20%7C%0D%0A%09array%20isEmpty%20ifTrue%3A%20%5B%20%5Eself%20error%3A%20%27Empty%20encoding%20array%20for%20%27%2CtargetBlock%20value%20%5D.%0D%0A%09encoding%20%3A%3D%20%28self%20unaryEncoding%3A%20array%20first%29%20%2C%27@%3A%27.%0D%0A%092%20to%3A%20array%20size%20do%3A%20%5B%3Ai%7C%0D%0A%09%09encoding%20%3A%3D%20encoding%20%2C%28self%20unaryEncoding%3A%20%28array%20at%3A%20i%29%29%0D%0A%09%5D.%0D%0A%09%5Eencoding"));
smalltalk.bind(smalltalk.JSCocoa,"class:bindings:",0
,function (definition,bindings){var $s8Ret$={name:"stReturn"};try{var self=this;var parts=nil;parts=definition.asArrayOfSubstringsSeparatedBy_(unescape("%3C")).collect_((function(each){return each.trimBlanks();}));
((parts.size()._eq((2))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.class_subclassOf_bindings_(parts.first(), parts.last(), bindings);})();throw($s8Ret$)})();})() : nil);
parts=definition.asArrayOfSubstringsSeparatedBy_(unescape("%3E")).collect_((function(each){return each.trimBlanks();}));
((parts.size()._eq((2))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.class_subclassOf_bindings_(parts.last(), parts.first(), bindings);})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.class_subclassOf_bindings_(definition, nil, bindings);})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"classes",unescape("class%3A%20definition%20bindings%3A%20bindings%0D%0A%09%22%20Private%20-%20Create%20an%20ObjC%20class%20from%20definition%20%28or%20nil%29.%0D%0A%09definition%20can%20be%20specified%20as%3A%0D%0A%09%09childClassName%20%20%3C%20parentClassName%0D%0A%09%09parentClassName%20%3E%20childClassName%0D%0A%09%09existingClassName%0D%0A%09%22%0D%0A%0D%0A%09%7C%20parts%20%7C%0D%0A%09parts%20%3A%3D%20%28definition%20asArrayOfSubstringsSeparatedBy%3A%20%24%3C%29%0D%0A%09%09collect%3A%20%5B%3Aeach%7C%20each%20trimBlanks%20%5D.%0D%0A%09parts%20size%20%3D%202%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20class%3A%20parts%20first%20subclassOf%3A%20parts%20last%20bindings%3A%20bindings%0D%0A%09%5D.%0D%0A%09parts%20%3A%3D%20%28definition%20asArrayOfSubstringsSeparatedBy%3A%20%24%3E%29%0D%0A%09%09collect%3A%20%5B%3Aeach%7C%20each%20trimBlanks%20%5D.%0D%0A%09parts%20size%20%3D%202%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20class%3A%20parts%20last%20subclassOf%3A%20parts%20first%20bindings%3A%20bindings%0D%0A%09%5D.%0D%0A%09%5Eself%20class%3A%20definition%20subclassOf%3A%20nil%20bindings%3A%20bindings"));
smalltalk.bind(smalltalk.JSCocoa,"currentClassNamed:",0
,function (aClassName){var self=this;var cls=nil;cls=self.classNamed_(aClassName);
(((nil.isNil_(cls))).mustBeBoolean()==true ? (function(){return self.error_("Missing class "._comma(aClassName.asLiteral()));})() : nil);
return cls;;return self;}
,"accessing",unescape("currentClassNamed%3A%20aClassName%0D%0A%09%22%20Private%20-%20Ensure%20class%20named%20aClassName%20exists.%0D%0A%09Return%20the%20existing%20class%20or%20generate%20an%20error.%0D%0A%09%22%0D%0A%0D%0A%09%7C%20cls%20%7C%0D%0A%09cls%20%3A%3D%20self%20classNamed%3A%20aClassName.%0D%0A%09cls%20isNil%20ifTrue%3A%20%5B%20self%20error%3A%20%27Missing%20class%20%27%2CaClassName%20asLiteral%20%5D.%0D%0A%09%5Ecls"));
smalltalk.bind(smalltalk.JSCocoa,"class:subclassOf:bindings:",0
,function (aClassName,parentClassName,bindings){var self=this;var parentClass=nil;var cls=nil;(((nil.isNil_(parentClassName)===false)).mustBeBoolean()==true ? (function(){parentClass=self.currentClassNamed_(parentClassName);self.createClass_parentClass_(aClassName, parentClassName);return cls=self.currentClassNamed_(aClassName);})() : (function(){cls=self.currentClassNamed_(aClassName);return parentClass=cls.superclass;})());
bindings.do_((function(assoc){var selector=nil;var value=nil;var isInstanceMethod=nil;var isOverload=nil;selector=assoc.key();value=assoc.value();return (((nil.isNil_(parentClass)).or_((function(){isInstanceMethod=smalltalk.Boolean._at(parentClass.instancesRespondToSelector(selector));isOverload=isInstanceMethod.or_((function(){return smalltalk.Boolean._at(parentClass.respondsToSelector(selector));}));return isOverload;}))).mustBeBoolean()==true ? (function(){(((nil.isNil_(value)).or_((function(){return self.typeOf_(value)._no_eq("function");}))).mustBeBoolean()==true ? (function(){return ((value.isArray().and_((function(){return value.notEmpty();}))).mustBeBoolean()==true ? (function(){return value=value.last();})() : nil);})() : nil);((self.typeOf_(value)._no_eq("function")).mustBeBoolean()==true ? (function(){return self.error_(aClassName._comma(unescape("%23"))._comma(selector)._comma(unescape("%20-%20binding%20must%20be%20a%20function.")));})() : nil);return ((isInstanceMethod).mustBeBoolean()==true ? (function(){return self.overloadInstanceMethod_class_jsFunction_(selector, cls, value);})() : (function(){return self.overloadClassMethod_class_jsFunction_(selector, cls, value);})());})() : (function(){return self.class_bind_with_(cls, selector, value);})());}));
cls=parentClass=nil;return self;}
,"classes",unescape("class%3A%20aClassName%20subclassOf%3A%20parentClassName%20bindings%3A%20bindings%0D%0A%09%22%20Create%20an%20ObjC%20class%20subclass%20of%20parentClassName.%20%22%0D%0A%0D%0A%09%7C%20parentClass%20cls%20%7C%0D%0A%09parentClassName%20notNil%20ifTrue%3A%20%5B%0D%0A%09%09parentClass%20%3A%3D%20self%20currentClassNamed%3A%20parentClassName.%0D%0A%09%09self%20createClass%3A%20aClassName%20parentClass%3A%20parentClassName.%0D%0A%09%09cls%20%3A%3D%20self%20currentClassNamed%3A%20aClassName.%0D%0A%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09cls%20%3A%3D%20self%20currentClassNamed%3A%20aClassName.%0D%0A%09%09parentClass%20%3A%3D%20cls%23superclass.%0D%0A%09%5D.%0D%0A%0D%0A%22self%20print%3A%20%27//%5BJSCocoa%5Dclass%3A%20%27%0D%0A%20%20%20%20%2CaClassName%20%2C%27%20subclassOf%3A%20%27%0D%0A%20%20%20%20%2C%28parentClass%20notNil%0D%0A%20%20%20%20%20%20%20%20ifTrue%3A%20%5Bself%20nameOfClass%3A%20parentClass%5D%0D%0A%20%20%20%20%20%20%20%20ifFalse%3A%20%5B%23nil%5D%29.%22%0D%0A%0D%0A%09bindings%20do%3A%20%5B%3Aassoc%7C%0D%0A%09%09%7C%20selector%20value%20isInstanceMethod%20isOverload%20%7C%0D%0A%09%09selector%20%3A%3D%20assoc%20key.%20value%20%3A%3D%20assoc%20value.%0D%0A%09%09%28parentClass%20isNil%20or%3A%20%5B%0D%0A%09%09%09isInstanceMethod%20%3A%3D%20Boolean%20@%20%28parentClass%20%23instancesRespondToSelector%3A%20selector%29.%0D%0A%09%09%09isOverload%20%3A%3D%20isInstanceMethod%20or%3A%20%5B%20Boolean%20@%20%28parentClass%20%23respondsToSelector%3A%20selector%29%20%5D.%0D%0A%09%09%09isOverload%0D%0A%09%09%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%28value%20isNil%20or%3A%20%5B%20%28self%20typeOf%3A%20value%29%20%7E%3D%20%23function%20%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%09%09%28value%20isArray%20and%3A%20%5Bvalue%20notEmpty%5D%29%0D%0A%09%09%09%09ifTrue%3A%20%5B%20value%20%3A%3D%20value%20last%20%5D%0D%0A%09%09%09%5D.%0D%0A%09%09%09%28self%20typeOf%3A%20value%29%20%7E%3D%20%23function%20ifTrue%3A%20%5B%0D%0A%09%09%09%09self%20error%3A%20aClassName%20%2C%27%23%27%20%2Cselector%20%0D%0A%09%09%09%09%09%2C%27%20-%20binding%20must%20be%20a%20function.%27%0D%0A%09%09%09%5D.%0D%0A%09%09%09isInstanceMethod%20ifTrue%3A%20%5B%0D%0A%09%09%09%09self%20overloadInstanceMethod%3A%20selector%20class%3A%20cls%20jsFunction%3A%20value%0D%0A%09%09%09%5D%20ifFalse%3A%20%5B%0D%0A%09%09%09%09self%20overloadClassMethod%3A%20selector%20class%3A%20cls%20jsFunction%3A%20value%0D%0A%09%09%09%5D%0D%0A%09%09%5D%20ifFalse%3A%20%5B%20self%20class%3A%20cls%20bind%3A%20selector%20with%3A%20value%20%5D%0D%0A%09%5D.%0D%0A%0D%0A%09cls%20%3A%3D%20parentClass%20%3A%3D%20nil."));
smalltalk.bind(smalltalk.JSCocoa,"class:subclassOf:",0
,function (aClassName,parentClassName){var self=this;return self.class_subclassOf_bindings_(aClassName, parentClassName, []);;return self;}
,"classes",unescape("class%3A%20aClassName%20subclassOf%3A%20parentClassName%0D%0A%09%22%20Create%20an%20ObjC%20class%20subclass%20of%20parentClassName.%20%22%0D%0A%0D%0A%09%5Eself%20class%3A%20aClassName%20subclassOf%3A%20parentClassName%20bindings%3A%20%23%28%29"));
smalltalk.bind(smalltalk.JSCocoa,"class:bind:with:",0
,function (aClass,selector,value){var $s8Ret$={name:"stReturn"};try{var self=this;(("IBOutlet"._eq(value)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.class_outlet_setter_(aClass, selector, nil);})();throw($s8Ret$)})();})() : nil);
(("Key"._eq(value)).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.class_key_getter_setter_(aClass, selector, nil, nil);})();throw($s8Ret$)})();})() : nil);
((self.typeOf_(value.last())._eq("function")).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.error_(unescape("Invalid%20binding%20value%3D")._comma(value.toString()));})();throw($s8Ret$)})();})());
((value.size()._eq((2)).and_((function(){return value.first()._eq("IBAction");}))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.class_add_action_(aClass, selector, value.last());})();throw($s8Ret$)})();})() : nil);
((value.isEmpty()).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.error_("Missing encoding for "._comma(selector));})();throw($s8Ret$)})();})() : nil);
(function(){$s8Ret$.result=(function(){return self.class_add_instance_method_(aClass, selector, value.removeLast(), self.encoding_for_(value, (function(){return self.nameOfClass_(aClass)._comma(unescape("%3E%3E%23"))._comma(selector);})));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"binding",unescape("class%3A%20aClass%20bind%3A%20selector%20with%3A%20value%0D%0A%09%22%20Private%20-%20Bind%20encoded%20method%20to%20aClass.%20%22%0D%0A%0D%0A%09%23IBOutlet%20%3D%20value%20ifTrue%3A%20%5B%20%5Eself%20class%3A%20aClass%20outlet%3A%20selector%20setter%3A%20nil%20%5D.%0D%0A%09%23Key%20%3D%20value%20ifTrue%3A%20%5B%20%5Eself%20class%3A%20aClass%20key%3A%20selector%20getter%3A%20nil%20setter%3A%20nil%20%5D.%0D%0A%09%28self%20typeOf%3A%20value%20last%29%20%3D%20%23function%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20%27Invalid%20binding%20value%3D%27%20%2Cvalue%20toString%0D%0A%09%5D.%0D%0A%09%28value%20size%20%3D%202%20and%3A%20%5B%20value%20first%20%3D%20%23IBAction%5D%29%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20class%3A%20aClass%20add%3A%20selector%20action%3A%20value%20last%0D%0A%09%5D.%0D%0A%09value%20isEmpty%20ifTrue%3A%20%5B%0D%0A%09%09%5Eself%20error%3A%20%27Missing%20encoding%20for%20%27%2Cselector%0D%0A%09%5D.%0D%0A%09%5Eself%0D%0A%09%09class%3A%20aClass%20add%3A%20selector%0D%0A%09%09instance%3A%20value%20removeLast%0D%0A%09%09method%3A%20%28self%20encoding%3A%20value%20for%3A%20%5B%28self%20nameOfClass%3A%20aClass%29%2C%27%3E%3E%23%27%2Cselector%5D%29"));
smalltalk.bind(smalltalk.JSCocoa,"capture:",0
,function (anObject){var self=this;return self.$klass.capture_(anObject);;return self;}
,"cache",unescape("capture%3A%20anObject%0D%0A%09%22%20Private%20-%20Cache%20the%20object%20in%20receiver%27s%20cache.%20%22%0D%0A%0D%0A%09%5Eself%20class%20capture%3A%20anObject"));
smalltalk.bind(smalltalk.JSCocoa,"class:outlet:setter:",0
,function (aClass,name,setter){var self=this;var selector=nil;var aFunction=nil;var _name=nil;_name="_"._comma(name);
selector="set"._comma(name.first().asUpperCase())._comma(name.copyFrom_to_((2), name.size()))._comma(":");
aFunction=((self.typeOf_(setter)._eq("function")).mustBeBoolean()==true ? (function(){return setter;})() : (function(){return self.capture_((function(outlet){return this.setJSValue_forJSName_(outlet, _name);}));})());
self.addInstanceMethod_class_jsFunction_encoding_(selector, aClass, aFunction, self.encoding_for_(["void", "id"], (function(){return self.nameOfClass_(aClass)._comma(unescape("%20outlet%20%23"))._comma(name);})));
aFunction=self.capture_((function(){return this.JSValueForJSName(_name);}));
self.addInstanceMethod_class_jsFunction_encoding_(name, aClass, aFunction, self.encoding_for_(["id"], (function(){return self.nameOfClass_(aClass)._comma(unescape("%20outlet%3A%20%23"))._comma(name);})));return self;}
,"binding",unescape("class%3A%20aClass%20outlet%3A%20name%20setter%3A%20setter%0D%0A%09%22%20Private%20-%20Set%20the%20outlet%20binding%20in%20aClass.%0D%0A%09Outlets%20are%20set%20as%20properties%20starting%20with%20an%20underscore.%0D%0A%09%22%0D%0A%09%7C%20selector%20aFunction%20_name%20%7C%0D%0A%09_name%20%3A%3D%20%24_%20%2Cname.%0D%0A%09selector%20%3A%3D%20%27set%27%20%2Cname%20first%20asUpperCase%20%2C%28name%20copyFrom%3A%202%20to%3A%20name%20size%29%20%2C%24%3A.%0D%0A%09aFunction%20%3A%3D%20%28self%20typeOf%3A%20setter%29%20%3D%20%23function%20ifTrue%3A%20%5B%20setter%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20capture%3A%20%5B%3Aoutlet%7C%20%23%7Bthis%7D%20setJSValue%3A%20outlet%20forJSName%3A%20_name%20%5D%20%5D.%0D%0A%09self%20addInstanceMethod%3A%20selector%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20%28self%20encoding%3A%20%23%28%20void%20id%20%29%20for%3A%20%5B%28self%20nameOfClass%3A%20aClass%29%2C%27%20outlet%20%23%27%2Cname%5D%29.%0D%0A%09aFunction%20%3A%3D%20self%20capture%3A%20%5B%20%23%7Bthis%7D%20%23JSValueForJSName%3A%20_name%20%5D.%0D%0A%09self%20addInstanceMethod%3A%20name%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20%28self%20encoding%3A%20%23%28%20id%20%29%20for%3A%20%5B%28self%20nameOfClass%3A%20aClass%29%2C%27%20outlet%3A%20%23%27%2Cname%5D%29."));
smalltalk.bind(smalltalk.JSCocoa,"class:add:action:",0
,function (aClass,selector,aFunction){var $s8Ret$={name:"stReturn"};try{var self=this;((selector.last()._eq(":")).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return self.class_add_action_(aClass, selector._comma(":"), aFunction);})();throw($s8Ret$)})();})());
self.addInstanceMethod_class_jsFunction_encoding_(selector, aClass, aFunction, self.encoding_for_(["void", "id"], (function(){return self.nameOfClass_(aClass)._comma(unescape("%3E%3E%23"))._comma(selector)._comma(":");})));return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"binding",unescape("class%3A%20aClass%20add%3A%20selector%20action%3A%20aFunction%0D%0A%0D%0A%09%28selector%20last%20%3D%20%24%3A%29%20ifFalse%3A%20%5B%0D%0A%09%09%5Eself%20class%3A%20aClass%20add%3A%20selector%20%2C%24%3A%20action%3A%20aFunction%0D%0A%09%5D.%0D%0A%09self%20addInstanceMethod%3A%20selector%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20%28self%20encoding%3A%20%23%28%20void%20id%20%29%20for%3A%20%5B%28self%20nameOfClass%3A%20aClass%29%2C%27%3E%3E%23%27%2Cselector%2C%27%3A%27%5D%29"));
smalltalk.bind(smalltalk.JSCocoa,"class:key:getter:setter:",0
,function (aClass,name,getter,setter){var self=this;var _name=nil;var selector=nil;var $$function=nil;_name="_"._comma(name);
$$function=((self.typeOf_(getter)._eq("function")).mustBeBoolean()==true ? (function(){return getter;})() : (function(){return self.capture_((function(){return this.JSValueForJSName(_name);}));})());
self.addInstanceMethod_class_jsFunction_encoding_(name, aClass, $$function, self.encoding_for_(["id"], (function(){return self.nameOfClass_(aClass)._comma(unescape("%20key%3A%20%23"))._comma(name);})));
selector="set"._comma(name.first().asUpperCase())._comma(name.copyFrom_to_((2), name.size()))._comma(":");
$$function=((self.typeOf_(setter)._eq("function")).mustBeBoolean()==true ? (function(){return setter;})() : (function(){return self.capture_((function(outlet){return this.setJSValue_forJSName_(outlet, _name);}));})());
self.addInstanceMethod_class_jsFunction_encoding_(name, aClass, $$function, self.encoding_for_(["void", "id"], (function(){return self.nameOfClass_(aClass)._comma(unescape("%20key%3A%20%23"))._comma(name);})));return self;}
,"binding",unescape("class%3A%20aClass%20key%3A%20name%20getter%3A%20getter%20setter%3A%20setter%0D%0A%0D%0A%09%7C%20_name%20selector%20function%20%7C%0D%0A%09_name%20%3A%3D%20%24_%20%2Cname.%0D%0A%09function%20%3A%3D%20%28self%20typeOf%3A%20getter%29%20%3D%20%23function%20ifTrue%3A%20%5B%20getter%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20capture%3A%20%5B%20%23%7Bthis%7D%20%23JSValueForJSName%3A%20_name%20%5D%20%5D.%0D%0A%09self%09addInstanceMethod%3A%20name%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20function%0D%0A%09%09encoding%3A%20%28self%20encoding%3A%20%23%28%20id%20%29%20for%3A%20%5B%28self%20nameOfClass%3A%20aClass%29%2C%27%20key%3A%20%23%27%2Cname%5D%29.%0D%0A%09selector%20%3A%3D%20%27set%27%20%2C%20name%20first%20asUpperCase%20%2C%28name%20copyFrom%3A%202%20to%3A%20name%20size%29%2C%20%24%3A.%0D%0A%09function%20%3A%3D%20%28self%20typeOf%3A%20setter%29%20%3D%20%23function%20ifTrue%3A%20%5B%20setter%20%5D%0D%0A%09%09ifFalse%3A%20%5B%20self%20capture%3A%20%5B%3Aoutlet%7C%20%23%7Bthis%7D%20setJSValue%3A%20outlet%20forJSName%3A%20_name%20%5D%20%5D.%0D%0A%09self%09addInstanceMethod%3A%20name%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20function%0D%0A%09%09encoding%3A%20%28self%20encoding%3A%20%23%28%20void%20id%20%29%20for%3A%20%5B%28self%20nameOfClass%3A%20aClass%29%2C%27%20key%3A%20%23%27%2Cname%5D%29."));
smalltalk.bind(smalltalk.JSCocoa,"class:add:instance:method:",0
,function (aClass,selector,aFunction,encoded){var self=this;self.addInstanceMethod_class_jsFunction_encoding_(selector, aClass, aFunction, encoded);return self;}
,"binding",unescape("class%3A%20aClass%20add%3A%20selector%20instance%3A%20aFunction%20method%3A%20encoded%0D%0A%0D%0A%09self%09addInstanceMethod%3A%20selector%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20encoded"));
smalltalk.bind(smalltalk.JSCocoa,"class:add:class:method:",0
,function (aClass,selector,aFunction,encoded){var self=this;self.addClassMethod_class_jsFunction_encoding_(selector, aClass, aFunction, encoded);return self;}
,"binding",unescape("class%3A%20aClass%20add%3A%20selector%20class%3A%20aFunction%20method%3A%20encoded%0D%0A%0D%0A%09self%09addClassMethod%3A%20selector%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20encoded"));
smalltalk.bind(smalltalk.JSCocoa,"class:swizzle:instance:method:",0
,function (aClass,selector,aFunction,encoded){var self=this;self.swizzleInstanceMethod_class_jsFunction_encoding_(selector, aClass, aFunction, encoded);return self;}
,"binding",unescape("class%3A%20aClass%20swizzle%3A%20selector%20instance%3A%20aFunction%20method%3A%20encoded%0D%0A%0D%0A%09self%09swizzleInstanceMethod%3A%20selector%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20encoded"));
smalltalk.bind(smalltalk.JSCocoa,"class:swizzle:class:method:",0
,function (aClass,selector,aFunction,encoded){var self=this;self.swizzleClassMethod_class_jsFunction_encoding_(selector, aClass, aFunction, encoded);return self;}
,"binding",unescape("class%3A%20aClass%20swizzle%3A%20selector%20class%3A%20aFunction%20method%3A%20encoded%0D%0A%0D%0A%09self%09swizzleClassMethod%3A%20selector%0D%0A%09%09class%3A%20aClass%20jsFunction%3A%20aFunction%0D%0A%09%09encoding%3A%20encoded"));
smalltalk.bind(smalltalk.JSCocoa,"output:toFile:",0
,function (aString,localPathName){var self=this;return smalltalk.JSC.$$new().output_toFile_(aString, localPathName);;return self;}
,"io",unescape("output%3A%20aString%20toFile%3A%20localPathName%0D%0A%09%5EJSC%20new%20output%3A%20aString%20toFile%3A%20localPathName"));
smalltalk.bind(smalltalk.JSCocoa,"append:toFile:",0
,function (aString,localPathName){var self=this;return smalltalk.JSC.$$new().append_toFile_(aString, localPathName);;return self;}
,"io",unescape("append%3A%20aString%20toFile%3A%20localPathName%0D%0A%09%5EJSC%20new%20append%3A%20aString%20toFile%3A%20localPathName"));
smalltalk.bind(smalltalk.JSCocoa,"loadFramework:",0
,function (aName){var self=this;return smalltalk.JSC.$$new().loadFrameworkWithName_(aName);;return self;}
,"loading",unescape("loadFramework%3A%20aName%0D%0A%09%5EJSC%20new%20loadFrameworkWithName%3A%20aName"));
smalltalk.bind(smalltalk.JSCocoa,"initalizeCallbacks",0
,function (){var self=this;(function(o,level){return self.describeStruct_level_(o, level);}).installAs_("describeStruct");
(function(){return self.outArgument_(arguments);}).installAs_("outArgument");
(function(types){return self.memoryBuffer_(types);}).installAs_("memoryBuffer");
(function(){return self.collectCallStack_(arguments);}).installAs_("dumpCallStack");return self;}
,"initialize",unescape("initalizeCallbacks%0D%0A%09%22%20Private%20-%20Initialize%20the%20callback%20functions.%20%22%0D%0A%0D%0A%09%5B%3Ao%20%3Alevel%7C%20self%20describeStruct%3A%20o%20level%3A%20level%20%5D%20installAs%3A%20%23describeStruct.%0D%0A%09%5B%20self%20outArgument%3A%20%23%7Barguments%7D%20%5D%20installAs%3A%20%23outArgument.%0D%0A%09%5B%3Atypes%7C%20self%20memoryBuffer%3A%20types%20%5D%20installAs%3A%20%23memoryBuffer.%0D%0A%09%5B%20self%20collectCallStack%3A%20%23%7Barguments%7D%20%5D%20installAs%3A%20%23dumpCallStack."));
smalltalk.bind(smalltalk.JSCocoa,"describeStruct:level:",0
,function (o,level){var $s8Ret$={name:"stReturn"};try{var self=this;var js=nil;(((nil.isNil_(level))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return self.describeStruct_level_(o, (1));})();throw($s8Ret$)})();})() : nil);
((level._gt((100))).mustBeBoolean()==true ? (function(){return (function(){$s8Ret$.result=(function(){return "";})();throw($s8Ret$)})();})() : nil);
((["object", "function"].includes_typeOf_(self, o)).mustBeBoolean()==true ? nil : (function(){return (function(){$s8Ret$.result=(function(){return o.toString();})();throw($s8Ret$)})();})());
js=smalltalk.JS._at(o);
(function(){$s8Ret$.result=(function(){return js.ownPropertyNames().inject_into_(unescape("%7B"), (function(key,total){return total._comma(((total.size()._eq((1))).mustBeBoolean()==true ? (function(){return "";})() : (function(){return unescape("%2C");})()).key())._comma(":")._comma(self.describeStruct_level_(((function(){var $1$=o[key];if(nil.isNil_($1$))return nil;return $1$;})()), level._plus((1))));}))._comma(unescape("%7D"));})();throw($s8Ret$)})();return self;} catch($$ex) {if($$ex === $s8Ret$){return $$ex.result;} throw($$ex);}}
,"callbacks",unescape("describeStruct%3A%20o%20level%3A%20level%0D%0A%09%7C%20js%20%7C%0D%0A%09level%20isNil%20ifTrue%3A%20%5B%20%5Eself%20describeStruct%3A%20o%20level%3A%201%20%5D.%0D%0A%09level%20%3E%20100%20ifTrue%3A%20%5B%20%5E%27%27%20%5D.%0D%0A%09%28%23%28%20object%20function%20%29%20includes%3A%20self%20typeOf%3A%20o%29%20ifFalse%3A%20%5B%20%5Eo%20toString%20%5D.%0D%0A%09js%20%3A%3D%20JS%20@%20o.%0D%0A%09%5E%28js%20ownPropertyNames%20inject%3A%20%24%7B%20into%3A%20%5B%3Akey%20%3Atotal%7C%0D%0A%09%09total%09%2C%28total%20size%20%3D%201%20ifTrue%3A%20%5B%27%27%5D%20ifFalse%3A%20%5B%24%2C%5D%29%0D%0A%09%09%09key%20%2C%24%3A%0D%0A%09%09%09%2C%28self%20describeStruct%3A%20%28o%20basicAt%3A%20key%29%20level%3A%20level%20+%201%29%0D%0A%09%5D%29%2C%24%7D"));
smalltalk.bind(smalltalk.JSCocoa,"outArgument:",0
,function (args){var self=this;var cls=nil;var result=nil;cls=self.$klass.outArgument2();
(((nil.isNil_(cls))).mustBeBoolean()==true ? (function(){cls=self.class_subclassOf_("JSCocoaOutArgument2", "JSCocoaOutArgument");return self.$klass.outArgument2_(cls);})() : nil);
result=((function(){var $1$=cls["instance"];if(nil.isNil_($1$))return nil;return $1$;})());
(result["isOutArgument"]=(true));
((args.length._eq((2))).mustBeBoolean()==true ? (function(){return result.mateWithMemoryBuffer_atIndex_(((function(){var $1$=args[(0)];if(nil.isNil_($1$))return nil;return $1$;})()), ((function(){var $1$=args[(1)];if(nil.isNil_($1$))return nil;return $1$;})()));})() : nil);
return result;;return self;}
,"callbacks",unescape("outArgument%3A%20args%0D%0A%09%7C%20cls%20result%20%7C%0D%0A%09cls%20%3A%3D%20self%20class%20outArgument2.%0D%0A%09cls%20isNil%20ifTrue%3A%20%5B%0D%0A%09%09cls%20%3A%3D%20self%20class%3A%20%23JSCocoaOutArgument2%20subclassOf%3A%20%23JSCocoaOutArgument.%0D%0A%09%09self%20class%20outArgument2%3A%20cls.%0D%0A%09%5D.%0D%0A%09result%20%3A%3D%20cls%20basicAt%3A%20%23instance.%0D%0A%09result%20basicAt%3A%20%23isOutArgument%20put%3A%20true.%0D%0A%09args%23length%20%3D%202%20ifTrue%3A%20%5B%0D%0A%09%09result%0D%0A%09%09%09mateWithMemoryBuffer%3A%20%28args%20basicAt%3A%200%29%0D%0A%09%09%09atIndex%3A%20%28args%20basicAt%3A%201%29%0D%0A%09%5D.%0D%0A%09%5Eresult"));
smalltalk.bind(smalltalk.JSCocoa,"memoryBuffer:",0
,function (types){var self=this;var result=nil;result=self.classNamed_("JSCocoaMemoryBuffer").instanceWithTypes(types);
(result["isOutArgument"]=(true));
return result;;return self;}
,"callbacks",unescape("memoryBuffer%3A%20types%0D%0A%09%22%20Private%20-%20Return%20a%20memory%20buffer%20instance.%20%22%0D%0A%0D%0A%09%7C%20result%20%7C%0D%0A%09result%20%3A%3D%20%28self%20classNamed%3A%20%23JSCocoaMemoryBuffer%29%20%23instanceWithTypes%3A%20types.%0D%0A%20%20%20%20%20%20%20%20result%20basicAt%3A%20%23isOutArgument%20put%3A%20true.%0D%0A%20%20%20%20%20%20%20%20%5Eresult"));
smalltalk.bind(smalltalk.JSCocoa,"collectCallStack:",0
,function (args){var self=this;var maxDumpDepth=nil;var dumpDepth=nil;var caller=nil;var result=nil;maxDumpDepth=(100);
dumpDepth=(0);
caller=((function(){var $1$=args.callee["caller"];if(nil.isNil_($1$))return nil;return $1$;})());
result=[];
(function(){while((function(){return (nil.isNil_(caller)===false).and_((function(){return dumpDepth._lt_eq(maxDumpDepth);}));})()){(function(){result.add_(caller.toString());dumpDepth=dumpDepth._plus((1));return caller=caller.caller;})()};return nil})();
((result.notEmpty()).mustBeBoolean()==true ? (function(){return result.removeFirst();})() : nil);
return result.inject_into_("", (function(line,total){return line._comma(unescape("%0D%0A"))._comma(total);})).trimBlanks();;return self;}
,"callbacks",unescape("collectCallStack%3A%20args%0D%0A%09%22%20Private%20-%20Return%20the%20call%20stack.%20%22%0D%0A%0D%0A%09%7C%20maxDumpDepth%20dumpDepth%20caller%20result%20%7C%0D%0A%09maxDumpDepth%20%3A%3D%20100.%0D%0A%09dumpDepth%20%3A%3D%200.%0D%0A%09caller%20%3A%3D%20args%23callee%20basicAt%3A%20%23caller.%0D%0A%09result%20%3A%3D%20%23%28%29.%0D%0A%09%5B%20caller%20notNil%20and%3A%20%5B%20dumpDepth%20%3C%3D%20maxDumpDepth%20%5D%5D%20whileTrue%3A%20%5B%0D%0A%09%09result%20add%3A%20caller%20toString.%20%22ToDo%3A%20add%20caller%23arguments%20to%20each%20call.%22%0D%0A%09%09dumpDepth%20%3A%3D%20dumpDepth%20+%201.%0D%0A%09%09caller%20%3A%3D%20caller%23caller.%0D%0A%09%5D.%0D%0A%09result%20notEmpty%20ifTrue%3A%20%5B%20result%20removeFirst%20%5D.%0D%0A%09%5E%28result%20inject%3A%20%27%27%20into%3A%20%5B%3Aline%20%3Atotal%7C%20line%2C%27%0D%0A%27%2C%20total%20%5D%29trimBlanks"));
smalltalk.bind(smalltalk.JSCocoaFFIArgument,"jsName",0
,function (){var self=this;return "JSCocoaFFIArgument";;return self;}
,"private",unescape("jsName%0D%0A%09%22%20Private%20-%20Return%20the%20global%20name%20of%20handle.%20%22%0D%0A%0D%0A%09%5E%23JSCocoaFFIArgument"));
smalltalk.bind(smalltalk.JSCocoaFFIArgument,"typeEncodingForType:",0
,function (type){var self=this;return self.toString_(self.handle().typeEncodingForType_(type));;return self;}
,"converting",unescape("typeEncodingForType%3A%20type%0D%0A%20%20%20%20%22%20Return%20aString%20used%20to%20encode%20type.%20%22%0D%0A%0D%0A%20%20%20%20%5Eself%20toString%3A%20%28self%20handle%20typeEncodingForType%3A%20type%29"));
smalltalk.bind(smalltalk.JSCocoaFFIArgument,"structureFullTypeEncodingFromStructureName:",0
,function (encoding){var self=this;return self.toString_(self.handle().structureFullTypeEncodingFromStructureName(encoding));;return self;}
,"converting",unescape("structureFullTypeEncodingFromStructureName%3A%20encoding%0D%0A%20%20%20%20%22%20Return%20aString%20used%20for%20type%20encoding%20structure.%20%22%0D%0A%0D%0A%20%20%20%20%5Eself%20toString%3A%20%28self%20handle%20%23structureFullTypeEncodingFromStructureName%3A%20encoding%29"));

smalltalk.$imageFileName=unescape("../default.snapshot.js");
smalltalk.useManager=true;
smalltalk.$state="running";
smalltalk.OverwriteMethods=true;
smalltalk.DumpOverwritenMethods=false;
smalltalk.launchImage();